@@ -88,99 +88,13 @@ if ($authobj->authname == 'internal') {
 $elements['accountoptionsdesc'] = array(
     'value' => '<tr><td colspan="2"><h3>' . get_string('accountoptionsdesc', 'account') . '</h3></td></tr>'
 );
-$elements['friendscontrol'] = array(
-    'type' => 'radio',
-    'defaultvalue' => $prefs->friendscontrol, 
-    'title'  => get_string('friendsdescr', 'account'),
-    'separator' => '<br>',
-    'options' => array(
-        'nobody' => get_string('friendsnobody', 'account'),
-        'auth'   => get_string('friendsauth', 'account'),
-        'auto'   => get_string('friendsauto', 'account')
-    ),
-    'help' => true
-);
-$elements['wysiwyg'] = array(
-    'type' => 'checkbox',
-    'defaultvalue' => (get_config('wysiwyg')) ? get_config('wysiwyg') == 'enable' : $prefs->wysiwyg,
-    'title' => get_string('wysiwygdescr', 'account'),
-    'help' => true,
-    'disabled' => get_config('wysiwyg'),
-);
-$elements['maildisabled'] = array(
-    'type' => 'checkbox',
-    'defaultvalue' => get_account_preference($USER->get('id'), 'maildisabled'),
-    'title' => get_string('email'),
-    'help' => true,
-);
-$elements['messages'] = array(
-    'type' => 'radio',
-    'defaultvalue' => $prefs->messages,
-    'title' => get_string('messagesdescr', 'account'),
-    'separator' => '<br>',
-    'options' => array(
-        'nobody' => get_string('messagesnobody', 'account'),
-        'friends' => get_string('messagesfriends', 'account'),
-        'allow' => get_string('messagesallow', 'account'),
-    ),
-    'help' => true,
-);
-$languages = get_languages();
-$elements['lang'] = array(
-    'type' => 'select',
-    'defaultvalue' => $prefs->lang,
-    'title' => get_string('language', 'account'),
-    'options' => array_merge(array('default' => get_string('sitedefault', 'admin') . ' (' . $languages[get_config('lang')] . ')'), $languages),
-    'help' => true,
-    'ignore' => count($languages) < 2,
-);
-$elements['addremovecolumns'] = array(
-    'type' => 'checkbox',
-    'defaultvalue' => $prefs->addremovecolumns,
-    'title' => get_string('showviewcolumns', 'account'),
-    'help' => 'true'
-);
-// TODO: add a way for plugins (like blog!) to have account preferences
-$elements['multipleblogs'] = array(
-    'type' => 'checkbox',
-    'title'=> get_string('enablemultipleblogs' ,'account'),
-    'description' => get_string('enablemultipleblogsdescription', 'account'),
-    'defaultvalue' => $prefs->multipleblogs,
-);
-if (get_config('showtagssideblock')) {
-    $elements['tagssideblockmaxtags'] = array(
-        'type'         => 'text',
-        'size'         => 4,
-        'title'        => get_string('tagssideblockmaxtags', 'account'),
-        'description'  => get_string('tagssideblockmaxtagsdescription', 'account'),
-        'defaultvalue' => isset($prefs->tagssideblockmaxtags) ? $prefs->tagssideblockmaxtags : get_config('tagssideblockmaxtags'),
-        'rules'        => array('integer' => true, 'minvalue' => 0, 'maxvalue' => 1000),
-    );
-}
-if (get_config('userscanhiderealnames')) {
-    $elements['hiderealname'] = array(
-        'type'         => 'checkbox',
-        'title'        => get_string('hiderealname', 'account'),
-        'description'  => get_string('hiderealnamedescription', 'account'),
-        'defaultvalue' => $prefs->hiderealname,
-    );
-}
-if (get_config('homepageinfo')) {
-    $elements['showhomeinfo'] = array(
-        'type' => 'checkbox',
-        'defaultvalue' => $prefs->showhomeinfo,
-        'title' => get_string('showhomeinfo', 'account'),
-        'help' => 'true'
-    );
-}
-if (get_config('allowmobileuploads')) {
-    $elements['mobileuploadtoken'] = array(
-        'type'         => 'text',
-        'title'        => get_string('mobileuploadtoken', 'account'),
-        'description'  => get_string('mobileuploadtokendescription', 'account'),
-        'defaultvalue' => isset($prefs->mobileuploadtoken) ? $prefs->mobileuploadtoken : get_config('mobileuploadtoken')
-    );
-}
+
+// Add general account options
+$elements = array_merge($elements, general_account_prefs_form_elements($prefs));
+
+// If the user doesn't have exactly one blog, don't show the multipleblogs option.
+$elements['multipleblogs']['ignore'] = count_records('artefact', 'artefacttype', 'blog', 'owner', $USER->get('id')) != 1;
+
 $elements['submit'] = array(
     'type' => 'submit',
     'value' => get_string('save')
@@ -232,13 +146,6 @@ function accountprefs_validate(Pieform $form, $values) {
             $form->set_error('username', get_string('usernamealreadytaken', 'auth.internal'));
         }
     }
-
-    // Don't let users turn multiple blogs off unless they only have 1 blog
-    if ($USER->get_account_preference('multipleblogs')
-        && empty($values['multipleblogs'])
-        && count_records('artefact', 'artefacttype', 'blog', 'owner', $USER->get('id')) != 1) {
-        $form->set_error('multipleblogs', get_string('disablemultipleblogserror', 'account'));
-    }
 }
 
 function accountprefs_submit(Pieform $form, $values) {
@@ -270,9 +177,10 @@ function accountprefs_submit(Pieform $form, $values) {
     // Remember the user's language pref, so we can reload the page if they change it
     $oldlang = $USER->get_account_preference('lang');
 
-    foreach (array_keys($expectedprefs) as $pref) {
-        if (isset($values[$pref])) {
-            $USER->set_account_preference($pref, $values[$pref]);
+    // Set user account preferences
+    foreach ($expectedprefs as $eprefkey => $epref) {
+        if (isset($values[$eprefkey]) && $values[$eprefkey] != get_account_preference($USER->get('id'), $eprefkey)) {
+            $USER->set_account_preference($eprefkey, $values[$eprefkey]);
         }
     }
 
@@ -287,6 +195,9 @@ function accountprefs_submit(Pieform $form, $values) {
     db_commit();
 
     if (isset($values['lang']) && $values['lang'] != $oldlang) {
+        // The session language pref is used when the user has no user pref,
+        // and when logged out.
+        $SESSION->set('lang', $values['lang']);
         // Use PIEFORM_CANCEL here to force a page reload and show the new language.
         $returndata['location'] = get_config('wwwroot') . 'account/index.php';
         $SESSION->add_ok_msg(get_string_from_language($values['lang'], 'prefssaved', 'account'));
