@@ -33,6 +33,7 @@ define('SECTION_PLUGINNAME', 'admin');
 define('SECTION_PAGE', 'index');
 
 require(dirname(dirname(__FILE__)).'/init.php');
+require(get_config('libroot') . 'registration.php');
 if (get_config('installed')) {
     define('TITLE', get_string('administration', 'admin'));
 }
@@ -54,7 +55,7 @@ if (isset($upgrades['core']) && !empty($upgrades['core']->install)) {
 }
 
 if (!get_config('registration_lastsent')) {
-    $register = register_site();
+    $register = true;
 }
 
 $closed = get_config('siteclosedbyadmin');
@@ -73,11 +74,18 @@ $closeform = pieform(array(
     ),
 ));
 
+if (empty($upgrades)) {
+    $sitedata = site_statistics();
+}
+
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(get_string('administration', 'admin')));
+$smarty->assign('PAGEHEADING', get_string('administration', 'admin'));
 
 // normal admin page starts here
 $smarty->assign('upgrades', $upgrades);
+if (isset($sitedata)) {
+    $smarty->assign('sitedata', $sitedata);
+}
 
 if (isset($register)) {
     $smarty->assign('register', $register);
@@ -86,17 +94,19 @@ if (isset($register)) {
 $smarty->assign('closed', $closed);
 $smarty->assign('closeform', $closeform);
 
+$smarty->assign('warnings', site_warnings());
+
 $smarty->display('admin/index.tpl');
 
 function close_site_submit(Pieform $form, $values) {
     global $closed;
     if (!$closed && $values['close']) {
         set_config('siteclosedbyadmin', 1);
+        require_once(get_config('docroot') . 'auth/session.php');
+        remove_all_sessions();
     }
     else if ($closed && !$values['close']) {
         set_config('siteclosedbyadmin', 0);
     }
     redirect(get_config('wwwroot') . 'admin/index.php');
 }
-
-?>
