@@ -40,6 +40,8 @@ define('TITLE', get_string('siteoptions', 'admin'));
 
 $langoptions = get_languages();
 $themeoptions = get_all_themes();
+unset($themeoptions['custom']); // Only available for institution configurable themes
+
 $yesno = array(true  => get_string('yes'),
                false => get_string('no'));
 
@@ -47,8 +49,15 @@ $searchpluginoptions = get_search_plugins();
 
 $countries = getoptions_country();
 
-$spamtraps = available_spam_traps();
+$notificationmethods = array();
+foreach (array_keys(plugins_installed('notification')) as $n) {
+    $notificationmethods[$n] = get_string('name', 'notification.' . $n);
+}
+if (!$notificationdefault = get_config('defaultnotificationmethod')) {
+    $notificationdefault = isset($notificationmethods['email']) ? 'email' : 'internal';
+}
 
+$spamtraps = available_spam_traps();
 $siteoptionform = array(
     'name'       => 'siteoptions',
     'jsform'     => true,
@@ -100,6 +109,13 @@ $siteoptionform = array(
                     'help'         => true,
                     'disabled'     => in_array('theme', $OVERRIDDEN),
                 ),
+                'dropdownmenu' => array(
+                    'type'         => 'checkbox',
+                    'title'        => get_string('dropdownmenu', 'admin'),
+                    'description'  => get_string('dropdownmenudescription', 'admin'),
+                    'defaultvalue' => get_config('dropdownmenu'),
+                    'disabled'     => in_array('dropdownmenu', $OVERRIDDEN),
+                ),
                 'homepageinfo' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('homepageinfo', 'admin'),
@@ -159,6 +175,21 @@ $siteoptionform = array(
                     'defaultvalue' => get_config('anonymouscomments'),
                     'disabled'     => in_array('anonymouscomments', $OVERRIDDEN),
                 ),
+                'loggedinprofileviewaccess' => array(
+                    'type'         => 'checkbox',
+                    'title'        => get_string('loggedinprofileviewaccess', 'admin'),
+                    'description'  => get_string('loggedinprofileviewaccessdescription', 'admin'),
+                    'defaultvalue' => get_config('loggedinprofileviewaccess'),
+                    'disabled'     => in_array('loggedinprofileviewaccess', $OVERRIDDEN),
+                    'help'         => true,
+                ),
+                'staffreports' => array(
+                    'type'         => 'checkbox',
+                    'title'        => get_string('staffuserreports', 'admin'),
+                    'description'  => get_string('staffuserreportsdescription', 'admin'),
+                    'defaultvalue' => get_config('staffreports'),
+                    'disabled'     => in_array('staffreports', $OVERRIDDEN),
+                ),
             ),
         ),
         'searchsettings' => array(
@@ -195,6 +226,7 @@ $siteoptionform = array(
                         'staff'  => get_string('adminsandstaffonly', 'admin'),
                         'all'    => get_string('Everyone', 'admin'),
                     ),
+                    'disabled'     => in_array('creategroups', $OVERRIDDEN),
                 ),
                 'createpublicgroups' => array(
                     'type'         => 'select',
@@ -206,12 +238,14 @@ $siteoptionform = array(
                         'all' => get_string('Everyone', 'admin'),
                     ),
                     'help'         => true,
+                    'disabled'     => in_array('createpublicgroups', $OVERRIDDEN),
                 ),
                 'allowgroupcategories' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('allowgroupcategories', 'admin'),
                     'description'  => get_string('allowgroupcategoriesdescription', 'admin'),
                     'defaultvalue' => get_config('allowgroupcategories'),
+                    'disabled'     => in_array('allowgroupcategories', $OVERRIDDEN),
                 ),
             ),
         ),
@@ -232,7 +266,7 @@ $siteoptionform = array(
                 'institutionexpirynotification' => array(
                     'type'         => 'expiry',
                     'title'        => get_string('institutionexpirynotification', 'admin'),
-                    'description'  => get_string('institutionexpirynotificationdescription', 'admin'),
+                    'description'  => get_string('institutionexpirynotificationdescriptioninfo', 'admin'),
                     'defaultvalue' => get_config('institutionexpirynotification'),
                     'help'         => true,
                     'disabled'     => in_array('institutionexpirynotification', $OVERRIDDEN),
@@ -358,6 +392,7 @@ $siteoptionform = array(
                    'title'         => get_string('proxyaddress', 'admin'),
                    'description'   => get_string('proxyaddressdescription', 'admin'),
                    'defaultvalue'  => get_config('proxyaddress'),
+                   'disabled'      => in_array('proxyaddress', $OVERRIDDEN),
                 ),
                 'proxyauthmodel' => array(
                     'type'          => 'select',
@@ -368,12 +403,14 @@ $siteoptionform = array(
                                         '' => get_string('none', 'admin'),
                                         'basic' => get_string('proxyauthmodelbasic', 'admin'),
                                     ),
+                    'disabled'      => in_array('proxyauthmodel', $OVERRIDDEN),
                 ),
                 'proxyauthcredentials' => array(
                     'type'          => 'text',
                     'title'         => get_string('proxyauthcredentials', 'admin'),
                     'description'   => get_string('proxyauthcredentialsdescription', 'admin'),
                     'defaultvalue'  => get_config('proxyauthcredentials'),
+                    'disabled'      => in_array('proxyauthcredentials', $OVERRIDDEN),
                 ),
             ),
         ),
@@ -433,6 +470,15 @@ $siteoptionform = array(
                     'disabled'      => in_array('noreplyaddress', $OVERRIDDEN),
                     'help'          => true,
                 ),
+                'defaultnotificationmethod' => array(
+                    'type'          => 'select',
+                    'title'         => get_string('defaultnotificationmethod', 'admin'),
+                    'description'   => get_string('defaultnotificationmethoddescription', 'admin'),
+                    'defaultvalue'  => $notificationdefault,
+                    'disabled'      => in_array('defaultnotificationmethod', $OVERRIDDEN),
+                    'options'       => $notificationmethods,
+                    'help'          => true,
+                ),
             ),
         ),
         'generalsettings' => array(
@@ -455,19 +501,27 @@ $siteoptionform = array(
                     'description'  => get_string('allowpublicprofilesdescription', 'admin'),
                     'defaultvalue' => get_config('allowpublicprofiles'),
                     'help'         => true,
-                    'disabled'     => in_array('allowpublicprofiles', $OVERRIDDEN),
+                    'disabled'     => in_array('allowpublicprofiles', $OVERRIDDEN) || get_config('allowpublicviews'),
+                ),
+                'generatesitemap' => array(
+                    'type'         => 'checkbox',
+                    'title'        => get_string('generatesitemap', 'admin'),
+                    'description'  => get_string('generatesitemapdescription', 'admin'),
+                    'defaultvalue' => get_config('generatesitemap'),
+                    'help'         => true,
+                    'disabled'     => in_array('generatesitemap', $OVERRIDDEN) || !get_config('allowpublicviews'),
                 ),
                 'showselfsearchsideblock' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('showselfsearchsideblock', 'admin'),
-                    'description'  => get_string('showselfsearchsideblockdescription', 'admin'),
+                    'description'  => get_string('showselfsearchsideblockdescription1', 'admin'),
                     'defaultvalue' => get_config('showselfsearchsideblock'),
                     'disabled'     => in_array('showselfsearchsideblock', $OVERRIDDEN),
                 ),
                 'showtagssideblock' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('showtagssideblock', 'admin'),
-                    'description'  => get_string('showtagssideblockdescription', 'admin'),
+                    'description'  => get_string('showtagssideblockdescription1', 'admin'),
                     'defaultvalue' => get_config('showtagssideblock'),
                     'disabled'     => in_array('showtagssideblock', $OVERRIDDEN),
                 ),
@@ -490,10 +544,19 @@ $siteoptionform = array(
                 'showonlineuserssideblock' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('showonlineuserssideblock', 'admin'),
-                    'description'  => get_string('showonlineuserssideblockdescription', 'admin'),
+                    'description'  => get_string('showonlineuserssideblockdescriptionmessage', 'admin'),
                     'defaultvalue' => get_config('showonlineuserssideblock'),
                     'disabled'     => in_array('showonlineuserssideblock', $OVERRIDDEN),
                 ),
+                'onlineuserssideblockmaxusers' => array(
+                    'type'         => 'text',
+                    'size'         => 4,
+                    'title'        => get_string('onlineuserssideblockmaxusers', 'admin'),
+                    'description'  => get_string('onlineuserssideblockmaxusersdescription', 'admin'),
+                    'defaultvalue' => get_config('onlineuserssideblockmaxusers'),
+                    'rules'        => array('integer' => true, 'minvalue' => 0, 'maxvalue' => 100),
+                    'disabled'     => in_array('onlineuserssideblockmaxusers', $OVERRIDDEN),
+                ),
                 'registerterms' => array(
                     'type'         => 'checkbox',
                     'title'        => get_string('registerterms', 'admin'),
@@ -519,6 +582,7 @@ $siteoptionform = array(
                                         'enable' => get_string('enable'),
                                     ),
                     'help'         => true,
+                    'disabled'     => in_array('wysiwyg', $OVERRIDDEN),
                 ),
             ),
         ),
@@ -541,17 +605,28 @@ function siteoptions_fail(Pieform $form, $field) {
 
 function siteoptions_submit(Pieform $form, $values) {
     $fields = array(
-        'sitename','lang','theme', 'pathtoclam',
+        'sitename','lang','theme', 'pathtoclam', 'dropdownmenu',
         'defaultaccountlifetime', 'defaultaccountinactiveexpire', 'defaultaccountinactivewarn',
-        'allowpublicviews', 'allowpublicprofiles',
+        'allowpublicviews', 'allowpublicprofiles', 'generatesitemap',
         'registration_sendweeklyupdates', 'institutionexpirynotification', 'institutionautosuspend',
         'showselfsearchsideblock', 'searchusernames', 'searchplugin', 'showtagssideblock',
         'tagssideblockmaxtags', 'country', 'viewmicroheaders', 'userscanchooseviewthemes',
-        'remoteavatars', 'userscanhiderealnames', 'antispam', 'spamhaus', 'surbl', 'anonymouscomments', 'disableexternalresources',
+        'remoteavatars', 'userscanhiderealnames', 'antispam', 'spamhaus', 'surbl', 'anonymouscomments', 'loggedinprofileviewaccess', 'disableexternalresources',
         'proxyaddress', 'proxyauthmodel', 'proxyauthcredentials', 'smtphosts', 'smtpport', 'smtpuser', 'smtppass', 'smtpsecure',
-        'noreplyaddress', 'homepageinfo', 'showonlineuserssideblock', 'registerterms', 'allowmobileuploads',
-        'creategroups', 'createpublicgroups', 'allowgroupcategories', 'wysiwyg',
+        'noreplyaddress', 'defaultnotificationmethod', 'homepageinfo', 'showonlineuserssideblock', 'onlineuserssideblockmaxusers',
+        'registerterms', 'allowmobileuploads', 'creategroups', 'createpublicgroups', 'allowgroupcategories', 'wysiwyg',
+        'staffreports',
     );
+
+    // if public views are disabled, sitemap generation must also be disabled.
+    if ($values['allowpublicviews'] == false) {
+        $values['generatesitemap'] = false;
+    }
+    else {
+        // Ensure allowpublicprofiles is set as well
+        $values['allowpublicprofiles'] = 1;
+    }
+
     $oldlanguage = get_config('lang');
     $oldtheme = get_config('theme');
     foreach ($fields as $field) {
