@@ -137,6 +137,22 @@ if (!$USER->get('admin')) {
     unset ($elements['authinstance']['defaultvalue']);
 }
 
+if (!($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride'))) {
+    $elements['quota'] = array(
+        'type'         => 'text',
+        'disabled'     => true,
+        'title'        => get_string('filequota', 'admin'),
+        'description'  => get_string('filequotadescription', 'admin'),
+        'value'        => display_size(get_config_plugin('artefact', 'file', 'defaultquota')),
+    );
+}
+
+// Add general account options
+$prefs = (object) expected_account_preferences();
+$elements = array_merge($elements, general_account_prefs_form_elements($prefs));
+unset($prefs);
+
+
 $form = pieform(array(
     'name'       => 'adduser',
     'autofocus'  => false,
@@ -170,11 +186,19 @@ function adduser_validate(Pieform $form, $values) {
     }
 
     $username  = $values['username'];
-    $firstname = $values['firstname'];
-    $lastname  = $values['lastname'];
-    $email     = $values['email'];
+    $firstname = sanitize_firstname($values['firstname']);
+    $lastname  = sanitize_lastname($values['lastname']);
+    $email     = sanitize_email($values['email']);
     $password  = $values['password'];
 
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        $maxquotaenabled = get_config_plugin('artefact', 'file', 'maxquotaenabled');
+        $maxquota = get_config_plugin('artefact', 'file', 'maxquota');
+        if ($maxquotaenabled && $values['quota'] > $maxquota) {
+            $form->set_error('quota', get_string('maxquotaexceededform', 'artefact.file', display_size($maxquota)));
+        }
+    }
+
     if (method_exists($authobj, 'is_username_valid_admin')) {
         if (!$authobj->is_username_valid_admin($username)) {
             $form->set_error('username', get_string('usernameinvalidadminform', 'auth.internal'));
@@ -232,16 +256,15 @@ function adduser_validate(Pieform $form, $values) {
         }
     }
     else {
-        if (!$form->get_error('firstname') && !preg_match('/\S/', $firstname)) {
+        if (!$form->get_error('firstname') && empty($firstname)) {
             $form->set_error('firstname', $form->i18n('rule', 'required', 'required'));
         }
-        if (!$form->get_error('lastname') && !preg_match('/\S/', $lastname)) {
+        if (!$form->get_error('lastname') && empty($lastname)) {
             $form->set_error('lastname', $form->i18n('rule', 'required', 'required'));
         }
 
         if (!$form->get_error('email')) {
-            require_once('phpmailer/class.phpmailer.php');
-            if (!$form->get_error('email') && !PHPMailer::ValidateAddress($email)) {
+            if (!$form->get_error('email') && empty($email)) {
                 $form->set_error('email', get_string('invalidemailaddress', 'artefact.internal'));
             }
 
@@ -267,20 +290,22 @@ function adduser_submit(Pieform $form, $values) {
         'lastname'       => ($values['lastname']) ? $values['lastname'] : 'User',
         'email'          => $values['email'],
         'password'       => $values['password'],
-        'quota'          => $values['quota'],
         'passwordchange' => 1,
     );
     if ($USER->get('admin')) {  // Not editable by institutional admins
         $user->staff = (int) ($values['staff'] == 'on');
         $user->admin = (int) ($values['admin'] == 'on');
     }
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        $user->quota = $values['quota'];
+    }
 
     $authinstance = get_record('auth_instance', 'id', $values['authinstance']);
     if (!isset($values['remoteusername'])){
         $values['remoteusername'] = null;
     }
 
-    $user->id = create_user($user, array(), $authinstance->institution, $authinstance, $values['remoteusername']);
+    $user->id = create_user($user, array(), $authinstance->institution, $authinstance, $values['remoteusername'], $values);
 
     if (isset($user->admin) && $user->admin) {
         require_once('activity.php');
@@ -325,8 +350,8 @@ function adduser_submit(Pieform $form, $values) {
     if (!empty($user->email)) {
         try {
             email_user($user, $USER, get_string('accountcreated', 'mahara', get_config('sitename')),
-                get_string('accountcreatedchangepasswordtext', 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('sitename')),
-                get_string('accountcreatedchangepasswordhtml', 'mahara', $user->firstname, get_config('wwwroot'), get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('wwwroot'), get_config('sitename'))
+                get_string('accountcreatedchangepasswordtext', 'mahara', $user->firstname, get_config('sitename'), $user->username, $values['password'], get_config('wwwroot'), get_config('sitename')),
+                get_string('accountcreatedchangepasswordhtml', 'mahara', $user->firstname, get_config('wwwroot'), get_config('sitename'), $user->username, $values['password'], get_config('wwwroot'), get_config('wwwroot'), get_config('sitename'))
             );
         }
         catch (EmailException $e) {
@@ -334,19 +359,6 @@ function adduser_submit(Pieform $form, $values) {
         }
     }
 
-    // Add salt and encrypt the pw, if the auth instance allows for it
-    $userobj = new User();
-    $userobj = $userobj->find_by_id($user->id);
-    $authobj = AuthFactory::create($user->authinstance);
-    if (method_exists($authobj, 'change_password')) {
-        $authobj->change_password($userobj, $user->password, false);
-    } else {
-        $userobj->password = '';
-        $userobj->salt = auth_get_random_salt();
-        $userobj->commit();
-    }
-    unset($userobj, $authobj);
-
     $SESSION->add_ok_msg(get_string('newusercreated', 'admin'));
     redirect('/admin/users/edit.php?id=' . $user->id);
 }
