@@ -113,6 +113,12 @@ $form = array(
  * Work-around the redirection limit of Firefox (http://kb.mozillazine.org/Network.http.redirection-limit)
  */
 function meta_redirect() {
+    global $SESSION, $LEAP2AFILES, $ADDEDUSERS, $FAILEDUSERS;
+
+    $SESSION->set('bulkimport_leap2afiles', $LEAP2AFILES);
+    $SESSION->set('bulkimport_addedusers', $ADDEDUSERS);
+    $SESSION->set('bulkimport_failedusers', $FAILEDUSERS);
+
     $url = get_config('wwwroot') . '/admin/users/bulkimport.php';
     print_meta_redirect($url);
     exit;
@@ -250,14 +256,14 @@ function import_next_user() {
     if ($returnvar != 0) {
         $FAILEDUSERS[$username] = get_string('unzipfailed', 'admin', hsc($filename));
         log_debug("unzip command failed with return value $returnvar");
-        continue;
+        meta_redirect();
     }
 
     $leap2afilename = $uploaddir . 'leap2a.xml';
     if (!is_file($leap2afilename)) {
         $FAILEDUSERS[$username] = get_string('noleap2axmlfiledetected', 'admin');
         log_debug($FAILEDUSERS[$username]);
-        continue;
+        meta_redirect();
     }
 
     // If the username is already taken, append something to the end
@@ -319,13 +325,11 @@ function import_next_user() {
     if (empty($FAILEDUSERS[$username])) {
         // Reload the user details, as various fields are changed by the
         // importer when importing (e.g. firstname/lastname)
-        $ADDEDUSERS[] = get_record('usr', 'id', $user->id);
+        $newuser = get_record('usr', 'id', $user->id);
+        $newuser->clearpasswd = $user->password;
+        $ADDEDUSERS[] = $newuser;
     }
 
-    $SESSION->set('bulkimport_leap2afiles', $LEAP2AFILES);
-    $SESSION->set('bulkimport_addedusers', $ADDEDUSERS);
-    $SESSION->set('bulkimport_failedusers', $FAILEDUSERS);
-
     meta_redirect();
 }
 
@@ -347,8 +351,8 @@ function finish_import() {
             $noemailusers = array();
             try {
                 email_user($user, null, get_string('accountcreated', 'mahara', get_config('sitename')),
-                    get_string('accountcreatedchangepasswordtext', 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('sitename')),
-                    get_string('accountcreatedchangepasswordhtml', 'mahara', $user->firstname, get_config('wwwroot'), get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('wwwroot'), get_config('sitename'))
+                    get_string('accountcreatedchangepasswordtext', 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->clearpasswd, get_config('wwwroot'), get_config('sitename')),
+                    get_string('accountcreatedchangepasswordhtml', 'mahara', $user->firstname, get_config('wwwroot'), get_config('sitename'), $user->username, $user->clearpasswd, get_config('wwwroot'), get_config('wwwroot'), get_config('sitename'))
                 );
             }
             catch (EmailException $e) {
@@ -367,20 +371,6 @@ function finish_import() {
         }
     }
 
-    foreach ($ADDEDUSERS as $user) {
-        // Add salt and encrypt the pw, if the auth instance allows for it
-        $userobj = new User();
-        $userobj = $userobj->find_by_id($user->id);
-        $authobj = AuthFactory::create($user->authinstance);
-        if (method_exists($authobj, 'change_password')) {
-            $authobj->change_password($userobj, $user->password, false);
-        } else {
-            $userobj->password = '';
-            $userobj->salt = auth_get_random_salt();
-            $userobj->commit();
-        }
-    }
-
     if (!empty($FAILEDUSERS)) {
         $message = get_string('importfailedfornusers', 'admin', count($FAILEDUSERS), $totalusers) . "\n<ul>\n";
         foreach ($FAILEDUSERS as $username => $error) {
