@@ -45,6 +45,13 @@ if (!$USER->is_admin_for_user($user)) {
     redirect('/user/view.php?id=' . $id);
 }
 
+if ($user->deleted) {
+    $smarty = smarty();
+    $smarty->assign('PAGEHEADING', TITLE . ': ' . display_name($user));
+    $smarty->assign('message', get_string('thisuserdeleted', 'admin'));
+    $smarty->display('message.tpl');
+    exit;
+}
 
 // Site-wide account settings
 $currentdate = getdate();
@@ -99,7 +106,7 @@ if ($USER->get('admin')) {
 $elements['maildisabled'] = array(
     'type' => 'checkbox',
     'defaultvalue' => get_account_preference($user->id, 'maildisabled'),
-    'title' => get_string('email'),
+    'title' => get_string('disableemail', 'admin'),
     'help' => true,
 );
 $elements['expiry'] = array(
@@ -110,13 +117,25 @@ $elements['expiry'] = array(
     'maxyear'      => $currentdate['year'] + 20,
     'defaultvalue' => $user->expiry
 );
-$elements['quota'] = array(
-    'type'         => 'bytes',
-    'title'        => get_string('filequota','admin'),
-    'description'  => get_string('filequotadescription','admin'),
-    'rules'        => array('integer' => true),
-    'defaultvalue' => $user->quota,
-);
+$quotaused = get_string('quotaused', 'admin') . ': ' . display_size($user->quotaused);
+if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+    $elements['quota'] = array(
+        'type'         => 'bytes',
+        'title'        => get_string('filequota','admin'),
+        'description'  => get_string('filequotadescription','admin') . '<br>' . $quotaused,
+        'rules'        => array('integer' => true),
+        'defaultvalue' => $user->quota,
+    );
+}
+else {
+    $elements['quota'] = array(
+        'type'         => 'text',
+        'disabled'     => true,
+        'title'        => get_string('filequota', 'admin'),
+        'description'  => get_string('filequotadescription', 'admin') . '<br>' . $quotaused,
+        'value'        => display_size($user->quota),
+    );
+}
 
 $authinstances = auth_get_auth_instances();
 if (count($authinstances) > 1) {
@@ -133,7 +152,7 @@ if (count($authinstances) > 1) {
     $external = false;
     foreach ($authinstances as $authinstance) {
         if ($USER->can_edit_institution($authinstance->name)) {
-            $options[$authinstance->id] = $authinstance->instancename . ' (' . $authinstance->displayname . ')';
+            $options[$authinstance->id] = $authinstance->displayname . ': ' . $authinstance->instancename;
             if ($authinstance->authname != 'internal') {
                 $external = true;
             }
@@ -156,12 +175,23 @@ if (count($authinstances) > 1) {
                 'title'        => get_string('remoteusername', 'admin'),
                 'description'  => get_string('remoteusernamedescription', 'admin', hsc(get_config('sitename'))),
                 'defaultvalue' => $un ? $un : $user->username,
+                'help'         => true,
             );
         }
     }
 
 }
 
+$tags = get_column_sql('SELECT tag FROM {usr_tag} WHERE usr = ? AND NOT tag ' . db_ilike() . " 'lastinstitution:%'", array($user->id));
+
+$elements['tags'] = array(
+    'defaultvalue' => $tags,
+    'type'         => 'tags',
+    'title'        => get_string('tags'),
+    'description'  => get_string('tagsdesc'),
+    'help'         => true,
+);
+
 $elements['submit'] = array(
     'type'  => 'submit',
     'value' => get_string('savechanges','admin'),
@@ -180,11 +210,13 @@ function edituser_site_validate(Pieform $form, $values) {
     if (!$user = get_record('usr', 'id', $values['id'])) {
         return false;
     }
-    $maxquotaenabled = get_config_plugin('artefact', 'file', 'maxquotaenabled');
-    $maxquota = get_config_plugin('artefact', 'file', 'maxquota');
-    if ($maxquotaenabled && $values['quota'] > $maxquota) {
-        $form->set_error('quota', get_string('maxquotaexceededform', 'artefact.file', display_size($maxquota)));
-        $SESSION->add_error_msg(get_string('maxquotaexceeded', 'artefact.file', display_size($maxquota)));
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        $maxquotaenabled = get_config_plugin('artefact', 'file', 'maxquotaenabled');
+        $maxquota = get_config_plugin('artefact', 'file', 'maxquota');
+        if ($maxquotaenabled && $values['quota'] > $maxquota) {
+            $form->set_error('quota', get_string('maxquotaexceededform', 'artefact.file', display_size($maxquota)));
+            $SESSION->add_error_msg(get_string('maxquotaexceeded', 'artefact.file', display_size($maxquota)));
+        }
     }
 
     $userobj = new User();
@@ -221,15 +253,42 @@ function edituser_site_validate(Pieform $form, $values) {
         }
     }
 
-    // Check that the external username isn't already in use
-    if (isset($values['remoteusername']) &&
-        $usedby = get_record_select('auth_remote_user',
-        'authinstance = ? AND remoteusername = ? AND localusr != ?',
-        array($values['authinstance'], $values['remoteusername'], $values['id']))
-    ) {
-        $usedbyuser = get_field('usr', 'username', 'id', $usedby->localusr);
-        $SESSION->add_error_msg(get_string('duplicateremoteusername', 'auth', $usedbyuser));
-        $form->set_error('remoteusername', get_string('duplicateremoteusernameformerror', 'auth'));
+    // Check that the external username isn't already in use by someone else
+    if (isset($values['authinstance']) && isset($values['remoteusername'])) {
+        // there are 4 cases for changes on the page
+        // 1) ai and remoteuser have changed
+        // 2) just ai has changed
+        // 3) just remoteuser has changed
+        // 4) the ai changes and the remoteuser is wiped - this is a delete of the old ai-remoteuser
+
+        // determine the current remoteuser
+        $current_remotename = get_field('auth_remote_user', 'remoteusername',
+                                        'authinstance', $user->authinstance, 'localusr', $user->id);
+        if (!$current_remotename) {
+            $current_remotename = $user->username;
+        }
+        // what should the new remoteuser be
+        $new_remoteuser = get_field('auth_remote_user', 'remoteusername',
+                                    'authinstance', $values['authinstance'], 'localusr', $user->id);
+        if (!$new_remoteuser) {
+            $new_remoteuser = $user->username;
+        }
+        if (strlen(trim($values['remoteusername'])) > 0) {
+            // value changed on page - use it
+            if ($values['remoteusername'] != $current_remotename) {
+                $new_remoteuser = $values['remoteusername'];
+            }
+        }
+
+        // what really counts is who owns the target remoteuser slot
+        $target_owner = get_field('auth_remote_user', 'localusr',
+                                  'authinstance', $values['authinstance'], 'remoteusername', $new_remoteuser);
+        // target remoteuser is owned by someone else
+        if ($target_owner && $target_owner != $user->id) {
+            $usedbyuser = get_field('usr', 'username', 'id', $target_owner);
+            $SESSION->add_error_msg(get_string('duplicateremoteusername', 'auth', $usedbyuser));
+            $form->set_error('remoteusername', get_string('duplicateremoteusernameformerror', 'auth'));
+        }
     }
 }
 
@@ -240,9 +299,19 @@ function edituser_site_submit(Pieform $form, $values) {
         return false;
     }
 
-    $user->quota = $values['quota'];
-    $user->expiry = db_format_timestamp($values['expiry']);
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        $user->quota = $values['quota'];
+    }
 
+    $unexpire = $user->expiry && strtotime($user->expiry) < time() && (empty($values['expiry']) || $values['expiry'] > time());
+    $newexpiry = db_format_timestamp($values['expiry']);
+    if ($user->expiry != $newexpiry) {
+        $user->expiry = $newexpiry;
+        if ($unexpire) {
+            $user->expirymailsent = 0;
+            $user->lastaccess = db_format_timestamp(time());
+        }
+    }
 
     // Try to kick the user from any active login sessions, before saving data.
     require_once(get_config('docroot') . 'auth/session.php');
@@ -267,34 +336,55 @@ function edituser_site_submit(Pieform $form, $values) {
     }
     set_account_preference($user->id, 'maildisabled', $values['maildisabled']);
 
-    // Authinstance can be changed by institutional admins if both the
-    // old and new authinstances belong to the admin's institutions
-    $remotename = get_field('auth_remote_user', 'remoteusername', 'authinstance', $user->authinstance, 'localusr', $user->id);
-    if (!$remotename) {
-        $remotename = $user->username;
-    }
-    if (isset($values['authinstance'])
-        && ($values['authinstance'] != $user->authinstance
-            || (isset($values['remoteusername']) && $values['remoteusername'] != $remotename))) {
-        $authinst = get_records_select_assoc('auth_instance', 'id = ? OR id = ?', 
+    // process the change of the authinstance and or the remoteuser
+    if (isset($values['authinstance']) && isset($values['remoteusername'])) {
+        // Authinstance can be changed by institutional admins if both the
+        // old and new authinstances belong to the admin's institutions
+        $authinst = get_records_select_assoc('auth_instance', 'id = ? OR id = ?',
                                              array($values['authinstance'], $user->authinstance));
         if ($USER->get('admin') || 
             ($USER->is_institutional_admin($authinst[$values['authinstance']]->institution) &&
              $USER->is_institutional_admin($authinst[$user->authinstance]->institution))) {
-            delete_records('auth_remote_user', 'localusr', $user->id);
-            if ($authinst[$values['authinstance']]->authname != 'internal') {
-                if (isset($values['remoteusername']) && strlen($values['remoteusername']) > 0) {
-                    $un = $values['remoteusername'];
-                }
-                else {
-                    $un = $remotename;
-                }
-                insert_record('auth_remote_user', (object) array(
-                    'authinstance'   => $values['authinstance'],
-                    'remoteusername' => $un,
-                    'localusr'       => $user->id,
-                ));
+            // determine the current remoteuser
+            $current_remotename = get_field('auth_remote_user', 'remoteusername',
+                                            'authinstance', $user->authinstance, 'localusr', $user->id);
+            if (!$current_remotename) {
+                $current_remotename = $user->username;
             }
+            // if the remoteuser is empty and the ai has changed - delete the old remoteuser record
+            if (strlen(trim($values['remoteusername'])) == 0 &&
+                $values['authinstance'] != $user->authinstance) {
+                delete_records('auth_remote_user', 'authinstance', $user->authinstance, 'localusr', $user->id);
+            }
+            // we do not create a remoteuser record for internal ai's
+            if ($authinst[$values['authinstance']]->authname != 'internal') {
+                // what should the new remoteuser be
+                $new_remoteuser = get_field('auth_remote_user', 'remoteusername',
+                                            'authinstance', $values['authinstance'], 'localusr', $user->id);
+                // save the remotename for the target existence check
+                $target_remotename = $new_remoteuser;
+                if (!$new_remoteuser) {
+                    $new_remoteuser = $user->username;
+                }
+                if (strlen(trim($values['remoteusername'])) > 0) {
+                    // value changed on page - use it
+                    if ($values['remoteusername'] != $current_remotename) {
+                        $new_remoteuser = $values['remoteusername'];
+                    }
+                }
+                // only update remote name if the input actually changed on the page  or it doesn't yet exist
+                if ($current_remotename != $new_remoteuser || !$target_remotename) {
+                    // only remove the ones related to this traget authinstance as we now allow multiple
+                    // for dual login mechanisms
+                    delete_records('auth_remote_user', 'authinstance', $values['authinstance'], 'localusr', $user->id);
+                    insert_record('auth_remote_user', (object) array(
+                        'authinstance'   => $values['authinstance'],
+                        'remoteusername' => $new_remoteuser,
+                        'localusr'       => $user->id,
+                    ));
+                }
+            }
+            // update the ai on the user master
             $user->authinstance = $values['authinstance'];
 
             // update the global $authobj to match the new authinstance
@@ -306,7 +396,7 @@ function edituser_site_submit(Pieform $form, $values) {
 
     // Only change the pw if the new auth instance allows for it
     if (method_exists($authobj, 'change_password')) {
-        $user->passwordchange = (int) ($values['passwordchange'] == 'on');
+        $user->passwordchange = (int) (isset($values['passwordchange']) && $values['passwordchange'] == 'on' ? 1 : 0);
 
         if (isset($values['password']) && $values['password'] !== '') {
             $userobj = new User();
@@ -355,8 +445,26 @@ function edituser_site_submit(Pieform $form, $values) {
         unset($userobj);
     }
 
+    db_begin();
     update_record('usr', $user);
 
+    delete_records('usr_tag', 'usr', $user->id);
+    if (is_array($values['tags'])) {
+        foreach(array_unique($values['tags']) as $tag) {
+            if (empty($tag)) {
+                continue;
+            }
+            insert_record(
+                'usr_tag',
+                (object) array(
+                    'usr' => $user->id,
+                    'tag' => strtolower($tag),
+                )
+            );
+        }
+    }
+    db_commit();
+
     redirect('/admin/users/edit.php?id='.$user->id);
 }
 
@@ -414,6 +522,7 @@ else {
     $suspendform2 = pieform($suspendformdef);
 
     $suspender = display_name(get_record('usr', 'id', $suspended));
+    $suspendedtime = format_date($user->get('suspendedctime'), 'strftimedate');
 }
 
 function edituser_suspend_submit(Pieform $form, $values) {
@@ -626,7 +735,7 @@ $smarty = smarty();
 $smarty->assign('user', $user);
 $smarty->assign('suspended', $suspended);
 if ($suspended) {
-    $smarty->assign('suspendedby', get_string('suspendedby', 'admin', $suspender));
+    $smarty->assign('suspendedby', get_string('suspendedinfo', 'admin', $suspender, $suspendedtime));
 }
 $smarty->assign('suspendform', $suspendform);
 if (isset($suspendform2)) {
