@@ -43,6 +43,21 @@ $query = param_variable('query', '');
 $offset = param_integer('offset', 0);
 $limit  = 20;
 
+$customthemedefaults = array(
+    'background'   => array('type' => 'color', 'value' => '#182768'),
+    'backgroundfg' => array('type' => 'color', 'value' => '#FFFFFF'),
+    'link'         => array('type' => 'color', 'value' => '#d66800'),
+    'headings'     => array('type' => 'color', 'value' => '#182768'),
+    'sidebarbg'    => array('type' => 'color', 'value' => '#182768'),
+    'sidebarfg'    => array('type' => 'color', 'value' => '#f1f2f8'),
+    'sidebarlink'  => array('type' => 'color', 'value' => '#182768'),
+    'navbg'        => array('type' => 'color', 'value' => '#f6871f'),
+    'navfg'        => array('type' => 'color', 'value' => '#FFFFFF'),
+    'subbg'        => array('type' => 'color', 'value' => '#fff4ea'),
+    'subfg'        => array('type' => 'color', 'value' => '#14336F'),
+    'rowbg'        => array('type' => 'color', 'value' => '#fff4ea'),
+);
+
 if (!$USER->get('admin')) {
     // Institutional admins with only 1 institution go straight to the edit page for that institution
     // They cannot add or delete institutions, or edit an institution they don't administer
@@ -67,8 +82,28 @@ if ($institution || $add) {
 
     if ($delete) {
         function delete_validate(Pieform $form, $values) {
-            if (get_field('usr_institution', 'COUNT(*)', 'institution', $values['i'])) {
-                throw new ConfigException('Attempt to delete an institution that has members');
+            // Ensure the institution has no members left
+            if ($members = get_field('usr_institution', 'COUNT(*)', 'institution', $values['i'])) {
+                $form->set_error('submit', get_string('institutionstillhas', 'admin', get_string('nmembers', 'group', $members)));
+            }
+
+            // If some users are still using one of this institution's authinstances, it's okay if
+            // we can find a default authinstance for those users, otherwise it's an error.
+            if ($authinstanceids = get_column('auth_instance', 'id', 'institution', $values['i'])) {
+                $badusers = count_records_select(
+                    'usr',
+                    'authinstance IN (' . join(',', array_fill(0, count($authinstanceids), '?')) . ')',
+                    $authinstanceids
+                );
+                if ($badusers) {
+                    $defaultauth = record_exists('auth_instance', 'institution', 'mahara', 'authname', 'internal');
+                    if ($values['i'] == 'mahara' || !$defaultauth) {
+                        $form->set_error(
+                            'submit',
+                            get_string('institutionauthinuseby', 'admin', get_string('nusers', 'mahara', $badusers))
+                        );
+                    }
+                }
             }
         }
 
@@ -102,13 +137,34 @@ if ($institution || $add) {
                     }
                 }
             }
+
+            // If any users are still using this institution's authinstances, change them now.
+            if ($authinstanceids) {
+                execute_sql("
+                    UPDATE {usr}
+                    SET authinstance = (
+                        SELECT MIN(id) FROM {auth_instance} WHERE institution = 'mahara' AND authname = 'internal'
+                    )
+                    WHERE authinstance IN (" . join(',', array_fill(0, count($authinstanceids), '?')) . ')',
+                    $authinstanceids
+                );
+            }
+
             foreach ($authinstanceids as $id) {
                 delete_records('auth_instance_config', 'instance', $id);
             }
+
+            // The institution should have been removed from favourites lists when the members were removed,
+            // but make sure it's gone.
+            execute_sql('DELETE FROM {favorite_usr} WHERE favorite IN (SELECT id FROM {favorite} WHERE institution = ?)', array($values['i']));
+            delete_records('favorite', 'institution', $values['i']);
+
+            execute_sql("UPDATE {group} SET institution = NULL, shortname = NULL WHERE institution = ?", array($values['i']));
             delete_records('auth_instance', 'institution', $values['i']);
             delete_records('host', 'institution', $values['i']);
             delete_records('institution_locked_profile_field', 'name', $values['i']);
             delete_records('usr_institution_request', 'institution', $values['i']);
+            delete_records('view_access', 'institution', $values['i']);
             delete_records('institution', 'name', $values['i']);
             db_commit();
 
@@ -176,9 +232,12 @@ if ($institution || $add) {
         $data->expiry = null;
         if (!get_config('usersuniquebyusername')) {
             $data->registerallowed = 1;
+            $data->registerconfirm = 1;
         }
         $data->theme = 'sitedefault';
         $data->defaultmembershipperiod = null;
+        $data->showonlineusers = 2;
+        $data->allowinstitutionpublicviews = get_config('allowpublicviews') ? 1 : 0;
         $lockedprofilefields = array();
 
         $authtypes = auth_get_available_auth_types();
@@ -187,6 +246,7 @@ if ($institution || $add) {
     $themeoptions['sitedefault'] = '- ' . get_string('sitedefault', 'admin') . ' (' . $themeoptions[get_config('theme')] . ') -';
     uksort($themeoptions, 'theme_sort');
 
+    $showonlineusersoptions = array('0' => get_string('none'), '1' => get_string('institutiononly', 'admin'), '2' => get_string('all', 'admin'));
     $sitename = get_config('sitename');
 
     safe_require('artefact', 'internal');
@@ -267,10 +327,16 @@ if ($institution || $add) {
         $elements['registerallowed'] = array(
             'type'         => 'checkbox',
             'title'        => get_string('registrationallowed', 'admin'),
-            'description'  => get_string('registrationalloweddescription2', 'admin'),
+            'description'  => get_string('registrationalloweddescription3', 'admin'),
             'defaultvalue' => $data->registerallowed,
             'help'   => true,
         );
+        $elements['registerconfirm'] = array(
+            'type'         => 'checkbox',
+            'title'        => get_string('registrationconfirm', 'admin'),
+            'description'  => get_string('registrationconfirmdescription', 'admin'),
+            'defaultvalue' => $data->registerconfirm,
+        );
     }
 
     if (empty($data->name) || $data->name != 'mahara') {
@@ -281,6 +347,27 @@ if ($institution || $add) {
             'defaultvalue' => $data->defaultmembershipperiod,
             'help'   => true,
         );
+        $elements['logo'] = array(
+            'type'        => 'file',
+            'title'       => get_string('Logo', 'admin'),
+            'description' => get_string('logodescription', 'admin'),
+            'maxfilesize' => get_max_upload_size(false),
+        );
+        if (!empty($data->logo)) {
+            $logourl = get_config('wwwroot') . 'thumb.php?type=logobyid&id=' . $data->logo;
+            $elements['logohtml'] = array(
+                'type'        => 'html',
+                'value'       => '<img src="' . $logourl . '" alt="' . get_string('Logo', 'admin') . '">',
+            );
+            $elements['deletelogo'] = array(
+                'type'        => 'checkbox',
+                'title'       => get_string('deletelogo', 'admin'),
+                'description' => get_string('deletelogodescription', 'admin'),
+            );
+        }
+        if (!empty($data->style)) {
+            $customtheme = get_records_menu('style_property', 'style', $data->style, '', 'field,value');
+        }
         $elements['theme'] = array(
             'type'         => 'select',
             'title'        => get_string('theme'),
@@ -290,6 +377,64 @@ if ($institution || $add) {
             'options'      => $themeoptions,
             'help'         => true,
         );
+        $elements['customthemefs'] = array(
+            'type'         => 'fieldset',
+            'class'        => 'customtheme' . ($elements['theme']['defaultvalue'] != 'custom' ? ' js-hidden' : ''),
+            'legend'       => get_string('customtheme', 'admin'),
+            'elements'     => array(),
+        );
+        foreach ($customthemedefaults as $name => $styledata) {
+            $elements['customthemefs']['elements'][$name] = array(
+                'type'         => $styledata['type'],
+                'title'        => get_string('customtheme.' . $name, 'admin'),
+                'defaultvalue' => isset($customtheme[$name]) ? $customtheme[$name] : $styledata['value'],
+            );
+        }
+        $elements['customthemefs']['elements']['resetcustom'] = array(
+            'type'         => 'checkbox',
+            'class'        => 'nojs-hidden-inline',
+            'title'        => get_string('resetcolours', 'admin'),
+            'description'  => get_string('resetcoloursdesc', 'admin'),
+        );
+        $elements['showonlineusers'] = array(
+            'type'                  => 'select',
+            'title'                 => get_string('showonlineusers', 'admin'),
+            'description'           => get_string('showonlineusersdescription','admin'),
+            'defaultvalue'          => $data->showonlineusers,
+            'collapseifoneoption'   => true,
+            'options'               => $showonlineusersoptions,
+        );
+        if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+            $elements['defaultquota'] = array(
+               'type'         => 'bytes',
+               'title'        => get_string('defaultquota', 'artefact.file'),
+               'description'  => get_string('defaultinstitutionquotadescription', 'admin'),
+               'defaultvalue' => !empty($data->defaultquota) ? $data->defaultquota : get_config_plugin('artefact', 'file', 'defaultquota'),
+            );
+            $elements['updateuserquotas'] = array(
+                'title'        => get_string('updateuserquotas', 'artefact.file'),
+                'description'  => get_string('updateinstitutionuserquotasdesc', 'admin'),
+                'type'         => 'checkbox',
+            );
+        }
+        else {
+            $elements['defaultquota'] = array(
+                'type' => 'text',
+                'title' => get_string('defaultquota', 'artefact.file'),
+                'value' => display_size(!empty($data->defaultquota) ? $data->defaultquota : get_config_plugin('artefact', 'file', 'defaultquota')),
+                'disabled' => true,
+            );
+        }
+
+        $elements['allowinstitutionpublicviews'] = array(
+            'type'         => 'checkbox',
+            'title'        => get_string('allowinstitutionpublicviews', 'admin'),
+            'description'  => get_string('allowinstitutionpublicviewsdescription','admin'),
+            'defaultvalue' => get_config('allowpublicviews') && $data->allowinstitutionpublicviews,
+            'disabled'     => get_config('allowpublicviews') == false,
+            'help'         => true,
+        );
+
         if ($USER->get('admin')) {
             $elements['maxuseraccounts'] = array(
                 'type'         => 'text',
@@ -400,13 +545,46 @@ EOF;
 }
 
 function institution_validate(Pieform $form, $values) {
+    global $USER;
+
     if (!empty($values['name']) && !$form->get_error('name') && record_exists('institution', 'name', $values['name'])) {
         $form->set_error('name', get_string('institutionnamealreadytaken', 'admin'));
     }
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        if (get_config_plugin('artefact', 'file', 'maxquotaenabled') && get_config_plugin('artefact', 'file', 'maxquota') < $values['defaultquota']) {
+            $form->set_error('defaultquota', get_string('maxquotatoolow', 'artefact.file'));
+        }
+    }
+
+    // Check uploaded logo
+    if (!empty($values['logo'])) {
+        require_once('file.php');
+        require_once('uploadmanager.php');
+        $um = new upload_manager('logo');
+        if ($error = $um->preprocess_file()) {
+            $form->set_error('logo', $error);
+            return false;
+        }
+
+        $imageinfo = getimagesize($values['logo']['tmp_name']);
+        if (!$imageinfo || !is_image_type($imageinfo[2])) {
+            $form->set_error('logo', get_string('filenotimage'));
+            return false;
+        }
+
+        // Check the file isn't greater than the max allowable size
+        $width          = $imageinfo[0];
+        $height         = $imageinfo[1];
+        $imagemaxwidth  = get_config('imagemaxwidth');
+        $imagemaxheight = get_config('imagemaxheight');
+        if ($width > $imagemaxwidth || $height > $imagemaxheight) {
+            $form->set_error('logo', get_string('profileiconimagetoobig', 'artefact.file', $width, $height, $imagemaxwidth, $imagemaxheight));
+        }
+    }
 }
 
 function institution_submit(Pieform $form, $values) {
-    global $SESSION, $institution, $add, $instancearray, $USER, $authinstances;
+    global $SESSION, $institution, $add, $instancearray, $USER, $authinstances, $customthemedefaults;
 
     db_begin();
     // Update the basic institution record...
@@ -414,9 +592,13 @@ function institution_submit(Pieform $form, $values) {
     if ($add) {
         $institution = $newinstitution->name = strtolower($values['name']);
     }
+    else {
+        $oldinstitution = get_record('institution', 'name', $institution);
+    }
 
     $newinstitution->displayname                  = $values['displayname'];
     $newinstitution->authplugin                   = empty($values['authplugin']) ? null : $values['authplugin'];
+    $newinstitution->showonlineusers              = !isset($values['showonlineusers']) ? 2 : $values['showonlineusers'];
     if (get_config('usersuniquebyusername')) {
         // Registering absolutely not allowed when this setting is on, it's a 
         // security risk. See the documentation for the usersuniquebyusername 
@@ -425,8 +607,53 @@ function institution_submit(Pieform $form, $values) {
     }
     else {
         $newinstitution->registerallowed              = ($values['registerallowed']) ? 1 : 0;
+        $newinstitution->registerconfirm              = ($values['registerconfirm']) ? 1 : 0;
     }
     $newinstitution->theme                        = (empty($values['theme']) || $values['theme'] == 'sitedefault') ? null : $values['theme'];
+
+    if ($newinstitution->theme == 'custom') {
+        if (!empty($oldinstitution->style)) {
+            $styleid = $oldinstitution->style;
+            delete_records('style_property', 'style', $styleid);
+        }
+        else {
+            $record = (object) array('title' => get_string('customstylesforinstitution', 'admin', $newinstitution->displayname));
+            $styleid = insert_record('style', $record, 'id', true);
+        }
+
+        $properties = array();
+        $record = (object) array('style' => $styleid);
+        foreach (array_keys($customthemedefaults) as $name) {
+            $record->field = $name;
+            $record->value = $values[$name];
+            insert_record('style_property', $record);
+            $properties[$name] = $values[$name];
+        }
+
+        // Cache the css
+        $smarty = smarty_core();
+        $smarty->assign('data', $properties);
+        set_field('style', 'css', $smarty->fetch('customcss.tpl'), 'id', $styleid);
+
+        $newinstitution->style = $styleid;
+    }
+    else {
+        $newinstitution->style = null;
+    }
+
+    if (!empty($values['resetcustom']) && !empty($oldinstitution->style)) {
+        $newinstitution->style = null;
+    }
+
+    if ($USER->get('admin') || get_config_plugin('artefact', 'file', 'institutionaloverride')) {
+        if (!empty($values['updateuserquotas']) && !empty($values['defaultquota'])) {
+            execute_sql(
+                "UPDATE {usr} SET quota = ? WHERE id IN (SELECT usr FROM {usr_institution} WHERE institution = ?)",
+                array($values['defaultquota'], $institution)
+            );
+        }
+        $newinstitution->defaultquota = empty($values['defaultquota']) ? get_config_plugin('artefact', 'file', 'defaultquota') : $values['defaultquota'];
+    }
     if ($institution != 'mahara') {
         $newinstitution->defaultmembershipperiod  = ($values['defaultmembershipperiod']) ? intval($values['defaultmembershipperiod']) : null;
         if ($USER->get('admin')) {
@@ -435,6 +662,8 @@ function institution_submit(Pieform $form, $values) {
         }
     }
 
+    $newinstitution->allowinstitutionpublicviews  = (isset($values['allowinstitutionpublicviews']) && $values['allowinstitutionpublicviews']) ? 1 : 0;
+
     if (!empty($values['authplugin'])) {
         $allinstances = array_merge($values['authplugin']['instancearray'], $values['authplugin']['deletearray']);
 
@@ -496,10 +725,58 @@ function institution_submit(Pieform $form, $values) {
     else {
         $where = new StdClass;
         $where->name = $institution;
-        $oldtheme = get_field('institution', 'theme', 'name', $institution);
         update_record('institution', $newinstitution, $where);
     }
 
+    if (is_null($newinstitution->style) && !empty($oldinstitution->style)) {
+        delete_records('style_property', 'style', $oldinstitution->style);
+        delete_records('style', 'id', $oldinstitution->style);
+    }
+
+    // Set the logo after updating the institution, because the institution
+    // needs to exist before it can own the logo artefact.
+    if (!empty($values['logo'])) {
+        safe_require('artefact', 'file');
+
+        // Entry in artefact table
+        $data = (object) array(
+            'institution' => $institution,
+            'title'       => 'logo',
+            'description' => 'Institution logo',
+            'note'        => $values['logo']['name'],
+            'size'        => $values['logo']['size'],
+        );
+
+        $imageinfo      = getimagesize($values['logo']['tmp_name']);
+        $data->width    = $imageinfo[0];
+        $data->height   = $imageinfo[1];
+        $data->filetype = $imageinfo['mime'];
+        $artefact = new ArtefactTypeProfileIcon(0, $data);
+        if (preg_match("/\.([^\.]+)$/", $values['logo']['name'], $saved)) {
+            $artefact->set('oldextension', $saved[1]);
+        }
+        $artefact->commit();
+
+        $id = $artefact->get('id');
+
+        // Move the file into the correct place.
+        $directory = get_config('dataroot') . 'artefact/file/profileicons/originals/' . ($id % 256) . '/';
+        check_dir_exists($directory);
+        move_uploaded_file($values['logo']['tmp_name'], $directory . $id);
+
+        // Delete the old logo
+        if (!empty($oldinstitution->logo)) {
+            $oldlogo = new ArtefactTypeProfileIcon($oldinstitution->logo);
+            $oldlogo->delete();
+        }
+
+        set_field('institution', 'logo', $id, 'name', $institution);
+    }
+
+    if (!empty($values['deletelogo'])) {
+        execute_sql("UPDATE {institution} SET logo = NULL WHERE name = ?", array($institution));
+    }
+
     delete_records('institution_locked_profile_field', 'name', $institution);
     foreach (ArtefactTypeProfile::get_all_fields() as $field => $type) {
         if ($values[$field]) {
@@ -522,10 +799,13 @@ function institution_submit(Pieform $form, $values) {
     }
     else {
         $message = get_string('institutionupdatedsuccessfully', 'admin');
-        if (isset($values['theme']) && $oldtheme != $values['theme']
-            && (!empty($oldtheme) || $values['theme'] != 'sitedefault')) {
+        if (isset($values['theme'])) {
+            $changedtheme = $oldinstitution->theme != $values['theme']
+                && (!empty($oldinstitution->theme) || $values['theme'] != 'sitedefault');
+            if ($changedtheme || $values['theme'] == 'custom') {
+                $message .= '  ' . get_string('usersseenewthemeonlogin', 'admin');
+            }
             $USER->update_theme();
-            $message .= '  ' . get_string('usersseenewthemeonlogin', 'admin');
         }
         $SESSION->add_ok_msg($message);
         $nexturl = '/admin/users/institutions.php';
@@ -620,7 +900,22 @@ function search_submit(Pieform $form, $values) {
     redirect('/admin/users/institutions.php' . (!empty($values['query']) ? '?query=' . urlencode($values['query']) : ''));
 }
 
-$smarty = smarty();
+// Hide custom colour boxes unless theme selector is on 'custom'
+$customthemejs = '
+$j(function() {
+    $j("#institution_theme").change(function() {
+        if ($(this).value == "custom") {
+            $j(".customtheme").removeClass("js-hidden");
+        }
+        else {
+            $j(".customtheme").addClass("js-hidden");
+        }
+    });
+});
+';
+
+$smarty = smarty(array('jquery'));
+$smarty->assign('INLINEJAVASCRIPT', $customthemejs);
 $smarty->assign('institution_form', $institutionform);
 $smarty->assign('instancestring', $instancestring);
 $smarty->assign('add', $add);
