@@ -27,7 +27,7 @@
 
 define('INTERNAL', 1);
 define('JSON', 1);
-define('INSTITUTIONALADMIN', 1);
+define('INSTITUTIONALSTAFF', 1);
 
 require(dirname(dirname(dirname(__FILE__))) . '/init.php');
 
@@ -41,21 +41,15 @@ if ($action == 'search') {
     $params->institution = param_alphanum('institution', null);
     $params->f           = param_alpha('f', null);
     $params->l           = param_alpha('l', null);
-    $params->institution_requested = param_alphanum('institution_requested', null);
+    $params->sortby      = param_alpha('sortby', 'firstname');
+    $params->sortdir     = param_alpha('sortdir', 'asc');
 
     $offset  = param_integer('offset', 0);
     $limit   = param_integer('limit', 10);
-    $sortby  = param_alpha('sortby', 'firstname');
-    $sortdir = param_alpha('sortdir', 'asc');
 
-    json_headers();
-    if (param_boolean('raw', false)) {
-        $data = get_admin_user_search_results($params, $offset, $limit, $sortby, $sortdir);
-    } else {
-        $data['data'] = build_admin_user_search_results($params, $offset, $limit, $sortby, $sortdir);
-    }
+    $data = array();
+    $data['data'] = build_admin_user_search_results($params, $offset, $limit);
     $data['error'] = false;
     $data['message'] = null;
-    echo json_encode($data);
-    exit;
+    json_reply(false, $data);
 }
