@@ -35,7 +35,33 @@ define('SECTION_PLUGINNAME', 'admin');
 define('SECTION_PAGE', 'suspendedusers');
 require_once('pieforms/pieform.php');
 
+$type = param_alpha('type', 'suspended') == 'expired' ? 'expired' : 'suspended';
+$enc_type = json_encode($type);
+
+$typeform = pieform(
+    array(
+        'name' => 'usertype',
+        'elements' => array(
+            'type' => array(
+                'type' => 'select',
+                'title' => get_string('show') . ':',
+                'options' => array(
+                    'suspended' => get_string('suspendedusers', 'admin'),
+                    'expired'   => get_string('expiredusers', 'admin'),
+                ),
+                'defaultvalue' => $type,
+            ),
+            'typesubmit' => array(
+                'type' => 'submit',
+                'class' => 'js-hidden',
+                'value' => get_string('change'),
+            ),
+        ),
+    )
+);
+
 $smarty = smarty(array('tablerenderer'));
+$smarty->assign('typeform', $typeform);
 
 $smarty->assign('INLINEJAVASCRIPT', <<<EOF
 var suspendedlist = new TableRenderer(
@@ -51,11 +77,24 @@ var suspendedlist = new TableRenderer(
         },
         'cusrname',
         'reason',
+        'expiry',
         function (rowdata) { return TD(null, INPUT({'type': 'checkbox', 'name': 'usr_' + rowdata.id})); }
     ]
 );
+suspendedlist.type = {$enc_type};
+suspendedlist.statevars.push('type');
 suspendedlist.updateOnLoad();
 
+addLoadEvent(function() {
+    connect('usertype_type', 'onchange', function() {
+        if (suspendedlist.type != $('usertype_type').value) {
+            suspendedlist.offset = 0;
+            suspendedlist.type = $('usertype_type').value;
+            suspendedlist.doupdate();
+        }
+    });
+});
+
 EOF
 );
 
@@ -74,7 +113,12 @@ $form = new Pieform(array(
             'confirm' => get_string('confirmdeleteusers', 'admin'),
             'name'    => 'delete',
             'value'   => get_string('deleteusers', 'admin')
-        )
+        ),
+        'unexpire' => array(
+            'type' => 'submit',
+            'name' => 'unexpire',
+            'value' => get_string('unexpireusers', 'admin')
+        ),
     )
 ));
 $smarty->assign('buttonformopen', $form->get_form_tag());
@@ -94,6 +138,18 @@ function buttons_submit_unsuspend(Pieform $form, $values) {
     redirect('/admin/users/suspended.php');
 }
 
+function buttons_submit_unexpire(Pieform $form, $values) {
+    global $SESSION;
+
+    $ids = get_user_ids_from_post();
+    foreach ($ids as $userid) {
+        unexpire_user($userid);
+    }
+
+    $SESSION->add_ok_msg(get_string('usersreactivated', 'admin'));
+    redirect('/admin/users/suspended.php?type=expired');
+}
+
 function buttons_submit_delete(Pieform $form, $values) {
     global $SESSION;
 
