@@ -27,7 +27,7 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'Journal Entry';
+$string['title'] = 'Journal entry';
 $string['description'] = 'Display one journal entry';
 
 $string['defaulttitledescription'] = 'If you leave this blank, the title of the journal entry will be used';
