@@ -41,9 +41,7 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
         $configdata = $bi->get('configdata');
 
         if (!empty($configdata['artefactid'])) {
-            require_once(get_config('docroot') . 'artefact/lib.php');
-            $blogpost = artefact_instance_from_id($configdata['artefactid']);
-            return $blogpost->get('title');
+            return $bi->get_artefact_instance($configdata['artefactid'])->get('title');
         }
         return '';
     }
@@ -64,6 +62,7 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
             require_once(get_config('docroot') . 'artefact/lib.php');
             $blogpost = $instance->get_artefact_instance($configdata['artefactid']);
             $configdata['hidetitle'] = true;
+            $configdata['countcomments'] = true;
             $configdata['viewid'] = $instance->get('view');
             $result = $blogpost->render_self($configdata);
             $result = $result['html'];
@@ -140,8 +139,6 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
     }
 
     public static function artefactchooser_element($default=null) {
-        $extrajoin   = ' JOIN {artefact_blog_blogpost} ON {artefact_blog_blogpost}.blogpost = a.id ';
-
         $element = array(
             'name'  => 'artefactid',
             'type'  => 'artefactchooser',
@@ -151,8 +148,6 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
             'limit'     => 10,
             'selectone' => true,
             'artefacttypes' => array('blogpost'),
-            'extrajoin' => $extrajoin,
-            'extracols' => '1 - {artefact_blog_blogpost}.published AS draft',
             'template'  => 'artefact:blog:artefactchooser-element.tpl',
         );
         return $element;
@@ -180,7 +175,8 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
      * This is a valid SQL string for the ORDER BY clause. Fields you can sort on are as per the artefact table
      */
     public static function artefactchooser_get_sort_order() {
-        return 'parent, ctime DESC';
+        return array(array('fieldname' => 'parent'),
+                     array('fieldname' => 'ctime', 'order' => 'DESC'));
     }
 
     public static function default_copy_type() {
@@ -196,5 +192,3 @@ class PluginBlocktypeBlogpost extends PluginBlocktype {
     }
 
 }
-
-?>
