@@ -31,8 +31,8 @@ $string['pluginname'] = 'Journals';
 
 $string['blog'] = 'Journal';
 $string['blogs'] = 'Journals';
-$string['addblog'] = 'Create Journal';
-$string['addpost'] = 'New Entry';
+$string['addblog'] = 'Create journal';
+$string['addpost'] = 'New entry';
 $string['alignment'] = 'Alignment';
 $string['allowcommentsonpost'] = 'Allow comments on your entry.';
 $string['allposts'] = 'All entries';
@@ -46,19 +46,19 @@ $string['blogdesc'] = 'Description';
 $string['blogdescdesc'] = 'e.g., ‘A record of Jill\'s experiences and reflections’.';
 $string['blogdoesnotexist'] = 'You are trying to access a journal that does not exist';
 $string['blogpostdoesnotexist'] = 'You are trying to access a journal entry that does not exist';
-$string['blogpost'] = 'Journal Entry';
+$string['blogpost'] = 'Journal entry';
 $string['blogdeleted'] = 'Journal deleted';
 $string['blogpostdeleted'] = 'Journal entry deleted';
 $string['blogpostpublished'] = 'Journal entry published';
 $string['blogpostsaved'] = 'Journal entry saved';
-$string['blogsettings'] = 'Journal Settings';
+$string['blogsettings'] = 'Journal settings';
 $string['blogtitle'] = 'Title';
 $string['blogtitledesc'] = 'e.g., ‘Jill’s Nursing Practicum Journal’.';
 $string['border'] = 'Border';
 $string['cancel'] = 'Cancel';
 $string['createandpublishdesc'] = 'This will create the journal entry and make it available to others.';
 $string['createasdraftdesc'] = 'This will create the journal entry, but it will not become available to others until you choose to publish it.';
-$string['createblog'] = 'Create Journal';
+$string['createblog'] = 'Create journal';
 $string['dataimportedfrom'] = 'Data imported from %s';
 $string['defaultblogtitle'] = '%s\'s Journal';
 $string['delete'] = 'Delete';
@@ -68,8 +68,8 @@ $string['description'] = 'Description';
 $string['dimensions'] = 'Dimensions';
 $string['draft'] = 'Draft';
 $string['edit'] = 'Edit';
-$string['editblogpost'] = 'Edit Journal Entry';
-$string['entriesimportedfromleapexport'] = 'Entries imported from a LEAP export, that were not able to be imported elsewhere';
+$string['editblogpost'] = 'Edit journal entry';
+$string['entriesimportedfromleapexport'] = 'Entries imported from a LEAP export that were not able to be imported elsewhere';
 $string['errorsavingattachments'] = 'An error occurred while saving journal entry attachments';
 $string['horizontalspace'] = 'Horizontal space';
 $string['insert'] = 'Insert';
@@ -78,43 +78,44 @@ $string['moreoptions'] = 'More options';
 $string['mustspecifytitle'] = 'You must specify a title for your entry';
 $string['mustspecifycontent'] = 'You must specify some content for your entry';
 $string['name'] = 'Name';
-$string['newattachmentsexceedquota'] = 'The total size of the new files that you have uploaded to this entry would exceed your quota.  You may be able to save the entry if you remove some of the attachments you have just added.';
-$string['newblog'] = 'New Journal';
-$string['newblogpost'] = 'New Journal Entry in Journal "%s"';
+$string['newattachmentsexceedquota'] = 'The total size of the new files that you have uploaded to this entry would exceed your quota. You may be able to save the entry if you remove some of the attachments you have just added.';
+$string['newblog'] = 'New journal';
+$string['newblogpost'] = 'New journal entry in journal "%s"';
 $string['newerposts'] = 'Newer entries';
+$string['nodefaultblogfound'] = 'No default journal found. This is a bug in the system. To fix it, you need to enable the multiple journals option on the <a href="%saccount/">account settings</a> page.';
 $string['nopostsyet'] = 'No entries yet.';
-$string['addone'] = 'Add one!';
-$string['noimageshavebeenattachedtothispost'] = 'No images have been attached to this entry.  You need to upload or attach an image to the entry before you can insert it.';
+$string['addone'] = 'Add one';
+$string['noimageshavebeenattachedtothispost'] = 'No images have been attached to this entry. You need to upload or attach an image to the entry before you can insert it.';
 $string['nofilesattachedtothispost'] = 'No attached files';
 $string['noresults'] = 'No journal entries found';
 $string['olderposts'] = 'Older entries';
 $string['post'] = 'entry';
-$string['postbody'] = 'Body';
+$string['postbody'] = 'Entry';
 $string['postbodydesc'] = ' ';
 $string['postedon'] = 'Posted on';
 $string['postedbyon'] = 'Posted by %s on %s';
 $string['posttitle'] = 'Title';
 $string['posts'] = 'entries';
 $string['publish'] = 'Publish';
-$string['publishfailed'] = 'An error occurred.  Your entry was not published';
+$string['publishfailed'] = 'An error occurred. Your entry was not published';
 $string['publishblogpost?'] = 'Are you sure you want to publish this entry?';
 $string['published'] = 'Published';
 $string['remove'] = 'Remove';
 $string['save'] = 'Save';
-$string['saveandpublish'] = 'Save and Publish';
-$string['saveasdraft'] = 'Save as Draft';
+$string['saveandpublish'] = 'Save and publish';
+$string['saveasdraft'] = 'Save as draft';
 $string['savepost'] = 'Save entry';
-$string['savesettings'] = 'Save Settings';
+$string['savesettings'] = 'Save settings';
 $string['settings'] = 'Settings';
 $string['thisisdraft'] = 'This entry is a draft';
 $string['thisisdraftdesc'] = 'When your entry is a draft, no one except you can see it.';
 $string['title'] = 'Title';
 $string['update'] = 'Update';
 $string['verticalspace'] = 'Vertical space';
-$string['viewblog'] = 'View Journal';
+$string['viewblog'] = 'View journal';
 $string['youarenottheownerofthisblog'] = 'You are not the owner of this journal';
 $string['youarenottheownerofthisblogpost'] = 'You are not the owner of this journal entry';
-$string['cannotdeleteblogpost'] = 'An error occured removing this journal entry.';
+$string['cannotdeleteblogpost'] = 'An error occurred removing this journal entry.';
 
 $string['baseline'] = 'Baseline';
 $string['top'] = 'Top';
