@@ -410,6 +410,35 @@ class ArtefactTypeBlog extends ArtefactType {
             ),
         ));
     }
+
+    /**
+     * During the copying of a view, we might be allowed to copy
+     * blogs. Users need to have multipleblogs enabled for these
+     * to be visible.
+     */
+    public function default_parent_for_copy(&$view, &$template, $artefactstoignore) {
+        global $USER, $SESSION;
+
+        $viewid = $view->get('id');
+
+        try {
+            $user = get_user($view->get('owner'));
+            set_account_preference($user->id, 'multipleblogs', 1);
+            $SESSION->add_ok_msg(get_string('copiedblogpoststonewjournal', 'collection'));
+        }
+        catch (Exception $e) {
+            $SESSION->add_error_msg(get_string('unabletosetmultipleblogs', 'error', $user->username, $viewid, get_config('wwwroot') . 'account/'), false);
+        }
+
+        try {
+            $USER->accountprefs = load_account_preferences($user->id);
+        }
+        catch (Exception $e) {
+            $SESSION->add_error_msg(get_string('pleaseloginforjournals', 'error'));
+        }
+
+        return null;
+    }
 }
 
 /**
@@ -907,13 +936,16 @@ class ArtefactTypeBlogPost extends ArtefactType {
      * blog to hold the copied posts.
      */
     public function default_parent_for_copy(&$view, &$template, $artefactstoignore) {
-        static $blogid;
+        static $blogids;
+        global $USER, $SESSION;
 
-        if (!empty($blogid)) {
-            return $blogid;
+        $viewid = $view->get('id');
+
+        if (isset($blogids[$viewid])) {
+            return $blogids[$viewid];
         }
 
-        $blogname = get_string('viewposts', 'artefact.blog', $view->get('id'));
+        $blogname = get_string('viewposts', 'artefact.blog', $viewid);
         $data = (object) array(
             'title'       => $blogname,
             'description' => get_string('postscopiedfromview', 'artefact.blog', $template->get('title')),
@@ -924,9 +956,25 @@ class ArtefactTypeBlogPost extends ArtefactType {
         $blog = new ArtefactTypeBlog(0, $data);
         $blog->commit();
 
-        $blogid = $blog->get('id');
+        $blogids[$viewid] = $blog->get('id');
 
-        return $blogid;
+        try {
+            $user = get_user($view->get('owner'));
+            set_account_preference($user->id, 'multipleblogs', 1);
+            $SESSION->add_ok_msg(get_string('copiedblogpoststonewjournal', 'collection'));
+        }
+        catch (Exception $e) {
+            $SESSION->add_error_msg(get_string('unabletosetmultipleblogs', 'error', $user->username, $viewid, get_config('wwwroot') . 'account/'), false);
+        }
+
+        try {
+            $USER->accountprefs = load_account_preferences($user->id);
+        }
+        catch (Exception $e) {
+            $SESSION->add_error_msg(get_string('pleaseloginforjournals', 'error'));
+        }
+
+        return $blogids[$viewid];
     }
 
     /**
