@@ -251,7 +251,22 @@ class ArtefactTypeComment extends ArtefactType {
         return array('author', 'owner', 'admin');
     }
 
-    public static function get_comments($limit=10, $offset=0, $showcomment=null, &$view=null, &$artefact=null) {
+    /**
+     * Generates data object required for displaying comments on the page.
+     *
+     * @param  int $limit              The number of comments to display (set to
+     *                                 0 for disabling pagination and showing all comments)
+     * @param  int $offset             The offset of comments used for pagination
+     * @param  int|string $showcomment Optionally show page with particular comment
+     *                                 on it or the last page. $offset will be ignored.
+     *                                 Specify either comment_id or 'last' respectively.
+     *                                 Set to null to use $offset for pagination.
+     * @param  object $view            The view object
+     * @param  object $artefact        Optional artefact object
+     * @param  bool   $export          Determines if comments are fetched for html export purposes
+     * @return object $result          Comments data object
+     */
+    public static function get_comments($limit=10, $offset=0, $showcomment, &$view, &$artefact=null, $export=false) {
         global $USER;
         $userid = $USER->get('id');
         $viewid = $view->get('id');
@@ -262,7 +277,7 @@ class ArtefactTypeComment extends ArtefactType {
             $artefactid = $artefact->get('id');
         }
         else {
-            $canedit = $USER->can_edit_view($view);
+            $canedit = $USER->can_moderate_view($view);
             $owner = $view->get('owner');
             $isowner = $userid && $userid == $owner;
             $artefactid = null;
@@ -276,6 +291,7 @@ class ArtefactTypeComment extends ArtefactType {
             'canedit'  => $canedit,
             'owner'    => $owner,
             'isowner'  => $isowner,
+            'export'   => $export,
             'data'     => array(),
         );
 
@@ -295,30 +311,34 @@ class ArtefactTypeComment extends ArtefactType {
             WHERE ' . $where);
 
         if ($result->count > 0) {
-            if ($showcomment == 'last') { // Ignore $offset and just get the last page of feedback
-                $result->forceoffset = $offset = (ceil($result->count / $limit) - 1) * $limit;
-            }
-            else if (is_numeric($showcomment)) {
-                // Ignore $offset and get the page that has the comment
-                // with id $showcomment on it.
-                // Fetch everything up to $showcomment to get its rank
-                // This will get ugly if there are 1000s of comments
-                $ids = get_column_sql('
-                SELECT a.id
-                FROM {artefact} a JOIN {artefact_comment_comment} c ON a.id = c.artefact
-                WHERE ' . $where . ' AND a.id <= ?
-                ORDER BY a.ctime', array($showcomment));
-                $last = end($ids);
-                if ($last == $showcomment) {
-                    $rank = key($ids);
-                    $result->forceoffset = $offset = ((ceil($rank / $limit) - 1) * $limit);
-                    $result->showcomment = $showcomment;
+            // If pagination is in use, see if we want to get a page with particular comment
+            if ($limit) {
+                if ($showcomment == 'last') {
+                    // If we have limit (pagination is used) ignore $offset and just get the last page of feedback.
+                    $result->forceoffset = $offset = (ceil($result->count / $limit) - 1) * $limit;
+                }
+                else if (is_numeric($showcomment)) {
+                    // Ignore $offset and get the page that has the comment
+                    // with id $showcomment on it.
+                    // Fetch everything up to $showcomment to get its rank
+                    // This will get ugly if there are 1000s of comments
+                    $ids = get_column_sql('
+                    SELECT a.id
+                    FROM {artefact} a JOIN {artefact_comment_comment} c ON a.id = c.artefact
+                    WHERE ' . $where . ' AND a.id <= ?
+                    ORDER BY a.ctime', array($showcomment));
+                    $last = end($ids);
+                    if ($last == $showcomment) {
+                        $rank = key($ids);
+                        $result->forceoffset = $offset = ((ceil($rank / $limit) - 1) * $limit);
+                        $result->showcomment = $showcomment;
+                    }
                 }
             }
 
             $comments = get_records_sql_assoc('
                 SELECT
-                    a.id, a.author, a.authorname, a.ctime, a.description,
+                    a.id, a.author, a.authorname, a.ctime, a.mtime, a.description,
                     c.private, c.deletedby, c.requestpublic, c.rating,
                     u.username, u.firstname, u.lastname, u.preferredname, u.email, u.staff, u.admin,
                     u.deleted, u.profileicon
@@ -344,7 +364,7 @@ class ArtefactTypeComment extends ArtefactType {
         return $result;
     }
 
-    public static function count_comments(&$viewids=null, &$artefactids=null) {
+    public static function count_comments($viewids=null, $artefactids=null) {
         if (!empty($viewids)) {
             return get_records_sql_assoc('
                 SELECT c.onview, COUNT(c.artefact) AS comments
@@ -404,6 +424,9 @@ class ArtefactTypeComment extends ArtefactType {
         foreach ($data->data as &$item) {
             $item->ts = strtotime($item->ctime);
             $item->date = format_date($item->ts, 'strftimedatetime');
+            if ($item->ts < strtotime($item->mtime)) {
+                $item->updated = format_date(strtotime($item->mtime), 'strftimedatetime');
+            }
             $item->isauthor = $item->author && $item->author == $USER->get('id');
             if (!empty($item->attachments)) {
                 if ($data->isowner) {
@@ -476,15 +499,12 @@ class ArtefactTypeComment extends ArtefactType {
             }
 
             if (get_config_plugin('artefact', 'comment', 'commentratings') and $item->rating) {
-                $item->rating = valid_rating($item->rating);
-                $item->ratingimage = '';
-                for ($i = MIN_RATING; $i <= MAX_RATING; $i++) {
-                    $checked = '';
-                    if ($i === $item->rating) {
-                        $checked = 'checked="checked"';
-                    }
-                    $item->ratingimage .= '<input name="star'.$item->id.'" type="radio" class="star" '.$checked.' disabled="disabled"/>';
-                }
+                $item->ratingdata = (object) array(
+                    'value' => valid_rating($item->rating),
+                    'min_rating' => MIN_RATING,
+                    'max_rating' => MAX_RATING,
+                    'export' => $data->export,
+                );
             }
         }
 
@@ -635,16 +655,19 @@ class ArtefactTypeComment extends ArtefactType {
         return empty($this->deletedby);
     }
 
-    public function get_view_url($viewid, $showcomment=true) {
+    public function get_view_url($viewid, $showcomment=true, $full=true) {
         if ($artefact = $this->get('onartefact')) {
-            $url = get_config('wwwroot') . 'view/artefact.php?view=' . $viewid . '&artefact=' . $artefact;
+            $url = 'view/artefact.php?view=' . $viewid . '&artefact=' . $artefact;
         }
         else {
-            $url = get_config('wwwroot') . 'view/view.php?id=' . $viewid;
+            $url = 'view/view.php?id=' . $viewid;
         }
         if ($showcomment) {
             $url .= '&showcomment=' . $this->get('id');
         }
+        if ($full) {
+            $url = get_config('wwwroot') . $url;
+        }
         return $url;
     }
 
@@ -727,7 +750,8 @@ function make_public_submit(Pieform $form, $values) {
 
     $comment = new ArtefactTypeComment((int) $values['comment']);
 
-    $url = $comment->get_view_url($view->get('id'));
+    $relativeurl = $comment->get_view_url($view->get('id'), true, false);
+    $url = get_config('wwwroot') . $relativeurl;
 
     $author    = $comment->get('author');
     $owner     = $comment->get('owner');
@@ -785,7 +809,7 @@ function make_public_submit(Pieform $form, $values) {
             ),
         ),
         'users'     => array($userid),
-        'url'       => $url,
+        'url'       => $relativeurl,
     );
     activity_occurred('maharamessage', $data);
     db_commit();
@@ -811,10 +835,10 @@ function delete_comment_submit(Pieform $form, $values) {
 
     $viewid = $view->get('id');
     if ($artefact = $comment->get('onartefact')) {
-        $url = get_config('wwwroot') . 'view/artefact.php?view=' . $viewid . '&artefact=' . $artefact;
+        $url = 'view/artefact.php?view=' . $viewid . '&artefact=' . $artefact;
     }
     else {
-        $url = get_config('wwwroot') . 'view/view.php?id=' . $viewid;
+        $url = 'view/view.php?id=' . $viewid;
     }
 
     db_begin();
@@ -866,7 +890,7 @@ function delete_comment_submit(Pieform $form, $values) {
     db_commit();
 
     $SESSION->add_ok_msg(get_string('commentremoved', 'artefact.comment'));
-    redirect($url);
+    redirect(get_config('wwwroot') . $url);
 }
 
 function add_feedback_form_validate(Pieform $form, $values) {
@@ -938,7 +962,8 @@ function add_feedback_form_submit(Pieform $form, $values) {
 
     $comment->commit();
 
-    $goto = $comment->get_view_url($view->get('id'));
+    $url = $comment->get_view_url($view->get('id'), true, false);
+    $goto = get_config('wwwroot') . $url;
 
     if (isset($data->requestpublic) && $data->requestpublic === 'author' && $data->owner) {
         $arg = $author ? display_name($USER, null, true) : $data->authorname;
@@ -962,7 +987,7 @@ function add_feedback_form_submit(Pieform $form, $values) {
                 ),
             ),
             'users'     => array($data->owner),
-            'url'       => $goto,
+            'url'       => $url,
         );
     }
 
@@ -1077,8 +1102,7 @@ class ActivityTypeArtefactCommentFeedback extends ActivityTypePlugin {
                 $userid = $artefactinstance->get('owner');
             }
             if (empty($this->url)) {
-                $this->url = get_config('wwwroot') . 'view/artefact.php?artefact='
-                    . $onartefact . '&view=' . $this->viewid;
+                $this->url = 'view/artefact.php?artefact=' . $onartefact . '&view=' . $this->viewid;
             }
         }
         else { // feedback on view.
@@ -1088,7 +1112,7 @@ class ActivityTypeArtefactCommentFeedback extends ActivityTypePlugin {
             }
             $userid = $viewrecord->owner;
             if (empty($this->url)) {
-                $this->url = get_config('wwwroot') . 'view/view.php?id=' . $onview;
+                $this->url = 'view/view.php?id=' . $onview;
             }
         }
         if (empty($userid)) {
@@ -1122,11 +1146,11 @@ class ActivityTypeArtefactCommentFeedback extends ActivityTypePlugin {
             // Email
             $this->users[0]->htmlmessage = get_string_from_language(
                 $lang, 'feedbackdeletedhtml', 'artefact.comment',
-                hsc($title), $removedbyline, clean_html($body), $this->url, hsc($title)
+                hsc($title), $removedbyline, clean_html($body), get_config('wwwroot') . $this->url, hsc($title)
             );
             $this->users[0]->emailmessage = get_string_from_language(
                 $lang, 'feedbackdeletedtext', 'artefact.comment',
-                $title, $removedbyline, trim(html2text($body)), $title, $this->url
+                $title, $removedbyline, trim(html2text($body)), $title, get_config('wwwroot') . $this->url
             );
             return;
         }
@@ -1147,11 +1171,11 @@ class ActivityTypeArtefactCommentFeedback extends ActivityTypePlugin {
 
         $this->users[0]->htmlmessage = get_string_from_language(
             $lang, 'feedbacknotificationhtml', 'artefact.comment',
-            hsc($authorname), hsc($title), $posttime, clean_html($body), $this->url
+            hsc($authorname), hsc($title), $posttime, clean_html($body), get_config('wwwroot') . $this->url
         );
         $this->users[0]->emailmessage = get_string_from_language(
             $lang, 'feedbacknotificationtext', 'artefact.comment',
-            $authorname, $title, $posttime, trim(html2text($body)), $this->url
+            $authorname, $title, $posttime, trim(html2text($body)), get_config('wwwroot') . $this->url
         );
     }
 
