@@ -27,7 +27,7 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'A Folder';
-$string['description'] = 'A single folder from your Files area';
+$string['title'] = 'Folder';
+$string['description'] = 'A single folder from your files area';
 
 $string['defaulttitledescription'] = 'If you leave this blank, the title of the folder will be used';
