@@ -28,4 +28,4 @@
 defined('INTERNAL') || die();
 
 $string['title'] = 'Some HTML';
-$string['description'] = 'A single html file from your Files area';
+$string['description'] = 'A single html file from your files area';
