@@ -271,5 +271,126 @@ function xmldb_artefact_file_upgrade($oldversion=0) {
         }
     }
 
+    if ($oldversion < 2011052500) {
+        // Set default quota to 50MB
+        set_config_plugin('artefact', 'file', 'defaultgroupquota', 52428800);
+    }
+
+    if ($oldversion < 2011070700) {
+
+        // Create an images folder for everyone with a profile icon
+        $imagesdir = get_string('imagesdir', 'artefact.file');
+        $imagesdirdesc = get_string('imagesdirdesc', 'artefact.file');
+
+        execute_sql("
+            INSERT INTO {artefact} (artefacttype, container, owner, ctime, mtime, atime, title, description, author)
+            SELECT 'folder', 1, owner, current_timestamp, current_timestamp, current_timestamp, ?, ?, owner
+            FROM {artefact} WHERE owner IS NOT NULL AND artefacttype = 'profileicon'
+            GROUP BY owner",
+            array($imagesdir, $imagesdirdesc)
+        );
+
+        // Put profileicons into the images folder and update the description
+        $profileicondesc = get_string('uploadedprofileicon', 'artefact.file');
+
+        if (is_postgres()) {
+            execute_sql("
+                UPDATE {artefact}
+                SET parent = f.folderid, description = ?
+                FROM (
+                    SELECT owner, MAX(id) AS folderid
+                    FROM {artefact}
+                    WHERE artefacttype = 'folder' AND title = ? AND description = ?
+                    GROUP BY owner
+                ) f
+                WHERE artefacttype = 'profileicon' AND {artefact}.owner = f.owner",
+                array($profileicondesc, $imagesdir, $imagesdirdesc)
+            );
+        }
+        else {
+            execute_sql("
+                UPDATE {artefact}, (
+                    SELECT owner, MAX(id) AS folderid
+                    FROM {artefact}
+                    WHERE artefacttype = 'folder' AND title = ? AND description = ?
+                    GROUP BY owner
+                ) f
+                SET parent = f.folderid, description = ?
+                WHERE artefacttype = 'profileicon' AND {artefact}.owner = f.owner",
+                array($imagesdir, $imagesdirdesc, $profileicondesc)
+            );
+        }
+    }
+
+    if ($oldversion < 2011082200) {
+        // video file type
+        if (!get_record('artefact_installed_type', 'plugin', 'file', 'name', 'video')) {
+            insert_record('artefact_installed_type', (object) array('plugin' => 'file', 'name' => 'video'));
+        }
+
+        // update existing records
+        $videotypes = get_records_sql_array('
+            SELECT DISTINCT description
+            FROM {artefact_file_mime_types}
+            WHERE mimetype ' . db_ilike() . ' \'%video%\'', array());
+        if ($videotypes) {
+            $mimetypes = array();
+            foreach ($videotypes as $type) {
+                $mimetypes[] = $type->description;
+            }
+            $files = get_records_sql_array('
+                SELECT *
+                FROM {artefact_file_files}
+                WHERE filetype IN (
+                    SELECT mimetype
+                    FROM {artefact_file_mime_types}
+                    WHERE description IN (' . join(',', array_map('db_quote', array_values($mimetypes))) . ')
+                )', array());
+            if ($files) {
+                $checked = array();
+                foreach ($files as $file) {
+                    $checked[] = $file->artefact;
+                }
+                if (!empty($checked)) {
+                    set_field_select('artefact', 'artefacttype', 'video', "artefacttype = 'file' AND id IN (" . join(',', $checked) . ')', array());
+                }
+            }
+        }
+
+        // audio file type
+        if (!get_record('artefact_installed_type', 'plugin', 'file', 'name', 'audio')) {
+            insert_record('artefact_installed_type', (object) array('plugin' => 'file', 'name' => 'audio'));
+        }
+
+        // update existing records
+        $audiotypes = get_records_sql_array('
+            SELECT DISTINCT description
+            FROM {artefact_file_mime_types}
+            WHERE mimetype ' . db_ilike() . ' \'%audio%\'', array());
+        if ($audiotypes) {
+            $mimetypes = array();
+            foreach ($audiotypes as $type) {
+                $mimetypes[] = $type->description;
+            }
+            $files = get_records_sql_array('
+                SELECT *
+                FROM {artefact_file_files}
+                WHERE filetype IN (
+                    SELECT mimetype
+                    FROM {artefact_file_mime_types}
+                    WHERE description IN (' . join(',', array_map('db_quote', array_values($mimetypes))) . ')
+                 )', array());
+             if ($files) {
+                 $checked = array();
+                 foreach ($files as $file) {
+                     $checked[] = $file->artefact;
+                 }
+                 if (!empty($checked)) {
+                     set_field_select('artefact', 'artefacttype', 'audio', "artefacttype = 'file' AND id IN (" . join(',', $checked) . ')', array());
+                }
+            }
+        }
+    }
+
     return $status;
 }
