@@ -33,6 +33,7 @@ require_once('file.php');
 
 $fileid = param_integer('file');
 $viewid = param_integer('view', null);
+$postid = param_integer('post', null);
 $size   = get_imagesize_parameters();
 $forcedl = param_boolean('download');
 
@@ -47,7 +48,20 @@ else {
 }
 
 if ($viewid && $fileid) {
-    if (!artefact_in_view($fileid, $viewid)) {
+
+    // The user may be trying to download a file that's not in the view, but which has
+    // been attached to public feedback on the view
+    if ($commentid = param_integer('comment', null)) {
+        if (!record_exists('artefact_attachment', 'artefact', $commentid, 'attachment', $fileid)) {
+            throw new AccessDeniedException('');
+        }
+        safe_require('artefact', 'comment');
+        $comment = new ArtefactTypeComment($commentid);
+        if (!$comment->viewable_in($viewid)) {
+            throw new AccessDeniedException('');
+        }
+    }
+    else if (!artefact_in_view($fileid, $viewid)) {
         throw new AccessDeniedException('');
     }
 
@@ -83,7 +97,17 @@ else {
             // Alternatively, if you own the file or you are an admin, it should always work
 
             if (!$USER->can_view_artefact($file)) {
-                throw new AccessDeniedException(get_string('accessdenied', 'error'));
+
+                // Check for images sitting in visible forum posts
+                $visibleinpost = false;
+                if ($postid && $file instanceof ArtefactTypeImage) {
+                    safe_require('interaction', 'forum');
+                    $visibleinpost = PluginInteractionForum::can_see_attached_file($file, $postid);
+                }
+
+                if (!$visibleinpost) {
+                    throw new AccessDeniedException(get_string('accessdenied', 'error'));
+                }
             }
         }
     }
@@ -96,5 +120,3 @@ if ($contenttype = $file->override_content_type()) {
 }
 $options['owner'] = $file->get('owner');
 serve_file($path, $title, $file->get('filetype'), $options);
-
-?>
