@@ -57,7 +57,7 @@ class LeapExportElementFile extends LeapExportElement {
 
     public function add_attachments() {
         $this->filename = $this->exporter->add_attachment($this->artefact->get_path(), $this->artefact->get('title'));
-        $this->add_enclosure_link($this->filename);
+        $this->add_enclosure_link($this->filename, $this->get_content_type());
     }
 
     public function get_content_type() {
@@ -96,5 +96,3 @@ class LeapExportElementProfileIcon extends LeapExportElementFile {
 }
 
 class LeapExportElementArchive extends LeapExportElementFile { }
-
-?>
