@@ -41,8 +41,12 @@ function pieform_element_filebrowser(Pieform $form, $element) {
     $group = $form->get_property('group');
     $institution = $form->get_property('institution');
 
+
+    $formid = $form->get_name();
+    $prefix = $formid . '_' . $element['name'];
+
     if (!empty($element['tabs'])) {
-        $tabdata = pieform_element_filebrowser_configure_tabs($element['tabs']);
+        $tabdata = pieform_element_filebrowser_configure_tabs($element['tabs'], $prefix);
         $smarty->assign('tabs', $tabdata);
         if (!$group && $tabdata['owner'] == 'group') {
             $group = $tabdata['ownerid'];
@@ -79,9 +83,6 @@ function pieform_element_filebrowser(Pieform $form, $element) {
         $smarty->assign('groupinfo', pieform_element_filebrowser_get_groupinfo($group));
     }
 
-    $formid = $form->get_name();
-    $prefix = $formid . '_' . $element['name'];
-
     if ($config['select']) {
         if (function_exists($element['selectlistcallback'])) {
             if ($form->is_submitted() && $form->has_errors() && isset($_POST[$prefix . '_selected']) && is_array($_POST[$prefix . '_selected'])) {
@@ -146,6 +147,10 @@ function pieform_element_filebrowser(Pieform $form, $element) {
         $initjs .= "{$prefix}.selecteddata = {$selectedliststr};";
     }
 
+    if (isset($tabdata)) {
+        $initjs .= "{$prefix}.tabdata = " . json_encode($tabdata) . ';';
+    }
+
     $_PIEFORM_FILEBROWSERS[$prefix]['views_js'] = $initjs;
 
     $initjs .= "addLoadEvent({$prefix}.init);";
@@ -269,7 +274,7 @@ function pieform_element_filebrowser_build_filelist($form, $element, $folder, $h
 }
 
 
-function pieform_element_filebrowser_configure_tabs($viewowner) {
+function pieform_element_filebrowser_configure_tabs($viewowner, $prefix) {
     if ($viewowner['type'] == 'institution' && $viewowner['id'] == 'mahara') {
         // No filebrowser tabs for site views
         return null;
@@ -281,19 +286,19 @@ function pieform_element_filebrowser_configure_tabs($viewowner) {
     $upload = null;
     $selectedsubtab = null;
     if ($viewowner['type'] == 'institution') {
-        $selectedtab = param_variable('owner', 'institution');
+        $selectedtab = param_variable($prefix . '_owner', 'institution');
         $upload = $selectedtab == 'institution';
         $tabs['institution'] = get_string('institutionfiles', 'admin');
     }
     else if ($viewowner['type'] == 'group') {
-        $selectedtab = param_variable('owner', 'group');
+        $selectedtab = param_variable($prefix . '_owner', 'group');
         $upload = $selectedtab == 'group';
         $tabs['user'] = get_string('myfiles', 'artefact.file');
         $tabs['group'] = get_string('groupfiles', 'artefact.file');
     }
     else { // $viewowner['type'] == 'user'
         global $USER;
-        $selectedtab = param_variable('owner', 'user');
+        $selectedtab = param_variable($prefix . '_owner', 'user');
         $upload = $selectedtab == 'user';
         $tabs['user'] = get_string('myfiles', 'artefact.file');
         if ($groups = $USER->get('grouproles')) {
@@ -301,7 +306,7 @@ function pieform_element_filebrowser_configure_tabs($viewowner) {
             require_once(get_config('libroot') . 'group.php');
             $groups = group_get_user_groups($USER->get('id'));
             if ($selectedtab == 'group') {
-                if (!$selectedsubtab = (int) param_variable('ownerid', 0)) {
+                if (!$selectedsubtab = (int) param_variable($prefix . '_ownerid', 0)) {
                     $selectedsubtab = $groups[0]->id;
                 }
                 foreach ($groups as &$g) {
@@ -314,7 +319,7 @@ function pieform_element_filebrowser_configure_tabs($viewowner) {
             $institutions = get_records_select_array('institution', 'name IN (' 
                 . join(',', array_map('db_quote', array_keys($institutions))) . ')');
             if ($selectedtab == 'institution') {
-                if (!$selectedsubtab = param_variable('ownerid', '')) {
+                if (!$selectedsubtab = param_variable($prefix . '_ownerid', '')) {
                     $selectedsubtab = $institutions[0]->name;
                 }
                 $selectedsubtab = hsc($selectedsubtab);
@@ -325,7 +330,13 @@ function pieform_element_filebrowser_configure_tabs($viewowner) {
         }
     }
     $tabs['site'] = get_string('sitefiles', 'admin');
-    return array('tabs' => $tabs, 'subtabs' => $subtabs, 'owner' => $selectedtab, 'ownerid' => $selectedsubtab, 'upload' => $upload);
+    return array(
+        'tabs'    => $tabs,
+        'subtabs' => $subtabs,
+        'owner'   => $selectedtab,
+        'ownerid' => $viewowner['type'] == 'group' ? $viewowner['id'] : $selectedsubtab,
+        'upload'  => $upload
+    );
 }
 
 
@@ -503,39 +514,92 @@ function pieform_element_filebrowser_doupdate(Pieform $form, $element) {
                 'browse'  => 1,
             );
         }
+        else if (is_array($_FILES['userfile']['name'])) {
+            foreach ($_FILES['userfile']['name'] as $filename) {
+                if (empty($filename)) {
+                    // TODO, how to specify which file is in error...
+                    return array(
+                        'error'   => true,
+                        'message' => get_string('filenamefieldisrequired', 'artefact.file'),
+                        'browse'  => 1,
+                    );
+                }
+            }
+        }
     }
 
     if (!empty($_FILES['userfile']['name'])) {
-        if (strlen($_FILES['userfile']['name']) > 1024) {
-            return array(
-                'error'   => true,
-                'message' => get_string('nametoolong', 'artefact.file'),
-            );
-        }
-        else if ($element['config']['uploadagreement'] && !param_boolean($prefix . '_notice', false)) {
-            return array(
-                'error'   => true,
-                'message' => get_string('youmustagreetothecopyrightnotice', 'artefact.file'),
-                'browse'  => 1,
-            );
-        }
-        $result = pieform_element_filebrowser_upload($form, $element, array(
-            'userfile'         => $_FILES['userfile'],
-            'uploadnumber'     => param_integer($prefix . '_uploadnumber'),
-            'uploadfolder'     => $element['folder'] ? $element['folder'] : null,
-            'uploadfoldername' => param_variable($prefix . '_foldername'),
-        ));
-        // If it's a non-js upload, automatically select the newly uploaded file.
-        $result['browse'] = 1;
-        if (!$form->submitted_by_js() && !$result['error'] && !empty($element['config']['select'])) {
-            if (isset($element['selectcallback']) && is_callable($element['selectcallback'])) {
-                $element['selectcallback']($result['highlight']);
+        if (!is_array($_FILES['userfile']['name'])) {
+            if (strlen($_FILES['userfile']['name']) > 1024) {
+                return array(
+                    'error'   => true,
+                    'message' => get_string('nametoolong', 'artefact.file'),
+                );
             }
-            else {
-                $result['select'] = $result['highlight'];
+            else if ($element['config']['uploadagreement'] && !param_boolean($prefix . '_notice', false)) {
+                return array(
+                    'error'   => true,
+                    'message' => get_string('youmustagreetothecopyrightnotice', 'artefact.file'),
+                    'browse'  => 1,
+                );
             }
+            $result = pieform_element_filebrowser_upload($form, $element, array(
+                'userfile'         => $_FILES['userfile'],
+                'uploadnumber'     => param_integer($prefix . '_uploadnumber'),
+                'uploadfolder'     => $element['folder'] ? $element['folder'] : null,
+                'uploadfoldername' => param_variable($prefix . '_foldername'),
+            ));
+            // If it's a non-js upload, automatically select the newly uploaded file.
+            $result['browse'] = 1;
+            if (!$form->submitted_by_js() && !$result['error'] && !empty($element['config']['select'])) {
+                if (isset($element['selectcallback']) && is_callable($element['selectcallback'])) {
+                    $element['selectcallback']($result['highlight']);
+                }
+                else {
+                    $result['select'] = $result['highlight'];
+                }
+            }
+            return $result;
+        }
+        else if (!empty($_FILES['userfile']['name'][0])) {
+            if ($element['config']['uploadagreement'] && !param_boolean($prefix . '_notice', false)) {
+                return array(
+                    'error'   => true,
+                    'message' => get_string('youmustagreetothecopyrightnotice', 'artefact.file'),
+                    'browse'  => 1,
+                );
+            }
+            $result = array('multiuploads' => array());
+            $size = sizeof($_FILES['userfile']['name']);
+            for ($i = 0; $i < $size; $i ++) {
+                if (strlen($_FILES['userfile']['name'][$i]) > 1024) {
+                    return array(
+                        'error'   => true,
+                        'message' => get_string('nametoolong', 'artefact.file'),
+                    );
+                }
+                $result['multiuploads'][$i] = pieform_element_filebrowser_upload($form, $element, array(
+                    'userfile'         => $_FILES['userfile'],
+                    'userfileindex'    => $i,
+                    'uploadnumber'     => param_integer($prefix . '_uploadnumber') - ($size - $i - 1),
+                    'uploadfolder'     => $element['folder'] ? $element['folder'] : null,
+                    'uploadfoldername' => param_variable($prefix . '_foldername'),
+                ));
+                // TODO, what to do here...
+                // If it's a non-js upload, automatically select the newly uploaded file.
+                $result['multiuploads'][$i]['browse'] = 1;
+                if (!$form->submitted_by_js() && !$result['multiuploads'][$i]['error'] && !empty($element['config']['select'])) {
+                    if (isset($element['selectcallback']) && is_callable($element['selectcallback'])) {
+                        $element['selectcallback']($result['multiuploads'][$i]['highlight']);
+                    }
+                    else {
+                        $result['multiuploads'][$i]['select'] = $result['multiuploads'][$i]['highlight'];
+                    }
+                }
+                $result['multiuploads'][$i]['folder'] = $element['folder'];
+            }
+            return $result;
         }
-        return $result;
     }
 
     if (!$form->submitted_by_js()) {
@@ -630,6 +694,7 @@ function pieform_element_filebrowser_upload(Pieform $form, $element, $data) {
     $selectable       = (int) $element['config']['select'];
     $querybase        = $element['page'] . (strpos($element['page'], '?') === false ? '?' : '&');
     $prefix           = $form->get_name() . '_' . $element['name'];
+    $userfileindex    = isset($data['userfileindex']) ? $data['userfileindex'] : null;
 
     $result = array('error' => false, 'uploadnumber' => $uploadnumber);
 
@@ -678,23 +743,40 @@ function pieform_element_filebrowser_upload(Pieform $form, $element, $data) {
 
     $data->container = 0;
 
-    $originalname = $_FILES['userfile']['name'];
+    if (isset($userfileindex)) {
+        $originalname = $_FILES['userfile']['name'][$userfileindex];
+    }
+    else {
+        $originalname = $_FILES['userfile']['name'];
+    }
     $originalname = $originalname ? basename($originalname) : get_string('file', 'artefact.file');
     $data->title = ArtefactTypeFileBase::get_new_file_title($originalname, $parentfolder, $data->owner, $group, $institution);
 
     try {
-        $newid = ArtefactTypeFile::save_uploaded_file('userfile', $data);
+        $newid = ArtefactTypeFile::save_uploaded_file('userfile', $data, $userfileindex);
     }
     catch (QuotaExceededException $e) {
         prepare_upload_failed_message($result, $e, $parentfoldername, $originalname);
         // update the file listing
-        $result['quota'] = $USER->get('quota');
-        $result['quotaused'] = $USER->get('quotaused');
+        if (defined('GROUP')) {
+            $group = group_current_group();
+            $result['quota'] = $group->quota;
+            $result['quotaused'] = $group->quotaused;
+        }
+        else {
+            $result['quota'] = $USER->get('quota');
+            $result['quotaused'] = $USER->get('quotaused');
+        }
         $result['newlist'] = pieform_element_filebrowser_build_filelist($form, $element, $parentfolder);
         return $result;
     }
     catch (UploadException $e) {
         prepare_upload_failed_message($result, $e, $parentfoldername, $originalname);
+        if (defined('GROUP')) {
+            $group = group_current_group();
+            $result['quota'] = $group->quota;
+            $result['quotaused'] = $group->quotaused;
+        }
         return $result;
     }
 
@@ -736,8 +818,15 @@ function pieform_element_filebrowser_upload(Pieform $form, $element, $data) {
     $result['highlight'] = $newid;
     $result['uploaded'] = true;
     $result['newlist'] = pieform_element_filebrowser_build_filelist($form, $element, $parentfolder, $newid);
-    $result['quota'] = $USER->get('quota');
-    $result['quotaused'] = $USER->get('quotaused');
+    if (defined('GROUP')) {
+        $group = group_current_group();
+        $result['quota'] = $group->quota;
+        $result['quotaused'] = $group->quotaused;
+    }
+    else {
+        $result['quota'] = $USER->get('quota');
+        $result['quotaused'] = $USER->get('quotaused');
+    }
     $result['maxuploadsize'] = display_size(get_max_upload_size(!$institution && !$group));
     return $result;
 }
@@ -771,7 +860,7 @@ function pieform_element_filebrowser_createfolder(Pieform $form, $element, $data
     $data = (object) array(
         'parent'      => $parentfolder,
         'owner'       => null,
-        'title'       => $data['title'],
+        'title'       => trim($data['title']),
     );
 
     if ($parentfolder) {
@@ -809,6 +898,7 @@ function pieform_element_filebrowser_createfolder(Pieform $form, $element, $data
         'message'   => get_string('foldercreated', 'artefact.file'),
         'highlight' => $f->get('id'),
         'newlist'   => pieform_element_filebrowser_build_filelist($form, $element, $parentfolder, $f->get('id')),
+        'foldercreated' => true,
     );
 }
 
@@ -848,7 +938,7 @@ function pieform_element_filebrowser_update(Pieform $form, $element, $data) {
         }
     }
 
-    $artefact->set('title', $data['title']);
+    $artefact->set('title', trim($data['title']));
     $artefact->set('description', $data['description']);
     $artefact->set('allowcomments', (int) $data['allowcomments']);
 
@@ -900,22 +990,31 @@ function pieform_element_filebrowser_delete(Pieform $form, $element, $artefact)
     }
 
     if (!$USER->can_edit_artefact($artefact) || $artefact->get('locked')) {
-        return array('error' => true, get_string('nodeletepermission', 'mahara'));
+        return array('error' => true, 'message' => get_string('nodeletepermission', 'mahara'));
     }
     $parentfolder = $artefact->get('parent');
     $artefact->delete();
-    return array(
+
+    $result = array(
         'error' => false,
         'deleted' => true,
         'message' => get_string('filethingdeleted', 'artefact.file',
                                 get_string($artefact->get('artefacttype'), 'artefact.file') . ' ' . $artefact->get('title')),
-        'quotaused' => $USER->get('quotaused'),
-        'quota' => $USER->get('quota'),
         'maxuploadsize' => display_size(get_max_upload_size(!$institution && !$group)),
         'newlist' => pieform_element_filebrowser_build_filelist($form, $element, $parentfolder),
     );
-}
 
+    if (defined('GROUP')) {
+        $group = group_current_group();
+        $result['quota'] = $group->quota;
+        $result['quotaused'] = $group->quotaused;
+    }
+    else {
+        $result['quota'] = $USER->get('quota');
+        $result['quotaused'] = $USER->get('quotaused');
+    }
+    return $result;
+}
 
 function pieform_element_filebrowser_move(Pieform $form, $element, $data) {
     global $USER;
@@ -1032,9 +1131,10 @@ function pieform_element_filebrowser_edit_group_folder($group, $folder) {
 
 
 function pieform_element_filebrowser_changeowner(Pieform $form, $element) {
-    $newtabdata = pieform_element_filebrowser_configure_tabs($element['tabs']);
+    $prefix = $form->get_name() . '_' . $element['name'];
+    $newtabdata = pieform_element_filebrowser_configure_tabs($element['tabs'], $prefix);
     $smarty = smarty_core();
-    $smarty->assign('prefix', $form->get_name() . '_' . $element['name']);
+    $smarty->assign('prefix', $prefix);
     $smarty->assign('querybase', $element['page'] . (strpos($element['page'], '?') === false ? '?' : '&'));
     $smarty->assign('tabs', $newtabdata);
     $newtabhtml = $smarty->fetch('artefact:file:form/ownertabs.tpl');
@@ -1065,7 +1165,7 @@ function pieform_element_filebrowser_changeowner(Pieform $form, $element) {
         'error'         => false, 
         'changedowner'  => true,
         'changedfolder' => true,
-        'tabupload'     => $newtabdata['upload'],
+        'newtabdata'    => $newtabdata,
         'folder'        => $folder,
         'disableedit'   => $group && !pieform_element_filebrowser_edit_group_folder($group, $folder),
         'newlist'       => pieform_element_filebrowser_build_filelist($form, $element, $folder, null, $user, $group, $institution),
@@ -1079,12 +1179,14 @@ function pieform_element_filebrowser_changeowner(Pieform $form, $element) {
 function pieform_element_filebrowser_changefolder(Pieform $form, $element, $folder) {
     $owner = $ownerid = $group = $institution = $user = null;
 
+    $prefix = $form->get_name() . '_' . $element['name'];
+
     if (isset($element['tabs'])) {
-        if ($owner = param_variable('owner', null)) {
+        if ($owner = param_variable($prefix . '_owner', null)) {
             if ($owner == 'site') {
                 $owner = 'institution';
                 $institution = $ownerid = 'mahara';
-            } else if ($ownerid = param_variable('ownerid', null)) {
+            } else if ($ownerid = param_variable($prefix . '_ownerid', null)) {
                 if ($owner == 'group') {
                     $group = (int) $ownerid;
                 }
