@@ -60,7 +60,10 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
 
     this.upload_init = function () {
         if ($(self.id + '_notice')) {
-            setNodeAttribute(self.id + '_userfile', 'disabled', true);
+            // If the file input is disabled immediately without this delay, later javascript changes
+            // to the filebrowser are not rendered by Chrome when the filebrowser is inside a block
+            // configuration form.
+            callLater(0.0001, function() { setNodeAttribute(self.id + '_userfile', 'disabled', true); });
         }
         if (!$(self.id + '_upload')) {
             insertSiblingNodesAfter(self.id + '_uploadnumber', INPUT({
@@ -117,14 +120,18 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
 
     this.upload_presubmit = function (e) {
         // Display upload status
-        self.nextupload++;
-        var localname = basename($(self.id + '_userfile').value);
-        var message = makeMessage(DIV(null,
-            IMG({'src':get_themeurl('images/loading.gif')}), ' ',
-            get_string('uploadingfiletofolder',localname,self.foldername)
-        ), 'info');
-        setNodeAttribute(message, 'id', 'uploadstatusline' + self.nextupload);
-        appendChildNodes(self.id + '_upload_messages', message);
+        if ($(self.id + '_userfile').files) {
+            for (var i = 0; i < $(self.id + '_userfile').files.length; ++ i) {
+                self.nextupload++;
+                var localname = $(self.id + '_userfile').files[i].fileName;
+                var message = makeMessage(DIV(null,
+                    IMG({'src':get_themeurl('images/loading.gif')}), ' ',
+                    get_string('uploadingfiletofolder',localname,self.foldername)
+                    ), 'info');
+                setNodeAttribute(message, 'id', 'uploadstatusline' + self.nextupload);
+                appendChildNodes(self.id + '_upload_messages', message);
+            }
+        }
         $(self.id+'_uploadnumber').value = self.nextupload;
         return true;
     }
@@ -144,7 +151,8 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
             'type':'file',
             'class':'file',
             'id':self.id+'_userfile',
-            'name':'userfile',
+            'name':'userfile[]',
+            'multiple':'',
             'size':40
         }));
         if (!$(self.id + '_uploadsubmit')) {
@@ -256,6 +264,13 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         var id = getNodeAttribute(this, 'name').replace(/.*_edit\[(\d+)\]$/, '$1');
         self.hide_edit_form();
         $(self.id + '_edit_heading').innerHTML = self.filedata[id].artefacttype == 'folder' ? get_string('editfolder') : get_string('editfile');
+        var descriptionrow = getFirstParentByTagAndClassName($(self.id + '_edit_description'), 'tr');
+        if (self.filedata[id].artefacttype == 'profileicon') {
+            addElementClass(descriptionrow, 'hidden');
+        }
+        else {
+            removeElementClass(descriptionrow, 'hidden');
+        }
         $(self.id + '_edit_title').value = self.filedata[id].title;
         $(self.id + '_edit_description').value = self.filedata[id].description == null ? '' : self.filedata[id].description;
         $(self.id + '_edit_allowcomments').checked = self.filedata[id].allowcomments;
@@ -311,6 +326,9 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                             }
                             if (self.filedata[id].childcount > 0) {
                                 warn += get_string('foldernotempty') + ' ';
+                                if (self.filedata[id].profileiconcount > 0) {
+                                    warn += get_string('foldercontainsprofileicons', self.filedata[id].profileiconcount) + ' ';
+                                }
                                 warn += get_string('confirmdeletefolderandcontents');
                             }
                             else if (warn != '') {
@@ -318,8 +336,11 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                             }
                         }
                         else {
+                            if (self.filedata[id].defaultprofileicon == id) {
+                                warn += get_string('defaultprofileicon') + ' ';
+                            }
                             if (self.filedata[id].attachcount > 0) {
-                                warn += get_string('fileattached', self.filedata[id].attachcount) + ' ';
+                                warn += get_string('fileattachedtoportfolioitems', self.filedata[id].attachcount) + ' ';
                             }
                             if (self.filedata[id].viewcount > 0) {
                                 warn += get_string('fileappearsinviews') + ' ';
@@ -356,6 +377,7 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                     self.make_icon_draggable(elem);
                 });
                 forEach(getElementsByTagAndClassName('tr', 'folder', self.id + '_filelist'), self.make_row_droppable);
+                forEach(getElementsByTagAndClassName('a', 'changefolder', self.id + '_foldernav'), self.make_folderlink_droppable);
             }
         }
         forEach(getElementsByTagAndClassName('a', 'changeowner', self.id + '_upload_browse'), function (elem) {
@@ -427,6 +449,25 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         undoPositioned(row);
     };
 
+    this.make_folderlink_droppable = function(link) {
+        new Droppable(link, {
+            accept: ['icon-drag-current'],
+            hoverclass: 'folderhover',
+            ondrop: function (dragged, dropped) {
+                var dragid = dragged.id.replace(/^.*drag:(\d+)$/, '$1');
+                var dropid = dropped.href.replace(/^.*\?folder=(\d+)$/, '$1');
+                if (dragid == dropid) {
+                    return;
+                }
+                $(self.id + '_move').value = dragid;
+                $(self.id + '_moveto').value = dropid;
+                self.submitform();
+                $(self.id + '_move').value = '';
+                $(self.id + '_moveto').value = '';
+            }
+        });
+    };
+
     this.drag = {};
 
     this.make_icon_draggable = function(elem) {
@@ -545,9 +586,16 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
         }
         var remove = INPUT({'type': 'submit', 'class':'button small unselect', 'name':self.id+'_unselect[' + id + ']', 'value':get_string('remove')});
         connect(remove, 'onclick', self.unselect);
+        filelink = ''
+        if (self.filedata[id].artefacttype == 'folder') {
+            filelink = self.filedata[id].title;
+        }
+        else {
+            filelink = A({'href':self.config.wwwroot + 'artefact/file/download.php?file=' + id, 'target':'_blank'}, self.filedata[id].title);
+        }
         appendChildNodes(tbody, TR({'class': 'r' + rows.length % 2 + (highlight ? ' highlight-file' : '')},
                                    TD(null, IMG({'src':self.filedata[id].icon})),
-                                   TD(null, A({'href':self.config.wwwroot + 'artefact/file/download.php?file=' + id, 'target':'_blank'}, self.filedata[id].title)),
+                                   TD(null, filelink),
                                    TD(null, self.filedata[id].description),
                                    TD(null, remove, INPUT({'type':'hidden', 'name':self.id+'_selected[' + id + ']', 'value':id}))
                                   ));
@@ -588,6 +636,12 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
     }
 
     this.callback = function (form, data) {
+        if (data.multiuploads) {
+            for (var i in data.multiuploads) {
+                self.callback(form, data.multiuploads[i]);
+            }
+            return;
+        }
         self.form = form; // ????
         if (data.uploaded || data.error || data.deleted) {
             self.callback_feedback(data);  // add/update message
@@ -596,6 +650,10 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                 replaceChildNodes(self.id + '_userfile_maxuploadsize', '(' + get_string('maxuploadsize') + ' ' + data.maxuploadsize + ')');
             }
         }
+        // Clear the create folder form
+        if (data.foldercreated && $(self.id + '_createfolder_name')) {
+            $(self.id + '_createfolder_name').value = '';
+        }
         // Only update the file listing if the user hasn't changed folders yet
         if (data.newlist && (data.folder == self.folderid || data.changedfolder)) {
             self.filedata = data.newlist.data;
@@ -607,10 +665,11 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                 $(self.id+'_folder').value = self.folderid = data.folder;
                 $(self.id+'_foldername').value = self.foldername = data.newpath.foldername;
                 $(self.id+'_foldernav').innerHTML = data.newpath.html;
-                if (data.changedowner && data.newtabs) {
+                if (data.changedowner && data.newtabs && data.newtabdata) {
+                    self.tabdata = data.newtabdata;
                     $(self.id+'_ownertabs').innerHTML = data.newtabs;
                     $(self.id+'_ownersubtabs').innerHTML = data.newsubtabs;
-                    if (data.tabupload) {
+                    if (data.newtabdata.upload) {
                         removeElementClass(self.id + '_upload_container', 'hidden');
                     } else {
                         addElementClass(self.id + '_upload_container', 'hidden');
@@ -625,7 +684,9 @@ function FileBrowser(idprefix, folderid, config, globalconfig) {
                         removeElementClass(self.id + '_upload_disabled', 'hidden');
                     }
                     else if (hasElementClass(self.id + '_upload_container', 'hidden') && !data.disableedit) {
-                        removeElementClass(self.id + '_upload_container', 'hidden');
+                        if (!self.tabdata || self.tabdata.upload) {
+                            removeElementClass(self.id + '_upload_container', 'hidden');
+                        }
                         if ($('createfolder')) {
                             removeElementClass('createfolder', 'hidden');
                         }
