@@ -36,6 +36,8 @@ class PluginArtefactFile extends PluginArtefact {
             'image',
             'profileicon',
             'archive',
+            'video',
+            'audio',
         );
     }
     
@@ -89,7 +91,9 @@ class PluginArtefactFile extends PluginArtefact {
 
     public static function postinst($prevversion) {
         if ($prevversion == 0) {
+            // Set default quotas to 50MB
             set_config_plugin('artefact', 'file', 'defaultquota', 52428800);
+            set_config_plugin('artefact', 'file', 'defaultgroupquota', 52428800);
         }
         set_config_plugin('artefact', 'file', 'commentsallowedimage', 1);
         self::resync_filetype_list();
@@ -122,12 +126,14 @@ class PluginArtefactFile extends PluginArtefact {
                     'confirmdeletefile',
                     'confirmdeletefolder',
                     'confirmdeletefolderandcontents',
+                    'defaultprofileicon',
                     'editfile',
                     'editfolder',
                     'fileappearsinviews',
-                    'fileattached',
+                    'fileattachedtoportfolioitems',
                     'filewithnameexists',
                     'folderappearsinviews',
+                    'foldercontainsprofileicons',
                     'foldernamerequired',
                     'foldernotempty',
                     'maxuploadsize',
@@ -215,11 +221,31 @@ class PluginArtefactFile extends PluginArtefact {
         }
     }
 
-    public static function get_mimetypes_from_description($description=null) {
-        if (is_null($description)) {
-            return get_column('artefact_file_mime_types', 'mimetype');
+    public static function get_mimetypes_from_description($description=null, $getrecords=false) {
+        static $allmimetypes = null;
+
+        if (is_null($allmimetypes)) {
+            $allmimetypes = get_records_assoc('artefact_file_mime_types');
         }
-        return get_column('artefact_file_mime_types', 'mimetype', 'description', $description);
+
+        if (is_string($description)) {
+            $description = array($description);
+        }
+
+        $mimetypes = array();
+
+        foreach ($allmimetypes as $r) {
+            if (is_null($description) || in_array($r->description, $description)) {
+                if ($getrecords) {
+                    $mimetypes[$r->mimetype] = $r;
+                }
+                else {
+                    $mimetypes[] = $r->mimetype;
+                }
+            }
+        }
+
+        return $mimetypes;
     }
 
     public static function can_be_disabled() {
@@ -230,20 +256,28 @@ class PluginArtefactFile extends PluginArtefact {
         return array(
             'file'        => array('file'),
             'image'       => array('file', 'image'),
-            'profileicon' => array('image'),
+            'profileicon' => array('file', 'image'),
             'archive'     => array('file'),
+            'video'       => array('file'),
+            'audio'       => array('file'),
         );
     }
 
     public static function get_attachment_types() {
-        return array('file', 'image', 'archive');
+        return array(
+            'file',
+            'image',
+            'archive',
+            'video',
+            'audio'
+        );
     }
 
     public static function recalculate_quota() {
         $data = get_records_sql_assoc("
             SELECT a.owner, SUM(f.size) AS bytes
             FROM {artefact} a JOIN {artefact_file_files} f ON a.id = f.artefact
-            WHERE a.artefacttype IN ('file', 'image', 'profileicon', 'archive')
+            WHERE a.artefacttype IN (" . join(',',  array_map('db_quote', PluginArtefactFile::get_artefact_types())) . ")
             AND a.owner IS NOT NULL
             GROUP BY a.owner", array()
         );
@@ -252,6 +286,21 @@ class PluginArtefactFile extends PluginArtefact {
         }
         return array();
     }
+
+    public static function recalculate_group_quota() {
+
+        $data = get_records_sql_assoc("
+            SELECT a.group, SUM(f.size) AS bytes
+            FROM {artefact} a JOIN {artefact_file_files} f ON a.id = f.artefact
+            WHERE a.artefacttype IN (" . join(',',  array_map('db_quote', PluginArtefactFile::get_artefact_types())) . ")
+            AND a.group IS NOT NULL
+            GROUP BY a.group", array()
+        );
+        if ($data) {
+            return array_map(create_function('$a', 'return $a->bytes;'), $data);
+        }
+        return array();
+    }
 }
 
 abstract class ArtefactTypeFileBase extends ArtefactType {
@@ -285,7 +334,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
     // Check if something exists in the db with a given title and parent,
     // either in adminfiles or with a specific owner.
     public static function file_exists($title, $owner, $folder, $institution=null, $group=null) {
-        $filetypesql = "('" . join("','", array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'))) . "')";
+        $filetypesql = "('" . join("','", PluginArtefactFile::get_artefact_types()) . "')";
         $ownersql = artefact_owner_sql($owner, $group, $institution);
         return get_field_sql('SELECT a.id FROM {artefact} a
             LEFT OUTER JOIN {artefact_file_files} f ON f.artefact = a.id
@@ -318,21 +367,24 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
         global $USER;
         $select = '
             SELECT
-                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments,
-                COUNT(DISTINCT c.id) AS childcount, COUNT (DISTINCT aa.artefact) AS attachcount, COUNT(DISTINCT va.view) AS viewcount';
+                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments, u.profileicon AS defaultprofileicon,
+                COUNT(DISTINCT c.id) AS childcount, COUNT (DISTINCT aa.artefact) AS attachcount, COUNT(DISTINCT va.view) AS viewcount,
+                COUNT(DISTINCT api.id) AS profileiconcount';
         $from = '
             FROM {artefact} a
                 LEFT OUTER JOIN {artefact_file_files} f ON f.artefact = a.id
-                LEFT OUTER JOIN {artefact} c ON c.parent = a.id 
+                LEFT OUTER JOIN {artefact} c ON c.parent = a.id
+                LEFT OUTER JOIN {artefact} api ON api.parent = a.id AND api.artefacttype = \'profileicon\'
                 LEFT OUTER JOIN {view_artefact} va ON va.artefact = a.id
-                LEFT OUTER JOIN {artefact_attachment} aa ON aa.attachment = a.id';
+                LEFT OUTER JOIN {artefact_attachment} aa ON aa.attachment = a.id
+                LEFT OUTER JOIN {usr} u ON a.id = u.profileicon AND a.owner = u.id';
 
         if (!empty($filters['artefacttype'])) {
             $artefacttypes = $filters['artefacttype'];
             $artefacttypes[] = 'folder';
         }
         else {
-            $artefacttypes = array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'));
+            $artefacttypes = PluginArtefactFile::get_artefact_types();
         }
         $where = "
             WHERE a.artefacttype IN (" . join(',',  array_map('db_quote', $artefacttypes)) . ")";
@@ -343,7 +395,8 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
 
         $groupby = '
             GROUP BY
-                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments';
+                a.id, a.artefacttype, a.mtime, f.size, a.title, a.description, a.locked, a.allowcomments,
+                u.profileicon';
 
         $phvals = array();
 
@@ -363,7 +416,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
         }
         else if ($group) {
             $select .= ',
-                r.can_edit, r.can_view, r.can_republish';
+                r.can_edit, r.can_view, r.can_republish, a.author';
             $from .= '
                 LEFT OUTER JOIN (
                     SELECT ar.artefact, ar.can_edit, ar.can_view, ar.can_republish
@@ -374,9 +427,10 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             $phvals[] = $group;
             $phvals[] = $USER->get('id');
             $where .= '
-            AND a.group = ? AND a.owner IS NULL AND r.can_view = 1';
+            AND a.group = ? AND a.owner IS NULL AND (r.can_view = 1 OR a.author = ?)';
             $phvals[] = $group;
-            $groupby .= ', r.can_edit, r.can_view, r.can_republish';
+            $phvals[] = $USER->get('id');
+            $groupby .= ', r.can_edit, r.can_view, r.can_republish, a.author';
         }
         else {
             $where .= '
@@ -407,6 +461,9 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
                 if ($item->size) { // Doing this here now for non-js users
                     $item->size = ArtefactTypeFile::short_size($item->size, true);
                 }
+                if ($group && $item->author == $USER->get('id')) {
+                    $item->can_edit = 1;    // This will show the delete, edit buttons in filelist, but doesn't change the actual permissions in the checkbox
+                }
             }
             $where = 'artefact IN (' . join(',', array_keys($filedata)) . ')';
             $tags = get_records_select_array('artefact_tag', $where);
@@ -500,7 +557,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
     }
 
     public static function count_user_files($owner=null, $group=null, $institution=null) {
-        $filetypes = array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'));
+        $filetypes = PluginArtefactFile::get_artefact_types();
         foreach ($filetypes as $k => $v) {
             if ($v == 'folder') {
                 unset($filetypes[$k]);
@@ -552,6 +609,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
         $ownerkey = $artefact->owner . '::' . $artefact->group . '::' . $artefact->institution;
         if (!isset($folderdata[$ownerkey])) {
             $ownersql = artefact_owner_sql($artefact->owner, $artefact->group, $artefact->institution);
+            $folderdata[$ownerkey] = new stdClass();
             $folderdata[$ownerkey]->data = get_records_select_assoc('artefact', "artefacttype='folder' AND $ownersql", array(), '', 'id, title, parent');
             if ($artefact->group) {
                 $folderdata[$ownerkey]->ownername = get_field('group', 'name', 'id', $artefact->group) . ':';
@@ -586,15 +644,17 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
     }
 
     public function default_parent_for_copy(&$view, &$template, $artefactstoignore) {
-        static $folderid;
+        static $folderids;
 
-        if (!empty($folderid)) {
-            return $folderid;
+        $viewid = $view->get('id');
+
+        if (isset($folderids[$viewid])) {
+            return $folderids[$viewid];
         }
 
         $viewfilesfolder = ArtefactTypeFolder::get_folder_id(get_string('viewfilesdirname', 'view'), get_string('viewfilesdirdesc', 'view'),
                                                              null, true, $view->get('owner'), $view->get('group'), $view->get('institution'), $artefactstoignore);
-        $foldername = $view->get('id');
+        $foldername = $viewid;
         $existing = get_column_sql("
             SELECT title
             FROM {artefact}
@@ -618,9 +678,9 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
         $folder = new ArtefactTypeFolder(0, $data);
         $folder->commit();
 
-        $folderid = $folder->get('id');
+        $folderids[$viewid] = $folder->get('id');
 
-        return $folderid;
+        return $folderids[$viewid];
     }
 
     /**
@@ -652,7 +712,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
 
         $taken = get_column_sql("
             SELECT title FROM {artefact}
-            WHERE artefacttype IN ('" . join("','", array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'))) . "')
+            WHERE artefacttype IN ('" . join("','", PluginArtefactFile::get_artefact_types()) . "')
             AND title LIKE ? || '%' || ? AND " . $where, array($start, $end));
         $taken = array_flip($taken);
 
@@ -673,7 +733,7 @@ abstract class ArtefactTypeFileBase extends ArtefactType {
             'folder'       => (int) param_variable('folder', 0),
             'highlight'    => null,
             'browse'       => true,
-            'page'         => '/view/blocks.php' . View::make_base_url(),
+            'page'         => get_config('wwwroot') . 'view/blocks.php' . View::make_base_url(),
             'config'       => array(
                 'upload'          => true,
                 'uploadagreement' => get_config_plugin('artefact', 'file', 'uploadagreement'),
@@ -786,9 +846,26 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             $data->height   = $imageinfo[1];
             return new ArtefactTypeImage(0, $data);
         }
-        if ($archive = ArtefactTypeArchive::new_archive($path, $data)) {
-            return $archive;
+
+        // If $data->filetype is set here, it's probably the claim made by the
+        // browser during upload or by a Leap2a file.  Generally we believe this
+        // claim, because it gives better results when serving the file on
+        // download.  If there's no claimed mimetype, use file_mime_type to make
+        // a guess, and give each file artefact type access to both the claimed
+        // and guessed mimetypes.
+        $data->guess = file_mime_type($path);
+
+        if (empty($data->filetype) || $data->filetype == 'application/octet-stream') {
+            $data->filetype = $data->guess;
         }
+
+        foreach (array('video', 'audio', 'archive') as $artefacttype) {
+            $classname = 'ArtefactType' . ucfirst($artefacttype);
+            if (call_user_func_array(array($classname, 'is_valid_file'), array($path, &$data))) {
+                return new $classname(0, $data);
+            }
+        }
+
         return new ArtefactTypeFile(0, $data);
     }
 
@@ -802,6 +879,8 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
      * future version. So think twice before using it :)
      */
     public static function save_file($pathname, $data, User &$user=null, $outsidedataroot=false) {
+        global $USER;
+
         $dataroot = get_config('dataroot');
         if (!$outsidedataroot) {
             $pathname = $dataroot . $pathname;
@@ -813,11 +892,6 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         $f = self::new_file($pathname, $data);
         $f->set('size', $size);
 
-        // sometimes the filetype is actually set, assume it is correct
-        if (empty($data->filetype)) {
-            $f->set('filetype', file_mime_type($pathname));
-        }
-
         // if an extension has been provided (only from self::extract() at this stage), use it
         if (!empty($data->extension)) {
             $f->set('oldextension', $data->extension);
@@ -833,13 +907,27 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             $f->delete();
             return false;
         }
-        if (empty($user)) {
-            global $USER;
-            $user = $USER;
+        $owner = null;
+        if ($user) {
+            $owner = $user;
+        }
+        else if ($data->owner == $USER->get('id')) {
+            $owner = $USER;
+            $owner->quota_refresh();
+        }
+        else if (!empty($data->owner)) {
+            $owner = new User;
+            $owner->find_by_id($data->owner);
         }
         try {
-            $user->quota_add($size);
-            $user->commit();
+            if ($owner) {
+                $owner->quota_add($size);
+                $owner->commit();
+            }
+            else if (!empty($data->group)) {
+                require_once('group.php');
+                group_quota_add($data->group, $size);
+            }
             return $id;
         }
         catch (QuotaExceededException $e) {
@@ -855,13 +943,22 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
      * Takes the name of a file input.
      * Returns false for no errors, or a string describing the error.
      */
-    public static function save_uploaded_file($inputname, $data) {
+    public static function save_uploaded_file($inputname, $data, $inputindex=null) {
         require_once('uploadmanager.php');
-        $um = new upload_manager($inputname);
+        $um = new upload_manager($inputname, false, $inputindex);
         if ($error = $um->preprocess_file()) {
             throw new UploadException($error);
         }
-        $size = $um->file['size'];
+        if (isset($inputindex)) {
+            $size = $um->file['size'][$inputindex];
+            $tmpname = $um->file['tmp_name'][$inputindex];
+            $filetype = $um->file['type'][$inputindex];
+        }
+        else {
+            $size = $um->file['size'];
+            $tmpname = $um->file['tmp_name'];
+            $filetype = $um->file['type'];
+        }
         if (!empty($data->owner)) {
             global $USER;
             if ($data->owner == $USER->get('id')) {
@@ -876,19 +973,16 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
                 throw new QuotaExceededException(get_string('uploadexceedsquota', 'artefact.file'));
             }
         }
+        if (!empty($data->group)) {
+            require_once('group.php');
+            if (!group_quota_allowed($data->group, $size)) {
+                throw new QuotaExceededException(get_string('uploadexceedsquota', 'artefact.file'));
+            }
+        }
         $data->size = $size;
-
-        if ($um->file['type'] == 'application/octet-stream') {
-            // the browser wasn't sure, so use file_mime_type to guess
-            require_once('file.php');
-            $data->filetype = file_mime_type($um->file['tmp_name']);
-        }
-        else {
-            $data->filetype = $um->file['type'];
-        }
-
+        $data->filetype = $filetype;
         $data->oldextension = $um->original_filename_extension();
-        $f = self::new_file($um->file['tmp_name'], $data);
+        $f = self::new_file($tmpname, $data);
         $f->commit();
         $id = $f->get('id');
         // Save the file using its id as the filename, and use its id modulo
@@ -901,6 +995,9 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             $owner->quota_add($size);
             $owner->commit();
         }
+        else if (!empty($data->group)) {
+            group_quota_add($data->group, $size);
+        }
         return $id;
     }
 
@@ -994,6 +1091,10 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
                 $USER->quota_remove($size);
                 $USER->commit();
             }
+            if (!empty($this->group)) {
+                require_once('group.php');
+                group_quota_remove($this->group, $size);
+            }
         }
 
         delete_records('artefact_attachment', 'attachment', $this->id);
@@ -1004,6 +1105,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
 
     public static function bulk_delete($artefactids) {
         global $USER;
+        require_once('group.php');
 
         if (empty($artefactids)) {
             return;
@@ -1014,12 +1116,22 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         db_begin();
         // Get the size of all the files we're about to delete that belong to
         // the user.
-        $totalsize = get_field_sql('
-            SELECT SUM(size)
-            FROM {artefact_file_files} f JOIN {artefact} a ON f.artefact = a.id
-            WHERE a.owner = ? AND f.artefact IN (' . $idstr . ')',
-            array($USER->get('id'))
-        );
+        if ($group = group_current_group()) {
+            $totalsize = get_field_sql('
+                SELECT SUM(size)
+                FROM {artefact_file_files} f JOIN {artefact} a ON f.artefact = a.id
+                WHERE a.group = ? AND f.artefact IN (' . $idstr . ')',
+                array($group->id)
+            );
+        }
+        else {
+            $totalsize = get_field_sql('
+                SELECT SUM(size)
+                FROM {artefact_file_files} f JOIN {artefact} a ON f.artefact = a.id
+                WHERE a.owner = ? AND f.artefact IN (' . $idstr . ')',
+                array($USER->get('id'))
+            );
+        }
 
         // Get all fileids so that we can delete the files on disk
         $fileids = get_records_select_assoc('artefact_file_files', 'artefact IN (' . $idstr . ')', array());
@@ -1053,8 +1165,13 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         }
 
         if ($totalsize) {
-            $USER->quota_remove($totalsize);
-            $USER->commit();
+            if ($group) {
+                group_quota_remove($group->id, $totalsize);
+            }
+            else {
+                $USER->quota_remove($totalsize);
+                $USER->commit();
+            }
         }
         db_commit();
     }
@@ -1072,7 +1189,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         $elements = array();
         $defaultquota = get_config_plugin('artefact', 'file', 'defaultquota');
         if (empty($defaultquota)) {
-            $defaultquota = 1024 * 1024 * 10;
+            $defaultquota = 1024 * 1024 * 50;
         }
         $elements['quotafieldset'] = array(
             'type' => 'fieldset',
@@ -1085,11 +1202,33 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
                     'title'        => get_string('defaultquota', 'artefact.file'), 
                     'type'         => 'bytes',
                     'defaultvalue' => $defaultquota,
+                ),
+                'updateuserquotas' => array(
+                    'title'        => get_string('updateuserquotas', 'artefact.file'),
+                    'description'  => get_string('updateuserquotasdesc', 'artefact.file'),
+                    'type'         => 'checkbox',
                 )
             ),
             'collapsible' => true
         );
 
+        $override = get_config_plugin('artefact', 'file', 'institutionaloverride');
+        $elements['overridefieldset'] = array(
+            'type' => 'fieldset',
+            'legend' => get_string('institutionoverride', 'artefact.file'),
+            'elements' => array(
+                'institutionaloverridedescription' => array(
+                    'value' => '<tr><td colspan="2">' . get_string('institutionoverridedescription', 'artefact.file') . '</td></tr>',
+                ),
+                'institutionaloverride' => array(
+                    'title'        => get_string('institutionoverride', 'artefact.file'),
+                    'type'         => 'checkbox',
+                    'defaultvalue' => $override,
+                ),
+            ),
+            'collapsible' => true,
+        );
+
         $maxquota = get_config_plugin('artefact', 'file', 'maxquota');
         $maxquotaenabled = get_config_plugin('artefact', 'file', 'maxquotaenabled');
         if (empty($maxquota)) {
@@ -1116,6 +1255,31 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             'collapsible' => true
         );
 
+        $defaultgroupquota = get_config_plugin('artefact', 'file', 'defaultgroupquota');
+        if (empty($defaultgroupquota)) {
+            $defaultgroupquota = 1024 * 1024 * 10;
+        }
+        $elements['groupquotafieldset'] = array(
+            'type' => 'fieldset',
+            'legend' => get_string('defaultgroupquota', 'artefact.file'),
+            'elements' => array(
+                'defaultgroupquotadescription' => array(
+                    'value' => '<tr><td colspan="2">' . get_string('defaultgroupquotadescription', 'artefact.file') . '</td></tr>'
+                ),
+                'defaultgroupquota' => array(
+                    'title'        => get_string('defaultgroupquota', 'artefact.file'),
+                    'type'         => 'bytes',
+                    'defaultvalue' => $defaultgroupquota,
+                ),
+                'updategroupquotas' => array(
+                    'title'        => get_string('updategroupquotas', 'artefact.file'),
+                    'description'  => get_string('updategroupquotasdesc', 'artefact.file'),
+                    'type'         => 'checkbox',
+                )
+            ),
+            'collapsible' => true
+        );
+
         // Require user agreement before uploading files
         // Rework this when/if we provide translatable agreements
         $uploadagreement = get_config_plugin('artefact', 'file', 'uploadagreement');
@@ -1227,7 +1391,15 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
 
     public static function save_config_options($values) {
         global $USER;
+        if ($values['updateuserquotas'] && $values['defaultquota']) {
+            set_field('usr', 'quota', $values['defaultquota'], 'deleted', 0);
+        }
+        if ($values['updategroupquotas'] && $values['defaultgroupquota']) {
+            set_field('group', 'quota', $values['defaultgroupquota'], 'deleted', 0);
+        }
         set_config_plugin('artefact', 'file', 'defaultquota', $values['defaultquota']);
+        set_config_plugin('artefact', 'file', 'defaultgroupquota', $values['defaultgroupquota']);
+        set_config_plugin('artefact', 'file', 'institutionaloverride', $values['institutionaloverride']);
         set_config_plugin('artefact', 'file', 'maxquota', $values['maxquota']);
         set_config_plugin('artefact', 'file', 'maxquotaenabled', $values['maxquotaenabled']);
         set_config_plugin('artefact', 'file', 'profileiconwidth', $values['profileiconwidth']);
@@ -1243,6 +1415,7 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
             update_record('site_content', $data, 'name');
         }
         else {
+            $data->ctime = db_format_timestamp(time());
             insert_record('site_content', $data);
         }
         foreach(PluginArtefactFile::get_artefact_types() as $at) {
@@ -1440,9 +1613,13 @@ class ArtefactTypeFolder extends ArtefactTypeFileBase {
         $parentclause = ($parentfolderid && is_int($parentfolderid)) ? 'parent = ' . $parentfolderid : 'parent IS NULL';
         $ownerclause = artefact_owner_sql($userid, $groupid, $institution);
         $ignoreclause = $artefactstoignore ? ' AND id NOT IN(' . implode(', ', array_map('db_quote', $artefactstoignore)) . ')' : '';
-        return get_record_sql('SELECT * FROM {artefact}
+        $records = get_records_sql_array('
+           SELECT * FROM {artefact}
            WHERE title = ? AND ' . $parentclause . ' AND ' . $ownerclause . "
-           AND artefacttype = 'folder'" . $ignoreclause, array($name));
+           AND artefacttype = 'folder'" . $ignoreclause,
+           array($name), 0, 1
+        );
+        return $records ? $records[0] : false;
     }
 
     /**
@@ -1660,6 +1837,24 @@ class ArtefactTypeImage extends ArtefactTypeFile {
 
 class ArtefactTypeProfileIcon extends ArtefactTypeImage {
 
+    public function delete() {
+        global $USER;
+        parent::delete();
+        if ($USER->get('profileicon') == $this->id) {
+            $USER->profileicon = null;
+            $USER->commit();
+        }
+    }
+
+    public static function bulk_delete($artefactids) {
+        global $USER;
+        parent::bulk_delete($artefactids);
+        if (in_array($USER->get('profileicon'), $artefactids)) {
+            $USER->profileicon = null;
+            $USER->commit();
+        }
+    }
+
     public static function get_links($id) {
         $wwwroot = get_config('wwwroot');
 
@@ -1714,14 +1909,29 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
         }
     }
 
-    public static function new_archive($path, $data) {
-        if (!isset($data->filetype)) {
-            return self::archive_from_file($path, $data);
-        }
+    public static function is_valid_file($path, $data) {
         $descriptions = self::archive_file_descriptions();
         $validtypes = self::archive_mime_types();
-        if (isset($validtypes[$data->filetype])) {
-            return self::archive_from_file($path, $data, $descriptions[$validtypes[$data->filetype]->description]);
+        if (!isset($validtypes[$data->filetype])) {
+            return false;
+        }
+
+        $type = $descriptions[$validtypes[$data->filetype]->description];
+
+        if (is_null($type)) {
+            if (self::is_zip($path)) {
+                $data->filetype = 'application/zip';
+                $data->archivetype = 'zip';
+                return true;
+            }
+            if ($data->filetype = self::is_tar($path)) {
+                $data->archivetype = 'tar';
+                return true;
+            }
+        }
+        else if ($type == 'zip' && self::is_zip($path) || $type == 'tar' && self::is_tar($path)) {
+            $data->archivetype = $type;
+            return true;
         }
         return false;
     }
@@ -1754,32 +1964,10 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
         return false;
     }
 
-    public static function archive_from_file($path, $data, $type=null) {
-        if (is_null($type)) {
-            if (self::is_zip($path)) {
-                $data->filetype = 'application/zip';
-                $data->archivetype = 'zip';
-                return new ArtefactTypeArchive(0, $data);
-            }
-            if ($data->filetype = self::is_tar($path)) {
-                $data->archivetype = 'tar';
-                return new ArtefactTypeArchive(0, $data);
-            }
-        }
-        else if ($type == 'zip' && self::is_zip($path) || $type == 'tar' && self::is_tar($path)) {
-            $data->archivetype = $type;
-            return new ArtefactTypeArchive(0, $data);
-        }
-        return false;
-    }
-
     public static function archive_file_descriptions() {
-        static $descriptions = null;
-        if (is_null($descriptions)) {
-            $descriptions = array('tar' => 'tar', 'gz' => 'tar', 'tgz' => 'tar', 'bz2' => 'tar');
-            if (function_exists('zip_open')) {
-                $descriptions['zip'] = 'zip';
-            }
+        $descriptions = array('tar' => 'tar', 'gz' => 'tar', 'tgz' => 'tar', 'bz2' => 'tar');
+        if (function_exists('zip_open')) {
+            $descriptions['zip'] = 'zip';
         }
         return $descriptions;
     }
@@ -1788,7 +1976,7 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
         static $mimetypes = null;
         if (is_null($mimetypes)) {
             $descriptions = self::archive_file_descriptions();
-            $mimetypes = get_records_select_assoc('artefact_file_mime_types', 'description IN (' . join(',', array_map('db_quote', array_keys($descriptions))) . ')');
+            $mimetypes = PluginArtefactFile::get_mimetypes_from_description(array_keys($descriptions), true);
         }
         return $mimetypes;
     }
@@ -1972,7 +2160,7 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
                     $this->data['filescreated']++;
                 }
                 if ($progresscallback && ++$i % 5 == 0) {
-                    call_user_func_array($progresscallback, $i);
+                    call_user_func($progresscallback, $i);
                 }
             }
 
@@ -2024,7 +2212,7 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
                     $this->data['filescreated']++;
                 }
                 if ($progresscallback && ++$i % 5 == 0) {
-                    call_user_func_array($progresscallback, $i);
+                    call_user_func($progresscallback, $i);
                 }
             }
         }
@@ -2032,3 +2220,101 @@ class ArtefactTypeArchive extends ArtefactTypeFile {
     }
 
 }
+
+class ArtefactTypeVideo extends ArtefactTypeFile {
+
+    protected $videotype;
+
+    public function __construct($id = 0, $data = null) {
+        parent::__construct($id, $data);
+
+        if ($this->id) {
+            $descriptions = self::video_file_descriptions();
+            $validtypes = self::video_mime_types();
+            $this->videotype = $descriptions[$validtypes[$this->filetype]->description];
+        }
+    }
+
+    public static function is_valid_file($path, $data) {
+        $validtypes = self::video_mime_types();
+        if (!isset($validtypes[$data->guess])) {
+            return false;
+        }
+        $data->filetype = $data->guess;
+        return true;
+    }
+
+    public static function video_file_descriptions() {
+        static $descriptions = null;
+        if (is_null($descriptions)) {
+            $descriptions = array(
+                'flv'       => 'flv',
+                'avi'       => 'avi',
+                'mpeg'      => 'mpeg',
+                'wmv'       => 'wmv',
+                'quicktime' => 'quicktime',
+                'sgi_movie' => 'sgi_movie',
+                'mp4_video' => 'mp4_video',
+            );
+        }
+        return $descriptions;
+    }
+
+    public static function video_mime_types() {
+        static $mimetypes = null;
+        if (is_null($mimetypes)) {
+            $descriptions = self::video_file_descriptions();
+            $mimetypes = PluginArtefactFile::get_mimetypes_from_description(array_keys($descriptions), true);
+        }
+        return $mimetypes;
+    }
+
+    public static function get_icon($options=null) {
+        global $THEME;
+        return $THEME->get_url('images/video.gif');
+    }
+
+}
+
+class ArtefactTypeAudio extends ArtefactTypeFile {
+
+    public static function is_valid_file($path, $data) {
+        $validtypes = self::audio_mime_types();
+        if (!isset($validtypes[$data->guess])) {
+            return false;
+        }
+        $data->filetype = $data->guess;
+        return true;
+    }
+
+    public static function audio_file_descriptions() {
+        static $descriptions = null;
+        if (is_null($descriptions)) {
+            $descriptions = array(
+                'mp3',
+                'mp4_audio',
+                'mp4',
+                'wav',
+                'ra',
+                'au',
+                'aiff',
+                'm3u'
+            );
+        }
+        return $descriptions;
+    }
+
+    public static function audio_mime_types() {
+        static $mimetypes = null;
+        if (is_null($mimetypes)) {
+            $descriptions = self::audio_file_descriptions();
+            $mimetypes = PluginArtefactFile::get_mimetypes_from_description($descriptions, true);
+        }
+        return $mimetypes;
+    }
+
+    public static function get_icon($options=null) {
+        global $THEME;
+        return $THEME->get_url('images/audio.gif');
+    }
+}
