@@ -206,16 +206,19 @@ function upload_submit(Pieform $form, $values) {
     }
 
     // Entry in artefact table
-    $data = (object) array(
-        'owner'    => $USER->id,
-        'title'    => $values['title'] ? $values['title'] : $values['file']['name'],
-        'note'     => $values['file']['name'],
-        'size'     => $filesize,
-    );
+    $data = new stdClass;
+    $data->owner = $USER->id;
+    $data->parent = ArtefactTypeFolder::get_folder_id(get_string('imagesdir', 'artefact.file'), get_string('imagesdirdesc', 'artefact.file'), null, true, $USER->id);
+    $data->title = $values['title'] ? $values['title'] : $values['file']['name'];
+    $data->title = ArtefactTypeFileBase::get_new_file_title($data->title, (int)$data->parent, $USER->id);  // unique title
+    $data->note = $values['file']['name'];
+    $data->size = $filesize;
     $imageinfo = getimagesize($values['file']['tmp_name']);
     $data->width    = $imageinfo[0];
     $data->height   = $imageinfo[1];
     $data->filetype = $imageinfo['mime'];
+    $data->description = get_string('uploadedprofileicon', 'artefact.file');
+
     $artefact = new ArtefactTypeProfileIcon(0, $data);
     if (preg_match("/\.([^\.]+)$/", $values['file']['name'], $saved)) {
         $artefact->set('oldextension', $saved[1]);
@@ -235,7 +238,7 @@ function upload_submit(Pieform $form, $values) {
 
     $USER->commit();
 
-    $form->json_reply(PIEFORM_OK, get_string('uploadedprofileiconsuccessfully', 'artefact.file'));
+    $form->json_reply(PIEFORM_OK, get_string('profileiconaddedtoimagesfolder', 'artefact.file', get_string('imagesdir', 'artefact.file')));
 }
 
 function settings_submit_default(Pieform $form, $values) {
@@ -280,7 +283,9 @@ function settings_submit_delete(Pieform $form, $values) {
 
         db_commit();
 
-        $SESSION->add_ok_msg(get_string('profileiconsdeletedsuccessfully', 'artefact.file'));
+        $SESSION->add_ok_msg(
+            get_string('filethingdeleted', 'artefact.file', get_string('nprofilepictures', 'artefact.file', count($icons)))
+        );
     }
     else {
         $SESSION->add_info_msg(get_string('profileiconsnoneselected', 'artefact.file'));
