@@ -27,7 +27,7 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'Contact Information';
+$string['title'] = 'Contact information';
 $string['description'] = 'Choose contact information to display';
 $string['dontshowemail'] = 'Don\'t show email address';
 $string['fieldstoshow'] = 'Fields to show';
