@@ -96,7 +96,7 @@ class LeapExportElementInternal extends LeapExportElement {
         if ($icons = get_column_sql("SELECT id
             FROM {artefact}
             WHERE artefacttype = 'profileicon'
-            AND owner = ?
+            AND \"owner\" = ?
             ORDER BY id = (
                 SELECT profileicon FROM {usr} WHERE id = ?
             ) DESC, id", array($userid, $userid))) {
@@ -247,5 +247,3 @@ class LeapExportElementInternalNonPerson extends LeapExportElement {
 
 class LeapExportElementIndustry extends LeapExportElementInternalNonPerson { }
 class LeapExportElementOccupation extends LeapExportElementInternalNonPerson { }
-
-?>
