@@ -26,6 +26,7 @@
  */
 
 defined('INTERNAL') || die();
+require_once(get_config('libroot') . 'group.php');
 
 /**
  * Base artefact plugin class
@@ -206,14 +207,22 @@ abstract class ArtefactType {
         $this->atime = time();
     }
 
+    /**
+     * Returns the instances of all views where this artefact is used.
+     *
+     * @return array Array of view instances.
+     */
     public function get_views_instances() {
         // @todo test this
         if (!isset($this->viewsinstances)) {
             $this->viewsinstances = false;
             if ($views = $this->get_views_metadata()) {
                 $this->viewsinstances = array();
+                if (!class_exists('View')) {
+                    require_once(get_config('libroot') . 'view.php');
+                }
                 foreach ($views as $view) {
-                    $this->viewsinstances[] = new View($view->id, $view);
+                    $this->viewsinstances[] = new View($view->view);
                 }
             }
         }
@@ -627,6 +636,8 @@ abstract class ArtefactType {
         delete_records_select('artefact_tag', "artefact IN $idstr");
         delete_records_select('artefact_access_role', "artefact IN $idstr");
         delete_records_select('artefact_access_usr', "artefact IN $idstr");
+        execute_sql("UPDATE {usr} SET profileicon = NULL WHERE profileicon IN $idstr");
+        execute_sql("UPDATE {institution} SET logo = NULL WHERE logo IN $idstr");
 
         delete_records_select('artefact', "id IN $idstr");
 
@@ -678,12 +689,12 @@ abstract class ArtefactType {
      * A dummy method, giving graceful output, if this method is not implemented in the relevant child class
      */
     public function render_self($options) {
-        $smarty = smarty();
-        $smarty->assign('viewtitle', $this->get('title'));
-        $smarty->assign('viewdescription', $this->get('description'));
+        $smarty = smarty_core();
+        $smarty->assign('title', $this->get('title'));
+        $smarty->assign('description', $this->get('description'));
 
         return array(
-            'html' => $smarty->fetch('view/viewcontent.tpl'),
+            'html' => $smarty->fetch('artefact.tpl'),
             'javascript'=>''
         );
     }
@@ -811,7 +822,6 @@ abstract class ArtefactType {
         if (!$this->group) {
             return;
         }
-        require_once(get_config('libroot') . 'group.php');
         if (!isset($this->rolepermissions)) {
             $this->rolepermissions = group_get_default_artefact_permissions($this->group);
         }
@@ -850,6 +860,10 @@ abstract class ArtefactType {
         }
     }
 
+    public function role_has_permission($role, $permission) {
+        return $this->rolepermissions[$role]->{$permission};
+    }
+
     public function copy_data() {
         $ignore = array(
             'dirty' => 1,
@@ -1242,54 +1256,109 @@ function rebuild_artefact_parent_cache_dirty() {
 }
 
 function rebuild_artefact_parent_cache_complete() {
+
+    // The artefact table may get too big to read in all at once.  Because
+    // all artefacts' parents have the same owner (or group, institution) as
+    // the child artefact, we can read the table in chunks as long as all
+    // artefacts with the same owner are processed in one go.
+
+    // Attachment relationships also get records in artefact_parent_cache,
+    // but these are fetched separately in a per-artefact query inside
+    // rebuild_artefact_parent_cache_partial, and there is no assumption
+    // that attachments have the same owner as the artefact they're attached
+    // to.
+
     db_begin();
     delete_records('artefact_parent_cache');
 
-    $artefacts = get_records_sql_assoc('
-        SELECT id, parent, COUNT(aa.artefact) AS attached
-        FROM {artefact} a LEFT JOIN {artefact_attachment} aa ON a.id = aa.attachment
-        GROUP BY id, parent
-        HAVING parent IS NOT NULL OR COUNT(aa.artefact) > 0',
-        array()
-    );
+    foreach (array('owner', 'group', 'institution') as $f) {
+        $select = '
+            SELECT id, parent, COUNT(aa.artefact) AS attached
+            FROM {artefact} a LEFT JOIN {artefact_attachment} aa ON a.id = aa.attachment';
+        $where = "
+            WHERE a.$f IS NOT NULL";
+        $groupby = "
+            GROUP BY id, parent
+            HAVING parent IS NOT NULL OR COUNT(aa.artefact) > 0";
 
-    if ($artefacts) {
-
-        foreach ($artefacts as &$artefact) {
-
-            // Nothing that can be a parent can be an attachment, so it's good
-            // enough to first get everything this artefact is attached to, and
-            // then find all its ancestors and the ancestors of everything it's
-            // attached to.
-
-            $ancestors = array();
-            if ($artefact->attached) {
-                $ancestors = get_column('artefact_attachment', 'artefact', 'attachment', $artefact->id);
+        if ($f == 'group' || $f == 'institution') {
+            $sql = $select . $where . $groupby;
+            if ($artefacts = get_records_sql_assoc($sql, array())) {
+                rebuild_artefact_parent_cache_partial($artefacts);
             }
+            continue;
+        }
 
-            $tocheck = $ancestors;
-            $tocheck[] = $artefact->id;
+        // There are usually a lot of individual user artefacts, so these are processed in
+        // chunks.  Ideally we would like to do < $artefactlimit artefacts at a time, but
+        // it's more important to make sure all artefacts with the same owner are processed
+        // together, so if one user has too many artefacts, this limit will be exceeded.
+        $artefactlimit = 25000;
+        $defaultuserlimit = 1000; // Try to do this many users in each run
 
-            foreach ($tocheck as $id) {
-                $p = isset($artefacts[$id]) ? $artefacts[$id]->parent : null;
-                while (!empty($p)) {
-                    $ancestors[] = $p;
-                    $p = isset($artefacts[$p]) ? $artefacts[$p]->parent : null;
+        $maxuser = get_field('artefact', 'MAX(owner)');
+        $sql = $select . $where . ' AND owner >= ? AND owner < ?' . $groupby;
+        $countsql = 'SELECT COUNT(r.id) FROM (' . $sql . ') r';
+
+        $i = 0;
+        while ($i <= $maxuser) {
+            $userlimit = $defaultuserlimit;
+            $n = count_records_sql($countsql, array($i, $i + $userlimit));
+            // If we have too many artefacts, try fewer users.
+            while ($n > $artefactlimit) {
+                $userlimit = floor($userlimit / 2);
+                if ($userlimit < 2) {
+                    break;
                 }
+                $n = count_records_sql($countsql, array($i, $i + $userlimit));
             }
-
-            foreach (array_unique($ancestors) as $p) {
-                insert_record('artefact_parent_cache', (object) array(
-                    'artefact' => $artefact->id,
-                    'parent'   => $p,
-                    'dirty'    => 0,
-                ));
+            if ($artefacts = get_records_sql_assoc($sql, array($i, $i + $userlimit))) {
+                $lastuser = min($i + $userlimit, $maxuser);
+                log_debug("Rebuilding parent cache for " . count($artefacts) . " artefacts (users $i-$lastuser of $maxuser)");
+                rebuild_artefact_parent_cache_partial($artefacts);
             }
+            $i += $userlimit;
         }
     }
+
     db_commit();
 }
 
+function rebuild_artefact_parent_cache_partial($artefacts) {
+
+    foreach ($artefacts as &$artefact) {
+
+        // Nothing that can be a parent can be an attachment, so it's good
+        // enough to first get everything this artefact is attached to, and
+        // then find all its ancestors and the ancestors of everything it's
+        // attached to.
+
+        $ancestors = array();
+        if ($artefact->attached) {
+            $ancestors = get_column('artefact_attachment', 'artefact', 'attachment', $artefact->id);
+        }
+
+        $tocheck = $ancestors;
+        $tocheck[] = $artefact->id;
+
+        foreach ($tocheck as $id) {
+            $p = isset($artefacts[$id]) ? $artefacts[$id]->parent : null;
+            while (!empty($p)) {
+                $ancestors[] = $p;
+                $p = isset($artefacts[$p]) ? $artefacts[$p]->parent : null;
+            }
+        }
+
+        foreach (array_unique($ancestors) as $p) {
+            insert_record('artefact_parent_cache', (object) array(
+                'artefact' => $artefact->id,
+                'parent'   => $p,
+                'dirty'    => 0,
+            ));
+        }
+    }
+}
+
 function artefact_get_attachment_types() {
     static $artefacttypes = null;
     if (is_null($artefacttypes)) {
@@ -1466,6 +1535,21 @@ function artefact_owner_sql($userid=null, $groupid=null, $institution=null) {
     return null;
 }
 
+function artefact_new_title($title, $artefacttype, $owner, $group, $institution) {
+    $taken = get_column_sql('
+        SELECT title
+        FROM {artefact}
+        WHERE ' . artefact_owner_sql($owner, $group, $institution) . "
+            AND title LIKE ? || '%'", array($title));
+    $ext = ''; $i = 0;
+    if ($taken) {
+        while (in_array($title . $ext, $taken)) {
+            $ext = ' (' . ++$i . ')';
+        }
+    }
+    return $title . $ext;
+}
+
 /**
  * Given a string of html, look for references to artefacts in it and return a 
  * list of artefact IDs found
@@ -1545,3 +1629,50 @@ function artefact_get_types_from_filter($filter) {
 
     return $contenttype_artefacttype[$filter];
 }
+
+/**
+ * Given a list of artefact ids, return a name and url for the thing that
+ * owns each artefact, suitable for display.
+ *
+ * @param array $ids list of artefact ids
+ *
+ * @return array list of StdClass objects, each containing a name & url property
+ */
+function artefact_get_owner_info($ids) {
+    $data = get_records_sql_assoc('
+        SELECT
+            a.id AS aid, a.owner, a.group, a.institution,
+            u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email,
+            g.name AS groupname,
+            i.displayname
+        FROM
+            {artefact} a
+            LEFT JOIN {usr} u ON a.owner = u.id
+            LEFT JOIN {group} g ON a.group = g.id
+            LEFT JOIN {institution} i ON a.institution = i.name
+        WHERE
+            a.id IN (' . join(',', array_fill(0, count($ids), '?')) . ')',
+        $ids
+    );
+    $wwwroot = get_config('wwwroot');
+    foreach ($data as &$d) {
+        if ($d->institution == 'mahara') {
+            $name = get_config('sitename');
+            $url  = '';
+        }
+        else if ($d->institution) {
+            $name = $d->displayname;;
+            $url  = 'institution/index.php?institution=' . $d->institution;
+        }
+        else if ($d->group) {
+            $name = $d->groupname;;
+            $url  = 'group/view.php?id=' . $d->group;
+        }
+        else {
+            $name = display_name($d);
+            $url  = 'user/view.php?id=' . $d->id;
+        }
+        $d = (object) array('name' => $name, 'url' => $wwwroot . $url);
+    }
+    return $data;
+}
