@@ -261,7 +261,7 @@ class ArtefactTypePlan extends ArtefactType {
         $pagination = array(
             'baseurl' => $baseurl,
             'id' => 'task_pagination',
-            'datatable' => 'tasklist',
+            'datatable' => 'tasktable',
             'jsonscript' => 'artefact/plans/viewtasks.json.php',
         );
 
@@ -544,7 +544,7 @@ class ArtefactTypeTask extends ArtefactType {
                     if ($result->completiondate < $datenow && !$result->completed) {
                         $result->completed = -1;
                     }
-                    $result->completiondate = strftime(get_string('strftimedate'), $result->completiondate);
+                    $result->completiondate = format_date($result->completiondate, 'strftimedate');
                 }
             }
         }
