@@ -28,17 +28,12 @@
 define('INTERNAL', 1);
 define('JSON', 1);
 
-if (isset($_POST['view'])) {
-    define('PUBLIC', 1);
-}
-
 require(dirname(dirname(dirname(__FILE__))) . '/init.php');
 safe_require('artefact', 'resume');
 
 $limit = param_integer('limit', null);
 $offset = param_integer('offset', 0);
 $type = param_alpha('type');
-$view = param_integer('view', 0);
 
 $data = array();
 $count = 0;
@@ -53,26 +48,16 @@ $sql = 'SELECT ar.*, a.owner
     WHERE a.owner = ? AND a.artefacttype = ?
     ORDER BY ar.displayorder';
 
-if (!empty($view)) { 
-    if (!can_view_view($view)) {
-        throw new AccessDeniedException();
-    }
-    require_once('view.php');
-    $v = new View($view);
-    $owner = $v->get('owner');
-}
-
 if (!$data = get_records_sql_array($sql, array($owner, $type))) {
     $data = array();
 }
 
 $count = count_records('artefact', 'owner', $owner, 'artefacttype', $type);
 
-echo json_encode(array(
+json_reply(false, array(
     'data' => $data,
     'limit' => $limit,
     'offset' => $offset,
     'count' => $count,
-    'type' => $type));
-
-?>
+    'type' => $type,
+));
