@@ -28,9 +28,9 @@
 defined('INTERNAL') || die();
 
 /**
- * Implements LEAP2A import of resume related entries into Mahara
+ * Implements Leap2A import of resume related entries into Mahara
  *
- * For more information about LEAP resume importing, see:
+ * For more information about Leap resume importing, see:
  * http://wiki.mahara.org/Developer_Area/Import//Export/LEAP_Import/Resume_Artefact_Plugin
  */
 class LeapImportResume extends LeapImportArtefactPlugin {
@@ -84,7 +84,9 @@ class LeapImportResume extends LeapImportArtefactPlugin {
      * for imported users.
      */
     public static function setup(PluginImportLeap $importer) {
-        ArtefactTypeContactinformation::setup_new($importer->get('usr'));
+        try {
+            ArtefactTypeContactinformation::setup_new($importer->get('usr'));
+        } catch (ParamOutOfRangeException $e) {} // probably already has one
     }
 
     /**
@@ -476,7 +478,7 @@ class LeapImportResume extends LeapImportArtefactPlugin {
     }
 
     /**
-     * Converts a LEAP2A date point to a plain text version for resume date 
+     * Converts a Leap2A date point to a plain text version for resume date 
      * purposes.
      *
      * @param array $date The date - expected to come from {PluginImportLeap::....()}
@@ -564,5 +566,3 @@ class LeapImportResume extends LeapImportArtefactPlugin {
     }
 
 }
-
-?>
