@@ -59,7 +59,19 @@ class AuthInternal extends Auth {
      */
     public function authenticate_user_account($user, $password) {
         $this->must_be_ready();
-        return $this->validate_password($password, $user->password, $user->salt);
+        $result = $this->validate_password($password, $user->password, $user->salt);
+        // If result == 1, password is correct
+        // If result > 1, password is correct but using old settings, should be changed
+        if ($result > 1 ) {
+            if ($user->passwordchange != 1) {
+                $userobj = new User();
+                $userobj->find_by_id($user->id);
+                $this->change_password($userobj, $password);
+                $user->password = $userobj->password;
+                $user->salt = $userobj->salt;
+            }
+        }
+        return $result > 0;
     }
 
     /**
@@ -82,15 +94,6 @@ class AuthInternal extends Auth {
         if (!preg_match('/^[a-zA-Z0-9 ~!@#\$%\^&\*\(\)_\-=\+\,\.<>\/\?;:"\[\]\{\}\\\|`\']{6,}$/', $password)) {
             return false;
         }
-        // The password must have at least one digit and two letters in it
-        if (!preg_match('/[0-9]/', $password)) {
-            return false;
-        }
-
-        $password = preg_replace('/[a-zA-Z]/', "\0", $password);
-        if (substr_count($password, "\0") < 2) {
-            return false;
-        }
         return true;
     }
 
@@ -105,11 +108,19 @@ class AuthInternal extends Auth {
      * @param boolean $resetpasswordchange Whether to reset the passwordchange variable or not
      * @return string The new password, or empty if the password could not be set
      */
-    public function change_password(User $user, $password, $resetpasswordchange = true) {
+    public function change_password(User $user, $password, $resetpasswordchange = true, $quickhash = false) {
         $this->must_be_ready();
         // Create a salted password and set it for the user
         $user->salt = substr(md5(rand(1000000, 9999999)), 2, 8);
-        $user->password = $this->encrypt_password($password, $user->salt);
+        if ($quickhash) {
+            // $6$ is SHA512, used as a quick hash instead of bcrypt for now.
+            $user->password = $this->encrypt_password($password, $user->salt, '$6$', get_config('passwordsaltmain'));
+        }
+        else {
+            // $2a$ is bcrypt hash. See http://php.net/manual/en/function.crypt.php
+            // It requires a cost, a 2 digit number in the range 04-31
+            $user->password = $this->encrypt_password($password, $user->salt, '$2a$' . get_config('bcrypt_cost') . '$', get_config('passwordsaltmain'));
+        }
         if ($resetpasswordchange) {
             $user->passwordchange = 0;
         }
@@ -198,13 +209,29 @@ class AuthInternal extends Auth {
     *
     * @param string $password The password to encrypt
     * @param string $salt     The salt to use to encrypt the password
+    * @param string $alg      The algorithm to use, defaults to $6$ which is SHA512
+    * @param string $sitesalt A salt to combine with the user's salt to add an extra layer or salting
     * @todo salt mandatory
     */
-    public function encrypt_password($password, $salt='') {
+    public function encrypt_password($password, $salt='', $alg='$6$', $sitesalt='') {
         if ($salt == '') {
             $salt = substr(md5(rand(1000000, 9999999)), 2, 8);
         }
-        return sha1($salt . $password);
+        if ($alg == '$6$') { // $6$ is the identifier for the SHA512 algorithm
+            // Return a hash which is sha512(originalHash, salt), where original is sha1(salt + password)
+            $password = sha1($salt . $password);
+            // Generate a salt based on a supplied salt and the passwordsaltmain
+            $fullsalt = substr(md5($sitesalt . $salt), 0, 16); // SHA512 expects 16 chars of salt
+        }
+        else { // This is most likely bcrypt $2a$, but any other algorithm can take up to 22 chars of salt
+            // Generate a salt based on a supplied salt and the passwordsaltmain
+            $fullsalt = substr(md5($sitesalt . $salt), 0, 22); // bcrypt expects 22 chars of salt
+        }
+        $hash = crypt($password, $alg . $fullsalt);
+        // Strip out the computed salt
+        // We strip out the salt hide the computed salt (in case the sitesalt was used which isn't in the database)
+        $hash = substr($hash, 0, strlen($alg)) . substr($hash, strlen($alg)+strlen($fullsalt));
+        return $hash;
     }
 
     /**
@@ -212,8 +239,9 @@ class AuthInternal extends Auth {
      * and the salt we have, see if the password they sent is correct.
      *
      * @param string $theysent The password the user sent
-     * @param string $wehave   The password we have in the database for them
+     * @param string $wehave   The salted and hashed password we have in the database for them
      * @param string $salt     The salt we have.
+     * @returns int     0 means not validated, 1 means validated, 2 means validated but needs updating
      */
     private function validate_password($theysent, $wehave, $salt) {
         $this->must_be_ready();
@@ -224,9 +252,50 @@ class AuthInternal extends Auth {
             return false;
         }
 
-        // The main type - a salted sha1
-        $sha1sent = $this->encrypt_password($theysent, $salt);
-        return $sha1sent == $wehave;
+        if (empty($wehave)) {
+            // This means the user has not been set up completely yet
+            // Common cause is that still in registration phase
+            return false;
+        }
+
+        $sitesalt = get_config('passwordsaltmain');
+        $bcrypt = substr($wehave, 0, 4) == '$2a$';
+        if ($bcrypt) {
+            $alg = substr($wehave, 0, 7);
+            $hash = $this->encrypt_password($theysent, $salt, $alg, $sitesalt);
+        }
+        else {
+            $alg = substr($wehave, 0, 3);
+            $hash = $this->encrypt_password($theysent, $salt, $alg, $sitesalt);
+        }
+        if ($hash == $wehave) {
+            if (!$bcrypt || substr($alg, 4, 2) != get_config('bcrypt_cost')) {
+                // Either not using bcrypt yet, or the cost parameter has changed, update the hash
+                return 2;
+            }
+            // Using bcrypt with the correct cost parameter, leave as is.
+            return 1;
+        }
+        // See http://docs.moodle.org/20/en/Password_salting#Changing_the_salt
+        if (!empty($sitesalt)) {
+            // There is a sitesalt set, try without it, and update if passes
+            $hash = $this->encrypt_password($theysent, $salt, $alg, '');
+            if ($hash == $wehave) {
+                return 2;
+            }
+        }
+        for ($i = 1; $i <= 20; ++ $i) {
+            // Try 20 alternate sitesalts
+            $alt = get_config('passwordsaltalt' . $i);
+            if (!empty($alt)) {
+                $hash = $this->encrypt_password($theysent, $salt, $alg, $alt);
+                if ($hash == $wehave) {
+                    return 2;
+                }
+            }
+        }
+        // Nothing works, fail
+        return 0;
     }
 
 }
