@@ -52,6 +52,8 @@ class AuthLdap extends Auth {
         $this->config['firstnamefield' ] = '';
         $this->config['surnamefield'] = '';
         $this->config['emailfield'] = '';
+        $this->config['studentidfield'] = '';
+        $this->config['preferrednamefield'] = '';
 
         if (!empty($id)) {
             return $this->init($id);
@@ -77,7 +79,7 @@ class AuthLdap extends Auth {
     /**
      * Attempt to authenticate user
      *
-     * @param string $user The username to authenticate with
+     * @param string $user     The user record to authenticate with
      * @param string $password The password being used for authentication
      * @return bool            True/False based on whether the user
      *                         authenticated successfully
@@ -123,21 +125,43 @@ class AuthLdap extends Auth {
                     // Define ldap attributes
                     $ldapattributes = array();
                     $ldapattributes['firstname'] = $this->config['firstnamefield'];
-                    $ldapattributes['lastname']  = $this->config['surnamefield' ];
-                    $ldapattributes['email']     = $this->config['emailfield' ];
+                    $ldapattributes['lastname'] = $this->config['surnamefield'];
+                    $ldapattributes['email'] = $this->config['emailfield'];
+                    $ldapattributes['studentid'] = $this->config['studentidfield'];
+                    $ldapattributes['preferredname'] = $this->config['preferrednamefield'];
 
                     // Retrieve information of user from LDAP
                     $ldapdetails = $this->get_userinfo_ldap($username, $ldapattributes);
 
                     // Match database and ldap entries and update in database if required
-                    $fieldstoimport = array('firstname', 'lastname', 'email');
+                    $fieldstoimport = array_keys($ldapattributes);
                     foreach ($fieldstoimport as $field) {
+                        if (!isset($ldapdetails[$field])) {
+                            continue;
+                        }
+                        $sanitizer = "sanitize_$field";
+                        $ldapdetails[$field] = $sanitizer($ldapdetails[$field]);
                         if (!empty($ldapdetails[$field]) && ($user->$field != $ldapdetails[$field])) {
                             $user->$field = $ldapdetails[$field];
-                            set_profile_field($user->id, $field, $user->$field);
+                            set_profile_field($user->id, $field, $ldapdetails[$field]);
+                            if (('studentid' == $field) && ('mahara' != $this->institution)) {
+                                // studentid is specific for the institution, so store it there too.
+                                $dataobject = array(
+                                    'usr' => $user->id,
+                                    'institution' => $this->institution,
+                                    'ctime' => db_format_timestamp(time()),
+                                    'studentid' => $user->studentid,
+                                );
+                                $whereobject = $dataobject;
+                                unset($whereobject['ctime']);
+                                unset($whereobject['studentid']);
+                                ensure_record_exists('usr_institution', $whereobject, $dataobject);
+                                unset($dataobject);
+                                unset($whereobject);
+                            }
                         }
                     }
-               }
+                }
                 return true;
             }
         }
@@ -179,7 +203,14 @@ class AuthLdap extends Auth {
                 continue;
             }
 
-            $connresult = ldap_connect($server);
+            $lastcolon = strrpos($server, ":");
+            if ($lastcolon !== FALSE && preg_match('/^([0-9]+)$/', $port = substr($server, $lastcolon + 1))) {
+                $server = substr($server, 0, $lastcolon);
+                $connresult = ldap_connect($server, $port);
+            }
+            else {
+                $connresult = ldap_connect($server);
+            }
             // ldap_connect returns ALWAYS true
 
             if (!empty($this->config['version'])) {
@@ -297,8 +328,10 @@ class AuthLdap extends Auth {
         // get the attribute field names
         $attributes = array();
         $attributes['firstname'] = $this->config['firstnamefield'];
-        $attributes['lastname']  = $this->config['surnamefield' ];
-        $attributes['email']     = $this->config['emailfield'];
+        $attributes['lastname'] = $this->config['surnamefield' ];
+        $attributes['email'] = $this->config['emailfield'];
+        $attributes['studentid'] = $this->config['studentidfield'];
+        $attributes['preferredname'] = $this->config['preferrednamefield'];
 
         $userinfo = $this->get_userinfo_ldap($username, $attributes);
 
@@ -423,7 +456,9 @@ class PluginAuthLdap extends PluginAuth {
         'weautocreateusers' => 1,
         'firstnamefield'    => '',
         'surnamefield'      => '',
-        'emailfield'        => ''
+        'emailfield'        => '',
+        'studentidfield'    => '',
+        'preferrednamefield' => '',
         );
 
     public static function has_config() {
@@ -603,6 +638,18 @@ class PluginAuthLdap extends PluginAuth {
                 'defaultvalue' => self::$default_config['emailfield'],
                 'help' => true,
             ),
+            'studentidfield' => array(
+                'type'  => 'text',
+                'title' => get_string('ldapfieldforstudentid', 'auth.ldap'),
+                'defaultvalue' => self::$default_config['studentidfield'],
+                'help' => true,
+            ),
+            'preferrednamefield' => array(
+                'type'  => 'text',
+                'title' => get_string('ldapfieldforpreferredname', 'auth.ldap'),
+                'defaultvalue' => self::$default_config['preferrednamefield'],
+                'help' => true,
+            ),
         );
 
         return array(
@@ -611,7 +658,7 @@ class PluginAuthLdap extends PluginAuth {
         );
     }
 
-    public static function save_config_options($values, $form) {
+    public static function save_instance_config_options($values, $form) {
 
         $authinstance = new stdClass();
 
@@ -664,7 +711,9 @@ class PluginAuthLdap extends PluginAuth {
                                         'weautocreateusers' => $values['weautocreateusers'],
                                         'firstnamefield' => $values['firstnamefield'],
                                         'surnamefield' => $values['surnamefield'],
-                                        'emailfield' => $values['emailfield']
+                                        'emailfield' => $values['emailfield'],
+                                        'studentidfield' => $values['studentidfield'],
+                                        'preferrednamefield' => $values['preferrednamefield'],
                                         );
 
         foreach(self::$default_config as $field => $value) {
