@@ -44,7 +44,13 @@ class AuthUnknownUserException extends UserException {}
  * If appropriate - the 'message' of the exception will be used
  * as the display message, so don't forget to language translate it
  */
-class AuthInstanceException extends UserException {}
+class AuthInstanceException extends UserException {
+
+    public function strings() {
+        return array_merge(parent::strings(),
+                           array('title' => $this->get_sitename() . ': Authentication problem'));
+    }
+}
 
 /**
  * We tried to call a method on an auth plugin that hasn't been init'ed 
@@ -52,6 +58,20 @@ class AuthInstanceException extends UserException {}
  */
 class UninitialisedAuthException extends SystemException {}
 
+/**
+ * We tried creating automatically creating an account for a user but
+ * it failed for a reason that the user might want to know about
+ * (e.g. they used an email address that's already used on the site)
+ */
+class AccountAutoCreationException extends AuthInstanceException {
+
+    public function strings() {
+        return array_merge(parent::strings(),
+                           array('message' => 'The automatic creation of your user account failed.'
+                                 . "\nDetails if any, follow:"));
+    }
+}
+
 /**
  * Base authentication class. Provides a common interface with which
  * authentication can be carried out for system users.
@@ -395,26 +415,26 @@ function auth_setup () {
         // The session is still active, so continue it.
         // Make sure that if a user's admin status has changed, they're kicked
         // out of the admin section
-        if (defined('ADMIN')) {
-            $userreallyadmin = get_field('usr', 'admin', 'id', $USER->id);
-            if (!$USER->get('admin') && $userreallyadmin) {
+        if (in_admin_section()) {
+            // Reload site admin/staff permissions
+            $realuser = get_record('usr', 'id', $USER->id, null, null, null, null, 'admin,staff');
+            if (!$USER->get('admin') && $realuser->admin) {
                 // The user has been made into an admin
                 $USER->admin = 1;
             }
-            else if ($USER->get('admin') && !$userreallyadmin) {
+            else if ($USER->get('admin') && !$realuser->admin) {
                 // The user's admin rights have been taken away
                 $USER->admin = 0;
             }
-            if (!$USER->get('admin')) {
-                $SESSION->add_error_msg(get_string('accessforbiddentoadminsection'));
-                redirect();
+            if (!$USER->get('staff') && $realuser->staff) {
+                $USER->staff = 1;
             }
-        } else if (defined('INSTITUTIONALADMIN') && !$USER->get('admin')) {
+            else if ($USER->get('staff') && !$realuser->staff) {
+                $USER->staff = 0;
+            }
+            // Reload institutional admin/staff permissions
             $USER->reset_institutions();
-            if (!$USER->is_institutional_admin()) {
-                $SESSION->add_error_msg(get_string('accessforbiddentoadminsection'));
-                redirect();
-            }
+            auth_check_admin_section();
         }
         $USER->renew();
         auth_check_required_fields();
@@ -695,7 +715,7 @@ function auth_get_available_auth_types($institution=null) {
             $row->description = get_string('notusable', 'auth.' . $row->name);
         }
     }
-    usort($result, create_function('$a, $b', 'return strnatcasecmp($a->title, $b->title);'));
+    usort($result, create_function('$a, $b', 'if ($a->is_usable != $b->is_usable) return $b->is_usable; return strnatcasecmp($a->title, $b->title);'));
 
     return $result;
 }
@@ -976,6 +996,13 @@ function auth_draw_login_page($message=null, Pieform $form=null) {
 
     }
 
+    $externallogin = get_config('externallogin');
+    if ($externallogin) {
+        $externallogin = preg_replace('/{shorturlencoded}/', urlencode(get_relative_script_path()), $externallogin);
+        $externallogin = preg_replace('/{wwwroot}/', get_config('wwwroot'), $externallogin);
+        redirect($externallogin);
+    }
+
     if ($message) {
         $SESSION->add_info_msg($message);
     }
@@ -1013,12 +1040,39 @@ function auth_get_login_form() {
             'type'  => 'submit',
             'value' => get_string('login')
         ),
+        'register' => array(
+            'value' => '<div id="login-helplinks">' . '<a href="' . get_config('wwwroot') . 'forgotpass.php" tabindex="2">' . get_string('lostusernamepassword') . '</a></div>'
+        ),
         'login_submitted' => array(
             'type'  => 'hidden',
             'value' => 1
         ),
     );
 
+
+    // Get any extra elements from the enabled auth plugins
+    $extraelements = array();
+    $showbasicform = false;
+    $authplugins = auth_get_enabled_auth_plugins();
+    foreach ($authplugins as $plugin) {
+        $classname = 'PluginAuth' . ucfirst(strtolower($plugin));
+        $pluginelements = call_static_method($classname, 'login_form_elements');
+        if (!empty($pluginelements)) {
+            $extraelements = array_merge($extraelements, $pluginelements);
+        }
+        if (call_static_method($classname, 'need_basic_login_form')) {
+            $showbasicform = true;
+        }
+    }
+
+    // Replace or supplement the standard login form elements
+    if ($showbasicform) {
+        $elements = array_merge($elements, $extraelements);
+    }
+    else {
+        $elements = $extraelements;
+    }
+
     // The login page is completely transient, and it is smart because it
     // remembers the GET and POST data sent to it and resends that on
     // afterwards. 
@@ -1053,6 +1107,7 @@ function auth_get_login_form() {
 
     $form = array(
         'name'           => 'login',
+        'renderer'       => 'div',
         'method'         => 'post',
         'action'         => $action,
         'plugintype'     => 'auth',
@@ -1078,7 +1133,7 @@ function get_login_form_js($form) {
     $form = str_replace('/', '\/', str_replace("'", "\'", (str_replace(array("\n", "\t"), '', $form))));
     $strcookiesnotenabled    = json_encode(get_string('cookiesnotenabled'));
     $cookiename = get_config('cookieprefix') . 'ctest';
-    return <<<EOF
+    $js = <<< EOF
 <script type="text/javascript">
 var loginbox = $('loginform_container');
 document.cookie = "$cookiename=1";
@@ -1091,6 +1146,53 @@ else {
 }
 </script>
 EOF;
+
+    $authplugins = auth_get_enabled_auth_plugins();
+    foreach ($authplugins as $plugin) {
+        $classname = 'PluginAuth' . ucfirst(strtolower($plugin));
+        $pluginjs = call_static_method($classname, 'login_form_js');
+        if (!empty($pluginjs)) {
+            $js .= $pluginjs;
+        }
+    }
+
+    return $js;
+}
+
+/**
+ * Return a list of all enabled and usable auth plugins.
+ */
+function auth_get_enabled_auth_plugins() {
+
+    static $cached_plugins = null;
+    if ($cached_plugins !== null) {
+        return $cached_plugins;
+    }
+
+    $sql = 'SELECT
+                DISTINCT(authname)
+            FROM
+                {auth_instance} ai
+            JOIN
+                {institution} i ON ai.institution = i.name
+            JOIN
+                {auth_installed} inst ON inst.name = ai.authname
+            WHERE
+                i.suspended = 0 AND
+                inst.active = 1';
+    $authplugins = get_column_sql($sql);
+
+    $usableplugins = array();
+    foreach ($authplugins as $plugin) {
+        safe_require('auth', strtolower($plugin));
+        $classname = 'PluginAuth' . ucfirst(strtolower($plugin));
+        if (call_static_method($classname, 'is_usable')) {
+            $usableplugins[] = $plugin;
+        }
+    }
+
+    $cached_plugins = $usableplugins;
+    return $cached_plugins;
 }
 
 
@@ -1141,10 +1243,9 @@ class AuthFactory {
 function login_submit(Pieform $form, $values) {
     global $SESSION, $USER;
 
-    $username      = $values['login_username'];
+    $username      = trim($values['login_username']);
     $password      = $values['login_password'];
     $authenticated = false;
-    $oldlastlogin  = 0;
 
     try {
         $authenticated = $USER->login($username, $password);
@@ -1164,10 +1265,11 @@ function login_submit(Pieform $form, $values) {
             $SESSION->destroy_session();
             $USER = new LiveUser();
 
-            $authinstances = get_records_sql_array('
+            $authinstances = get_records_sql_array("
                 SELECT a.id, a.instancename, a.priority, a.authname, a.institution, i.suspended, i.displayname
                 FROM {institution} i JOIN {auth_instance} a ON a.institution = i.name
-                ORDER BY a.institution, a.priority, a.instancename', null);
+                WHERE a.authname != 'internal'
+                ORDER BY a.institution, a.priority, a.instancename", null);
 
             if ($authinstances == false) {
                 throw new AuthUnknownUserException("\"$username\" is not known");
@@ -1217,23 +1319,34 @@ function login_submit(Pieform $form, $values) {
                 // We have the data - create the user
                 $USER->lastlogin = db_format_timestamp(time());
                 if (isset($userdata->firstname)) {
-                    $USER->firstname = $userdata->firstname;
+                    $USER->firstname = sanitize_firstname($userdata->firstname);
                 }
                 if (isset($userdata->lastname)) {
-                    $USER->lastname = $userdata->lastname;
+                    $USER->lastname = sanitize_firstname($userdata->lastname);
                 }
                 if (isset($userdata->email)) {
-                    $USER->email = $userdata->email;
+                    $USER->email = sanitize_email($userdata->email);
                 }
                 else {
                     // The user will be asked to populate this when they log in.
                     $USER->email = null;
                 }
+
+                $profilefields = array();
+                foreach (array('studentid', 'preferredname') as $pf) {
+                    if (isset($userdata->$pf)) {
+                        $sanitize = 'sanitize_' . $pf;
+                        if (($USER->$pf = $sanitize($userdata->$pf)) !== '') {
+                            $profilefields[$pf] = $USER->$pf;
+                        }
+                    }
+                }
+
                 try {
                     // If this authinstance is a parent auth for some xmlrpc authinstance, pass it along to create_user
                     // so that this username also gets recorded as the username for sso from the remote sites.
                     $remoteauth = count_records('auth_instance_config', 'field', 'parent', 'value', $authinstance->id) ? $authinstance : null;
-                    create_user($USER, array(), $institution, $remoteauth);
+                    create_user($USER, $profilefields, $institution, $remoteauth);
                     $USER->reanimate($USER->id, $authinstance->id);
                 }
                 catch (Exception $e) {
@@ -1258,46 +1371,84 @@ function login_submit(Pieform $form, $values) {
         }
     }
 
-    // Only admins in the admin section!
-    if (!$USER->get('admin') && 
-        (defined('ADMIN') || defined('INSTITUTIONALADMIN') && !$USER->is_institutional_admin())) {
-        $SESSION->add_error_msg(get_string('accessforbiddentoadminsection'));
-        redirect();
-    }
-
-    // Check if the user's account has been deleted
-    if ($USER->deleted) {
-        $USER->logout();
-        die_info(get_string('accountdeleted'));
-    }
-
-    // Check if the user's account has expired
-    if ($USER->expiry > 0 && time() > $USER->expiry) {
-        $USER->logout();
-        die_info(get_string('accountexpired'));
-    }
-
-    // Check if the user's account has become inactive
-    $inactivetime = get_config('defaultaccountinactiveexpire');
-    if ($inactivetime && $oldlastlogin > 0
-        && $oldlastlogin + $inactivetime < time()) {
-        $USER->logout();
-        die_info(get_string('accountinactive'));
-    }
-
-    // Check if the user's account has been suspended
-    if ($USER->suspendedcusr) {
-        $suspendedctime  = strftime(get_string('strftimedaydate'), $USER->suspendedctime);
-        $suspendedreason = $USER->suspendedreason;
-        $USER->logout();
-        die_info(get_string('accountsuspended', 'mahara', $suspendedctime, $suspendedreason));
-    }
+    auth_check_admin_section();
+    ensure_user_account_is_active();
 
     // User is allowed to log in
     //$USER->login($userdata);
     auth_check_required_fields();
 }
 
+/**
+ * Redirect to the home page if the user is trying to access the admin
+ * area without permission
+ */
+function auth_check_admin_section() {
+    global $USER, $SESSION;
+
+    if (defined('ADMIN')) {
+        $allowed = $USER->get('admin');
+    }
+    else if (defined('STAFF')) {
+        $allowed = $USER->get('admin') || $USER->get('staff');
+    }
+    else if (defined('INSTITUTIONALADMIN')) {
+        $allowed = $USER->get('admin') || $USER->is_institutional_admin();
+    }
+    else if (defined('INSTITUTIONALSTAFF')) {
+        $allowed = $USER->get('admin') || $USER->get('staff') || $USER->is_institutional_admin() || $USER->is_institutional_staff();
+    }
+    else {
+        return;
+    }
+
+    if (!$allowed) {
+        $SESSION->add_error_msg(get_string('accessforbiddentoadminsection'));
+        redirect();
+    }
+}
+
+/**
+ * Die and log the user out if their account is not active.
+ *
+ * @param $user The user object to check or null for the currently logged in user.
+ */
+function ensure_user_account_is_active($user=null) {
+
+    $dologout = false;
+    if (!$user) {
+        global $USER;
+        $user = $USER;
+        $dologout = true;
+    }
+
+    // Check if the user's account has been deleted
+    if ($user->deleted) {
+        if ($dologout) {
+            $user->logout();
+        }
+        die_info(get_string('accountdeleted'));
+    }
+
+    // Check if the user's account has expired
+    if ($user->expiry > 0 && time() > $user->expiry) {
+        if ($dologout) {
+            $user->logout();
+        }
+        die_info(get_string('accountexpired'));
+    }
+
+    // Check if the user's account has been suspended
+    if ($user->suspendedcusr) {
+        $suspendedctime  = strftime(get_string('strftimedaydate'), $user->suspendedctime);
+        $suspendedreason = $user->suspendedreason;
+        if ($dologout) {
+            $user->logout();
+        }
+        die_info(get_string('accountsuspended', 'mahara', $suspendedctime, $suspendedreason));
+    }
+}
+
 /**
  * Removes registration requests that were not completed in the allowed amount of time
  */
@@ -1311,8 +1462,8 @@ function _email_or_notify($user, $subject, $bodytext, $bodyhtml) {
     try {
         email_user($user, null, $subject, $bodytext, $bodyhtml);
     }
-    catch (EmailDisabledException $e) {
-        // Send a notification instead - email is disabled for this user
+    catch (EmailException $e) {
+        // Send a notification instead - email is invalid or disabled for this user
         $message = new StdClass;
         $message->users = array($user->id);
         $message->subject = $subject;
@@ -1351,7 +1502,7 @@ function auth_handle_account_expiries() {
     if ($users = get_records_sql_array('SELECT u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.admin, u.staff
         FROM {usr} u
         WHERE ' . db_format_tsfield('u.expiry', false) . ' < ?
-        AND expirymailsent = 0', array(time() + $warn))) {
+        AND expirymailsent = 0 AND deleted = 0', array(time() + $warn))) {
         foreach ($users as $user) {
             $displayname  = display_name($user);
             _email_or_notify($user, get_string('accountexpirywarning'),
@@ -1375,10 +1526,34 @@ function auth_handle_account_expiries() {
     
     if ($expire) {
         // Inactivity (lastlogin is too old)
-        if ($users = get_records_sql_array('SELECT u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.admin, u.staff
+
+        // MySQL doesn't want to compare intervals, so when editing the where clauses below, make sure
+        // the intervals are always added to datetimes first.
+        $dbexpire = db_interval($expire);
+        $dbwarn = db_interval($warn);
+
+        $installationtime = get_config('installation_time');
+        $lastactive = "COALESCE(u.lastaccess, u.lastlogin, u.ctime, ?)";
+
+        // Actual inactive users
+        if ($users = get_records_sql_array("
+            SELECT u.id
             FROM {usr} u
-            WHERE (? - ' . db_format_tsfield('u.lastlogin', false) . ') > ' . ($expire - $warn) . '
-            AND inactivemailsent = 0', array(time()))) {
+            WHERE $lastactive + $dbexpire < current_timestamp
+                AND (u.expiry IS NULL OR u.expiry > current_timestamp) AND id > 0", array($installationtime))) {
+            // Users have become inactive!
+            foreach ($users as $user) {
+                deactivate_user($user->id);
+            }
+        }
+
+        // Inactivity warning emails
+        if ($users = get_records_sql_array("
+            SELECT u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.admin, u.staff
+            FROM {usr} u
+            WHERE $lastactive + $dbexpire < current_timestamp + $dbwarn
+                AND (u.expiry IS NULL OR u.expiry > current_timestamp)
+                AND inactivemailsent = 0 AND deleted = 0 AND id > 0",  array($installationtime))) {
             foreach ($users as $user) {
                 $displayname = display_name($user);
                 _email_or_notify($user, get_string('accountinactivewarning'),
@@ -1388,16 +1563,6 @@ function auth_handle_account_expiries() {
                 set_field('usr', 'inactivemailsent', 1, 'id', $user->id);
             }
         }
-        
-        // Actual inactive users
-        if ($users = get_records_sql_array('SELECT u.id
-            FROM {usr} u
-            WHERE (? - ' . db_format_tsfield('lastlogin', false) . ') > ?', array(time(), $expire))) {
-            // Users have become inactive!
-            foreach ($users as $user) {
-                deactivate_user($user->id);
-            }
-        }
     }
 
     // Institution membership expiry
@@ -1413,7 +1578,7 @@ function auth_handle_account_expiries() {
         INNER JOIN {usr_institution} ui ON u.id = ui.usr
         INNER JOIN {institution} i ON ui.institution = i.name
         WHERE ' . db_format_tsfield('ui.expiry', false) . ' < ?
-        AND ui.expirymailsent = 0', array(time() + $warn))) {
+        AND ui.expirymailsent = 0 AND u.deleted = 0', array(time() + $warn))) {
         foreach ($users as $user) {
             $displayname  = display_name($user);
             _email_or_notify($user, get_string('institutionmembershipexpirywarning'),
@@ -1506,10 +1671,36 @@ function auth_handle_institution_expiries() {
  * out session files of users whose sessions have timed out.
  */
 function auth_remove_old_session_files() {
-    // Note: read the manpage for find and xargs to understand what is going on 
-    // here. In particular, -mtime +1 means files older than about two days 
-    // will be removed
-    exec('find ' . escapeshellarg(get_config('dataroot') . 'sessions') . ' -type f -mtime +1 | xargs -n 1000 -r rm');
+    $basedir = get_config('dataroot') . 'sessions/';
+
+    // delete sessions older than the session timeout plus 2 days
+    $mintime = time() - get_config('session_timeout') - 2 * 24 * 60 * 60;
+
+    // Session files are stored in a three tier md5sum layout
+    // The actual files are stored in the third directory
+    // This loops through all three directories, then checks the files for age
+
+    $iter1 = new DirectoryIterator($basedir);
+    foreach ($iter1 as $dir1) {
+        if ($dir1->isDot()) continue;
+        $dir1path = $dir1->getPath() . '/' . $dir1->getFilename();
+        $iter2 = new DirectoryIterator($dir1path);
+        foreach ($iter2 as $dir2) {
+            if ($dir2->isDot()) continue;
+            $dir2path = $dir2->getPath() . '/' . $dir2->getFilename();
+            $iter3 = new DirectoryIterator($dir2path);
+            foreach ($iter3 as $dir3) {
+                if ($dir3->isDot()) continue;
+                $dir3path = $dir3->getPath() . '/' . $dir3->getFilename();
+                $fileiter = new DirectoryIterator($dir3path);
+                foreach ($fileiter as $file) {
+                    if ($file->isFile() && $file->getCTime() < $mintime) {
+                        unlink($file->getPath() . '/' . $file->getFilename());
+                    }
+                }
+            }
+        }
+    }
     // Throw away records of old login sessions. Should check whether any are still alive.
     delete_records_select('usr_session', 'ctime < ?', array(db_format_timestamp(time() - 86400 * 30)));
 }
@@ -1531,6 +1722,59 @@ function auth_generate_login_form() {
     else {
         $registerlink = '';
     }
+
+    $elements = array(
+        'login_username' => array(
+            'type'        => 'text',
+            'title'       => get_string('username') . ':',
+            'description' => get_string('usernamedescription'),
+            'defaultvalue' => (isset($_POST['login_username'])) ? $_POST['login_username'] : '',
+            'rules' => array(
+                'required'    => true
+            )
+        ),
+        'login_password' => array(
+            'type'        => 'password',
+            'title'       => get_string('password') . ':',
+            'description' => get_string('passworddescription'),
+            'defaultvalue'       => '',
+            'rules' => array(
+                'required'    => true
+            )
+        ),
+        'submit' => array(
+            'type'  => 'submit',
+            'value' => get_string('login')
+        ),
+        'register' => array(
+            'value' => '<div id="login-helplinks">' . $registerlink
+                . '<a href="' . get_config('wwwroot') . 'forgotpass.php" tabindex="2">' . get_string('lostusernamepassword') . '</a></div>'
+        ),
+    );
+
+    // Get any extra elements from the enabled auth plugins
+    $extraelements = array();
+    $showbasicform = false;
+    $authplugins = auth_get_enabled_auth_plugins();
+    foreach ($authplugins as $plugin) {
+        $classname = 'PluginAuth' . ucfirst(strtolower($plugin));
+        $pluginelements = call_static_method($classname, 'login_form_elements');
+        if (!empty($pluginelements)) {
+            $extraelements = array_merge($extraelements, $pluginelements);
+        }
+        if (call_static_method($classname, 'need_basic_login_form')) {
+            $showbasicform = true;
+        }
+    }
+
+    // Replace or supplement the standard login form elements
+    if ($showbasicform) {
+        $elements = array_merge($elements, $extraelements);
+    }
+    else {
+        $elements = $extraelements;
+    }
+
     $loginform = get_login_form_js(pieform(array(
         'name'       => 'login',
         'renderer'   => 'div',
@@ -1538,34 +1782,7 @@ function auth_generate_login_form() {
         'plugintype' => 'auth',
         'pluginname' => 'internal',
         'autofocus'  => false,
-        'elements'   => array(
-            'login_username' => array(
-                'type'        => 'text',
-                'title'       => get_string('username') . ':',
-                'description' => get_string('usernamedescription'),
-                'defaultvalue' => (isset($_POST['login_username'])) ? $_POST['login_username'] : '',
-                'rules' => array(
-                    'required'    => true
-                )
-            ),
-            'login_password' => array(
-                'type'        => 'password',
-                'title'       => get_string('password') . ':',
-                'description' => get_string('passworddescription'),
-                'defaultvalue'       => '',
-                'rules' => array(
-                    'required'    => true
-                )
-            ),
-            'submit' => array(
-                'type'  => 'submit',
-                'value' => get_string('login')
-            ),
-            'register' => array(
-                'value' => '<div id="login-helplinks">' . $registerlink
-                    . '<a href="' . get_config('wwwroot') . 'forgotpass.php" tabindex="2">' . get_string('lostusernamepassword') . '</a></div>'
-            )
-        )
+        'elements'   => $elements,
     )));
 
     return $loginform;
@@ -1621,6 +1838,25 @@ function auth_get_random_salt() {
     return substr(md5(rand(1000000, 9999999)), 2, 8);
 }
 
+// Add salt and encrypt the pw for a user, if their auth instance allows for it
+function reset_password($user, $resetpasswordchange=true, $quickhash=false) {
+    $userobj = new User();
+    $userobj->find_by_id($user->id);
+    $authobj = AuthFactory::create($user->authinstance);
+    if (isset($user->password) && $user->password != '' && method_exists($authobj, 'change_password')) {
+        $authobj->change_password($userobj, $user->password, $resetpasswordchange, $quickhash);
+    }
+    else {
+        $userobj->password = '';
+        $userobj->salt = auth_get_random_salt();
+        $userobj->commit();
+    }
+}
+
+function user_login_tries_to_zero() {
+    execute_sql('UPDATE {usr} SET logintries = 0 WHERE logintries > 0');
+}
+
 class PluginAuth extends Plugin {
 
     public static function get_event_subscriptions() {
@@ -1658,6 +1894,14 @@ class PluginAuth extends Plugin {
     }
 
     public static function update_active_flag($event, $user) {
+        if (!isset($user['id'])) {
+            log_warn("update_active_flag called without a user id");
+        }
+
+        if ($user['id'] === 0 || $user['id'] === '0') {
+            return;
+        }
+
         $active = true;
 
         // ensure we have everything we need
@@ -1670,8 +1914,11 @@ class PluginAuth extends Plugin {
         else if ($user->expiry && $user->expiry < time()) {
             $active = false;
         }
-        else if ($inactivetime && $user->lastlogin + $inactivetime < time()) {
-            $active = false;
+        else if ($inactivetime) {
+            $lastactive = max($user->lastlogin, $user->lastaccess, $user->ctime);
+            if ($lastactive && ($lastactive + $inactivetime < time())) {
+                $active = false;
+            }
         }
         else if ($user->deleted) {
             $active = false;
@@ -1685,4 +1932,28 @@ class PluginAuth extends Plugin {
     public static function can_be_disabled() {
         return false;
     }
+
+    /**
+     * Can be overridden by plugins that need to inject more
+     * pieform elements into the login form.
+     */
+    public static function login_form_elements() {
+        return false;
+    }
+
+    /**
+     * Can be overridden by plugins that need to inject more
+     * Javascript to make the login form work.
+     */
+    public static function login_form_js() {
+        return false;
+    }
+
+    /**
+     * Can be overridden by plugins that inject the things they need
+     * in the login form and don't need the standard elements.
+     */
+    public static function need_basic_login_form() {
+        return true;
+    }
 }
