@@ -26,20 +26,29 @@
 
 defined('INTERNAL') || die();
 
-//$string['defaultidpidentity'] = 'Default IdP Identity Service';
+//$string['defaultidpidentity'] = 'Default IdP identity service';
 $string['defaultinstitution'] = 'Default institution';
 $string['description'] = 'Authenticate against a SAML 2.0 IdP service';
 $string['errorbadinstitution'] = 'Institution for connecting user not resolved';
-$string['errorretryexceeded'] = 'Maximum number of retries exceeded (%s) - there must be a problem with the Identity Service';
-$string['errnosamluser'] = 'No User found';
+$string['errorbadssphp'] = 'Invalid SimpleSAMLphp session handler - must not be phpsession';
+$string['errorbadssphplib'] = 'Invalid SimpleSAMLphp library configuration';
+$string['errorretryexceeded'] = 'Maximum number of retries exceeded (%s) - there must be a problem with the identity service';
+$string['errnosamluser'] = 'No user found';
 $string['errorbadlib'] = 'SimpleSAMLPHP lib directory %s is not correct.';
-$string['errorbadconfig'] = 'SimpleSAMLPHP config directory %s is in correct.';
+$string['errorbadconfig'] = 'SimpleSAMLPHP config directory %s is incorrect.';
 $string['errorbadcombo'] = 'You can only choose user auto creation if you have not selected remoteuser';
-$string['errormissinguserattributes'] = 'You seem to be authenticated but we did not receive the required user attributes. Please check that your Identity Provider releases these SSO fields for First Name, Surname, and Email to the Service Provider Mahara is running on or inform the webmaster of this server.';
+$string['errorbadinstitutioncombo'] = 'There is already an existing authinstance with this institutionattribute and institutionvalue combination';
+$string['errormissinguserattributes1'] = 'You seem to be authenticated but we did not receive the required user attributes. Please check that your Identity Provider releases the First Name, Surname, and Email fields for SSO to %s, or inform the administrator.';
 $string['errorremoteuser'] = 'Matching on remoteuser is mandatory if usersuniquebyusername is turned off';
 $string['institutionattribute'] = 'Institution attribute (contains "%s")';
 $string['institutionvalue'] = 'Institution value to check against attribute';
+$string['link'] = 'Link accounts';
+$string['linkaccounts'] = 'Do you want to link remote account %s with local account %s ?';
+$string['loginlink'] = 'Allow users to link own account';
+$string['logintolink'] = 'Local login to %s to link to remote account';
+$string['logintolinkdesc'] = '<p><b>You are currently connected with remote user %s.  Please login with your local account to link them together, or register if you do not currently have an account on %s.</b></p>';
 $string['institutionregex'] = 'Do partial string match with institution shortname';
+$string['login'] = 'SSO Login';
 $string['notusable'] = 'Please install the SimpleSAMLPHP SP libraries';
 $string['samlfieldforemail'] = 'SSO field for Email';
 $string['samlfieldforfirstname'] = 'SSO field for First Name';
