@@ -26,6 +26,7 @@
  */
 
 defined('INTERNAL') || die();
+define('MAXLOGINTRIES', 5);
 $put = array();
 
 
@@ -86,6 +87,8 @@ class User {
             'institutions'     => array(),
             'grouproles'       => array(),
             'theme'            => null,
+            'headerlogo'       => null,
+            'stylesheets'      => array(),
             'admininstitutions' => array(),
             'staffinstitutions' => array(),
             'parentuser'       => null,
@@ -93,7 +96,8 @@ class User {
             'sesskey'          => '',
             'ctime'            => null,
             'views'            => array(),
-            'showhomeinfo'     => 1
+            'showhomeinfo'     => 1,
+            'unread'           => 0,
         );
         $this->attributes = array();
 
@@ -329,6 +333,21 @@ class User {
         }
     }
 
+    /**
+     * Convert from a row object from the usr table
+     *
+     * @param  object $data  The row data
+     */
+    public function from_stdclass($data) {
+        foreach (array('expiry', 'lastlogin', 'lastlastlogin', 'lastaccess', 'suspendedctime', 'ctime') as $f) {
+            if (isset($data->$f) && !is_numeric($data->$f)) {
+                $data->$f = strtotime($data->$f);
+            }
+        }
+        $this->populate($data);
+        return $this;
+    }
+
     /**
      * Gets the user property keyed by $key.
      *
@@ -513,7 +532,7 @@ class User {
             $configdata['artefactids'][] = $intro;
         }
         else {
-            $configdata['introtext'] = get_string('thisistheprofilepagefor', 'mahara', display_name($this, null, true));
+            $configdata['introtext'] = '';
         }
         if ($this->get('profileicon')) {
             $configdata['profileicon'] = $this->get('profileicon');
@@ -521,13 +540,26 @@ class User {
         $aboutme->set('configdata', $configdata);
         $view->addblockinstance($aboutme);
 
-        $view->set_access(array(
+        // Set view access
+        $access = array(
             array(
                 'type'      => 'loggedin',
                 'startdate' => null,
                 'stopdate'  => null,
             ),
-        ));
+        );
+        if ($institutions = $this->get('institutions')) {
+            foreach ($institutions as $i) {
+                $access[] = array(
+                    'type'      => 'institution',
+                    'id'        => $i->institution,
+                    'startdate' => null,
+                    'stopdate'  => null,
+                );
+            }
+        }
+        $view->set_access($access);
+
         db_commit();
 
         return $view;
@@ -708,6 +740,23 @@ class User {
         return $this->get('admin') || $this->is_institutional_admin($institution);
     }
 
+    public function institution_allows_public_views($institution = null) {
+        $user_institutions = $this->get('institutions');
+        if (empty($user_institutions)) {
+            // user belongs to no institutions
+            return true;
+        }
+        else if (is_null($institution) || !isset($user_institutions[$institution->institution])) {
+            foreach ($user_institutions as $institution) {
+                if ($institution->allowinstitutionpublicviews == 1) {
+                    return true;
+                }
+            }
+            return false;
+        }
+        return $user_institutions[$institution->institution]->allowinstitutionpublicviews == 1;
+    }
+
     /**
      * Returns whether this user is allowed to perform administration type
      * actions on another user.
@@ -783,35 +832,58 @@ class User {
         $institution->addRequestFromUser($this, $studentid);
     }
 
-    public function reset_institutions() {
+    public function reset_institutions($nocachecss=false) {
         $institutions             = load_user_institutions($this->id);
         $admininstitutions = array();
         $staffinstitutions = array();
         $this->theme = get_config('theme');
-        foreach ($institutions as $i) {
+        $this->headerlogo = null;
+        $stylesheets = array();
+        $themeinstitution = null;
+        foreach ($institutions as $name => $i) {
             if ($i->admin) {
                 $admininstitutions[$i->institution] = $i->institution;
             }
             if ($i->staff) {
                 $staffinstitutions[$i->institution] = $i->institution;
             }
-            if (!empty($i->theme) && $this->theme == get_config('theme') && $i->theme != $this->theme) {
-                $this->theme = $i->theme;
+            if (is_null($themeinstitution)) {
+                $themeinstitution = $name;
             }
         }
         if ($this->authinstance) {
             $authobj = AuthFactory::create($this->authinstance);
             if (isset($institutions[$authobj->institution])) {
-                if ($t = $institutions[$authobj->institution]->theme) {
-                    $this->theme = $t;
+                if ($institutions[$authobj->institution]->theme) {
+                    $themeinstitution = $authobj->institution;
                 }
             }
         }
+        if (!is_null($themeinstitution)) {
+            $this->theme      = $institutions[$themeinstitution]->theme;
+            $this->headerlogo = $institutions[$themeinstitution]->logo;
+            if ($institutions[$themeinstitution]->style) {
+                $stylesheet = get_config('wwwroot') . 'style.php?id=' . $institutions[$themeinstitution]->style;
+                if ($nocachecss) {
+                    $stylesheet .= '&time=' . time();
+                }
+                $stylesheets[] = $stylesheet;
+            }
+        }
+        $this->stylesheets        = $stylesheets;
         $this->institutions       = $institutions;
         $this->admininstitutions  = $admininstitutions;
         $this->staffinstitutions  = $staffinstitutions;
     }
 
+    public function get_themedata() {
+        return (object) array(
+            'basename'    => $this->theme,
+            'headerlogo'  => $this->headerlogo,
+            'stylesheets' => $this->stylesheets,
+        );
+    }
+
     public function reset_grouproles() {
         $memberships = get_records_array('group_member', 'member', $this->get('id'));
         $roles = array();
@@ -845,34 +917,53 @@ class User {
             || ($a->get('institution') and $this->is_institutional_admin($a->get('institution')))) {
             return true;
         }
-        $group = $a->get('group');
-        if ($group) {
-            return count_records_sql("SELECT COUNT(*) FROM {artefact_access_role} ar
-                INNER JOIN {group_member} g ON ar.role = g.role
-                WHERE ar.artefact = ? AND g.member = ? AND ar.can_edit = 1 AND g.group = ?", array($a->get('id'), $this->get('id'), $group));
-            /*
-            require_once(get_config('docroot') . 'lib/group.php');
-            $role = group_user_access($group, $this->get('id'));
-            if ($role) {
-                $aperms = $a->get('rolepermissions');
-                return $aperms->{$role}->edit;
-            } */
+
+        if (!$group = $a->get('group')) {
+            return false;
         }
-        return false;
+
+        require_once('group.php');
+        if (!$role = group_user_access($group, $this->id)) {
+            return false;
+        }
+        if ($role == 'admin') {
+            return true;
+        }
+        if ($this->id == $a->get('author')) {
+            return true;
+        }
+
+        return $a->role_has_permission($role, 'edit');
     }
 
     public function can_publish_artefact($a) {
-        if (($this->get('id') and $this->get('id') == $a->get('owner'))
-            || ($a->get('institution') and $this->is_institutional_admin($a->get('institution')))) {
+        if (($this->get('id') and $this->get('id') == $a->get('owner'))) {
             return true;
         }
-        $group = $a->get('group');
-        if ($group) {
-            return count_records_sql("SELECT COUNT(*) FROM {artefact_access_role} ar
-                INNER JOIN {group_member} g ON ar.role = g.role
-                WHERE ar.artefact = ? AND g.member = ? AND ar.can_publish = 1 AND g.group = ?", array($a->get('id'), $this->get('id'), $group));
+
+        if ($i = $a->get('institution')) {
+            if ($i == 'mahara') {
+                return $this->get('admin');
+            }
+            return $this->in_institution($i);
         }
-        return false;
+
+        if (!$group = $a->get('group')) {
+            return false;
+        }
+
+        require_once('group.php');
+        if (!$role = group_user_access($group, $this->id)) {
+            return false;
+        }
+        if ($role == 'admin') {
+            return true;
+        }
+        if ($this->id == $a->get('author')) {
+            return true;
+        }
+
+        return $a->role_has_permission($role, 'republish');
     }
 
     public function can_edit_view($v) {
@@ -886,12 +977,42 @@ class User {
         }
         $group = $v->get('group');
         if ($group) {
-            $editroles = $v->get('editingroles');
             $this->reset_grouproles();
-            if ($v->get('type') == 'grouphomepage' && $this->grouproles[$group] != 'admin') {
+            if (!isset($this->grouproles[$group])) {
                 return false;
             }
-            return isset($this->grouproles[$group]) && in_array($this->grouproles[$group], $editroles);
+            if (($v->get('type') == 'grouphomepage' || $v->get('locked')) && $this->grouproles[$group] != 'admin') {
+                return false;
+            }
+            require_once('group.php');
+            return group_role_can_edit_views($group, $this->grouproles[$group]);
+        }
+        return false;
+    }
+
+    /**
+     * Function to check if user can moderate (ie; delete) comments in a view
+     */
+    public function can_moderate_view($v) {
+        $owner = $v->get('owner');
+        if ($owner > 0 && $owner == $this->get('id')) {
+            return true;
+        }
+        $institution = $v->get('institution');
+        if ($institution && $this->can_edit_institution($institution)) {
+            return true;
+        }
+        $group = $v->get('group');
+        if ($group) {
+            $this->reset_grouproles();
+            if (!isset($this->grouproles[$group])) {
+                return false;
+            }
+            if (($v->get('type') == 'grouphomepage' || $v->get('locked')) && $this->grouproles[$group] != 'admin') {
+                return false;
+            }
+            require_once('group.php');
+            return group_role_can_moderate_views($group, $this->grouproles[$group]);
         }
         return false;
     }
@@ -1005,15 +1126,13 @@ class LiveUser extends User {
             throw new AuthUnknownUserException("\"$username\" is not known");
         }
 
-        $siteclosedforupgrade = get_config('siteclosed');
-        if ($siteclosedforupgrade && get_config('disablelogin')) {
-            global $SESSION;
-            $SESSION->add_error_msg(get_string('siteclosedlogindisabled', 'mahara', get_config('wwwroot') . 'admin/upgrade.php'), false);
-            return false;
+        if (isset($user->logintries) && $user->logintries >= MAXLOGINTRIES) {
+           global $SESSION;
+           $SESSION->add_error_msg(get_string('toomanytries', 'auth'));
+           return false;
         }
-        if (!$user->admin && ($siteclosedforupgrade || get_config('siteclosedbyadmin'))) {
-            global $SESSION;
-            $SESSION->add_error_msg(get_string('siteclosed'));
+
+        if (is_site_closed($user->admin)) {
             return false;
         }
 
@@ -1064,6 +1183,16 @@ class LiveUser extends User {
             $SESSION->add_info_msg(clean_html($auth->authloginmsg), false);
         }
 
+        if (empty($user->logintries)) {
+            $user->logintries = 0;
+        }
+
+        if ($user->logintries < MAXLOGINTRIES) {
+            $record =get_record('usr', 'id', $user->id, null, null, null, null, 'id, logintries');
+            $record->logintries = ($user->logintries + 1);
+            update_record('usr', $record, false);
+        }
+
         return false;
     }
 
@@ -1071,6 +1200,8 @@ class LiveUser extends User {
      * Logs the current user out
      */
     public function logout () {
+        require_once(get_config('libroot') . 'ddl.php');
+
         if ($this->changed == true) {
             log_debug('Destroying user with un-committed changes');
         }
@@ -1082,7 +1213,7 @@ class LiveUser extends User {
         // Unset session variables related to authentication
         $this->SESSION->set('authinstance', null);
         if (get_config('installed') && !defined('INSTALLER') && $this->get('sessionid')
-            && function_exists('table_exists') && table_exists(new XMLDBTable('usr_session'))) {
+            && table_exists(new XMLDBTable('usr_session'))) {
             delete_records('usr_session', 'session', $this->get('sessionid'));
         }
 
@@ -1094,6 +1225,38 @@ class LiveUser extends User {
         $this->changed = false;
     }
 
+    /**
+     * Some fields may have been changed in the db by some other process, and
+     * should be occasionally reloaded into the session.
+     */
+    public function reload_background_fields() {
+        $reload = array(
+            'active', 'deleted', 'expiry', 'expirymailsent', 'inactivemailsent', 'suspendedctime', 'suspendedreason',
+            'suspendedcusr', 'quota', 'unread',
+        );
+        $tsfields = array('expiry', 'suspendedctime');
+        $record = get_record('usr', 'id', $this->id);
+        foreach ($reload as $f) {
+            if (!isset($record->$f)) {
+                continue;
+            }
+            if (in_array($f, $tsfields)) {
+                $record->$f = strtotime($record->$f);
+            }
+            if ($record->$f != $this->$f) {
+                $this->$f = $record->$f;
+            }
+        }
+    }
+
+    public function commit() {
+        if ($this->changed == false) {
+            return;
+        }
+        $this->reload_background_fields();
+        parent::commit();
+    }
+
     /**
      * Updates information in a users' session once we know their session is 
      * continuing
@@ -1163,6 +1326,13 @@ class LiveUser extends User {
         $this->load_views();
         $this->store_sessionid();
 
+        // This user may have logged in to reactivate themselves, so now we know they're active, reset
+        // the fields that may have been changed by cron.
+        if (!$this->active || $this->inactivemailsent) {
+            // Properties will be reloaded by the call to $this->commit() below
+            execute_sql('UPDATE {usr} SET active = 1, inactivemailsent = 0 WHERE id = ?', array($user->id));
+        }
+
         $this->commit();
 
         // finally, after all is done, call the (maybe non existant) hook on their auth plugin
@@ -1243,7 +1413,7 @@ class LiveUser extends User {
 
         $olduser = new StdClass;
         $olduser->id = $this->get('id');
-        $olduser->name = $this->firstname . ' ' . $this->lastname;
+        $olduser->name = display_name($this, null, true);
 
         $this->reloadLiveUser($userid);
 
@@ -1271,15 +1441,15 @@ class LiveUser extends User {
     }
 
     public function update_theme() {
-        $this->reset_institutions();
+        $this->reset_institutions(true);
         $this->commit();
     }
 
-    public function reset_institutions() {
+    public function reset_institutions($nocachecss=false) {
         global $THEME;
-        parent::reset_institutions();
-        if (isset($THEME->basename) && $this->theme != $THEME->basename && !defined('INSTALLER')) {
-            $THEME = new Theme($this->theme);
+        parent::reset_institutions($nocachecss);
+        if (!defined('INSTALLER')) {
+            $THEME = new Theme($this);
         }
     }
 
@@ -1293,4 +1463,52 @@ class LiveUser extends User {
         ));
     }
 
+   /**
+    * Writes a file to dataroot and saves details in the session,
+    * for later download by the user
+    *
+    * @param $content string file contents
+    * @param $name string filename to be used when downloading the file
+    * @param $mimetype string
+    */
+    public function set_download_file($content, $name, $mimetype) {
+        global $SESSION;
+
+        $filename = get_random_key();
+        $dir = get_config('dataroot') . 'export/' . $this->id . '/';
+        check_dir_exists($dir);
+        file_put_contents($dir . $filename, $content);
+
+        $SESSION->set('downloadfile', array(
+            'file'     => $filename,
+            'name'     => $name,
+            'mimetype' => $mimetype,
+        ));
+    }
+
+    public function add_unread($n) {
+        // The unread property can change any time a notification is processed on
+        // cron, so it's reloaded from the db in commit(), every time the last
+        // access time is saved.  This just updates it in the session.
+        $new = $this->get('unread') + $n;
+        $this->SESSION->set('user/unread', $new);
+        return $new;
+    }
+}
+
+function is_site_closed($adminuser) {
+    $siteclosedforupgrade = get_config('siteclosed');
+    if ($siteclosedforupgrade && get_config('disablelogin')) {
+        global $SESSION;
+        $SESSION->add_error_msg(get_string('siteclosedlogindisabled', 'mahara', get_config('wwwroot') . 'admin/upgrade.php'), false);
+        return true;
+    }
+
+    if (!$adminuser && ($siteclosedforupgrade || get_config('siteclosedbyadmin'))) {
+        global $SESSION;
+        $SESSION->add_error_msg(get_string('siteclosed'));
+        return true;
+    }
+
+    return false;
 }
