@@ -114,6 +114,7 @@ if ($res == true) {
     if ($remoteurl) {
         redirect($remotewwwroot . $wantsurl);
     }
+    $wantsurl = ltrim($wantsurl, '/');  // wwwroot ends with / so don't bother having extra slashes
     redirect(get_config('wwwroot') . $wantsurl);
     // Redirect exits
 }
@@ -121,5 +122,6 @@ if ($res == true) {
 if ($rpcconfigured === false) {
     throw new XmlrpcUserNotFoundException(get_string('errnoxmlrpcinstances','auth', $remotewwwroot));
 } else {
-    throw new XmlrpcUserNotFoundException(get_string('errnoxmlrpcuser','auth'));
+    $sitename = get_config('sitename');
+    throw new XmlrpcUserNotFoundException(get_string('errnoxmlrpcuser1', 'auth', $sitename, $sitename));
 }
