@@ -337,8 +337,11 @@ class AuthXmlrpc extends Auth {
                         // Entry in artefact table
                         $artefact = new ArtefactTypeProfileIcon();
                         $artefact->set('owner', $user->id);
-                        $artefact->set('title', 'Profile Icon');
-                        $artefact->set('note', 'Profile Icon');
+                        $artefact->set('parent', ArtefactTypeFolder::get_folder_id(get_string('imagesdir', 'artefact.file'),
+                            get_string('imagesdirdesc', 'artefact.file'), null, true, $user->id));
+                        $artefact->set('title', ArtefactTypeFileBase::get_new_file_title(get_string('profileicon', 'artefact.file'), (int)$artefact->get('parent'), $user->id));  // unique title
+                        $artefact->set('description', get_string('uploadedprofileicon', 'artefact.file'));
+                        $artefact->set('note', get_string('profileicon', 'artefact.file'));
                         $artefact->set('size', $filesize);
                         $artefact->set('filetype', $mime);
                         $artefact->set('width', $width);
@@ -378,7 +381,9 @@ class AuthXmlrpc extends Auth {
         // the session object.
         $SESSION->set('mnetuser', $user->id);
         $SESSION->set('authinstance', $this->instanceid);
-        $SESSION->set('mnetuserfrom', $_SERVER['HTTP_REFERER']);
+        if (isset($_SERVER['HTTP_REFERER'])) {
+            $SESSION->set('mnetuserfrom', $_SERVER['HTTP_REFERER']);
+        }
 
         if ($update && isset($locked)) {
             $SESSION->set('lockedfields', $locked);
@@ -467,7 +472,7 @@ class AuthXmlrpc extends Auth {
         // Language
         if (!empty($remoteuser->lang)) {
             $validlanguages = array_keys(get_languages());
-            $newlanguage = str_replace('_', '.', strtolower($remoteuser->lang));
+            $newlanguage = str_replace('_utf8', '', strtolower($remoteuser->lang)) . '.utf8';
             if (in_array($newlanguage, $validlanguages)) {
                 set_account_preference($user->id, 'lang', $newlanguage);
                 $user->set_account_preference('lang', $newlanguage);
@@ -524,6 +529,8 @@ class AuthXmlrpc extends Auth {
     public function logout() {
         global $USER, $SESSION;
 
+        $sessionlogouttime = $USER->get('logout_time');
+
         if (get_config('usersuniquebyusername')) {
             // The auth_remote_user will have a row for the institution in 
             // which the user SSOed into first. However, they could have 
@@ -553,12 +560,14 @@ class AuthXmlrpc extends Auth {
         }
         elseif (!$this->parent) {
             $this->kill_parent($remoteusername);
-            // Redirect back to their IDP if they don't have a parent auth method set 
-            // (aka: they can't log in at Mahara's log in form)
-            $peer = get_peer($this->wwwroot);
-            // TODO: This should be stored in the application config table
-            $jumpurl = str_replace('land', 'jump', $peer->application->ssolandurl);
-            redirect($this->wwwroot . $jumpurl . '?hostwwwroot=' . dropslash(get_config('wwwroot')) . '&wantsurl=' . urlencode($_SERVER['REQUEST_URI']));
+            if ($sessionlogouttime == 0 || $sessionlogouttime > time()) {
+                // Redirect back to their IDP if they don't have a parent auth method set
+                // (aka: they can't log in at Mahara's log in form)
+                $peer = get_peer($this->wwwroot);
+                // TODO: This should be stored in the application config table
+                $jumpurl = str_replace('land', 'jump', $peer->application->ssolandurl);
+                redirect($this->wwwroot . $jumpurl . '?hostwwwroot=' . dropslash(get_config('wwwroot')) . '&wantsurl=' . urlencode($_SERVER['REQUEST_URI']));
+            }
         }
 
         // Anything else is a session timeout
@@ -853,7 +862,7 @@ class PluginAuthXmlrpc extends PluginAuth {
         );
     }
 
-    public static function validate_config_options($values, $form) {
+    public static function validate_instance_config_options($values, $form) {
         if (false === strpos($values['wwwroot'], '://')) {
             $values['wwwroot'] = 'http://' . $values['wwwroot'];
         }
@@ -893,7 +902,7 @@ class PluginAuthXmlrpc extends PluginAuth {
         //TODO: test values and set appropriate errors on form
     }
 
-    public static function save_config_options($values, $form) {
+    public static function save_instance_config_options($values, $form) {
         if (false === strpos($values['wwwroot'], '://')) {
             $values['wwwroot'] = 'http://' . $values['wwwroot'];
         }
