@@ -27,10 +27,23 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'External Video';
-$string['description'] = 'Embed external videos';
-$string['videourl'] = 'Video URL';
-$string['videourldescription2'] = 'Paste the embed code or the URL of the page where the video is located. You can embed videos from the following sites:';
+$string['title'] = 'External media';
+$string['description'] = 'Embed external content';
+$string['videourl'] = 'Content URL';
+$string['videourldescription2'] = 'Paste the embed code or the URL of the page where the content is located. You can embed content from the following sites:';
 $string['width'] = 'Width';
 $string['height'] = 'Height';
 $string['invalidurl'] = 'Invalid URL';
+
+//Supported sites language strings
+$string['googlevideo'] = 'Google Video';
+$string['scivee'] = 'SciVee';
+$string['youtube'] = 'YouTube';
+$string['teachertube'] = 'TeacherTube';
+$string['slideshare'] = 'SlideShare';
+$string['prezi'] = 'Prezi';
+$string['glogster'] = 'Glogster';
+$string['vimeo'] = 'Vimeo';
+$string['voki'] = 'Voki';
+$string['voicethread'] = 'VoiceThread';
+$string['wikieducator'] = 'WikiEducator';
