@@ -38,10 +38,19 @@ defined('INTERNAL') || die();
  */
 class PluginBlocktypeExternalvideo extends SystemBlocktype {
 
-    // Default width and height for video players
-    private static $default_width = 250;
-
-    private static $default_height = 250;
+    private static $media_sources = array(
+        'youtube',
+        'teachertube',
+        'scivee',
+        'googlevideo',
+        'glogster',
+        'slideshare',
+        'voicethread',
+        'wikieducator',
+        'prezi',
+        'vimeo',
+        'voki',
+    );
 
     public static function get_title() {
         return get_string('title', 'blocktype.externalvideo');
@@ -55,13 +64,40 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
         return array('external');
     }
 
+    private static function load_media_sources() {
+        static $loaded_sources = array();
+
+        if (!empty($loaded_sources)) {
+            return $loaded_sources;
+        }
+
+        foreach (self::$media_sources as $source) {
+            include_once('media_sources/' . $source . '/mediasource.php');
+            $sourcename = 'Media_' . $source;
+            $loaded_sources[$source] = new $sourcename;
+        }
+        return $loaded_sources;
+    }
+
     public static function render_instance(BlockInstance $instance, $editing=false) {
         $configdata = $instance->get('configdata');
         $result = '';
-        $width  = (!empty($configdata['width'])) ? hsc($configdata['width']) : self::$default_width;
-        $height = (!empty($configdata['height'])) ? hsc($configdata['height']) : self::$default_height;
+        $width  = (!empty($configdata['width'])) ? hsc($configdata['width']) : 0;
+        $height = (!empty($configdata['height'])) ? hsc($configdata['height']) : 0;
 
         if (isset($configdata['videoid'])) {
+            if (!isset($configdata['type'])) {
+                $configdata = self::process_url($configdata['videoid'], $configdata['width'], $configdata['height']);
+                $instance->set('configdata', $configdata);
+                $instance->commit();
+                if (!$configdata) {
+                    // The video link doesn't work
+                    return $result;
+                }
+            }
+
+            $url = hsc($configdata['videoid']);
+
             // IE seems to wait for all elements on the page to load
             // fully before the onload event goes off.  This means the
             // view editor isn't initialised until all videos have
@@ -72,21 +108,27 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
             // view editing page, keep the embed code out of the page
             // initially and add it in after the page has loaded.
 
-            $url     = hsc(self::make_video_url($configdata['videoid']));
+            $embed = '';
 
-            $embed = '<object width="' . $width . '" height="' . $height . '">';
-            $embed .= '<param name="movie" value="' . $url . '"></param>';
-            $embed .= '<param name="wmode" value="transparent"></param>';
-            $embed .= '<param name="allowscriptaccess" value="never"></param>';
-            $embed .= '<embed src="' . $url . '" ';
-            $embed .= 'type="application/x-shockwave-flash" wmode="transparent" width="' . $width . '" ';
-            $embed .= 'height="' . $height . '" allowscriptaccess="never"></embed></object>';
+            if (isset($configdata['type']) && $configdata['type'] == 'embed') {
+                $embed  = '<object width="' . $width . '" height="' . $height . '">';
+                $embed .= '<param name="movie" value="' . $url . '"></param>';
+                $embed .= '<param name="wmode" value="transparent"></param>';
+                $embed .= '<param name="allowscriptaccess" value="never"></param>';
+                $embed .= '<embed src="' . $url . '" ';
+                $embed .= 'type="application/x-shockwave-flash" wmode="transparent" width="' . $width . '" ';
+                $embed .= 'height="' . $height . '" allowscriptaccess="never"></embed></object>';
+            }
+            else if (isset($configdata['type']) && $configdata['type'] == 'iframe') {
+                $embed  = '<iframe width="' . $width . '" height="' . $height . '" ';
+                $embed .= 'src="' . $url . '" frameborder=0></iframe>';
+            }
 
             $block = $instance->get('id');
             $configuring = $block == param_integer('blockconfig', 0);
 
             $result .= '<div class="mediaplayer-container center">';
-            $result .= '<div id="vid_' . $block . '" class="mediaplayer" style="width: {$width}px; height: {$height}px; margin: 0 auto;">';
+            $result .= '<div id="vid_' . $block . '" class="mediaplayer" style="width: ' . $width . 'px; height: ' . $height . 'px; margin: 0 auto;">';
 
             if (!$editing || $configuring) {
                 $result .= $embed;
@@ -100,7 +142,6 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
                 $result .= '</script>';
             }
         }
-
         return $result;
     }
 
@@ -110,6 +151,7 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
 
     public static function instance_config_form($instance) {
         $configdata = $instance->get('configdata');
+
         return array(
             'videoid' => array(
                 'type'  => 'text',
@@ -118,7 +160,7 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
                 'width' => '90%',
                 'defaultvalue' => isset($configdata['videoid']) ? $configdata['videoid'] : null,
                 'rules' => array(
-                    'required' => true
+                    'required' => true,
                 ),
             ),
             'width' => array(
@@ -126,95 +168,77 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
                 'title' => get_string('width','blocktype.externalvideo'),
                 'size' => 3,
                 'rules' => array(
-                    'required' => true,
-                    'integer'  => true,
-                    'minvalue' => 100,
-                    'maxvalue' => 800,
+                    'regex'  => '#\d+%?#',
+                    'minvalue' => 0,
+                    'maxvalue' => 2000,
                 ),
-                'defaultvalue' => (!empty($configdata['width'])) ? $configdata['width'] : self::$default_width,
+                'defaultvalue' => (!empty($configdata['width'])) ? $configdata['width'] : 0,
             ),
             'height' => array(
                 'type' => 'text',
                 'title' => get_string('height','blocktype.externalvideo'),
                 'size' => 3,
                 'rules' => array(
-                    'required' => true,
-                    'integer'  => true,
-                    'minvalue' => 100,
-                    'maxvalue' => 800,
+                    'regex'  => '#\d+%?#',
+                    'minvalue' => 0,
+                    'maxvalue' => 2000,
                 ),
-                'defaultvalue' => (!empty($configdata['height'])) ? $configdata['height'] : self::$default_height,
+                'defaultvalue' => (!empty($configdata['height'])) ? $configdata['height'] : 0,
             ),
         );
     }
 
     public static function instance_config_validate(Pieform $form, $values) {
         if ($values['videoid']) {
-            $urlparts = parse_url($values['videoid']);
-            if (empty($urlparts['host'])) {
+            $sources = self::load_media_sources();
+
+            $valid = false;
+            foreach ($sources as $name => $source) {
+                if ($valid = $source->validate_url($values['videoid'])) {
+                    break;
+                }
+            }
+            if (!$valid) {
                 $form->set_error('videoid', get_string('invalidurl', 'blocktype.externalvideo'));
             }
         }
     }
 
-    private static function make_video_url($url) {
-        static $embedsources = array(
-            // www.youtube.com (old style)
-            array(
-                'match' => '#.*youtube\.com.*(v|(cp))(=|\/)([a-zA-Z0-9_=-]+).*#',
-                'url'   => 'http://www.youtube.com/$1/$4'
-            ),
-            // www.youtube.com (iframe)
-            array(
-                'match' => '#.*youtube\.com.*(embed\/)([a-zA-Z0-9_=-]+).*#',
-                'url' => 'http://www.youtube.com/v/$2'
-            ),
-            // video.google.com
-            array(
-                'match' => '#.*video.google.com.*docid=(\-?[0-9]+).*#',
-                'url'   => 'http://video.google.com/googleplayer.swf?docId=$1',
-            ),
-            // www.teachertube.com
-            array(
-                'match' => '#.*teachertube.com/flvideo/([0-9]+)\.flv.*#',
-                'url'   => 'http://www.teachertube.com/skin-p/mediaplayer.swf?file=http://www.teachertube.com/flvideo/$1.flv'
-            ),
-            array(
-                'match' => '#.*teachertube\.com/viewVideo\.php\?video_id=(\d+).*#',
-                'url'   => 'http://www.teachertube.com/embed/player.swf?file=http://www.teachertube.com/embedFLV.php?pg=video_$1'
-            ),
-            // www.scivee.tv
-            array(
-                'match' => '#.*scivee.tv/node/([0-9]+).*#',
-                'url'   => 'http://scivee.tv/flash/embedPlayer.swf?id=$1&type=3',
-            ),
-            array(
-                'match' => '#.*scivee.tv.*id=([0-9]+).*#',
-                'url'   => 'http://scivee.tv/flash/embedPlayer.swf?id=$1&type=3',
-            ),
-        );
+    public static function instance_config_save($values) {
+        $title = $values['title'];
+        $values = self::process_url($values['videoid'], $values['width'], $values['height']);
+        $values['title'] = $title;
+        return $values;
+    }
 
-        foreach ($embedsources as $source) {
-            if (preg_match($source['match'], $url)) {
-                return preg_replace($source['match'], $source['url'], $url);
+    private static function process_url($url, $width=0, $height=0) {
+        $sources = self::load_media_sources();
+
+        foreach ($sources as $name => $source) {
+            if ($result = $source->process_url($url, $width, $height)) {
+                return $result;
             }
         }
-        // TODO handle failure case
+        return false;
     }
 
     /**
-     * Returns a block of HTML that the external video block can use to list 
+     * Returns a block of HTML that the external video block can use to list
      * which video sites are supported.
      */
     private static function get_html_of_supported_websites() {
-        return <<<EOF
-<ul style="list-style-type: none;" class="inlinelist">
-    <li><a href="http://www.youtube.com/" target="_blank"><img src="http://www.youtube.com/favicon.ico" alt="YouTube"> youtube.com</a></li>
-    <li><a href="http://video.google.com/" target="_blank"><img src="http://video.google.com/favicon.ico" alt="Google Video"> video.google.com</a></li>
-    <li><a href="http://www.teachertube.com/" target="_blank"><img src="http://www.teachertube.com/favicon.ico" alt="TeacherTube"> teachertube.com</a></li>
-    <li><a href="http://www.scivee.tv/" target="_blank"><img src="http://www.scivee.tv/files/favicon.ico" alt="SciVee"> scivee.tv</a></li>
-</ul>
-EOF;
+        $source_instances = self::load_media_sources();
+
+        $wwwroot = get_config('wwwroot');
+        $html    = '<ul style="list-style-type: none;" class="inlinelist">';
+
+        foreach ($source_instances as $name => $source) {
+            $sourcestr = get_string($name, 'blocktype.externalvideo');
+            $html .= '<li><a href="' . $source->get_base_url() . '" target="_blank"><img src="' . $wwwroot . 'blocktype/externalvideo/media_sources/' . $name . '/favicon.png" alt="' . $sourcestr . '" title="' . $sourcestr . '"></a></li>';
+        }
+        $html .= '</ul>';
+
+        return $html;
     }
 
     public static function default_copy_type() {
