@@ -56,6 +56,13 @@ class PluginBlocktypeGroupViews extends SystemBlocktype {
 
     public static function render_instance(BlockInstance $instance, $editing=false) {
         $configdata = $instance->get('configdata');
+        if (!isset($configdata['showgroupviews'])) {
+            // If not set, use default
+            $configdata['showgroupviews'] = 1;
+        }
+        if (!isset($configdata['showsharedviews'])) {
+            $configdata['showsharedviews'] = 1;
+        }
         $groupid = $instance->get_view()->get('group');
         if (!$groupid) {
             return '';
@@ -112,7 +119,7 @@ class PluginBlocktypeGroupViews extends SystemBlocktype {
                     0 => get_string('no'),
                 ),
                 'separator' => '<br>',
-                'defaultvalue' => isset($configdata['showsharedviews']) ? $configdata['showsharedviews'] : 0,
+                'defaultvalue' => isset($configdata['showsharedviews']) ? $configdata['showsharedviews'] : 1,
             ),
         );
     }
@@ -132,7 +139,8 @@ class PluginBlocktypeGroupViews extends SystemBlocktype {
         $role = group_user_access($group->id);
         if ($role) {
             // Get all views created in the group
-            $data['groupviews'] = View::view_search(null, null, (object) array('group' => $group->id));
+            $sort = array(array('column' => 'type=\'grouphomepage\'', 'desc' => true));
+            $data['groupviews'] = View::view_search(null, null, (object) array('group' => $group->id), null, null, 0, true, $sort);
             foreach ($data['groupviews']->data as &$view) {
                 if (isset($view['template']) && $view['template']) {
                     $view['form'] = pieform(create_view_form($group->id, null, $view['id']));
@@ -154,7 +162,7 @@ class PluginBlocktypeGroupViews extends SystemBlocktype {
             }
         }
 
-        if (group_allows_submission($group->grouptype) && ($userviewdata = View::get_user_views())) {
+        if ($group->submittableto && ($userviewdata = View::get_user_views())) {
             require_once('pieforms/pieform.php');
             // A user can submit more than one view to the same group, but no view can be
             // submitted to more than one group.
