@@ -92,6 +92,12 @@ abstract class PluginBlocktype extends Plugin {
         return array();
     }
 
+    /**
+     * Inline js to be executed when a block is rendered.
+     */
+    public static function get_instance_inline_javascript(BlockInstance $instance) {
+    }
+
     /**
      * If this blocktype contains artefacts, and uses the artefactchooser 
      * Pieform element to choose them, this method must return the definition 
@@ -513,12 +519,37 @@ class BlockInstance {
         unset($values['change']);
         unset($values['new']);
 
+        $redirect = '/view/blocks.php?id=' . $this->get('view');
+        if (param_boolean('new', false)) {
+            $redirect .= '&new=1';
+        }
+        if ($category = param_alpha('c', '')) {
+            $redirect .= '&c='. $category;
+        }
+
+        $result = array(
+            'goto' => $redirect,
+        );
+
         if (is_callable(array(generate_class_name('blocktype', $this->get('blocktype')), 'instance_config_save'))) {
-            $values = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'instance_config_save', $values);
+            try {
+                $values = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'instance_config_save', $values, $this);
+            }
+            catch (MaharaException $e) {
+                $result['message'] = $e instanceof UserException ? $e->getMessage() : get_string('unrecoverableerror', 'error');
+                $form->set_error(null, $result['message']);
+                $form->reply(PIEFORM_ERR, $result);
+            }
         }
 
         $title = (isset($values['title'])) ? $values['title'] : '';
         unset($values['title']);
+
+        // A block may return a list of other blocks that need to be
+        // redrawn after configuration of this block.
+        $torender = !empty($values['_redrawblocks']) && $form->submitted_by_js() ? $values['_redrawblocks'] : array();
+        unset($values['_redrawblocks']);
+
         $this->set('configdata', $values);
         $this->set('title', $title);
 
@@ -538,16 +569,21 @@ class BlockInstance {
             'data'    => $rendered,
             'blockid' => $this->get('id'),
             'viewid'  => $this->get('view'),
+            'goto'    => $redirect,
         );
 
-        $redirect = '/view/blocks.php?id=' . $this->get('view');
-        if (param_boolean('new', false)) {
-            $redirect .= '&new=1';
+        // Render all the other blocks in the torender list
+        $result['otherblocks'] = array();
+        foreach ($torender as $blockid) {
+            if ($blockid != $result['blockid']) {
+                $otherblock = new BlockInstance($blockid);
+                $result['otherblocks'][] = array(
+                    'blockid' => $blockid,
+                    'data'    => $otherblock->render_editing(false, false, true),
+                );
+            }
         }
-        if ($category = param_alpha('c', '')) {
-            $redirect .= '&c='. $category;
-        }
-        $result['goto'] = $redirect;
+
         $form->reply(PIEFORM_OK, $result);
     }
 
@@ -594,7 +630,8 @@ class BlockInstance {
             try {
                 $content = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'render_instance', $this, true);
                 $jsfiles = call_static_method($blocktypeclass, 'get_instance_javascript', $this);
-                $js = $this->get_get_javascript_javascript($jsfiles);
+                $inlinejs = call_static_method($blocktypeclass, 'get_instance_inline_javascript', $this);
+                $js = $this->get_get_javascript_javascript($jsfiles) . $inlinejs;
             }
             catch (NotFoundException $e) {
                 // Whoops - where did the image go? There is possibly a bug 
@@ -674,7 +711,9 @@ class BlockInstance {
 
     public function render_viewing() {
 
-        safe_require('blocktype', $this->get('blocktype'));
+        if (!safe_require_plugin('blocktype', $this->get('blocktype'))) {
+            return;
+        }
         $classname = generate_class_name('blocktype', $this->get('blocktype'));
         try {
             $content = call_static_method($classname, 'render_instance', $this);
@@ -860,7 +899,12 @@ class BlockInstance {
         }
 
         $configjs = call_static_method($blocktypeclass, 'get_instance_config_javascript', $this);
-        $js .= $this->get_get_javascript_javascript($configjs);
+        if (is_array($configjs)) {
+            $js .= $this->get_get_javascript_javascript($configjs);
+        }
+        else if (is_string($configjs)) {
+            $js .= $configjs;
+        }
 
         $renderedform = array('html' => $html, 'javascript' => $js);
         return $renderedform;
@@ -1097,6 +1141,9 @@ class BlockInstance {
         return $this->artefacts[$id] = $a;
     }
 
+    public function save_artefact_instance($artefact) {
+        $this->artefacts[$artefact->get('id')] = $artefact;
+    }
 
     /**
      * Builds a new block instance as a copy of this one, taking into account 
@@ -1143,6 +1190,7 @@ class BlockInstance {
             'blocktype'  => $this->get('blocktype'),
             'title'      => $this->get('title'),
             'view'       => $view->get('id'),
+            'view_obj'   => $view,
             'column'     => $this->get('column'),
             'order'      => $this->get('order'),
         ));
@@ -1235,7 +1283,7 @@ class BlockInstance {
 
             $file = (is_array($jsfile) && isset($jsfile['file'])) ? $jsfile['file'] : $jsfile;
 
-            if (strpos($file, 'http://') === false) {
+            if (stripos($file, 'http://') === false && stripos($file, 'https://') === false) {
                 $file = 'blocktype/' . $this->blocktype . '/' . $file;
                 if ($this->artefactplugin) {
                     $file = 'artefact/' . $this->artefactplugin . '/' . $file;
