@@ -27,5 +27,5 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'My Groups';
+$string['title'] = 'My groups';
 $string['description'] = 'Display a list of the groups you belong to';
