@@ -27,6 +27,6 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'My Groups';
-$string['otherusertitle'] = "%s's Groups";
+$string['title'] = 'My groups';
+$string['otherusertitle'] = "%s's groups";
 $string['description'] = 'Display a list of the groups you belong to';
