@@ -27,8 +27,8 @@
 
 defined('INTERNAL') || die();
 
-$string['title'] = 'Latest Pages';
-$string['description'] = 'List the most recently updated pages on the site';
+$string['title'] = 'Latest pages';
+$string['description1'] = 'List the most recently updated pages that you have access to on the site';
 $string['viewstoshow'] = 'Maximum number of pages to show';
 $string['viewstoshowdescription'] = 'Between 1 and 100';
-$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';
\ No newline at end of file
+$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';
