@@ -84,7 +84,7 @@ class PluginExportHtml extends PluginExport {
 
         // Find what stylesheets need to be included
         $themedirs = $THEME->get_path('', true, 'export/html');
-        $stylesheets = array('style.css', 'print.css');
+        $stylesheets = array('style.css', 'print.css', 'jquery.rating.css');
         foreach ($themedirs as $theme => $themedir) {
             foreach ($stylesheets as $stylesheet) {
                 if (is_readable($themedir . 'style/' . $stylesheet)) {
@@ -305,7 +305,7 @@ class PluginExportHtml extends PluginExport {
      * aren't legal on most real filesystems.
      */
     public static function sanitise_path($path) {
-        return substr(str_replace('/', '_', $path), 0, 255);
+        return trim(substr(str_replace('/', '_', $path), 0, 255));
     }
 
 
@@ -339,6 +339,7 @@ class PluginExportHtml extends PluginExport {
      * Dumps all views into the HTML export
      */
     private function dump_view_export_data() {
+        safe_require('artefact', 'comment');
         $progressstart = 55;
         $progressend   = 75;
         $i = 0;
@@ -373,6 +374,17 @@ class PluginExportHtml extends PluginExport {
             }
 
             $outputfilter = new HtmlExportOutputFilter($rootpath, $this);
+
+            // Include comments
+            if ($this->includefeedback) {
+                $feedback = null;
+                $artefact = null;
+                if ($feedback = ArtefactTypeComment::get_comments(0, 0, null, $view, $artefact, true)) {
+                    $feedback->tablerows = $outputfilter->filter($feedback->tablerows);
+                }
+                $smarty->assign('feedback', $feedback);
+            }
+
             $smarty->assign('view', $outputfilter->filter($view->build_columns()));
             $content = $smarty->fetch('export:html:view.tpl');
             if (!file_put_contents("$directory/index.html", $content)) {
@@ -510,7 +522,7 @@ abstract class HtmlExportArtefactPlugin {
     public function paginate($artefact) {
 
         // Create directory for storing the artefact
-        $dirname = PluginExportHtml::text_to_path($artefact->get('title'));
+        $dirname = PluginExportHtml::text_to_path(trim($artefact->get('title')));
         if (!check_dir_exists($this->fileroot . $dirname)) {
             throw new SystemException("Couldn't create artefact directory {$this->fileroot}{$dirname}");
         }
@@ -654,7 +666,7 @@ class HtmlExportOutputFilter {
         // Thumbnails
         require_once('file.php');
         $html = preg_replace_callback(
-            '#(?<=[\'"])(' . $wwwroot . ')?/?thumb\.php\?type=([a-z]+)((&amp;[a-z]+=[x0-9]+)+)*#',
+            '#(?<=[\'"])(' . $wwwroot . ')?/?thumb\.php\?type=([a-z]+)((?:(?:&amp;|&|%26)[a-z]+=[x0-9]+)+)*#',
             array($this, 'replace_thumbnail_link'),
             $html
         );
@@ -709,7 +721,10 @@ class HtmlExportOutputFilter {
         case 'file':
         case 'folder':
         case 'image':
+        case 'profileicon':
         case 'archive':
+        case 'video':
+        case 'audio':
             return '<a href="' . $this->get_export_path_for_file($artefact, array()) . '">' . $matches[5] . '</a>';
         default:
             return $matches[5];
@@ -752,7 +767,8 @@ class HtmlExportOutputFilter {
         if (isset($matches[3])) {
             $type = $matches[2];
 
-            $parts = explode('&amp;', substr($matches[3], 5));
+            $parts = preg_split('/(&amp;|&|%26)/', $matches[3]);
+            array_shift($parts);
             foreach ($parts as $part) {
                 list($key, $value) = explode('=', $part);
                 $options[$key] = $value;
