@@ -99,6 +99,11 @@ abstract class PluginExport extends Plugin {
      */
     public $views = array();
 
+    /**
+     * Whether the user requested to export feedback as well
+     */
+    public $includefeedback = false;
+
     /**
      * User object for the user being exported.
      */
@@ -236,7 +241,7 @@ abstract class PluginExport extends Plugin {
         $typestoplugins = get_records_assoc('artefact_installed_type');
         foreach ($tmpartefacts as $a) {
             $artefact = null;
-            if ($a instanceof ArefactType) {
+            if ($a instanceof ArtefactType) {
                 $artefact = $a;
             }
             else if (is_object($a) && isset($a->id)) {
@@ -288,6 +293,8 @@ abstract class PluginExport extends Plugin {
             throw new SystemException("Couldn't create the temporary export directory $this->exportdir");
         }
 
+        $this->messages = array();
+
         $this->notify_progress_callback(10, 'Setup');
     }
 
