@@ -43,40 +43,19 @@ class PluginGrouptypeStandard extends PluginGrouptype {
 
 class GroupTypeStandard extends GroupType {
 
-    public static function allowed_join_types($all=false) {
-        global $USER;
-        return self::user_allowed_join_types($USER, $all);
-    }
-
-    public static function user_allowed_join_types($user, $all=false) {
-        $jointypes = array('open', 'request', 'invite');
-        if (defined('INSTALLER') || defined('CRON') || $all || $user->get('admin') || $user->get('staff') || $user->is_institutional_admin() || $user->is_institutional_staff()) {
-           $jointypes[] = 'controlled';
-        }
-        return $jointypes;
-    }
-
     public static function get_roles() {
         return array('member', 'admin');
     }
 
-    public static function get_view_editing_roles() {
-        return array('member', 'admin');
+    public static function get_view_moderating_roles() {
+        return array('admin');
     }
 
     public static function get_view_assessing_roles() {
-        return array();
+        return array('admin');
     }
 
     public static function default_role() {
         return 'member';
     }
-
-    public static function default_artefact_rolepermissions() {
-        return array(
-            'member' => (object) array('view' => true, 'edit' => true, 'republish' => true),
-            'admin'  => (object) array('view' => true, 'edit' => true, 'republish' => true),
-        );
-    }
-
 }
