@@ -59,7 +59,7 @@ if ($USER->is_logged_in()) {
         )
     );
 
-    if ($USER->get_account_preference('showhomeinfo')) {
+    if (get_config('homepageinfo') && $USER->get_account_preference('showhomeinfo')) {
         // allow the user to choose never to see the info boxes again
         $strhowtodisable = json_encode(get_string('howtodisable', 'mahara', get_config('wwwroot') . 'account'));
         $js = <<<JAVASCRIPT
@@ -74,7 +74,9 @@ function nevershow() {
     sendjsonrequest('homeinfo.json.php', data, 'POST', hideinfo);
 }
 addLoadEvent(function () {
-    $('hideinfo').onclick = nevershow;
+    if ($('hideinfo')) {
+        $('hideinfo').onclick = nevershow;
+    }
 });
 JAVASCRIPT;
 
@@ -99,6 +101,8 @@ $urls = array(
     'views'   => $wwwroot . 'view',
     'friends' => $wwwroot . 'user/find.php',
     'groups'  => $wwwroot . 'group/find.php',
+    'topics'  => $wwwroot . 'group/topics.php',
+    'share'   => $wwwroot . 'view/share.php',
 );
 $smarty->assign('url', $urls);
 
