@@ -31,9 +31,9 @@ $string['addpostsuccess'] = 'Added post successfully';
 $string['addtitle'] = 'Add forum';
 $string['addtopic'] = 'Add topic';
 $string['addtopicsuccess'] = 'Added topic successfully';
-$string['autosubscribeusers'] = 'Automatically subscribe users?';
+$string['autosubscribeusers'] = 'Automatically subscribe users';
 $string['autosubscribeusersdescription'] = 'Choose whether group users will automatically be subscribed to this forum';
-$string['Body'] = 'Body';
+$string['Body'] = 'Message';
 $string['cantaddposttoforum'] = 'You are not allowed to post in this forum';
 $string['cantaddposttotopic'] = 'You are not allowed to post in this topic';
 $string['cantaddtopic'] = 'You are not allowed to add topics to this forum';
@@ -53,9 +53,9 @@ $string['Closed'] = 'Closed';
 $string['Close'] = 'Close';
 $string['closeddescription'] = 'Closed topics can only be replied to by moderators and the group administrators';
 $string['Count'] = 'Count';
-$string['createtopicusersdescription'] = 'If set to "All group members", anyone can create new topics and reply to existing topics.  If set to "Moderators and group admins", only moderators and group administrators can start new topics, but once topics exist, all users can post replies to them.';
-$string['currentmoderators'] = 'Current Moderators';
-$string['defaultforumtitle'] = 'General Discussion';
+$string['createtopicusersdescription'] = 'If set to "All group members", anyone can create new topics and reply to existing topics.  If set to "Moderators and group administrators", only moderators and group administrators can start new topics, but once topics exist, all users can post replies to them.';
+$string['currentmoderators'] = 'Current moderators';
+$string['defaultforumtitle'] = 'General discussion';
 $string['defaultforumdescription'] = '%s general discussion forum';
 $string['deleteforum'] = 'Delete forum';
 $string['deletepost'] = 'Delete post';
@@ -71,8 +71,8 @@ $string['editstothispost'] = 'Edits to this post:';
 $string['edittitle'] = 'Edit forum';
 $string['edittopic'] = 'Edit topic';
 $string['edittopicsuccess'] = 'Topic edited successfully';
-$string['forumname'] = 'Forum Name';
-$string['forumposthtmltemplate'] = "<div style=\"padding: 0.5em 0; border-bottom: 1px solid #999;\"><strong>%s by %s</strong><br>%s</div>
+$string['forumname'] = 'Forum name';
+$string['forumposthtmltemplate'] = "<div style=\"padding: 0.5em 0; border-bottom: 1px solid #999;\"><strong>Forum: %s (%s)</strong></div>
 
 <div style=\"margin: 1em 0;\">%s</div>
 
@@ -80,8 +80,7 @@ $string['forumposthtmltemplate'] = "<div style=\"padding: 0.5em 0; border-bottom
 <p><a href=\"%s\">Reply to this post online</a></p>
 <p><a href=\"%s\">Unsubscribe from this %s</a></p>
 </div>";
-$string['forumposttemplate'] = "%s by %s
-%s
+$string['forumposttemplate'] = "Forum: %s (%s)
 ------------------------------------------------------------------------
 
 %s
@@ -96,18 +95,18 @@ $string['forumsuccessfulsubscribe'] = 'Forum subscribed successfully';
 $string['forumsuccessfulunsubscribe'] = 'Forum unsubscribed successfully';
 $string['gotoforums'] = 'Go to forums';
 $string['groupadmins'] = 'Group administrators';
-$string['groupadminlist'] = 'Group admins:';
+$string['groupadminlist'] = 'Group administrators:';
 $string['Key'] = 'Key';
 $string['lastpost'] = 'Last post';
-$string['latestforumposts'] = 'Latest Forum Posts';
+$string['latestforumposts'] = 'Latest forum posts';
 $string['Moderators'] = 'Moderators';
-$string['moderatorsandgroupadminsonly'] = 'Moderators and group admins only';
+$string['moderatorsandgroupadminsonly'] = 'Moderators and group administrators only';
 $string['moderatorslist'] = 'Moderators:';
 $string['moderatorsdescription'] = 'Moderators can edit and delete topics and posts. They can also open, close, set and unset topics as sticky';
 $string['name'] = 'Forum';
 $string['nameplural'] = 'Forums';
 $string['newforum'] = 'New forum';
-$string['newforumpostnotificationsubject'] = '%s: %s: %s';
+$string['newforumpostnotificationsubjectline'] = '%s';
 $string['newpost'] = 'New post: ';
 $string['newtopic'] = 'New topic';
 $string['noforumpostsyet'] = 'There are no posts in this group yet';
@@ -119,19 +118,19 @@ $string['orderdescription'] = 'Choose where you want the forum to be ordered com
 $string['Post'] = 'Post';
 $string['postaftertimeout'] = 'You have submitted your change after timeout of %s minutes. Your change has not been applied.';
 $string['postbyuserwasdeleted'] = 'A post by %s was deleted';
-$string['postdelay'] = 'Post Delay';
-$string['postdelaydescription'] = 'The minimum time (in minutes) that must pass before a new post can be mailed out to forum subscribers.  The author of a post may make edits during this time.';
+$string['postdelay'] = 'Post delay';
+$string['postdelaydescription'] = 'The minimum time (in minutes) that must pass before a new post can be mailed out to forum subscribers. The author of a post may make edits during this time.';
 $string['postedin'] = '%s posted in %s';
 $string['Poster'] = 'Poster';
 $string['postreply'] = 'Post reply';
 $string['Posts'] = 'Posts';
 $string['allposts'] = 'All posts';
 $string['postsvariable'] = 'Posts: %s';
-$string['potentialmoderators'] = 'Potential Moderators';
+$string['potentialmoderators'] = 'Potential moderators';
 $string['re'] ='Re: %s';
 $string['regulartopics'] = 'Regular topics';
 $string['Reply'] = 'Reply';
-$string['replyforumpostnotificationsubject'] = 'Re: %s: %s: %s';
+$string['replyforumpostnotificationsubjectline'] = 'Re: %s';
 $string['replyto'] = 'Reply to: ';
 $string['Sticky'] = 'Sticky';
 $string['stickydescription'] = 'Sticky topics are at the top of every page';
@@ -146,7 +145,7 @@ $string['Topics'] = 'Topics';
 $string['topiclower'] = 'topic';
 $string['topicslower'] = 'topics';
 $string['topicclosedsuccess'] = 'Topics closed successfully';
-$string['topicisclosed'] = 'This topic is closed. Only moderators and the group admins can post new replies';
+$string['topicisclosed'] = 'This topic is closed. Only moderators and the group administrators can post new replies.';
 $string['topicopenedsuccess'] = 'Topics opened successfully';
 $string['topicstickysuccess'] = 'Topics set as sticky successfully';
 $string['topicsubscribesuccess'] = 'Topics subscribed successfully';
@@ -170,17 +169,17 @@ $string['yesterday'] = 'Yesterday';
 $string['strftimerecentrelative'] = '%%v, %%k:%%M';
 $string['strftimerecentfullrelative'] = '%%v, %%l:%%M %%p';
 
-$string['indentmode'] = 'Forum Indent Mode';
+$string['indentmode'] = 'Forum indent mode';
 $string['indentfullindent'] = 'Fully expand';
-$string['indentmaxindent'] = 'Expand to max';
+$string['indentmaxindent'] = 'Expand to maximum';
 $string['indentflatindent'] = 'No indents';
 $string['indentmodedescription'] = 'Specify how topics in this forum should be indented.';
-$string['maxindent'] = 'Maximum Indent Level';
-$string['maxindentdescription'] = 'Set the maximum indention level for a topic. This only applies if Indent mode has been set to Expand to max';
+$string['maxindent'] = 'Maximum indent level';
+$string['maxindentdescription'] = 'Set the maximum indentation level for a topic. This only applies if the indent mode has been set to "Expand to maximum"';
 
 $string['closetopics'] = 'Close new topics';
-$string['closetopicsdescription'] = 'If checked, all new topics in this forum will be closed by default.  Only moderators and group administrators can reply to closed topics.';
+$string['closetopicsdescription'] = 'If checked, all new topics in this forum will be closed by default. Only moderators and group administrators can reply to closed topics.';
 
 $string['activetopicsdescription'] = 'Recently updated topics in your groups.';
 
-$string['timeleftnotice'] = 'You have %s minutes left to finish editing';
\ No newline at end of file
+$string['timeleftnotice'] = 'You have %s minutes left to finish editing';
