@@ -379,7 +379,7 @@ EOF;
                 'path' => 'groups/topics',
                 'url' => 'group/topics.php',
                 'title' => get_string('Topics', 'interaction.forum'),
-                'weight' => 60,
+                'weight' => 70,
             ),
         );
     }
@@ -546,7 +546,7 @@ EOF;
         set_config_plugin('interaction', 'forum', 'postdelay', $values['postdelay']);
     }
 
-    public static function get_active_topics($limit, $offset, $category) {
+    public static function get_active_topics($limit, $offset, $category, $forumids = array()) {
         global $USER;
 
         if (is_postgres()) {
@@ -568,18 +568,27 @@ EOF;
                     GROUP BY topic';
         }
 
+        $values = array();
         $from = '
             FROM
                 {interaction_forum_topic} t
                 JOIN {interaction_instance} f ON t.forum = f.id
-                JOIN {group} g ON f.group = g.id
+                JOIN {group} g ON f.group = g.id';
+
+        // user is not anonymous
+        if ($USER->get('id') > 0) {
+            $from .= '
                 JOIN {group_member} gm ON (gm.group = g.id AND gm.member = ?)
+            ';
+
+            $values[] = $USER->get('id');
+        }
+
+        $from .= '
                 JOIN {interaction_forum_post} first ON (first.topic = t.id AND first.parent IS NULL)
                 JOIN (' . $lastposts . '
                 ) last ON last.topic = t.id';
 
-        $values = array($USER->get('id'));
-
         $where = '
             WHERE g.deleted = 0 AND f.deleted = 0 AND t.deleted = 0';
 
@@ -588,6 +597,11 @@ EOF;
             $values[] = (int) $category;
         }
 
+        if (!empty($forumids)) {
+            $where .= ' AND f.id IN (?)';
+            $values[] = implode(',', $forumids);
+        }
+
         $result = array(
             'count'  => count_records_sql('SELECT COUNT(*) ' . $from . $where, $values),
             'limit'  => $limit,
@@ -603,17 +617,18 @@ EOF;
             SELECT
                 t.id, t.forum AS forumid, f.title AS forumname, g.id AS groupid, g.name AS groupname,
                 first.subject AS topicname, first.poster AS firstpostby,
-                last.id AS postid, last.poster, last.subject, last.body, last.ctime,
+                last.id AS postid, last.poster, last.subject, last.body, last.ctime, edits.ctime as mtime,
                 COUNT(posts.id) AS postcount';
 
         $from .= '
-                LEFT JOIN {interaction_forum_post} posts ON posts.topic = t.id';
+                LEFT JOIN {interaction_forum_post} posts ON posts.topic = t.id
+                LEFT JOIN {interaction_forum_edit} edits ON edits.post = last.id';
 
         $sort = '
             GROUP BY
                 t.id, t.forum, f.title, g.id, g.name,
                 first.subject, first.poster,
-                last.id, last.poster, last.subject, last.body, last.ctime
+                last.id, last.poster, last.subject, last.body, last.ctime, edits.ctime
             ORDER BY last.ctime DESC';
 
         $result['data'] = get_records_sql_array($select . $from . $where . $sort, $values, $offset, $limit);
@@ -766,11 +781,16 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
         // When emailing forum posts, create Message-Id headers for threaded display by email clients
         $urlinfo = parse_url(get_config('wwwroot'));
         $hostname = $urlinfo['host'];
-        $cleanforumname = str_replace('"', "'", strip_tags($post->forumtitle));
+        $cleanforumname = clean_email_headers($post->forumtitle);
+        $cleangroupname = clean_email_headers($post->groupname);
+        $cleanforumname = str_replace('"', "'", strip_tags($cleanforumname));
+        $cleangroupname = str_replace('"', "'", strip_tags($cleangroupname));
         $this->customheaders = array(
             'List-Id: "' . $cleanforumname . '" <forum' . $post->forumid . '@' . $hostname . '>',
             'List-Help: ' . get_config('wwwroot') . 'interaction/forum/view.php?id=' . $post->forumid,
             'Message-ID: <forumpost' . $this->postid . '@' . $hostname . '>',
+            'X-Mahara-Group: ' . $cleangroupname,
+            'X-Mahara-Forum: ' . $cleanforumname
         );
         if ($post->parent) {
             $this->customheaders[] = 'In-Reply-To: <forumpost' . $post->parent . '@' . $hostname . '>';
@@ -782,7 +802,7 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
 
         $post->textbody = trim(html2text($post->body));
         $post->htmlbody = clean_html($post->body);
-        $this->url = get_config('wwwroot') . 'interaction/forum/topic.php?id=' . $post->topicid . '#post' . $this->postid;
+        $this->url = 'interaction/forum/topic.php?id=' . $post->topicid . '#post' . $this->postid;
 
         $this->add_urltext(array(
             'key'     => 'Topic',
@@ -790,9 +810,9 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
         ));
 
         $this->strings->subject = (object) array(
-            'key'     => $post->parent ? 'replyforumpostnotificationsubject' : 'newforumpostnotificationsubject',
+            'key'     => $post->parent ? 'replyforumpostnotificationsubjectline' : 'newforumpostnotificationsubjectline',
             'section' => 'interaction.forum',
-            'args'    => array($post->groupname, $post->forumtitle, $post->parent ? $post->topicsubject : $post->subject),
+            'args'    => array($post->parent ? $post->topicsubject : $post->subject),
         );
 
         foreach ($this->users as &$user) {
@@ -808,11 +828,10 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
         $unsubscribeid = $post->{$user->subscribetype . 'id'};
         $unsubscribelink = get_config('wwwroot') . 'interaction/forum/unsubscribe.php?' . $user->subscribetype . '=' . $unsubscribeid . '&key=' . $user->unsubscribekey;
         return get_string_from_language($user->lang, 'forumposttemplate', 'interaction.forum',
-            $post->subject ? $post->subject : get_string_from_language($user->lang, 're', 'interaction.forum', $post->topicsubject),
-            display_name($post->poster, $user),
-            $post->posttime,
+            $post->forumtitle,
+            $post->groupname,
             $post->textbody,
-            $this->url,
+            get_config('wwwroot') . $this->url,
             $user->subscribetype,
             $unsubscribelink
         );
@@ -823,11 +842,10 @@ class ActivityTypeInteractionForumNewPost extends ActivityTypePlugin {
         $unsubscribeid = $post->{$user->subscribetype . 'id'};
         $unsubscribelink = get_config('wwwroot') . 'interaction/forum/unsubscribe.php?' . $user->subscribetype . '=' . $unsubscribeid . '&key=' . $user->unsubscribekey;
         return get_string_from_language($user->lang, 'forumposthtmltemplate', 'interaction.forum',
-            $post->subject ? hsc($post->subject) : get_string_from_language($user->lang, 're', 'interaction.forum', hsc($post->topicsubject)),
-            hsc(display_name($post->poster, $user)),
-            $post->posttime,
+            hsc($post->forumtitle),
+            hsc($post->groupname),
             $post->htmlbody,
-            $this->url,
+            get_config('wwwroot') . $this->url,
             $unsubscribelink,
             $user->subscribetype
         );
