@@ -33,6 +33,10 @@ function ViewManager() {
             // base for positioned elements inside it
             self.columnContainer = $('column-container');
             makePositioned(self.columnContainer);
+            if (self.isIE7) {
+                // Stop blocktypes being dragged from disappearing underneath the content area
+                setStyle('top-pane', {'z-index': 1});
+            }
 
             // Hide 'new block here' buttons
             forEach(getElementsByTagAndClassName('div', 'add-button', self.bottomPane), function(i) {
@@ -76,6 +80,9 @@ function ViewManager() {
             // Make the block types draggable
             self.makeBlockTypesDraggable();
 
+            // Display block type description on hover
+            self.showBlockTypeDescription();
+
             // Change the intruction to be for ajax
             self.ajaxInstructions();
 
@@ -103,11 +110,17 @@ function ViewManager() {
                 });
         }
 
+        if (self.isIE7) {
+            // Disable IE's default image dragging function, otherwise blocktypes being dragged
+            // sometimes freeze and then stick to the cursor on mouseup
+            document.ondragstart = function () { return false; };
+        }
+
         // Now we're done, remove the loading message and display the page
         removeElement('views-loading');
         showElement(self.bottomPane);
 
-    }
+    };
 
     /**
      * Adds a column to the view
@@ -170,7 +183,7 @@ function ViewManager() {
         // Wire up the new column buttons to be AJAX
         self.rewriteAddColumnButtons('column_' + id);
         self.rewriteRemoveColumnButtons('column_' + id);
-    }
+    };
 
     /**
      * Removes a column from the view, sizes the others to take its place and
@@ -247,7 +260,7 @@ function ViewManager() {
                 i = 1;
             }
         });
-    }
+    };
 
     /**
      * Rewrites the category select links to be AJAX
@@ -262,11 +275,12 @@ function ViewManager() {
                     setNodeAttribute('category', 'value', queryString['c']);
                     $('blocktype-list').innerHTML = data.data;
                     self.makeBlockTypesDraggable();
+                    self.showBlockTypeDescription();
                 });
                 e.stop();
             });
         });
-    }
+    };
 
     /**
      * Rewrites the blockinstance configure buttons to be AJAX
@@ -275,7 +289,7 @@ function ViewManager() {
         forEach(getElementsByTagAndClassName('input', 'configurebutton', self.bottomPane), function(i) {
             self.rewriteConfigureButton(i);
         });
-    }
+    };
 
     /**
      * Rewrites one configure button to be AJAX
@@ -285,7 +299,7 @@ function ViewManager() {
             e.stop();
             self.getConfigureForm(getFirstParentByTagAndClassName(button, 'div', 'blockinstance'));
         });
-    }
+    };
 
 
     this.getConfigureForm = function(blockinstance) {
@@ -320,7 +334,7 @@ function ViewManager() {
             });
 
         });
-    }
+    };
 
 
     this.hideMediaPlayers = function () {
@@ -347,7 +361,7 @@ function ViewManager() {
         });
 
         insertSiblingNodesBefore(document.body.firstChild, DIV({'id': 'overlay'}));
-    }
+    };
 
 
     this.showMediaPlayers = function () {
@@ -364,8 +378,10 @@ function ViewManager() {
             removeElementClass(e.previousSibling, 'hidden');
             removeElement(e);
         });
-        removeElement('overlay');
-    }
+        if ($('overlay')) {
+            removeElement('overlay');
+        }
+    };
 
 
     this.addConfigureBlock = function(oldblock, configblock, removeoncancel) {
@@ -429,7 +445,7 @@ function ViewManager() {
 
         showElement(newblock);
         eval(configblock.javascript);
-    }
+    };
 
 
     this.replaceConfigureBlock = function(data) {
@@ -437,7 +453,7 @@ function ViewManager() {
         if (oldblock) {
             var temp = DIV();
             temp.innerHTML = data.data.html;
-            var newblock = getFirstElementByTagAndClassName('div', 'blockinstance', temp)
+            var newblock = getFirstElementByTagAndClassName('div', 'blockinstance', temp);
             swapDOM(oldblock, newblock);
             eval(data.data.javascript);
             self.makeBlockinstanceDraggable(newblock);
@@ -446,12 +462,12 @@ function ViewManager() {
         }
         self.removeConfigureBlocks();
         self.showMediaPlayers();
-    }
+    };
 
     this.removeConfigureBlocks = function() {
         // FF3 hangs unless you delay removal of the iframe inside the old configure block
         callLater(0.0001, function () { forEach(getElementsByTagAndClassName('div', 'configure'), removeElement); });
-    }
+    };
 
     /**
      * Rewrites the blockinstance delete buttons to be AJAX
@@ -460,7 +476,7 @@ function ViewManager() {
         forEach(getElementsByTagAndClassName('input', 'deletebutton', self.bottomPane), function(i) {
             self.rewriteDeleteButton(i);
         });
-    }
+    };
 
     /**
      * Rewrites one delete button to be AJAX
@@ -487,7 +503,7 @@ function ViewManager() {
             }
             e.stop();
         });
-    }
+    };
 
 
     /**
@@ -506,7 +522,7 @@ function ViewManager() {
             });
             e.stop();
         });
-    }
+    };
 
     /**
      * Rewrites the add column buttons to be AJAX
@@ -543,7 +559,7 @@ function ViewManager() {
                 e.stop();
             });
         });
-    }
+    };
 
     /**
      * Rewrite the remove column buttons to be AJAX
@@ -580,7 +596,7 @@ function ViewManager() {
                 e.stop();
             });
         });
-    }
+    };
     
     /**
      * Disables the 'add column' buttons
@@ -608,7 +624,7 @@ function ViewManager() {
                 removeNodeAttribute(i, 'disabled');
             }
         });
-    }
+    };
 
     /**
      * Makes block instances draggable
@@ -617,7 +633,7 @@ function ViewManager() {
         forEach(getElementsByTagAndClassName('div', 'blockinstance', self.bottomPane), function(i) {
             self.makeBlockinstanceDraggable(i);
         });
-    }
+    };
 
     /**
      * Make a particular blockinstance draggable
@@ -699,7 +715,7 @@ function ViewManager() {
                     {x: 0, y: 0, duration: 0});
             }
         });
-    }
+    };
 
     /**
      * Makes block types draggable
@@ -800,7 +816,18 @@ function ViewManager() {
                 }
             });
         });
-    }
+    };
+
+    this.showBlockTypeDescription = function() {
+        forEach(getElementsByTagAndClassName('li', null, 'blocktype-list'), function(i) {
+            connect(i, 'onmouseenter', function() {
+                $('current_bt_description').innerHTML = '<strong>' + scrapeText(getFirstElementByTagAndClassName('h4', 'blocktype-title', i)) + ':</strong> ' + scrapeText(getFirstElementByTagAndClassName('div', 'blocktype-description', i));
+            });
+            connect(i, 'onmouseleave', function() {
+                $('current_bt_description').innerHTML = '';
+            });
+        });
+    };
 
     /**
      * changes the intructions so they are for ajax
@@ -808,7 +835,7 @@ function ViewManager() {
 
     this.ajaxInstructions = function() {
         $('blocksinstruction').innerHTML = get_string('blocksinstructionajax');
-    }
+    };
 
     /**
      * Wire up the view theme selector
@@ -824,7 +851,7 @@ function ViewManager() {
                 self.viewThemeSelect.form.submit();
             }
         });
-    }
+    };
 
     /**
      * Place hotzones over the blockinstances on the page, so that we can work
@@ -988,7 +1015,7 @@ function ViewManager() {
                 previousHotzone = hotzone;
             }
         });
-    }
+    };
 
     /**
      * Creates a new hotzone and puts it in the DOM, ready for use
@@ -1063,7 +1090,7 @@ function ViewManager() {
         self.makeHotzoneDroppable(hotzone, node, placementFunction, dropFunction, placeAfter);
         appendChildNodes(self.hotzoneContainer, hotzone);
         return hotzone;
-    }
+    };
 
     /**
      * Makes a hotzone droppable. In a separate function for scoping purposes
@@ -1104,7 +1131,7 @@ function ViewManager() {
                 }
             }
         });
-    }
+    };
 
     /**
      * Removes hotzones from the document.
@@ -1113,7 +1140,7 @@ function ViewManager() {
      */
     this.destroyHotzones = function() {
         removeElement(self.hotzoneContainer);
-    }
+    };
 
     /**
      * Find the co-ordinates of a given block instance
@@ -1135,7 +1162,7 @@ function ViewManager() {
         });
 
         return {'column': column, 'order': order};
-    }
+    };
 
     /**
      * Adds CSS rules that should apply for the javascript only version
@@ -1147,7 +1174,7 @@ function ViewManager() {
             'href': config['wwwroot'] + 'theme/views-js.css'
         });
         appendChildNodes(getFirstElementByTagAndClassName('head'), styleNode);
-    }
+    };
 
 
     // Whether it is a blocktype that is being added, rather than a
@@ -1205,6 +1232,9 @@ function blockConfigSuccess(form, data) {
         }
         viewManager.replaceConfigureBlock(data);
     }
+    if (data.otherblocks) {
+        forEach(data.otherblocks, viewManager.replaceConfigureBlock);
+    }
 }
 
 function blockConfigError(form, data) {
