@@ -50,31 +50,19 @@ if ($page == 'myfriends') {
     $data['filter'] = $filter;
 }
 else {
-    $data = search_user($query, $limit, $offset, array('exclude' => $USER->get('id')));
+    $options = array('exclude' => $USER->get('id'));
+    if ($filter == 'myinstitutions') {
+        $options['myinstitutions'] = true;
+    }
+    $data = search_user($query, $limit, $offset, $options);
     $data['query'] = $query;
+    if (!empty($options['myinstitutions'])) {
+        $data['filter'] = $filter;
+    }
 }
 
-$controlledgroups = count_records_sql("SELECT COUNT(g.id)
-          FROM {group} g
-          JOIN {group_member} gm ON (gm.group = g.id)
-          JOIN {grouptype_roles} gtr ON (gtr.grouptype = g.grouptype AND gtr.role = gm.role)
-          WHERE gm.member = ?
-          AND g.jointype = 'controlled'
-          AND (gm.role = 'admin' OR gtr.see_submitted_views = 1)
-          AND g.deleted = 0", array($USER->get('id')));
-
-$invite = count_records_sql("SELECT COUNT(g.id)
-        FROM {group} g
-        JOIN {group_member} gm ON (gm.group = g.id)
-        WHERE gm.member = ?
-        AND g.jointype = 'invite'
-        AND gm.role = 'admin'
-        AND g.deleted = 0", array($USER->get('id')));
-
-$admingroups = new StdClass;
-$admingroups->controlled = $controlledgroups;
-$admingroups->invite = $invite;
-
+require_once('group.php');
+$admingroups = (bool) group_get_user_admintutor_groups();
 build_userlist_html($data, $page, $admingroups);
 unset($data['data']);
 
