@@ -31,7 +31,7 @@ $string['allmydata'] = 'All my data';
 $string['chooseanexportformat'] = 'Choose an export format';
 $string['clicktopreview'] = 'Click to preview';
 $string['collectionstoexport'] = 'Collections to export';
-$string['creatingzipfile'] = 'Creating zipfile';
+$string['creatingzipfile'] = 'Creating zip file';
 $string['Done'] = 'Done';
 $string['Export']     = 'Export';
 $string['exportgeneratedsuccessfully'] = 'Export generated successfully. %sClick here to download it%s';
@@ -42,12 +42,14 @@ $string['exportingartefactsprogress'] = 'Exporting artefacts: %s/%s';
 $string['exportingfooter'] = 'Exporting footer';
 $string['exportingviews'] = 'Exporting pages';
 $string['exportingviewsprogress'] = 'Exporting pages: %s/%s';
-$string['exportpagedescription'] = 'This tool exports all of your portfolio information and pages, but it does not export your site settings.';
-$string['exportyourportfolio'] = 'Export Your Portfolio';
+$string['exportportfoliodescription'] = 'This tool exports all of your portfolio information and pages. It does not export your site settings or any of the content you uploaded or created in groups.';
+$string['exportyourportfolio'] = 'Export Your portfolio';
 $string['generateexport'] = 'Generate export';
-$string['noexportpluginsenabled'] = 'No export plugins have been enabled by the administrator, so you are unable to use this feature';
-$string['justsomecollections'] = 'Just some of my Collections';
+$string['noexportpluginsenabled'] = 'No export plugins have been enabled by the site administrator, so you are unable to use this feature';
+$string['justsomecollections'] = 'Just some of my collections';
 $string['justsomeviews'] = 'Just some of my pages';
+$string['includefeedback'] = 'Include user feedback';
+$string['includefeedbackdescription'] = 'All user comments will be included in the HTML export.';
 $string['nonexistentfile'] = "Tried to add non-existent file: '%s'";
 $string['pleasewaitwhileyourexportisbeinggenerated'] = 'Please wait while your export is being generated...';
 $string['reverseselection'] = 'Reverse selection';
