@@ -28,50 +28,63 @@
 defined('INTERNAL') || die();
 
 // my groups
-$string['groupname'] = 'Group Name';
-$string['creategroup'] = 'Create Group';
+$string['groupname'] = 'Group name';
+$string['creategroup'] = 'Create group';
 $string['groupmemberrequests'] = 'Pending membership requests';
 $string['membershiprequests'] = 'Membership requests';
 $string['sendinvitation'] = 'Send invite';
 $string['invitetogroupsubject'] = 'You were invited to join a group';
-$string['invitetogroupmessage'] = '%s has invited you to join a group, \'%s\'.  Click on the link below for more information.';
+$string['invitetogroupmessage'] = '%s has invited you to join a group, \'%s\'. Click on the link below for more information.';
 $string['inviteuserfailed'] = 'Failed to invite the user';
 $string['userinvited'] = 'Invite sent';
 $string['addedtogroupsubject'] = 'You were added to a group';
-$string['addedtogroupmessage'] = '%s has added you to a group, \'%s\'.  Click on the link below to see the group';
+$string['addedtogroupmessage'] = '%s has added you to a group, \'%s\'. Click on the link below to see the group';
 $string['adduserfailed'] = 'Failed to add the user';
 $string['useradded'] = 'User added';
-$string['editgroup'] = 'Edit Group';
-$string['savegroup'] = 'Save Group';
-$string['groupsaved'] = 'Group Saved Successfully';
+$string['editgroup'] = 'Edit group';
+$string['savegroup'] = 'Save group';
+$string['groupsaved'] = 'Group saved successfully';
 $string['invalidgroup'] = 'The group doesn\'t exist';
 $string['canteditdontown'] = 'You can\'t edit this group because you don\'t own it';
-$string['groupdescription'] = 'Group Description';
-$string['membershiptype'] = 'Group Membership Type';
-$string['membershiptype.controlled'] = 'Controlled Membership';
-$string['membershiptype.invite']     = 'Invite Only';
-$string['membershiptype.request']    = 'Request Membership';
-$string['membershiptype.open']       = 'Open Membership';
+$string['groupdescription'] = 'Group description';
+$string['Membership'] = 'Membership';
+$string['Roles'] = 'Roles';
+$string['Open'] = 'Open';
+$string['opendescription'] = 'Users can join the group without approval from group administrators.';
+$string['requestdescription'] = 'Users can send membership requests to group administrators.';
+$string['Controlled'] = 'Controlled';
+$string['controlleddescription'] = 'Group administrators can add users to the group without their consent, and members cannot leave the group.';
+$string['membershiptype'] = 'Group membership type';
+$string['membershiptype.controlled'] = 'Controlled membership';
+$string['membershiptype.approve']    = 'Approved membership';
+$string['membershiptype.open']       = 'Open membership';
 $string['membershiptype.abbrev.controlled'] = 'Controlled';
-$string['membershiptype.abbrev.invite']     = 'Invite';
-$string['membershiptype.abbrev.request']    = 'Request';
+$string['membershiptype.abbrev.approve']    = 'Normal';
 $string['membershiptype.abbrev.open']       = 'Open';
-$string['pendingmembers']            = 'Pending Members';
+$string['membershipopencontrolled']  = 'Membership cannot be both open and controlled.';
+$string['membershipopenrequest']     = "Open membership groups don't accept membership requests.";
+$string['requestmembership']         = 'Request membership';
+$string['pendingmembers']            = 'Pending members';
 $string['reason']                    = 'Reason';
 $string['approve']                   = 'Approve';
 $string['reject']                    = 'Reject';
-$string['groupalreadyexists'] = 'A Group by this name already exists';
+$string['groupalreadyexists'] = 'A group by this name already exists.';
+$string['invalidshortname'] = 'Invalid group short name';
+$string['shortnameformat'] = 'Group short names can be from 2 to 255 characters in length and contain only alphanumeric characters, ".", "-", and "_"';
 $string['Created'] = 'Created';
-$string['groupadmins'] = 'Group admins';
+$string['groupadmins'] = 'Group admininistrators';
+$string['editroles'] = 'Create and edit pages';
+$string['editrolesdescription'] = 'Roles with permission to create and edit group pages.';
+$string['allexceptmember'] = 'Everyone except ordinary members';
 $string['Admin'] = 'Admin';
 $string['grouptype'] = 'Group type';
-$string['publiclyviewablegroup'] = 'Publicly Viewable Group?';
-$string['publiclyviewablegroupdescription'] = 'Allow people who are not logged-in to view this group, including the forums?';
+$string['publiclyviewablegroup'] = 'Publicly viewable group';
+$string['publiclyviewablegroupdescription'] = 'Allow people who are not logged in to view this group including the forums.';
 $string['Type'] = 'Type';
 $string['publiclyvisible'] = 'Publicly visible';
 $string['Public'] = 'Public';
-$string['usersautoadded'] = 'Users auto-added?';
-$string['usersautoaddeddescription'] = 'Automatically put all new users into this group?';
+$string['usersautoadded'] = 'Auto-add users';
+$string['usersautoaddeddescription'] = 'Automatically put all new users into this group.';
 $string['groupcategory'] = 'Group category';
 $string['allcategories'] = 'All categories';
 $string['groupoptionsset'] = 'Group options have been updated.';
@@ -82,7 +95,25 @@ $string['hasbeeninvitedtojoin'] = 'has been invited to join this group';
 $string['groupinvitesfrom'] = 'Invited to join:';
 $string['requestedmembershipin'] = 'Requested membership in:';
 $string['viewnotify'] = 'Shared page notifications';
-$string['viewnotifydescription'] = 'If checked, a notification will be sent to every group member whenever a member shares one of their pages with the group.  Enabling this setting in very large groups can produce a lot of notifications.';
+$string['viewnotifydescription'] = 'If checked, a notification will be sent to every group member whenever a member shares one of their pages with the group. Enabling this setting in very large groups can produce a lot of notifications.';
+$string['hiddengroup'] = 'Hide group';
+$string['hiddengroupdescription'] = 'Do not list this group on the "Find groups" page.';
+$string['hidemembers'] = 'Hide membership';
+$string['hidemembersdescription'] = 'Hide the group\'s membership listing from non-members.';
+$string['hidemembersfrommembers'] = 'Hide membership from members';
+$string['hidemembersfrommembersdescription'] = 'Members are not listed. Only group administrators can see the members listed. Administrators will still be shown on the group homepage.';
+$string['friendinvitations'] = 'Friend invitations';
+$string['invitefriendsdescription'] = 'If checked, members are allowed to invite friends to join the group. Regardless of this setting, group administrators can always send invitations to anyone.';
+$string['invitefriends'] = 'Invite friends';
+$string['Recommendations'] = 'Recommendations';
+$string['suggestfriendsdescription'] = 'If checked, members can easily send a recommendation for joining this group to their friends from a button on the group homepage.';
+$string['suggesttofriends'] = 'Recommend to friends';
+$string['userstosendrecommendationsto'] = 'Users who will be sent a recommendation';
+$string['suggestgroupnotificationsubject'] = '%s suggested you join a group';
+$string['suggestgroupnotificationmessage'] = '%s suggested that you join the group "%s" on %s';
+$string['recommendationssent'] = '%d recommendation(s) sent';
+$string['suggestinvitefriends'] = 'You cannot enable both friend invitations and recommendations.';
+$string['suggestfriendsrequesterror'] = 'You can only enable friend recommendations on open or request groups.';
 
 $string['editgroupmembership'] = 'Edit group membership';
 $string['editmembershipforuser'] = 'Edit membership for %s';
@@ -90,8 +121,7 @@ $string['changedgroupmembership'] = 'Group membership updated sucessfully.';
 $string['changedgroupmembershipsubject'] = 'Your group memberships have been changed';
 $string['addedtogroupsmessage'] = "%s has added you to the group(s):\n\n%s\n\n";
 $string['removedfromgroupsmessage'] = "%s has removed you from the group(s):\n\n%s\n\n";
-$string['cantremoveuserisadmin'] = "Tutor cannot remove admins and other tutorsmembers.";
-$string['cantremovemember'] = "Tutor cannot remove members.";
+$string['cantremovememberfromgroup'] = "You cannot remove users from %s";
 $string['current'] = "Current";
 $string['requests'] = "Requests";
 $string['invites'] = "Invites";
@@ -100,6 +130,10 @@ $string['invites'] = "Invites";
 $string['member'] = 'member';
 $string['members'] = 'members';
 $string['Members'] = 'Members';
+$string['nmembers'] = array(
+    '1 member',
+    '%s members',
+);
 
 $string['memberrequests'] = 'Membership requests';
 $string['declinerequest'] = 'Decline request';
@@ -113,21 +147,14 @@ $string['memberchangesuccess'] = 'Membership status changed successfully';
 $string['viewreleasedsubject'] = 'Your page "%s" has been released from %s by %s';
 $string['viewreleasedmessage'] = 'Your page "%s" has been released from %s by %s';
 $string['viewreleasedsuccess'] = 'Page was released successfully';
-$string['groupmembershipchangesubject'] = 'Group membership: %s';
-$string['groupmembershipchangedmessagetutor'] = 'You have been promoted to a tutor in this group';
-$string['groupmembershipchangedmessagemember'] = 'You have been demoted from a tutor in this group';
-$string['groupmembershipchangedmessageremove'] = 'You have been removed from this group';
-$string['groupmembershipchangedmessagedeclinerequest'] = 'Your request to join this group has been declined';
-$string['groupmembershipchangedmessageaddedtutor'] = 'You have been added as a tutor in this group';
-$string['groupmembershipchangedmessageaddedmember'] = 'You have been added as a member in this group';
 $string['leavegroup'] = 'Leave this group';
 $string['joingroup'] = 'Join this group';
 $string['requestjoingroup'] = 'Request to join this group';
 $string['grouphaveinvite'] = 'You have been invited to join this group';
 $string['grouphaveinvitewithrole'] = 'You have been invited to join this group with the role';
 $string['groupnotinvited'] = 'You have not been invited to join this group';
-$string['groupinviteaccepted'] = 'Invite accepted successfully! You are now a group member';
-$string['groupinvitedeclined'] = 'Invite declined successfully!';
+$string['groupinviteaccepted'] = 'Invite accepted successfully. You are now a group member';
+$string['groupinvitedeclined'] = 'Invite declined successfully.';
 $string['acceptinvitegroup'] = 'Accept';
 $string['declineinvitegroup'] = 'Decline';
 $string['leftgroup'] = 'You have now left this group';
@@ -135,25 +162,23 @@ $string['leftgroupfailed'] = 'Leaving group failed';
 $string['couldnotleavegroup'] = 'You cannot leave this group';
 $string['joinedgroup'] = 'You are now a group member';
 $string['couldnotjoingroup'] = 'You cannot join this group';
+$string['membershipcontrolled'] = 'Membership of this group is controlled.';
+$string['membershipbyinvitationonly'] = 'Membership to this group is by invitation only.';
 $string['grouprequestsent'] = 'Group membership request sent';
 $string['couldnotrequestgroup'] = 'Could not send group membership request';
 $string['cannotrequestjoingroup'] ='You cannot request to join this group';
-$string['groupjointypeopen'] = 'Membership to this group is open. Feel free to join!';
-$string['groupjointypecontrolled'] = 'Membership to this group  is controlled. You cannot join this group.';
-$string['groupjointypeinvite'] = 'Membership to this group is by invitation only.';
-$string['groupjointyperequest'] = 'Membership to this group is by request only.';
 $string['grouprequestsubject'] = 'New group membership request';
 $string['grouprequestmessage'] = '%s would like to join your group %s';
 $string['grouprequestmessagereason'] = "%s would like to join your group %s. Their reason for wanting to join is:\n\n%s";
 $string['cantdeletegroup'] = 'You cannot delete this group';
-$string['groupconfirmdelete'] = "This will delete all pages, files, and forums contained within the group.  Are you sure you wish to fully delete this group and all its content?";
-$string['deletegroup'] = 'Group Deleted Successfully';
-$string['deletegroup1'] = 'Delete Group';
-$string['allmygroups'] = 'All My Groups';
-$string['groupsimin']  = 'Groups I\'m In';
-$string['groupsiown']  = 'Groups I Own';
-$string['groupsiminvitedto'] = 'Groups I\'m Invited To';
-$string['groupsiwanttojoin'] = 'Groups I Want To Join';
+$string['groupconfirmdelete'] = "This will delete all pages, files and forums contained within the group. Are you sure you wish to fully delete this group and all its content?";
+$string['deletegroup'] = 'Group deleted successfully';
+$string['deletegroup1'] = 'Delete group';
+$string['allmygroups'] = 'All my groups';
+$string['groupsimin']  = 'Groups I\'m in';
+$string['groupsiown']  = 'Groups I own';
+$string['groupsiminvitedto'] = 'Groups I\'m invited to';
+$string['groupsiwanttojoin'] = 'Groups I want to join';
 $string['requestedtojoin'] = 'You have requested to join this group';
 $string['groupnotfound'] = 'Group with id %s not found';
 $string['groupconfirmleave'] = 'Are you sure you want to leave this group?';
@@ -166,7 +191,6 @@ $string['nogroups'] = 'No groups';
 $string['deletespecifiedgroup'] = 'Delete group \'%s\'';
 $string['requestjoinspecifiedgroup'] = 'Request to join group \'%s\'';
 $string['youaregroupmember'] = 'You are a member of this group';
-$string['youaregrouptutor'] = 'You are a tutor in this group';
 $string['youaregroupadmin'] = 'You are an admin in this group';
 $string['youowngroup'] = 'You own this group';
 $string['groupsnotin'] = 'Groups I\'m not in';
@@ -182,6 +206,8 @@ $string['notmembermayjoin'] = 'You must join the group \'%s\' to see this page.'
 $string['declinerequestsuccess'] = 'Group membership request has been declined sucessfully.';
 $string['notpublic'] = 'This group is not public.';
 $string['moregroups'] = 'More groups';
+$string['deletegroupnotificationsubject'] = 'The group "%s" was deleted';
+$string['deletegroupnotificationmessage'] = 'You were a member of the group %s on %s. This group has now been deleted.';
 
 // Bulk add, invite
 $string['addmembers'] = 'Add members';
@@ -206,21 +232,20 @@ $string['addtofriendslist'] = 'Add to friends';
 $string['requestfriendship'] = 'Request friendship';
 
 $string['addedtofriendslistsubject'] = '%s has added you as a friend';
-$string['addedtofriendslistmessage'] = '%s added you as a friend! This means that %s is also on your friend list now too. '
-    . ' Click on the link below to see their profile page';
+$string['addedtofriendslistmessage'] = '%s added you as a friend. This means that %s is on your friends list now, too. '
+    . ' Click on the link below to see their profile page.';
 
 $string['requestedfriendlistsubject'] = 'New friend request';
 $string['requestedfriendlistmessage'] = '%s has requested that you add them as a friend.  '
-    .' You can either do this from the link below, or from your friends list page';
+    .' You can either do this from the link below or from your friends list page';
 
 $string['requestedfriendlistmessagereason'] = '%s has requested that you add them as a friend.'
-    . ' You can either do this from the link below, or from your friends list page.'
+    . ' You can either do this from the link below or from your friends list page.'
     . ' Their reason was:
     ';
 
 $string['removefromfriendslist'] = 'Remove from friends';
 $string['removefromfriends'] = 'Remove %s from friends';
-$string['confirmremovefriend'] = 'Are you sure you want to remove this user from your friends list?';
 $string['removedfromfriendslistsubject'] = 'Removed from friends list';
 $string['removedfromfriendslistmessage'] = '%s has removed you from their friends list.';
 $string['removedfromfriendslistmessagereason'] = '%s has removed you from their friends list.  Their reason was: ';
@@ -236,25 +261,26 @@ $string['friendrequestacceptedmessage'] = '%s has accepted your friend request a
 $string['friendrequestrejectedsubject'] = 'Friend request rejected';
 $string['friendrequestrejectedmessage'] = '%s has rejected your friend request.';
 $string['friendrequestrejectedmessagereason'] = '%s has rejected your friend request.  Their reason was: ';
+$string['acceptfriendshiprequestfailed'] = 'Failed to accept friendship request.';
+$string['addtofriendsfailed'] = 'Failed to add %s to your friends list.';
 
-$string['allfriends']     = 'All Friends';
-$string['currentfriends'] = 'Current Friends';
+$string['allfriends']     = 'All friends';
+$string['currentfriends'] = 'Current friends';
 $string['pendingfriends'] = 'Pending friends';
-$string['backtofriendslist'] = 'Back to Friends List';
-$string['findnewfriends'] = 'Find New Friends';
+$string['backtofriendslist'] = 'Back to friends list';
+$string['findnewfriends'] = 'Find new friends';
 $string['Views']          = 'Pages';
 $string['Files']          = 'Files';
-$string['seeallviews']    = 'See all %s pages...';
 $string['noviewstosee']   = 'None that you can see :(';
 $string['whymakemeyourfriend'] = 'This is why you should make me your friend:';
-$string['approverequest'] = 'Approve Request!';
-$string['denyrequest']    = 'Deny Request';
+$string['approverequest'] = 'Approve request';
+$string['denyrequest']    = 'Deny request';
 $string['pending']        = 'pending';
-$string['trysearchingforfriends'] = 'Try %ssearching for new friends%s to grow your network!';
+$string['trysearchingforfriends'] = 'Try %ssearching for new friends%s to grow your network.';
 $string['nobodyawaitsfriendapproval'] = 'Nobody is awaiting your approval to become your friend';
-$string['sendfriendrequest'] = 'Send Friend Request!';
-$string['addtomyfriends'] = 'Add to My Friends!';
-$string['friendshiprequested'] = 'Friendship requested!';
+$string['sendfriendrequest'] = 'Send friend request';
+$string['addtomyfriends'] = 'Add to my friends';
+$string['friendshiprequested'] = 'Friendship requested';
 $string['existingfriend'] = 'existing friend';
 $string['nosearchresultsfound'] = 'No search results found :(';
 $string['friend'] = 'friend';
@@ -262,42 +288,45 @@ $string['friends'] = 'friends';
 $string['user'] = 'user';
 $string['users'] = 'users';
 $string['Friends'] = 'Friends';
+$string['Everyone'] = 'Everyone';
+$string['myinstitutions'] = 'My institutions';
 
 $string['friendlistfailure'] = 'Failed to modify your friends list';
 $string['userdoesntwantfriends'] = 'This user doesn\'t want any new friends';
-$string['cannotrequestfriendshipwithself'] = 'You cannot request a friendship with yourself';
+$string['cannotrequestfriendshipwithself'] = 'You cannot request friendship with yourself';
 $string['cantrequestfriendship'] = 'You cannot request friendship with this user';
 
 // Messaging between users
 $string['messagebody'] = 'Send message'; // wtf
 $string['sendmessage'] = 'Send message';
-$string['messagesent'] = 'Message sent!';
+$string['messagesent'] = 'Message sent';
 $string['messagenotsent'] = 'Failed to send message';
 $string['newusermessage'] = 'New message from %s';
-$string['newusermessageemailbody'] = '%s has sent you a message.  To view this message, visit
+$string['newusermessageemailbody'] = '%s has sent you a message. To view this message, visit
 
 %s';
 $string['sendmessageto'] = 'Send message to %s';
-$string['viewmessage'] = 'View Message';
+$string['viewmessage'] = 'View message';
 $string['Reply'] = 'Reply';
 
-$string['denyfriendrequest'] = 'Deny Friend Request';
+$string['denyfriendrequest'] = 'Deny friend request';
 $string['sendfriendshiprequest'] = 'Send %s a friendship request';
 $string['cantdenyrequest'] = 'That is not a valid friendship request';
 $string['cantmessageuser'] = 'You cannot send this user a message';
+$string['cantmessageuserdeleted'] = 'You cannot send this user a message because the account has been deleted';
 $string['cantviewmessage'] = 'You cannot view this message';
 $string['requestedfriendship'] = 'requested friendship';
 $string['notinanygroups'] = 'Not in any groups';
 $string['addusertogroup'] = 'Add to ';
 $string['inviteusertojoingroup'] = 'Invite to ';
 $string['invitemembertogroup'] = 'Invite %s to join \'%s\'';
-$string['cannotinvitetogroup'] = 'You can\'t invite this user to this group';
+$string['cannotinvitetogroup'] = 'You cannnot invite this user to this group';
 $string['useralreadyinvitedtogroup'] = 'This user has already been invited to, or is already a member of, this group.';
 $string['removefriend'] = 'Remove friend';
 $string['denyfriendrequestlower'] = 'Deny friend request';
 
 // Group interactions (activities)
-$string['groupinteractions'] = 'Group Activities';
+$string['groupinteractions'] = 'Group activities';
 $string['nointeractions'] = 'There are no activities in this group';
 $string['notallowedtoeditinteractions'] = 'You are not allowed to add or edit activities in this group';
 $string['notallowedtodeleteinteractions'] = 'You are not allowed to delete activities in this group';
@@ -320,9 +349,10 @@ $string['aboutgroup'] = 'About %s';
 
 $string['Joined'] = 'Joined';
 
-$string['membersdescription:invite'] = 'This is an invite-only group. You can invite users through their profile pages or <a href="%s">send multiple invitations at once</a>.';
-$string['membersdescription:controlled'] = 'This is a controlled membership group. You can add users through their profile pages or <a href="%s">add many users at once</a>.';
+$string['invitemembersdescription'] = 'You can invite users to join this group through their profile pages or <a href="%s">send multiple invitations at once</a>.';
+$string['membersdescription:controlled'] = 'This is a controlled membership group. You can add users directly through their profile pages or <a href="%s">add many users at once</a>.';
 
 // View submission
 $string['submit'] = 'Submit';
 $string['allowssubmissions'] = 'Allows submissions';
+$string['allowssubmissionsdescription'] = 'Members can submit pages to the group';
