@@ -51,6 +51,7 @@ $string['remove']  = 'Remove';
 $string['Close'] = 'Close';
 $string['Help'] = 'Help';
 $string['applychanges'] = 'Apply changes';
+$string['general'] = 'General';
 
 $string['no']     = 'No';
 $string['yes']    = 'Yes';
@@ -64,11 +65,24 @@ $string['enable'] = 'Enable';
 $string['disable'] = 'Disable';
 $string['show'] = 'Show';
 $string['hide'] = 'Hide';
-$string['pluginenabled'] = 'The plugin has is now visible.';
+$string['pluginenabled'] = 'The plugin is now visible.';
 $string['plugindisabled'] = 'The plugin has been hidden.';
-$string['pluginnotenabled'] = 'Plugin is hidden.  You must make the %s plugin visible first.';
+$string['pluginnotenabled'] = 'Plugin is hidden. You must make the %s plugin visible first.';
 $string['pluginexplainaddremove'] = 'Plugins in Mahara are always installed and can be accessed if users know the URLs and would otherwise have access. Rather than enabling and disabling the functionality, plugins are hidden or made visible by clicking on the \'Hide\' or \'Show\' links beside the plugins below.';
-$string['pluginexplainartefactblocktypes'] = 'When hiding an \'artefact\' type plugin, the Mahara system also stops the display of the blocks related to it.';
+$string['pluginexplainartefactblocktypes'] = 'When hiding an \'artefact\' type plugin, Mahara also stops the display of the blocks related to it.';
+$string['pluginbrokenanddisabledtitle'] = 'A broken plugin (%s) was disabled';
+$string['pluginbrokenanddisabled'] = 'A user attempted to load the %s plugin, but it could not be loaded.
+To prevent further errors, the plugin has been disabled.
+
+The error message generated by the plugin was:
+----------------------------------------------------------------------------
+
+    %s
+
+----------------------------------------------------------------------------
+
+To re-enable the plugin, please visit the page "Extensions" of your site.
+';
 
 $string['next']      = 'Next';
 $string['nextpage']  = 'Next page';
@@ -81,6 +95,8 @@ $string['lastpage']  = 'Last page';
 
 $string['accept'] = 'Accept';
 $string['memberofinstitutions'] = 'Member of %s';
+$string['staffofinstitutions'] = 'Staff of %s';
+$string['adminofinstitutions'] = 'Admin of %s';
 $string['reject'] = 'Reject';
 $string['sendrequest'] = 'Send request';
 $string['reason'] = 'Reason';
@@ -88,20 +104,24 @@ $string['select'] = 'Select';
 
 // Tags
 $string['tags'] = 'Tags';
-$string['tagsdesc'] = 'Enter comma separated tags for this item.';
-$string['tagsdescprofile'] = 'Enter comma separated tags for this item. Items tagged with \'profile\' are displayed in your sidebar.';
+$string['tagsdesc'] = 'Enter comma-separated tags for this item.';
+$string['tagsdescprofile'] = 'Enter comma-separated tags for this item. Items tagged with \'profile\' are displayed in your sidebar.';
 $string['youhavenottaggedanythingyet'] = 'You have not tagged anything yet';
 $string['mytags'] = 'My Tags';
 $string['Tag'] = 'Tag';
 $string['itemstaggedwith'] = 'Items tagged with "%s"';
-$string['numitems'] = '%s items';
+$string['nitems'] = array(
+    '%s item',
+    '%s items',
+);
 $string['searchresultsfor'] = 'Search results for';
-$string['alltags'] = 'All Tags';
+$string['alltags'] = 'All tags';
 $string['sortalpha'] = 'Sort tags alphabetically';
 $string['sortfreq'] = 'Sort tags by frequency';
 $string['sortresultsby'] = 'Sort results by:';
 $string['date'] = 'Date';
 $string['dateformatguide'] = 'Use the format YYYY/MM/DD';
+$string['dateofbirthformatguide'] = 'Use the format YYYY/MM/DD';
 $string['datetimeformatguide'] = 'Use the format YYYY/MM/DD HH:MM';
 $string['filterresultsby'] = 'Filter results by:';
 $string['tagfilter_all'] = 'All';
@@ -109,22 +129,24 @@ $string['tagfilter_file'] = 'Files';
 $string['tagfilter_image'] = 'Images';
 $string['tagfilter_text'] = 'Text';
 $string['tagfilter_view'] = 'Pages';
-$string['edittags'] = 'Edit Tags';
+$string['edittags'] = 'Edit tags';
 $string['selectatagtoedit'] = 'Select a tag to edit';
 $string['edittag'] = 'Edit <a href="%s">%s</a>';
-$string['editthistag'] = 'Edit This Tag';
+$string['editthistag'] = 'Edit this tag';
 $string['edittagdescription'] = 'All items in your portfolio tagged "%s" will be updated';
 $string['deletetag'] = 'Delete <a href="%s">%s</a>';
-$string['confirmdeletetag'] = 'Do you really want to delete this tag from everything in your portfolio?';
+$string['confirmdeletetag'] = 'Do you really want to delete this tag from all items in your portfolio?';
 $string['deletetagdescription'] = 'Remove this tag from all items in your portfolio';
 $string['tagupdatedsuccessfully'] = 'Tag updated successfully';
 $string['tagdeletedsuccessfully'] = 'Tag deleted successfully';
 
-$string['selfsearch'] = 'Search My Portfolio';
+$string['selfsearch'] = 'Search my portfolio';
+$string['resultsperpage'] = 'Results per page';
 
 // Quota strings
 $string['quota'] = 'Quota';
 $string['quotausage'] = 'You have used <span id="quota_used">%s</span> of your <span id="quota_total">%s</span> quota.';
+$string['groupquota'] = 'Group quota';
 
 $string['updatefailed'] = 'Update failed';
 
@@ -142,12 +164,14 @@ $string['views'] = 'Pages';
 // Online users sideblock strings
 $string['onlineusers'] = 'Online users';
 $string['lastminutes'] = 'Last %s minutes';
+$string['allonline'] = 'Show all online users';
+$string['noonlineusersfound'] = 'No online users found';
 
 // Links and resources sideblock
-$string['linksandresources'] = 'Links and Resources';
+$string['linksandresources'] = 'Links and resources';
 
 // auth
-$string['accesstotallydenied_institutionsuspended'] = 'Your institution %s, has been suspended.  Until it is unsuspended, you will be unable to log in to %s.
+$string['accesstotallydenied_institutionsuspended'] = 'Your institution %s has been suspended. Until it is unsuspended, you will not be able to log in to %s.
 Please contact your institution for help.';
 $string['accessforbiddentoadminsection'] = 'You are forbidden from accessing the administration section';
 $string['accountdeleted'] = 'Sorry, your account has been deleted';
@@ -162,7 +186,7 @@ Password: %s
 
 Visit %s to get started!
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['accountcreatedchangepasswordtext'] = 'Dear %s,
 
 A new account has been created for you on %s. Your details are as follows:
@@ -174,7 +198,7 @@ Once you log in for the first time, you will be asked to change your password.
 
 Visit %s to get started!
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['accountcreatedhtml'] = '<p>Dear %s</p>
 
 <p>A new account has been created for you on <a href="%s">%s</a>. Your details are as follows:</p>
@@ -186,7 +210,7 @@ $string['accountcreatedhtml'] = '<p>Dear %s</p>
 
 <p>Visit <a href="%s">%s</a> to get started!</p>
 
-<p>Regards, %s Site Administrator</p>
+<p>Regards, %s site administrator</p>
 ';
 $string['accountcreatedchangepasswordhtml'] = '<p>Dear %s</p>
 
@@ -201,29 +225,29 @@ $string['accountcreatedchangepasswordhtml'] = '<p>Dear %s</p>
 
 <p>Visit <a href="%s">%s</a> to get started!</p>
 
-<p>Regards, %s Site Administrator</p>
+<p>Regards, %s site administrator</p>
 ';
 $string['accountexpirywarning'] = 'Account expiry warning';
 $string['accountexpirywarningtext'] = 'Dear %s,
 
 Your account on %s will expire within %s.
 
-We recommend you save the contents of your portfolio using the Export tool. Instructions on using this feature may be found within the user guide.
+We recommend you save the contents of your portfolio using the export tool. Instructions on using this feature may be found within the user guide.
 
 If you wish to extend your account access or have any questions regarding the above, please feel free to contact us:
 
 %s
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['accountexpirywarninghtml'] = '<p>Dear %s,</p>
     
 <p>Your account on %s will expire within %s.</p>
 
-<p>We recommend you save the contents of your portfolio using the Export tool. Instructions on using this feature may be found within the user guide.</p>
+<p>We recommend you save the contents of your portfolio using the export tool. Instructions on using this feature may be found within the user guide.</p>
 
-<p>If you wish to extend your account access or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
+<p>If you wish to extend your account access or have any questions regarding the above, please feel free to <a href="%s">contact us</a>.</p>
 
-<p>Regards, %s Site Administrator</p>';
+<p>Regards, %s site administrator</p>';
 $string['institutionmembershipexpirywarning'] = 'Institution membership expiry warning';
 $string['institutionmembershipexpirywarningtext'] = 'Dear %s,
 
@@ -233,14 +257,14 @@ If you wish to extend your membership or have any questions regarding the above,
 
 %s
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['institutionmembershipexpirywarninghtml'] = '<p>Dear %s,</p>
 
 <p>Your membership of %s on %s will expire within %s.</p>
 
-<p>If you wish to extend your membership or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
+<p>If you wish to extend your membership or have any questions regarding the above, please feel free to <a href="%s">contact us</a>.</p>
 
-<p>Regards, %s Site Administrator</p>';
+<p>Regards, %s site administrator</p>';
 $string['institutionexpirywarning'] = 'Institution expiry warning';
 $string['institutionexpirywarningtext_institution'] = 'Dear %s,
 
@@ -250,28 +274,28 @@ If you wish to extend your institution\'s membership or have any questions regar
 
 %s
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['institutionexpirywarninghtml_institution'] = '<p>Dear %s,</p>
 
 <p>%s\'s membership of %s will expire within %s.</p>
 
-<p>If you wish to extend your institution\'s membership or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
+<p>If you wish to extend your institution\'s membership or have any questions regarding the above, please feel free to <a href="%s">contact us</a>.</p>
 
-<p>Regards, %s Site Administrator</p>';
+<p>Regards, %s site administrator</p>';
 $string['institutionexpirywarningtext_site'] = 'Dear %s,
 
 The institution \'%s\' will expire within %s.
 
 You may wish to contact them to extend their membership of %s.
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['institutionexpirywarninghtml_site'] = '<p>Dear %s,</p>
 
 <p>The institution \'%s\' will expire within %s.</p>
 
 <p>You may wish to contact them to extend their membership of %s.</p>
 
-<p>Regards, %s Site Administrator</p>';
+<p>Regards, %s site administrator</p>';
 $string['accountinactive'] = 'Sorry, your account is currently inactive';
 $string['accountinactivewarning'] = 'Account inactivity warning';
 $string['accountinactivewarningtext'] = 'Dear %s,
@@ -282,7 +306,7 @@ Once inactive, you will not be able to log in until an administrator re-enables
 
 You can prevent your account from becoming inactive by logging in.
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['accountinactivewarninghtml'] = '<p>Dear %s,</p>
 
 <p>Your account on %s will become inactive within %s.</p>
@@ -291,45 +315,50 @@ $string['accountinactivewarninghtml'] = '<p>Dear %s,</p>
 
 <p>You can prevent your account from becoming inactive by logging in.</p>
 
-<p>Regards, %s Site Administrator</p>';
+<p>Regards, %s site administrator</p>';
 $string['accountsuspended'] = 'Your account has been suspended as of %s. The reason for your suspension is:<blockquote>%s</blockquote>';
 $string['youraccounthasbeensuspended'] = 'Your account has been suspended';
 $string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspended';
 $string['changepasswordinfo'] = 'You are required to change your password before you can proceed.';
+$string['chooseinstitution'] = 'Choose your institution';
 $string['chooseusernamepassword'] = 'Choose your username and password';
-$string['chooseusernamepasswordinfo'] = 'You need a username and password to log in to %s.  Please choose them now.';
+$string['chooseusernamepasswordinfo'] = 'You need a username and password to log in to %s. Please choose them now.';
 $string['confirmpassword'] = 'Confirm password';
-$string['javascriptnotenabled'] = 'Your browser does not have javascript enabled for this site. Mahara requires javascript to be enabled before you can log in';
-$string['cookiesnotenabled'] = 'Your browser does not have cookies enabled, or is blocking cookies from this site. Mahara requires cookies to be enabled before you can log in';
+$string['deleteaccount'] = 'Delete account of: %s / %s';
+$string['javascriptnotenabled'] = 'Your browser does not have javascript enabled. This site requires javascript to be enabled before you can log in.';
+$string['cookiesnotenabled'] = 'Your browser does not have cookies enabled or is blocking cookies. This site requires cookies to be enabled before you can log in.';
 $string['institution'] = 'Institution';
+$string['institutioncontacts'] = '\'%s\' contacts';
+$string['institutionlink'] = '<a href="%s">%s</a>';
 $string['loggedoutok'] = 'You have been logged out successfully';
 $string['login'] = 'Login';
 $string['loginfailed'] = 'You have not provided the correct credentials to log in. Please check your username and password are correct.';
 $string['loginto'] = 'Log in to %s';
-$string['newpassword'] = 'New Password';
+$string['newpassword'] = 'New password';
 $string['nosessionreload'] = 'Reload the page to log in';
-$string['oldpassword'] = 'Current Password';
+$string['oldpassword'] = 'Current password';
 $string['password'] = 'Password';
 $string['passworddescription'] = ' ';
 $string['passwordhelp'] = 'The password you use to access the system';
-$string['passwordnotchanged'] = 'You did not change your password, please choose a new password';
+$string['passwordnotchanged'] = 'You did not change your password. Please choose a new password.';
 $string['passwordsaved'] = 'Your new password has been saved';
 $string['passwordsdonotmatch'] = 'The passwords do not match';
-$string['passwordtooeasy'] = 'Your password is too easy! Please choose a harder password';
+$string['passwordtooeasy'] = 'Your password is too easy. Please choose a harder password.';
 $string['register'] = 'Register';
-$string['sessiontimedout'] = 'Your session has timed out, please enter your login details to continue';
-$string['sessiontimedoutpublic'] = 'Your session has timed out. You may <a href="%s">log in</a> to continue browsing';
-$string['sessiontimedoutreload'] = 'Your session has timed out. Reload the page to log in again';
+$string['sessiontimedout'] = 'Your session has timed out. Please enter your login details to continue.';
+$string['sessiontimedoutpublic'] = 'Your session has timed out. You may <a href="%s">log in</a> to continue browsing.';
+$string['sessiontimedoutreload'] = 'Your session has timed out. Reload the page to log in again.';
 $string['username'] = 'Username';
-$string['preferredname'] = 'Display Name';
+$string['preferredname'] = 'Display name';
 $string['usernamedescription'] = ' ';
 $string['usernamehelp'] = 'The username you have been given to access this system.';
 $string['youaremasqueradingas'] = 'You are masquerading as %s.';
-$string['yournewpassword'] = 'Your new password. Passwords must be at least six characters long and contain at least one digit and two letters';
+$string['yournewpassword'] = 'Your new password. Passwords must be at least six characters long. Passwords are case-sensitive and must be different to your username.<br/>
+For good security, consider using a passphrase. A passphrase is a sentence rather than a single word. Consider using a favourite quote or listing two (or more!) of your favourite things separated by spaces.';
 $string['yournewpasswordagain'] = 'Your new password again';
 $string['invalidsesskey'] = 'Invalid session key';
 $string['cannotremovedefaultemail'] = 'You cannot remove your primary email address';
-$string['emailtoolong'] = 'E-mail addresses cannot be longer that 255 characters';
+$string['emailtoolong'] = 'E-mail addresses cannot be longer than 255 characters';
 $string['mustspecifyoldpassword'] = 'You must specify your current password';
 $string['Site'] = 'Site';
 
@@ -343,11 +372,11 @@ $string['lastnamedescription'] = ' ';
 $string['studentid'] = 'ID number';
 $string['displayname'] = 'Display name';
 $string['fullname'] = 'Full name';
-$string['registerwelcome'] = 'Welcome! To use this site you must first register.';
+$string['registerwelcome'] = 'Welcome! To use this site you must register first.';
 $string['registeragreeterms'] = 'You must also agree to the <a href="terms.php">terms and conditions</a>.';
 $string['registerprivacy'] = 'The data we collect here will be stored according to our <a href="privacy.php">privacy statement</a>.';
-$string['registerstep3fieldsoptional'] = '<h3>Choose an Optional Profile Image</h3><p>You have now successfully registered with %s! You may now choose an optional profile picture to be displayed as your avatar.</p>';
-$string['registerstep3fieldsmandatory'] = '<h3>Fill Out Mandatory Profile Fields</h3><p>The following fields are required. You must fill them out before your registration is complete.</p>';
+$string['registerstep3fieldsoptional'] = '<h3>Choose an optional profile picture</h3><p>You have now successfully registered with %s! You may now choose an optional profile picture to be displayed as your avatar.</p>';
+$string['registerstep3fieldsmandatory'] = '<h3>Fill Out mandatory profile fields</h3><p>The following fields are required. You must fill them out before your registration is complete.</p>';
 $string['registeringdisallowed'] = 'Sorry, you cannot register for this system at this time';
 $string['membershipexpiry'] = 'Membership expires';
 $string['institutionfull'] = 'The institution you have chosen is not accepting any more registrations.';
@@ -356,17 +385,17 @@ $string['registrationcomplete'] = 'Thank you for registering at %s';
 $string['language'] = 'Language';
 
 // Forgot password
-$string['cantchangepassword'] = 'Sorry, you are unable to change your password through this interface - please use your institution\'s interface instead';
+$string['cantchangepassword'] = 'Sorry, you are unable to change your password through this interface - please use your institution\'s interface instead.';
 $string['forgotusernamepassword'] = 'Forgotten your username or password?';
-$string['forgotusernamepasswordtext'] = '<p>If you have forgotten your username or password, enter the email address listed in your profile and we will send you a message you can use to give yourself a new password.</p>
+$string['forgotusernamepasswordtextprimaryemail'] = '<p>If you have forgotten your username or password, enter the primary email address listed in your profile and we will send you a message you can use to give yourself a new password.</p>
 <p>If you know your username and have forgotten your password, you can also enter your username instead.</p>';
-$string['lostusernamepassword'] = 'Lost Username/Password';
+$string['lostusernamepassword'] = 'Lost username / password';
 $string['emailaddressorusername'] = 'Email address or username';
-$string['pwchangerequestsent'] = 'You should receive an e-mail shortly with a link you can use to change the password for your account';
-$string['forgotusernamepasswordemailsubject'] = 'Username/Password details for %s';
+$string['pwchangerequestsent'] = 'You should receive an email shortly with a link you can use to change the password for your account';
+$string['forgotusernamepasswordemailsubject'] = 'Username / password details for %s';
 $string['forgotusernamepasswordemailmessagetext'] = 'Dear %s,
 
-A username/password request has been made for your account on %s.
+A username / password request has been made for your account on %s.
 
 Your username is %s.
 
@@ -380,10 +409,10 @@ If you have any questions regarding the above, please feel free to contact us:
 
 %s
 
-Regards, %s Site Administrator';
+Regards, %s site administrator';
 $string['forgotusernamepasswordemailmessagehtml'] = '<p>Dear %s,</p>
 
-<p>A username/password request has been made for your account on %s.</p>
+<p>A username / password request has been made for your account on %s.</p>
 
 <p>Your username is <strong>%s</strong>.</p>
 
@@ -395,9 +424,9 @@ $string['forgotusernamepasswordemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>If you have any questions regarding the above, please feel free to <a href="%s">contact us</a>.</p>
 
-<p>Regards, %s Site Administrator</p>';
-$string['forgotpassemailsendunsuccessful'] = 'Sorry, it appears that the e-mail could not be sent successfully. This is our fault, please try again shortly';
-$string['forgotpassemailsentanyway'] = 'An e-mail was sent to the address stored for this user, but the address may not be correct or the recipient server is returning messages. Please contact your Mahara administrator to reset your password if you do not receive the e-mail.';
+<p>Regards, %s site administrator</p>';
+$string['forgotpassemailsendunsuccessful'] = 'Sorry, it appears that the email could not be sent successfully. This is our fault. Please try again shortly.';
+$string['forgotpassemailsentanyway1'] = 'An email was sent to the address stored for this user, but the address may not be correct or the recipient server is returning messages. Please contact the %s administrator to reset your password if you do not receive the email.';
 $string['forgotpassnosuchemailaddressorusername'] = 'The email address or username you entered doesn\'t match any users for this site';
 $string['forgotpasswordenternew'] = 'Please enter your new password to continue';
 $string['nosuchpasswordrequest'] = 'No such password request';
@@ -419,7 +448,7 @@ us.
 
 %scontact.php
 
-Regards, %s Site Administrator
+Regards, %s site administrator
 
 %sforgotpass.php?key=%s';
 $string['noinstitutionsetpassemailmessagehtml'] = '<p>Dear %s,</p>
@@ -433,10 +462,45 @@ $string['noinstitutionsetpassemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>If you have any questions regarding the above, please feel free to <a href="%scontact.php">contact us</a>.</p>
 
-<p>Regards, %s Site Administrator</p>
+<p>Regards, %s site administrator</p>
 
 <p><a href="%sforgotpass.php?key=%s">%sforgotpass.php?key=%s</a></p>';
-$string['debugemail'] = 'NOTICE: This e-mail was intended for %s <%s> but has been sent to you as per the "sendallemailto" configuration setting.';
+
+// Send information about username and how to reset password
+// when moving from external to internal auth with a password already set
+$string['noinstitutionoldpassemailsubject'] = '%s: Membership of %s';
+$string['noinstitutionoldpassemailmessagetext'] = 'Dear %s,
+
+You are no longer a member of %s.
+You may continue to use %s with your current username %s, and the password that you have already set for your account.
+
+If you have forgotten your password, you can reset it by going to the following page and entering in your username.
+
+%sforgotpass.php
+
+If you have any questions regarding the above, please feel free to contact
+us.
+
+%scontact.php
+
+Regards, %s site administrator
+
+%sforgotpass.php';
+$string['noinstitutionoldpassemailmessagehtml'] = '<p>Dear %s,</p>
+
+<p>You are no longer a member of %s.</p>
+<p>You may continue to use %s with your current username %s and the password that you have already set for your account.</p>
+
+<p>If you have forgotten your password, you can reset it by going to the following page and entering in your username.</p>
+
+<p><a href="%sforgotpass.php">%sforgotpass.php</a></p>
+
+<p>If you have any questions regarding the above, please feel free to <a href="%scontact.php">contact us</a>.</p>
+
+<p>Regards, %s site administrator</p>
+
+<p><a href="%sforgotpass.php">%sforgotpass.php</a></p>';
+$string['debugemail'] = 'NOTICE: This email was intended for %s <%s> but has been sent to you as per the "sendallemailto" configuration setting.';
 $string['divertingemailto'] = 'Diverting email to %s';
 
 
@@ -464,7 +528,6 @@ $string['emailnotsent']             = 'Failed to send contact email. Error messa
 // mahara.js
 $string['namedfieldempty'] = 'The required field "%s" is empty';
 $string['processing']     = 'Processing';
-$string['requiredfieldempty'] = 'A required field is empty';
 $string['unknownerror']       = 'An unknown error occurred (0x20f91a0)';
 
 // menu
@@ -472,26 +535,28 @@ $string['home']        = 'Home';
 $string['Content']     = 'Content';
 $string['myportfolio'] = 'Portfolio';
 $string['settings']    = 'Settings';
-$string['myfriends']          = 'My Friends';
-$string['findfriends']        = 'Find Friends';
+$string['myfriends']          = 'My friends';
+$string['findfriends']        = 'Find friends';
 $string['groups']             = 'Groups';
-$string['mygroups']           = 'My Groups';
-$string['findgroups']         = 'Find Groups';
-$string['returntosite']       = 'Return to Site';
-$string['siteadministration'] = 'Site Administration';
-$string['institutionadministration'] = 'Institution Administration';
+$string['mygroups']           = 'My groups';
+$string['findgroups']         = 'Find groups';
+$string['returntosite']       = 'Return to site';
+$string['siteadministration'] = 'Site administration';
+$string['institutionadministration'] = 'Institution administration';
+$string['siteinformation']    = 'Site information';
+$string['institutioninformation'] = 'Institution information';
 
 $string['unreadmessages'] = 'unread messages';
 $string['unreadmessage'] = 'unread message';
 
-$string['siteclosed'] = 'The site is temporarily closed for a database upgrade.  Site administrators may log in.';
-$string['siteclosedlogindisabled'] = 'The site is temporarily closed for a database upgrade.  <a href="%s">Perform the upgrade now.</a>';
+$string['siteclosed'] = 'The site is temporarily closed for a database upgrade. Site administrators may log in.';
+$string['siteclosedlogindisabled'] = 'The site is temporarily closed for a database upgrade. <a href="%s">Perform the upgrade now.</a>';
 
 // footer
-$string['termsandconditions'] = 'Terms and Conditions';
-$string['privacystatement']   = 'Privacy Statement';
+$string['termsandconditions'] = 'Terms and conditions';
+$string['privacystatement']   = 'Privacy statement';
 $string['about']              = 'About';
-$string['contactus']          = 'Contact Us';
+$string['contactus']          = 'Contact us';
 
 // my account
 $string['account'] =  'Settings';
@@ -502,8 +567,8 @@ $string['changepassword'] = 'Change password';
 $string['notifications'] = 'Notifications';
 $string['inbox'] = 'Inbox';
 $string['gotoinbox'] = 'Go to inbox';
-$string['institutionmembership'] = 'Institution Membership';
-$string['institutionmembershipdescription'] = 'If you are a member of any institutions, they will be listed here. You may also request membership of institutions, and accept or decline pending membership invitations.';
+$string['institutionmembership'] = 'Institution membership';
+$string['institutionmembershipdescription'] = 'If you are a member of any institutions, they will be listed here. You may also request membership of institutions and accept or decline pending membership invitations.';
 $string['youareamemberof'] = 'You are a member of %s';
 $string['leaveinstitution'] = 'Leave institution';
 $string['reallyleaveinstitution'] = 'Are you sure you want to leave this institution?';
@@ -519,6 +584,8 @@ $string['institutionmemberconfirmsubject'] = 'Institution membership confirmatio
 $string['institutionmemberconfirmmessage'] = 'You have been added as a member of %s.';
 $string['institutionmemberrejectsubject'] = 'Institution membership request declined';
 $string['institutionmemberrejectmessage'] = 'Your request for membership of %s was declined.';
+$string['noinstitutionstafffound'] = 'No institution staff were found';
+$string['noinstitutionadminfound'] = 'No institution administrators were found';
 $string['Memberships'] = 'Memberships';
 $string['Requests'] = 'Requests';
 $string['Invitations'] = 'Invitations';
@@ -529,9 +596,9 @@ $string['sendmessage'] = 'Send message';
 $string['spamtrap'] = 'Spam trap';
 $string['formerror'] = 'There was an error processing your submission. Please try again.';
 $string['formerroremail'] = 'Contact us at %s if you continue to have problems.';
-$string['blacklisteddomaininurl'] = 'A url in this field contains the blacklisted domain %s.';
+$string['blacklisteddomaininurl'] = 'A URL in this field contains the blacklisted domain %s.';
 
-$string['notinstallable'] = 'Not installable!';
+$string['notinstallable'] = 'Not installable';
 $string['installedplugins'] = 'Installed plugins';
 $string['notinstalledplugins'] = 'Not installed plugins';
 $string['plugintype'] = 'Plugin type';
@@ -550,21 +617,22 @@ $string['more...'] = 'More ...';
 $string['nohelpfound'] = 'There was no help found for this item';
 $string['nohelpfoundpage'] = 'There was no help found for this page';
 $string['couldnotgethelp'] = 'An error occurred trying to retrieve the help page';
-$string['profileimage'] = 'Profile image';
+$string['profileimage'] = 'Profile picture';
 $string['primaryemailinvalid'] = 'Your primary email address is invalid';
 $string['addemail'] = 'Add email address';
 
 // Search
 $string['search'] = 'Search';
-$string['searchusers'] = 'Search Users';
-$string['Query'] = 'Query';
-$string['query'] = 'Query';
+$string['searchusers'] = 'Search users';
+$string['Query'] = 'Search';
+$string['query'] = 'Search';
 $string['querydescription'] = 'The words to be searched for';
 $string['result'] = 'result';
 $string['results'] = 'results';
 $string['Results'] = 'Results';
 $string['noresultsfound'] = 'No results found';
 $string['users'] = 'Users';
+$string['searchwithin'] = 'Search within';
 
 // artefact
 $string['artefact'] = 'artefact';
@@ -578,6 +646,7 @@ $string['Permissions'] = 'Permissions';
 $string['republish'] = 'Publish';
 $string['view'] = 'Page';
 $string['artefactnotpublishable'] = 'Artefact %s is not publishable in page %s';
+$string['nopublishpermissiononartefact'] = 'You don\'t have permission to publish %s';
 
 $string['belongingto'] = 'Belonging to';
 $string['allusers'] = 'All users';
@@ -588,15 +657,15 @@ $string['quarantinedirname'] = 'quarantine';
 $string['clammovedfile'] = 'The file has been moved to a quarantine directory.';
 $string['clamdeletedfile'] = 'The file has been deleted';
 $string['clamdeletedfilefailed'] = 'The file could not be deleted';
-$string['clambroken'] = 'Your administrator has enabled virus checking for file uploads but has misconfigured something.  Your file upload was NOT successful. Your administrator has been emailed to notify them so they can fix it.  Maybe try uploading this file later.';
-$string['clamemailsubject'] = '%s :: Clam AV notification';
-$string['clamlost'] = 'Clam AV is configured to run on file upload, but the path supplied to Clam AV, %s, is invalid.';
-$string['clamfailed'] = 'Clam AV has failed to run.  The return error message was %s. Here is the output from Clam:';
-$string['clamunknownerror'] = 'There was an unknown error with clam.';
+$string['clambroken'] = 'Your administrator has enabled virus checking for file uploads but has misconfigured something. Your file upload was NOT successful. Your administrator was notified so they can fix it. Maybe try uploading this file later.';
+$string['clamemailsubject'] = '%s :: ClamAV notification';
+$string['clamlost'] = 'ClamAV is configured to run on file upload, but the path supplied to ClamAV, %s, is invalid.';
+$string['clamfailed'] = 'ClamAV has failed to run. The return error message was %s. Here is the output from ClamAV:';
+$string['clamunknownerror'] = 'There was an unknown error with ClamAV.';
 $string['image'] = 'Image';
-$string['filenotimage'] = 'The file you uploaded is not valid image. It must be a PNG, JPEG or GIF file.';
+$string['filenotimage'] = 'The file you uploaded is not a valid image. It must be a PNG, JPEG or GIF file.';
 $string['uploadedfiletoobig'] = 'The file was too big. Please ask your administrator for more information.';
-$string['notphpuploadedfile'] = 'The file was lost in the upload process. This should not happen, please contact your administrator for more information.';
+$string['notphpuploadedfile'] = 'The file was lost in the upload process. This should not happen. Please contact your administrator for more information.';
 $string['virusfounduser'] = 'The file you have uploaded, %s, has been scanned by a virus checker and found to be infected! Your file upload was NOT successful.';
 $string['fileunknowntype'] = 'The type of your uploaded file could not be determined. Your file may be corrupted, or it could be a configuration problem. Please contact your administrator.';
 $string['virusrepeatsubject'] = 'Warning: %s is a repeat virus uploader.';
@@ -604,7 +673,7 @@ $string['virusrepeatmessage'] = 'The user %s has uploaded multiple files which h
 
 $string['phpuploaderror'] = 'An error occurred during file upload: %s (Error code %s)';
 $string['phpuploaderror_1'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';
-$string['phpuploaderror_2'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$string['phpuploaderror_2'] = 'The uploaded file exceeds the max_file_size directive that was specified in the HTML form.';
 $string['phpuploaderror_3'] = 'The uploaded file was only partially uploaded.';
 $string['phpuploaderror_4'] = 'No file was uploaded.';
 $string['phpuploaderror_6'] = 'Missing a temporary folder.';
@@ -620,7 +689,7 @@ $string['youraccounthasbeenunsuspendedtext2'] = 'Your account at %s has been uns
 $string['sizemb'] = 'MB';
 $string['sizekb'] = 'KB';
 $string['sizegb'] = 'GB';
-$string['sizeb'] = 'b';
+$string['sizeb'] = 'B';
 $string['bytes'] = 'bytes';
 
 // countries
@@ -884,6 +953,15 @@ $string['Total'] = 'Total';
 $string['Visits'] = 'Visits';
 $string['after'] = 'after';
 $string['before'] = 'before';
+$string['Visibility'] = 'Visibility';
+$string['nusers'] = array(
+    '1 user',
+    '%s users',
+);
+$string['hidden'] = 'hidden';
+$string['lastupdate'] = 'Last update';
+$string['lastupdateorcomment'] = 'Last update or comment';
+$string['Title'] = 'Title';
 
 // import related strings (maybe separated later)
 $string['importedfrom'] = 'Imported from %s';
@@ -893,22 +971,21 @@ $string['remotehost'] = 'Remote host %s';
 $string['Copyof'] = 'Copy of %s';
 
 // Profile views
-$string['loggedinusersonly'] = 'Allow logged in users only';
+$string['loggedinusersonly'] = 'Allow logged-in users only';
 $string['allowpublicaccess'] = 'Allow public access';
-$string['thisistheprofilepagefor'] = 'This is the profile page for %s';
 $string['viewmyprofilepage']  = 'View profile page';
 $string['editmyprofilepage']  = 'Edit profile page';
 $string['usersprofile'] = "%s's Profile";
 $string['profiledescription'] = 'Your profile page is what others see when they click on your name or profile picture';
 
 // Dashboard views
-$string['mydashboard'] = 'My Dashboard';
+$string['mydashboard'] = 'My dashboard';
 $string['editdashboard'] = 'Edit';
-$string['usersdashboard'] = "%s's Dashboard";
+$string['usersdashboard'] = "%s's dashboard";
 $string['dashboarddescription'] = 'Your dashboard page is what you see on the homepage when you first log in. Only you have access to it';
-$string['topicsimfollowing'] = "Topics I'm Following";
-$string['recentactivity'] = 'Recent Activity';
-$string['mymessages'] = 'My Messages';
+$string['topicsimfollowing'] = "Topics I'm following";
+$string['recentactivity'] = 'Recent activity';
+$string['mymessages'] = 'My messages';
 
 $string['pleasedonotreplytothismessage'] = "Please do not reply to this message.";
 $string['deleteduser'] = 'Deleted user';
@@ -916,23 +993,27 @@ $string['deleteduser'] = 'Deleted user';
 $string['theme'] = 'Theme';
 $string['choosetheme'] = 'Choose theme...';
 
-// Home page info block
+// Homepage info block
 $string['Hide'] = 'Hide';
-$string['createcollect'] = 'Create and Collect';
+$string['createcollect'] = 'Create and collect';
 $string['createcollectsubtitle'] = 'Develop your portfolio';
-$string['updateyourprofile'] = 'Update your <a href="%s">Profile</a>';
-$string['uploadyourfiles'] = 'Upload your <a href="%s">Files</a>';
-$string['createyourresume'] = 'Create your <a href="%s">Resume</a>';
-$string['publishablog'] = 'Publish a <a href="%s">Journal</a>';
+$string['updateyourprofile'] = 'Update your <a href="%s">profile</a>';
+$string['uploadyourfiles'] = 'Upload your <a href="%s">files</a>';
+$string['createyourresume'] = 'Create your <a href="%s">résumé</a>';
+$string['publishablog'] = 'Publish a <a href="%s">journal</a>';
 $string['Organise'] = 'Organise';
 $string['organisesubtitle'] = 'Showcase your portfolio';
 $string['organisedescription'] = 'Organise your portfolio into <a href="%s">pages.</a>  Create different pages for different audiences - you choose the elements to include.';
-$string['sharenetwork'] = 'Share and Network';
+$string['sharenetwork'] = 'Share and network';
 $string['sharenetworksubtitle'] = 'Find friends and join groups';
-$string['findfriendslinked'] = 'Find <a href="%s">Friends</a>';
-$string['joingroups'] = 'Join <a href="%s">Groups</a>';
-$string['sharenetworkdescription'] = '<br>Control your privacy.';
-$string['howtodisable'] = 'You have hidden the information box.  You can control its visibility in <a href="%s">Settings</a>.';
+$string['findfriendslinked'] = 'Find <a href="%s">friends</a>';
+$string['joingroups'] = 'Join <a href="%s">groups</a>';
+$string['controlyourprivacylinked'] = 'Control your <a href="%s">privacy</a>';
+$string['discusstopicslinked'] = 'Discuss <a href="%s">topics</a>';
+$string['howtodisable'] = 'You have hidden the information box. You can control its visibility in <a href="%s">Settings</a>.';
 
 // Blocktype
 $string['setblocktitle'] = 'Set a block title';
+
+// Download
+$string['filenotfound'] = 'File not found';
