@@ -27,35 +27,38 @@
 
 defined('INTERNAL') || die();
 
-$string['createview']             = 'Create Page';
-$string['edittitle']              = 'Edit Title';
-$string['edittitleanddescription'] = 'Edit Title and Description';
-$string['editcontent']            = 'Edit Content';
-$string['editcontentandlayout']   = 'Edit Content and Layout';
-$string['editlayout']             = 'Edit Layout';
-$string['editaccess']             = 'Edit Access';
+$string['createview']             = 'Create page';
+$string['edittitle']              = 'Edit title';
+$string['edittitleanddescription'] = 'Edit title and description';
+$string['editcontent']            = 'Edit content';
+$string['editcontentandlayout']   = 'Edit content and layout';
+$string['editlayout']             = 'Edit layout';
+$string['editaccess']             = 'Edit access';
 $string['next']                   = 'Next';
 $string['back']                   = 'Back';
-$string['title']                  = 'Page Title';
-$string['description']            = 'Page Description';
-$string['startdate']              = 'Access Start Date/Time';
-$string['stopdate']               = 'Access End Date/Time';
-$string['accessdates']            = 'Access Date/Time';
+$string['title']                  = 'Page title';
+$string['description']            = 'Page description';
+$string['startdate']              = 'Access start date/time';
+$string['stopdate']               = 'Access end date/time';
+$string['accessdates']            = 'Access date/time';
 $string['newstopdatecannotbeinpast'] = 'The end date for \'%s\' access cannot be in the past';
 $string['newstartdatemustbebeforestopdate'] = 'The start date for \'%s\' access must be before the end date';
 $string['unrecogniseddateformat'] = 'Unrecognised date format';
 $string['allowcommentsonview']    = 'If checked, users will be allowed to leave comments.';
 $string['ownerformat']            = 'Name display format';
 $string['ownerformatdescription'] = 'How do you want people who look at your page to see your name?';
+$string['Locked']                 = 'Locked';
+$string['lockedgroupviewdesc']    = 'If you lock this page, only group admins will be able to edit it.';
 $string['profileviewtitle']       = 'Profile page';
 $string['dashboardviewtitle']     = 'Dashboard page';
-$string['grouphomepageviewtitle'] = 'Group Homepage';
+$string['grouphomepageviewtitle'] = 'Group homepage';
+$string['viewname']               = 'Page name';
 
 // my views
 $string['artefacts'] = 'Artefacts';
 $string['groupviews'] = 'Group pages';
 $string['institutionviews'] = 'Institution pages';
-$string['reallyaddaccesstoemptyview'] = 'Your page contains no blocks.  Do you really want to give these users access to the page?';
+$string['reallyaddaccesstoemptyview'] = 'Your page contains no blocks. Do you really want to give these users access to the page?';
 $string['viewdeleted'] = 'Page deleted';
 $string['viewsubmitted'] = 'Page submitted';
 $string['deletethisview'] = 'Delete this page';
@@ -74,37 +77,43 @@ $string['viewsubmittedtogroup'] = 'This page has been submitted to <a href="%s">
 $string['viewsubmittedtogroupon'] = 'This page was submitted to <a href="%s">%s</a> on %s';
 $string['nobodycanseethisview2'] = 'Only you can see this page';
 $string['noviews'] = 'No pages.';
+$string['nviews'] = array(
+    '1 page',
+    '%s pages',
+);
 $string['youhavenoviews'] = 'You have no pages.';
 $string['youhaventcreatedanyviewsyet'] = "You haven't created any pages yet.";
 $string['youhaveoneview'] = 'You have 1 page.';
 $string['youhaveviews']   = 'You have %s pages.';
 $string['viewsownedbygroup'] = 'Pages owned by this group';
-$string['viewssharedtogroup'] = 'Pages shared to this group';
-$string['viewssharedtogroupbyothers'] = 'Pages shared to this group by others';
+$string['viewssharedtogroup'] = 'Pages shared with this group';
+$string['viewssharedtogroupbyothers'] = 'Pages shared with this group by others';
 $string['viewssubmittedtogroup'] = 'Pages submitted to this group';
 $string['submitaviewtogroup'] = 'Submit a page to this group';
 $string['youhavesubmitted'] = 'You have submitted <a href="%s">%s</a> to this group';
 $string['youhavesubmittedon'] = 'You submitted <a href="%s">%s</a> to this group on %s';
+$string['listedinpages'] = 'Listed in pages';
 
 // access levels
 $string['public'] = 'Public';
-$string['loggedin'] = 'Logged In Users';
+$string['loggedin'] = 'Logged-in users';
 $string['friends'] = 'Friends';
 $string['groups'] = 'Groups';
 $string['users'] = 'Users';
-$string['tutors'] = 'tutors';
-$string['everyoneingroup'] = 'Everyone in Group';
+$string['everyoneingroup'] = 'Everyone in group';
 
 // secret url
 $string['token'] = 'Secret URL';
 $string['editsecreturlaccess'] = 'Edit secret URL access';
-$string['newsecreturl'] = 'New Secret URL';
-$string['reallydeletesecreturl'] = 'Are you sure you want to delete this url?';
+$string['newsecreturl'] = 'New secret URL';
+$string['reallydeletesecreturl'] = 'Are you sure you want to delete this URL?';
 $string['secreturldeleted'] = 'Your secret URL was deleted.';
 $string['secreturlupdated'] = 'Secret URL updated';
 $string['generatesecreturl'] = 'Generate a new secret URL for %s';
 $string['secreturls'] = 'Secret URLs';
 
+$string['publicaccessnotallowed'] = "Your institution or site administrator has disabled public pages and secret URLs.  Any secret URLs you see listed here are currently inactive.";
+
 // view user
 $string['inviteusertojoingroup'] = 'Invite this user to join a group';
 $string['addusertogroup'] = 'Add this user to a group';
@@ -119,47 +128,53 @@ $string['alreadyinwatchlist'] = 'This page is already in your watchlist';
 $string['attachedfileaddedtofolder'] = "The attached file %s has been added to your '%s' folder.";
 $string['complaint'] = 'Complaint';
 $string['date'] = 'Date';
-$string['notifysiteadministrator'] = 'Notify site administrator';
-$string['notifysiteadministratorconfirm'] = 'Are you sure you wish to report this page as containing objectional material?';
+$string['notifyadministrator'] = 'Notify administrator';
+$string['notifyadministratorconfirm'] = 'Are you sure you wish to report this page as containing objectionable material?';
 $string['print'] = 'Print';
 $string['reportobjectionablematerial'] = 'Report objectionable material';
 $string['reportsent'] = 'Your report has been sent';
-$string['viewobjectionableunmark'] = 'This page, or something within it, has been reported as containing objectionable content.  If this is no longer the case, you can click the button to remove this notice and notify the other administrators.';
+$string['viewobjectionableunmark'] = 'This page, or something within it, has been reported as containing objectionable content. If this is no longer the case, you can click the button to remove this notice and notify the other administrators.';
 $string['notobjectionable'] = 'Not objectionable';
 $string['viewunobjectionablesubject'] = 'Page %s was marked as not objectionable by %s';
 $string['viewunobjectionablebody'] = '%s has looked at %s by %s and marked it as no longer containing objectionable material.';
 $string['updatewatchlistfailed'] = 'Update of watchlist failed';
 $string['watchlistupdated'] = 'Your watchlist has been updated';
 $string['viewvisitcount'] = '%d page visit(s) from %s to %s';
+$string['profilenotshared'] = 'Full access to this user profile is restricted.';
 
 $string['friend'] = 'Friend';
-$string['profileicon'] = 'Profile Picture';
+$string['profileicon'] = 'Profile picture';
 
 // general views stuff
 $string['Added'] = 'Added';
 $string['share'] = 'Share';
 $string['sharewith'] = 'Share with';
 $string['accesslist'] = 'Access list';
-$string['sharewithmygroups'] = 'Share with My Groups';
+$string['sharewithmygroups'] = 'Share with my groups';
+$string['sharewithmyinstitutions'] = 'Share with my institutions';
+$string['sharewithusers'] = 'Share with users';
 $string['shareview'] = 'Share page';
 $string['otherusersandgroups'] = 'Share with other users and groups';
-$string['moreoptions'] = 'Advanced Options';
+$string['moreoptions'] = 'Advanced options';
+$string['moreinstitutions'] = 'More institutions';
 $string['allviews'] = 'All pages';
 
-$string['submitviewconfirm'] = 'If you submit \'%s\' to \'%s\' for assessment, you will not be able to edit the page until your tutor has finished marking it.  Are you sure you want to submit this page now?';
+$string['submitviewconfirm'] = 'If you submit \'%s\' to \'%s\' for assessment, you will not be able to edit this page until your tutor has finished marking it. Are you sure you want to submit this page now?';
 $string['viewsubmitted'] = 'Page submitted';
 $string['submitviewtogroup'] = 'Submit \'%s\' to \'%s\' for assessment';
 $string['cantsubmitviewtogroup'] = 'You cannot submit this page to this group for assessment';
 
 $string['cantdeleteview'] = 'You cannot delete this page';
 $string['deletespecifiedview'] = 'Delete page "%s"';
-$string['deleteviewconfirm'] = 'Do you really want to delete this page? It cannot be undone.<br/>Please consider creating a backup of this page by <a href="%sexport/" target="_blank">exporting</a> it.';
-$string['deleteviewconfirmnote'] = '<strong>NOTE:</strong> All your files and journal entries that you linked in this page will still be available.<br/>However, any feedback placed on this page as well as text entered directly into text boxes will be deleted.';
+$string['deleteviewconfirm1'] = 'Do you really want to delete this page? It cannot be undone.';
+$string['deleteviewconfirmbackup'] = 'Please consider creating a backup of this page by <a href="%sexport/" target="_blank">exporting</a> it.';
+$string['deleteviewconfirmnote1'] = '<strong>NOTE:</strong> All your files and journal entries that you linked in this page will still be available.<br/>However, any feedback placed on this page will be deleted.';
 
-$string['editaccesspagedescription3'] = 'By default, only you can see your Pages. You can share pages with others by adding access rules.  Once you are done, scroll down and click Save to continue.';
+$string['editaccesspagedescription3'] = 'By default, only you can see your collections and pages. You can share pages with others by adding access rules below. You may set multiple items to have identical settings by choosing them from the checkboxes. Once you are done, scroll down and click Save to continue.';
+$string['editsecreturlsintable'] = '<b>Secret URLs</b> cannot be set on this page as they must be generated individually. To set secret URLs, please return to the <a href="%s">list of collections and pages</a>.';
 $string['editaccessinvalidviewset'] = 'Attempt to edit access on an invalid set of pages and collections';
 
-$string['overridingstartstopdate'] = 'Overriding Start/Stop Dates';
+$string['overridingstartstopdate'] = 'Overriding start/stop dates';
 $string['overridingstartstopdatesdescription'] = 'If you want, you can set an overriding start and/or stop date. Other people will not be able to see your page before the start date and after the end date, regardless of any other access you have granted.';
 
 $string['emptylabel'] = 'Click here to enter text for this label';
@@ -172,7 +187,6 @@ $string['canteditsubmitted'] = 'You can\'t edit this page because it has been su
 $string['Submitted'] = 'Submitted';
 $string['submittedforassessment'] = 'Submitted for assessment';
 
-$string['addtutors'] = 'Add Tutors';
 $string['viewcreatedsuccessfully'] = 'Page created successfully';
 $string['viewaccesseditedsuccessfully'] = 'Page access saved successfully';
 $string['viewsavedsuccessfully'] = 'Page saved successfully';
@@ -205,12 +219,12 @@ $string['confirmdeleteblockinstance'] = 'Are you sure you wish to delete this bl
 $string['blockinstanceconfiguredsuccessfully'] = 'Block configured successfully';
 $string['blockconfigurationrenderingerror'] = 'Configuration failed because the block could not be rendered.';
 
-$string['blocksintructionnoajax'] = 'Select a block and choose where to add it to your page. You can position a block using the arrow buttons in its titlebar';
+$string['blocksintructionnoajax'] = 'Select a block and choose where to add it to your page. You can position a block using the arrow buttons in its titlebar.';
 $string['blocksinstructionajax'] = 'This area shows a preview of what your page will look like.<br>Drag blocks below this line to add them to your page layout. You can drag blocks around your page layout to position them.';
 
 $string['addnewblockhere'] = 'Add new block here';
 $string['add'] = 'Add';
-$string['addcolumn'] = 'Add Column';
+$string['addcolumn'] = 'Add column';
 $string['remove'] = 'Remove';
 $string['removecolumn'] = 'Remove this column';
 $string['moveblockleft'] = "Move %s block left";
@@ -226,9 +240,9 @@ $string['configureblock'] = 'Configure %s block';
 $string['configurethisblock'] = 'Configure this block';
 $string['removeblock'] = 'Remove %s block';
 $string['removethisblock'] = 'Remove this block';
-$string['blocktitle'] = 'Block Title';
+$string['blocktitle'] = 'Block title';
 
-$string['changemyviewlayout'] = 'Change My page Layout';
+$string['changemyviewlayout'] = 'Change my page layout';
 $string['viewcolumnspagedescription'] = 'First, select the number of columns in your page. In the next step, you will be able to change the widths of the columns.';
 $string['viewlayoutpagedescription'] = 'Select how you would like the columns in your page to be layed out.';
 $string['changeviewlayout'] = 'Change my page\'s column layout';
@@ -239,6 +253,7 @@ $string['changecolumnlayoutfailed'] = 'Could not change the column layout. Someo
 
 $string['by'] = 'by';
 $string['viewtitleby'] = '%s by <a href="%s">%s</a>';
+$string['viewauthor'] = 'by <a href="%s">%s</a>';
 $string['in'] = 'in';
 $string['noblocks'] = 'Sorry, no blocks in this category :(';
 $string['timeofsubmission'] = 'Time of submission';
@@ -270,15 +285,20 @@ $string['access'] = 'Access';
 $string['noaccesstoview'] = 'You do not have permission to access this page';
 
 $string['changeviewtheme'] = 'The theme you have chosen for this page is no longer available to you.  Please select a different theme.';
+$string['nothemeselected'] = 'No theme selected';
 
 // Templates
 $string['Template'] = 'Template';
 $string['allowcopying'] = 'Allow copying';
+$string['retainviewrights1'] = 'Retain view access on copied pages or collections';
 $string['templatedescription'] = 'Check this box if you would like the people who can see your page to be able to make their own copies of it, along with any files and folders it contains.';
 $string['templatedescriptionplural'] = 'Check this box if you would like the people who can see your pages to be able to make their own copies of them, along with any files and folders they contain.';
-$string['choosetemplatepagedescription'] = '<p>Here you can search through the pages that you are allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy Page" button to make a copy and begin customising it.</p>';
-$string['choosetemplategrouppagedescription'] = '<p>Here you can search through the pages that this group is allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy Page" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Groups cannot currently make copies of Journals or Journal Entriess.</p>';
-$string['choosetemplateinstitutionpagedescription'] = '<p>Here you can search through the pages that this institution is allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy Page" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Institutions cannot currently make copies of Journals or Journal Entries.</p>';
+$string['retainviewrightsdescription'] = 'Check this box if you would like to add access for you to view copies of this page or collection that are copied by other users. Those users can revoke this access after they copy it if they wish. Pages that are copied from a copy of this page or collection will not have this same access.';
+$string['retainviewrightsgroupdescription'] = 'Check this box if you would like to add access for members of this group to view copies of this page that are copied by other users. Those users can revoke this access after they copy it if they wish. Pages that are copied from a copy of this page will not have this same access.';
+$string['choosetemplatepagedescription'] = '<p>Here you can search through the pages that you are allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy page" button to make a copy and begin customising it.</p>';
+$string['choosetemplatepageandcollectiondescription'] = '<p>Here you can search through the pages that you are allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy page" button to make a copy and begin customising it. You may also choose to copy the entire collection that the page belongs to by clicking the corresponding "Copy collection" button.</p>';
+$string['choosetemplategrouppagedescription'] = '<p>Here you can search through the pages that this group is allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy page" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Groups cannot currently make copies of journals or journal entries.</p>';
+$string['choosetemplateinstitutionpagedescription'] = '<p>Here you can search through the pages that this institution is allowed to copy as a starting point for making a new page. You can see a preview of each page by clicking on its name. Once you have found the page you wish to copy, click the corresponding "Copy page" button to make a copy and begin customising it.</p><p><strong>Note:</strong> Institutions cannot currently make copies of journals or journal entries.</p>';
 $string['copiedblocksandartefactsfromtemplate'] = 'Copied %d blocks and %d artefacts from %s';
 $string['filescopiedfromviewtemplate'] = 'Files copied from %s';
 $string['viewfilesdirname'] = 'viewfiles';
@@ -288,13 +308,14 @@ $string['copythisview'] = 'Copy this page';
 $string['copyview'] = 'Copy page';
 $string['createemptyview'] = 'Create empty page';
 $string['copyaview'] = 'Copy a page';
+$string['copyvieworcollection'] = 'Copy a page or collection';
 $string['Untitled'] = 'Untitled';
 $string['copyfornewusers'] = 'Copy for new users';
 $string['copyfornewusersdescription'] = 'Whenever a new user is created, automatically make a personal copy of this page in the user\'s portfolio.';
 $string['copyfornewmembers'] = 'Copy for new institution members';
 $string['copyfornewmembersdescription'] = 'Automatically make a personal copy of this page for all new members of %s.';
 $string['copyfornewgroups'] = 'Copy for new groups';
-$string['copyfornewgroupsdescription'] = 'Make a copy of this page in all new groups with these Group Types:';
+$string['copyfornewgroupsdescription'] = 'Make a copy of this page in all new groups with these group types:';
 $string['searchviews'] = 'Search pages';
 $string['searchowners'] = 'Search owners';
 $string['owner'] = 'owner';
@@ -308,6 +329,7 @@ $string['nocopyableviewsfound'] = 'No pages that you can copy';
 $string['noownersfound'] = 'No owners found';
 $string['Preview'] = 'Preview';
 $string['viewscopiedfornewusersmustbecopyable'] = 'You must allow copying before you can set a page to be copied for new users.';
+$string['viewswithretainviewrightsmustbecopyable'] = 'You must allow copying before you can set a page to retain view access.';
 $string['viewscopiedfornewgroupsmustbecopyable'] = 'You must allow copying before you can set a page to be copied for new groups.';
 $string['copynewusergroupneedsloggedinaccess'] = 'Pages copied for new users or groups must give access to logged-in users.';
 $string['viewcopywouldexceedquota'] = 'Copying this page would exceed your file quota.';
@@ -319,12 +341,14 @@ $string['blockcopypermissiondesc'] = 'If you allow other users to copy this page
 $string['dashboard'] = 'Dashboard';
 $string['profile'] = 'Profile';
 $string['portfolio'] = 'Portfolio';
-$string['grouphomepage'] = 'Group Homepage';
+$string['grouphomepage'] = 'Group homepage';
 
-$string['grouphomepagedescription'] = 'The Group Homepage is the content that appears on the About tab for this group';
+$string['grouphomepagedescription'] = 'The Group homepage is the content that appears on the About tab for this group';
 
 // Shared views
-$string['sharedviews'] = 'Shared Pages';
+$string['sharedviews'] = 'Shared pages';
 $string['titleanddescription'] = 'Title, description, tags';
 $string['tagsonly'] = 'Tags only';
 $string['sharedviewsdescription'] = 'This page lists the most recently modified or commented on pages that have been shared with you.  They may have been shared with you directly, shared with friends of the owner, or shared with one of your groups.';
+$string['sharedwith'] = 'Shared with';
+$string['Me'] = 'Me';
