@@ -117,7 +117,7 @@ function activity_get_users($activitytype, $userids=null, $userobjs=null, $admin
             ON (aic.instance = ai.id AND aic.field = \'wwwroot\')
         LEFT OUTER JOIN {host} h
             ON aic.value = h.wwwroot
-        WHERE TRUE';
+        WHERE u.deleted = 0';
     if (!empty($userobjs) && is_array($userobjs)) {
         $sql .= ' AND u.id IN (' . implode(',',db_array_to_ph($userobjs)) . ')';
         $values = array_merge($values, array_to_fields($userobjs));
@@ -142,11 +142,13 @@ function activity_get_users($activitytype, $userids=null, $userobjs=null, $admin
 function activity_default_notification_method() {
     static $method = null;
     if (is_null($method)) {
-        if (in_array('email', array_map(create_function('$a', 'return $a->name;'), plugins_installed('notification')))) {
-            $method = 'email';
-        }
-        else {
-            $method = 'internal';
+        if (!$method = get_config('defaultnotificationmethod')) {
+            if (in_array('email', array_keys(plugins_installed('notification')))) {
+                $method = 'email';
+            }
+            else {
+                $method = 'internal';
+            }
         }
     }
     return $method;
@@ -478,6 +480,8 @@ abstract class ActivityType {
             }
         }
 
+        // The user's unread message count does not need to be updated from $changes->read
+        // because of the db trigger on notification_internal_activity.
     }
 
     public function notify_users() {
@@ -521,7 +525,7 @@ class ActivityTypeContactus extends ActivityTypeAdmin {
     function __construct($data, $cron=false) { 
         parent::__construct($data, $cron);
         if (!empty($this->fromuser)) {
-            $this->url = get_config('wwwroot') . 'user/view.php?id=' . $this->fromuser;
+            $this->url = 'user/view.php?id=' . $this->fromuser;
         }
         else {
             $this->customheaders = array(
@@ -579,10 +583,10 @@ class ActivityTypeObjectionable extends ActivityTypeAdmin {
         }
 
         if (empty($this->artefact)) {
-            $this->url = $this->view->get_url();
+            $this->url = $this->view->get_url(false);
         }
         else {
-            $this->url = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->artefact->get('id') . '&view=' . $this->view->get('id');
+            $this->url = 'view/artefact.php?artefact=' . $this->artefact->get('id') . '&view=' . $this->view->get('id');
         }
 
         if (empty($this->strings->subject)) {
@@ -718,12 +722,12 @@ class ActivityTypeInstitutionmessage extends ActivityType {
     public function __construct($data, $cron=false) {
         parent::__construct($data, $cron);
         if ($this->messagetype == 'request') {
-            $this->url = get_config('wwwroot') . 'admin/users/institutionusers.php';
+            $this->url = 'admin/users/institutionusers.php';
             $this->users = activity_get_users($this->get_id(), null, null, null,
                                               array($this->institution->name));
             $this->add_urltext(array('key' => 'institutionmembers', 'section' => 'admin'));
         } else if ($this->messagetype == 'invite') {
-            $this->url = get_config('wwwroot') . 'account/institutions.php';
+            $this->url = 'account/institutions.php';
             $this->users = activity_get_users($this->get_id(), $this->users);
             $this->add_urltext(array('key' => 'institutionmembership', 'section' => 'mahara'));
         }
@@ -787,7 +791,7 @@ class ActivityTypeUsermessage extends ActivityType {
     }
 
     protected function update_url($internalid) {
-        $this->url = get_config('wwwroot') . 'user/sendmessage.php?id=' . $this->userfrom . '&replyto=' . $internalid . '&returnto=inbox';
+        $this->url = 'user/sendmessage.php?id=' . $this->userfrom . '&replyto=' . $internalid . '&returnto=inbox';
         return true;
     }
 
@@ -834,9 +838,10 @@ class ActivityTypeWatchlist extends ActivityType {
                     WHERE (p.activity = ? OR p.activity IS NULL)
                     AND wv.view = ?
                ';
-        $this->users = get_records_sql_array($sql, 
-                                       array(get_config('wwwroot') . 'view/view.php?id=' 
-                                             . $this->view, $this->get_id(), $this->view));
+        $this->users = get_records_sql_array(
+            $sql,
+            array('view/view.php?id=' . $this->view, $this->get_id(), $this->view)
+        );
 
         // Remove the view from the watchlist of users who can no longer see it
         if ($this->users) {
@@ -891,7 +896,7 @@ class ActivityTypeNewview extends ActivityType {
             throw new ViewNotFoundException(get_string('viewnotfound', 'error', $this->view));
         }
 
-        $this->url = get_config('wwwroot') . 'view/view.php?id=' . $this->view;
+        $this->url = 'view/view.php?id=' . $this->view;
 
         // add users on friendslist or userlist...
         $this->users = activity_get_viewaccess_users($this->view, $this->owner, $this->get_id()); 
@@ -941,7 +946,7 @@ class ActivityTypeViewaccess extends ActivityType {
             }
             throw new ViewNotFoundException(get_string('viewnotfound', 'error', $this->view));
         }
-        $this->url = get_config('wwwroot') . 'view/view.php?id=' . $this->view;
+        $this->url = 'view/view.php?id=' . $this->view;
         $this->users = array_diff_key(
             activity_get_viewaccess_users($this->view, $this->owner, $this->get_id()),
             $this->oldusers
@@ -982,14 +987,10 @@ class ActivityTypeGroupMessage extends ActivityType {
 
     protected $group;
     protected $roles;
-    protected $submittedview;
-    private $viewinfo;
-    private $groupinfo;
+    protected $deletedgroup;
 
     /**
      * @param array $data Parameters:
-     *                    - subject (string)
-     *                    - message (string)
      *                    - group (integer)
      *                    - roles (list of roles)
      */
@@ -997,35 +998,14 @@ class ActivityTypeGroupMessage extends ActivityType {
         require_once('group.php');
 
         parent::__construct($data, $cron);
-
-        $this->groupinfo = get_record('group', 'id', $this->group);
-
-        $members = group_get_member_ids($this->group, isset($this->roles) ? $this->roles : null);
-        $this->users = activity_get_users($this->get_id(), $members);
-
-        if ($this->submittedview) {
-            $this->viewinfo = get_record('view', 'id', $this->submittedview);
-            $this->viewinfo->ownername = display_name($this->viewinfo->owner);
-            $this->url = get_config('wwwroot') . 'view/view.php?id=' . $this->submittedview;
+        $members = group_get_member_ids($this->group, isset($this->roles) ? $this->roles : null, $this->deletedgroup);
+        if (!empty($members)) {
+            $this->users = activity_get_users($this->get_id(), $members);
         }
     }
 
-    public function get_subject($user) {
-        if ($this->submittedview) {
-            return get_string_from_language($user->lang, 'viewsubmittedsubject', 'activity', $this->groupinfo->name);
-        }
-        return $this->subject;
-    }
-
-    public function get_message($user) {
-        if ($this->submittedview) {
-            return get_string_from_language($user->lang, 'viewsubmittedmessage', 'activity', $this->viewinfo->ownername, $this->viewinfo->title, $this->groupinfo->name);
-        }
-        return $this->subject;
-    }
-
     public function get_required_parameters() {
-        return array('message', 'subject', 'group');
+        return array('group');
     }
 }
 
@@ -1098,6 +1078,8 @@ function activitylist_html($type='all', $limit=10, $offset=0) {
         'count'      => $count,
         'limit'      => $limit,
         'offset'     => $offset,
+        'jumplinks'  =>  6,
+        'numbersincludeprevnext' => 2,
     ));
 
     $result = array(
