@@ -35,6 +35,7 @@ require_once(get_config('docroot') . 'artefact/lib.php');
 require_once(get_config('docroot') . 'import/lib.php');
 require_once(get_config('docroot') . 'export/lib.php');
 require_once(get_config('docroot') . 'lib/activity.php');
+require_once(get_config('docroot') . 'lib/file.php');
 
 // This is here for debugging purposes, it allows us to fake the time to test
 // cron behaviour
@@ -42,11 +43,11 @@ $realstart = time();
 $fake = isset($argv[1]);
 $start = $fake ? strtotime($argv[1]) : $realstart;
 
-log_debug('---------- cron running ' . date('r', $start) . ' ----------');
+log_info('---------- cron running ' . date('r', $start) . ' ----------');
 raise_memory_limit('128M');
 
 if (!is_writable(get_config('dataroot'))) {
-    log_debug("Warning - unable to write to dataroot directory.");
+    log_warn("Unable to write to dataroot directory.");
 }
 
 // for each plugin type
@@ -80,20 +81,26 @@ foreach (plugin_types() as $plugintype) {
                 array($job->plugin, $job->callfunction)
             );
             if ($nextrun != $job->nextrun) {
-                log_debug("Too late to run $plugintype $job->plugin $job->callfunction; skipping.");
+                log_info("Too late to run $plugintype $job->plugin $job->callfunction; skipping.");
                 cron_free($job, $start, $plugintype);
                 continue;
             }
 
             $classname = generate_class_name($plugintype, $job->plugin);
 
-            log_debug("Running $classname::" . $job->callfunction);
+            log_info("Running $classname::" . $job->callfunction);
 
             safe_require($plugintype, $job->plugin, 'lib.php', 'require_once');
-            call_static_method(
-                $classname,
-                $job->callfunction
-            );
+
+            try {
+                call_static_method($classname, $job->callfunction);
+            }
+            catch (Exception $e) {
+                log_message($e->getMessage(), LOG_LEVEL_WARN, true, true, $e->getFile(), $e->getLine(), $e->getTrace());
+                $output = $e instanceof MaharaException ? $e->render_exception() : $e->getMessage();
+                echo "$output\n";
+                // Don't call handle_exception; try to update next run time and free the lock
+            }
 
             $nextrun = cron_next_run_time($start, (array)$job);
 
@@ -138,15 +145,24 @@ if ($jobs) {
             array($job->id)
         );
         if ($nextrun != $job->nextrun) {
-            log_debug("Too late to run core $job->callfunction; skipping.");
+            log_info("Too late to run core $job->callfunction; skipping.");
             cron_free($job, $start);
             continue;
         }
 
-        log_debug("Running core cron " . $job->callfunction);
+        log_info("Running core cron " . $job->callfunction);
 
         $function = $job->callfunction;
-        $function();
+
+        try {
+            $function();
+        }
+        catch (Exception $e) {
+            log_message($e->getMessage(), LOG_LEVEL_WARN, true, true, $e->getFile(), $e->getLine(), $e->getTrace());
+            $output = $e instanceof MaharaException ? $e->render_exception() : $e->getMessage();
+            echo "$output\n";
+            // Don't call handle_exception; try to update next run time and free the lock
+        }
         
         $nextrun = cron_next_run_time($start, (array)$job);
         
@@ -165,7 +181,7 @@ if (isset($argv[1])) {
     $diff = $realstart - $start;
     $finish = $finish - $diff;
 }
-log_debug('---------- cron finished ' . date('r', $finish) . ' ----------');
+log_info('---------- cron finished ' . date('r', $finish) . ' ----------');
 
 function cron_next_run_time($lastrun, $job) {
     $run_date = getdate($lastrun);
@@ -491,15 +507,14 @@ function cron_lock($job, $start, $plugintype='core') {
     $strstart = $started ? date('r', $started) : '';
     $msg = "long-running cron job $jobname ($strstart).";
 
-    // If it's been going for more than 24 hours, start another one anyway
+    // If it's been going for more than 24 hours, remove the lock
     if ($started && $started < $start - 60*60*24) {
-        delete_records('config', 'field', $lockname);
-        insert_record('config', (object) array('field' => $lockname, 'value' => $start));
-        log_debug('Restarting ' . $msg);
-        return true;
+        log_info('Removing lock record for ' . $msg);
+        cron_free($job, $started, $plugintype);
+        return false;
     }
 
-    log_debug('Skipping ' . $msg);
+    log_info('Skipping ' . $msg);
     return false;
 }
 
