@@ -152,8 +152,33 @@ class CsvFile {
 
         if ($this->data === null) {
             // Oops! Couldn't get CSV data for some reason
-            $this->add_error('file', get_string('uploadcsverrorunspecifiedproblem', 'admin'));
+            $this->add_error('file', get_string('uploadcsverrorunspecifiedproblem1', 'admin'));
         }
     }
 
 }
+
+class CSVErrors {
+
+    private $csverrors = array();
+
+    function add($line, $msg) {
+        if (!isset($this->csverrors[$line])) {
+            $this->csverrors[$line] = array();
+        }
+        $this->csverrors[$line][] = $msg;
+    }
+
+    function process() {
+        if (empty($this->csverrors)) {
+            return;
+        }
+        ksort($this->csverrors);
+        $errorstring = implode("<br>\n", array_shift($this->csverrors));
+        while ($lineerrors = array_shift($this->csverrors)) {
+            $errorstring .= "<br>\n" . implode("<br>\n", $lineerrors);
+        }
+        return $errorstring;
+    }
+
+}
