@@ -469,6 +469,10 @@ function find_index_name($table, $index) {
 /// Calculate the name of the table
     $tablename = $generator->getTableName($table, false);
 
+    if (empty($indcolumns)) {
+        $nocolumnindexname = $generator->getTableName($index);
+    }
+
 /// Get list of indexes in table
     $indexes = null;
     if ($indexes = $db->MetaIndexes($tablename)) {
@@ -477,6 +481,15 @@ function find_index_name($table, $index) {
 
 /// Iterate over them looking for columns coincidence
     if ($indexes) {
+
+        if (isset($nocolumnindexname)) {
+            log_debug("Function find_index_name called on an index $nocolumnindexname with no columns.  Attempting match on index names of all indexes on $tablename without columns.");
+            if (isset($indexes[$nocolumnindexname]) && empty($indexes[$nocolumnindexname]['columns'])) {
+                return $nocolumnindexname;
+            }
+            return false;
+        }
+
         foreach ($indexes as $indexname => $index) {
             $columns = $index['columns'];
         /// Lower case column names
@@ -532,6 +545,72 @@ function find_sequence_name($table) {
     return $sequencename;
 }
 
+/**
+ * This function will load one entire XMLDB file, generating all the needed
+ * SQL statements, specific for each RDBMS ($CFG->dbtype) and, finally, it
+ * will execute all those statements against the DB, to drop all tables.
+ *
+ * @param $file full path to the XML file to be used
+ * @return boolean (true on success, false on error)
+ */
+function uninstall_from_xmldb_file($file) {
+    global $CFG, $db;
+
+    $status = true;
+    $xmldb_file = new XMLDBFile($file);
+
+    if (!$xmldb_file->fileExists()) {
+        throw new InstallationException($xmldb_file->path . " doesn't exist.");
+    }
+
+    $loaded = $xmldb_file->loadXMLStructure();
+    if (!$loaded || !$xmldb_file->isLoaded()) {
+        throw new InstallationException("Could not load " . $xmldb_file->path);
+    }
+
+    $structure = $xmldb_file->getStructure();
+
+    if ($tables = array_reverse($structure->getTables())) {
+        foreach ($tables as $table) {
+            if ($indexes = $table->getIndexes()) {
+                $sortindexes = array();
+                foreach ($indexes as $index) {
+                    $sortindexes[] = find_index_name($table, $index);
+                }
+                array_multisort($indexes, SORT_DESC, $sortindexes);
+                foreach ($indexes as $index) {
+                    if ($index->getName() == 'usernameuk' && is_postgres()) {
+                        // this is a giant hack, but adodb cannot handle resolving
+                        // the column for indexes that include lower() or something similar
+                        // and i can't find a nice way to do it.
+                        execute_sql('DROP INDEX {usr_use_uix}');
+                        continue;
+                    }
+                    drop_index($table, $index);
+                }
+            }
+            if ($keys = $table->getKeys()) {
+                $sortkeys = array();
+                foreach ($keys as $key) {
+                    $sortkeys[] = find_key_name($table, $key);
+                }
+                array_multisort($keys, SORT_DESC, $sortkeys);
+                foreach ($keys as $key) {
+                    if (!is_postgres() && $key->type != XMLDB_KEY_FOREIGN && $key->type != XMLDB_KEY_FOREIGN_UNIQUE) {
+                        // Skip keys for MySQL because these will be
+                        // dropped when the table is dropped
+                        continue;
+                    }
+                    drop_key($table, $key);
+                }
+            }
+            drop_table($table);
+        }
+    }
+
+    return true;
+}
+
 /**
  * This function will load one entire XMLDB file, generating all the needed
  * SQL statements, specific for each RDBMS ($CFG->dbtype) and, finally, it
