@@ -1109,16 +1109,17 @@ function insert_record($table, $dataobject, $primarykey=false, $returnpk=false)
  */
 function ensure_record_exists($table, $whereobject, $dataobject, $primarykey=false, $returnpk=false) {
     $columns = (array)$whereobject;
-    $field = '*';
     $where = array();
+    $values = array();
     $toreturn = false;
 
     foreach ($columns as $key => $value) {
-        if ($field == '*') {
-            $field = $key;
+        if (is_null($value)) {
+            $where[] = db_quote_identifier($key) . ' IS NULL ';
+            continue;
         }
-
-        $where[] = db_quote_identifier($key) . ' = ' . db_quote($value);
+        $where[] = db_quote_identifier($key) . ' = ? ';
+        $values[] = $value;
     }
 
     $where = implode(' AND ', $where);
@@ -1131,7 +1132,7 @@ function ensure_record_exists($table, $whereobject, $dataobject, $primarykey=fal
     }
         
     db_begin();
-    if ($exists = get_record_select($table, $where)) {
+    if ($exists = get_record_select($table, $where, $values)) {
         if ($returnpk) {
             $toreturn = $exists->{$primarykey};
         }
@@ -1391,7 +1392,7 @@ function execute_sql_arr($sqlarr, $continue=true, $feedback=true) {
 
     $status = true;
     foreach($sqlarr as $sql) {
-        if (!execute_sql($sql, $feedback)) {
+        if (!execute_sql($sql)) {
             $status = false;
             if (!$continue) {
                 break;
@@ -1473,6 +1474,7 @@ function configure_dbconnection() {
     $db->Execute("SET NAMES 'utf8'");
 
     if (is_mysql()) {
+        $db->Execute("SET CHARACTER SET utf8");
         $db->Execute("SET SQL_MODE='POSTGRESQL'");
     }
 
@@ -1678,3 +1680,123 @@ function db_replace($replacearray) {
         }
     }
 }
+
+function db_interval($s) {
+    if (is_postgres()) {
+        return "INTERVAL '$s seconds'";
+    }
+    if (is_mysql()) {
+        return "INTERVAL $s SECOND";
+    }
+}
+
+function postgres_language_exists($language) {
+    if (!is_postgres()) {
+        throw new SQLException('postgres_language_exists() expects a postgres database');
+    }
+    return get_field_sql('SELECT 1 FROM pg_catalog.pg_language WHERE lanname = ?', array($language)) == 1;
+}
+
+function postgres_create_language($language) {
+    if (!is_postgres()) {
+        throw new SQLException('postgres_create_language() expects a postgres database');
+    }
+
+    // CREATE LANGUAGE fails if the language already exists
+    if (postgres_language_exists($language)) {
+        return true;
+    }
+
+    try {
+        execute_sql("CREATE LANGUAGE $language;");
+    }
+    catch (SQLException $e) {
+        // Instead of dying with a generic SQLException, return false below and
+        // let the caller decide what to do when the language cannot be created,
+        // e.g. throw a ConfigSanityException with a useful error message.
+    }
+
+    return postgres_language_exists($language);
+}
+
+function mysql_has_trigger_privilege() {
+    // Finding out whether the current user has trigger permission
+    // seems to be quite hard.  It would require parsing the output
+    // from SHOW GRANTS.  It's much easier to try and create one.
+
+    execute_sql("CREATE TABLE {testtable} (testcolumn INT);");
+
+    try {
+        execute_sql("CREATE TRIGGER {testtrigger} BEFORE INSERT ON {testtable} FOR EACH ROW BEGIN END;");
+        execute_sql("DROP TRIGGER {testtrigger};");
+        $success = true;
+    }
+    catch (SQLException $e) {
+        // Instead of dying with a generic SQLException, return false below and
+        // let the caller decide what to do when the trigger cannot be created,
+        // e.g. throw a ConfigSanityException with a useful error message.
+        $success = false;
+    }
+
+    execute_sql("DROP TABLE {testtable};");
+    return $success;
+}
+
+/**
+ * Creates a database row trigger
+ *
+ * @param string $name trigger name
+ * @param string $time trigger action time, e.g. AFTER
+ * @param string $event trigger event, one of (INSERT, UPDATE, DELETE)
+ * @param string $table table name
+ * @param string $body function body
+ */
+function db_create_trigger($name, $time, $event, $table, $body) {
+    if ($time != 'AFTER' || ($event != 'INSERT' && $event != 'UPDATE' && $event != 'DELETE')) {
+        throw new SQLException("db_create_trigger() not implemented for $time $event");
+    }
+    if (is_postgres()) {
+        $functionname = $name . '_function';
+        $triggername  = $name . '_trigger';
+        execute_sql('
+            CREATE FUNCTION {' . $functionname . '}() RETURNS TRIGGER AS $$
+            BEGIN
+                ' . $body . '
+                RETURN NULL;
+            END
+            $$ LANGUAGE plpgsql;
+            CREATE TRIGGER {' . $triggername . '} ' . $time . ' ' . $event . '
+                ON {' . $table . '} FOR EACH ROW
+                EXECUTE PROCEDURE {' . $functionname . '}();'
+        );
+    }
+    else if (is_mysql()) {
+        $triggername = $name . '_trigger';
+        execute_sql('
+            CREATE TRIGGER {' . $triggername . '} ' . $time . ' ' . $event . '
+                ON {' . $table . '} FOR EACH ROW
+                BEGIN
+                    ' . $body . '
+                END'
+        );
+    }
+    else {
+        throw new SQLException("db_create_trigger() is not implemented for your database engine");
+    }
+}
+
+function db_drop_trigger($name, $table) {
+    if (is_postgres()) {
+        $functionname = $name . '_function';
+        $triggername  = $name . '_trigger';
+        execute_sql('DROP TRIGGER {' . $triggername . '} ON {' . $table . '}');
+        execute_sql('DROP FUNCTION {' . $functionname . '}()');
+    }
+    else if (is_mysql()) {
+        $triggername = $name . '_trigger';
+        execute_sql('DROP TRIGGER {' . $triggername . '}');
+    }
+    else {
+        throw new SQLException("db_drop_trigger() is not implemented for your database engine");
+    }
+}
