@@ -553,8 +553,12 @@ class MaharaException extends Exception {
             echo json_encode(array('error' => true, 'message' => $this->render_exception()));
             exit;
         }
-        
-        if (defined('CRON')) {
+
+        if (defined('TESTSRUNNING')) {
+            exit; // let it be caught by phpunit
+        }
+
+        if (defined('CRON') || defined('CLI')) {
             echo $this->render_exception();
             exit;
         }
@@ -741,7 +745,7 @@ class SQLException extends SystemException {
         }
         parent::__construct($message, $code);
 
-        if (empty($DB_IGNORE_SQL_EXCEPTIONS)) {
+        if (empty($DB_IGNORE_SQL_EXCEPTIONS) && !defined('TESTSRUNNING')) {
             log_warn($this->getMessage());
         }
     }
@@ -782,7 +786,7 @@ class XmlrpcClientException extends SystemException {
     public function strings() {
         return array_merge(parent::strings(), array(
             'title'   => get_string('xmlrpccouldnotlogyouin', 'auth'),
-            'message' => get_string('xmlrpccouldnotlogyouindetail', 'auth'))
+            'message' => get_string('xmlrpccouldnotlogyouindetail1', 'auth', get_config('sitename')))
         );
     }
 }
@@ -869,6 +873,11 @@ class UploadException extends UserException {}
  */
 class CollectionNotFoundException extends NotFoundException {}
 
+/**
+ * Exception - file not found in dataroot
+ */
+class FileNotFoundException extends NotFoundException {}
+
 /**
  * Exception - Access denied. Throw this if a user is trying to view something they can't
  */
@@ -904,12 +913,12 @@ class GroupAccessDeniedException extends AccessDeniedException {
             if (!isset($roles[GROUP])) {
                 $group = group_current_group();
                 if ($group->jointype == 'open'
-                    || $group->jointype == 'invite' && get_record('group_member_invite', 'group', GROUP, 'member', $USER->get('id'))) {
+                    || get_record('group_member_invite', 'group', GROUP, 'member', $USER->get('id'))) {
                     $SESSION->add_error_msg(get_string('notmembermayjoin', 'group', $group->name));
                     $next = substr($_SERVER['REQUEST_URI'], strlen(get_mahara_install_subdirectory()) - 1);
                     redirect(get_config('wwwroot') . 'group/view.php?id=' . GROUP . '&next=' . urlencode($next));
                 }
-                if ($group->jointype == 'request' && !get_record('group_member_request', 'group', GROUP, 'member', $USER->get('id'))) {
+                if ($group->request && !get_record('group_member_request', 'group', GROUP, 'member', $USER->get('id'))) {
                     $SESSION->add_error_msg(get_string('notamember', 'group'));
                     redirect(get_config('wwwroot') . 'group/requestjoin.php?id=' . GROUP . '&returnto=view');
                 }
