@@ -149,7 +149,7 @@ function serve_file($path, $filename, $mimetype, $options=array()) {
         }
     }
     else { // Do not cache files in proxies and browsers
-        if (strpos(get_config('wwwroot'), 'https://') === 0) { //https sites - watch out for IE! KB812935 and KB316431
+        if (is_https() === true) { //https sites - watch out for IE! KB812935 and KB316431
             header('Cache-Control: max-age=10');
             header('Expires: '. gmdate('D, d M Y H:i:s', 0) .' GMT');
             header('Pragma: ');
@@ -520,15 +520,21 @@ function get_dataroot_image_path($path, $id, $size=null) {
 
         // Image is not available in this size. If there is a base image for
         // it, we can make one however.
-        if (is_readable($originalimage)) {
+        if (is_readable($originalimage) && filesize($originalimage)) {
 
             $imageinfo = getimagesize($originalimage);
             $originalmimetype = $imageinfo['mime'];
 
             // gd can eat a lot of memory shrinking large images, so use a placeholder image
             // here if necessary
-            if (isset($imageinfo[0]) && isset($imageinfo[1]) && isset($imageinfo['bits'])) {
-                $approxmem = $imageinfo[0] * $imageinfo[1] * ($imageinfo['bits'] / 8)
+            if (isset($imageinfo['bits'])) {
+                $bits = $imageinfo['bits'];
+            }
+            else if ($imageinfo['mime'] == 'image/gif') {
+                $bits = 8;
+            }
+            if (isset($imageinfo[0]) && isset($imageinfo[1]) && !empty($bits)) {
+                $approxmem = $imageinfo[0] * $imageinfo[1] * ($bits / 8)
                     * (isset($imageinfo['channels']) ? $imageinfo['channels'] : 3);
             }
             if (empty($approxmem) || $approxmem > get_config('maximageresizememory')) {
@@ -769,12 +775,14 @@ function rmdirr($dirname)
  * @author      Aidan Lister <aidan@php.net>
  * @version     1.0.1
  * @link        http://aidanlister.com/repos/v/function.copyr.php
+ * @license     Public Domain
  * @param       string   $source    Source path
  * @param       string   $dest      Destination path
  * @return      bool     Returns TRUE on success, FALSE on failure
  */
 function copyr($source, $dest)
 {
+    $dest = trim($dest);
     // Check for symlinks
     if (is_link($source)) {
         return symlink(readlink($source), $dest);
@@ -806,3 +814,55 @@ function copyr($source, $dest)
     $dir->close();
     return true;
 }
+
+function file_cleanup_old_cached_files() {
+    global $THEME;
+    $dirs = array('', '/profileicons');
+    foreach (get_all_theme_objects() as $basename => $theme) {
+        $dirs[] = '/profileicons/no_userphoto/' . $basename;
+    }
+    foreach ($dirs as $dir) {
+        $basedir = get_config('dataroot') . 'artefact/file' . $dir . '/resized/';
+        if (!check_dir_exists($basedir, false)) {
+            continue;
+        }
+
+        $mintime = time() - (12 * 7 * 24 * 60 * 60); // delete caches older than 12 weeks
+
+        // Cached files are stored in a three tier md5sum layout
+        // The actual files are stored in the third directory
+        // This loops through all three directories, then checks the files for age
+        // It cleans up any empty directories on the way down again
+
+        $iter1 = new DirectoryIterator($basedir);
+        foreach ($iter1 as $dir1) {
+            if ($dir1->isDot()) continue;
+            $dir1path = $dir1->getPath() . '/' . $dir1->getFilename();
+            $iter2 = new DirectoryIterator($dir1path);
+            foreach ($iter2 as $dir2) {
+                if ($dir2->isDot()) continue;
+                $dir2path = $dir2->getPath() . '/' . $dir2->getFilename();
+                $iter3 = new DirectoryIterator($dir2path);
+                foreach ($iter3 as $dir3) {
+                    if ($dir3->isDot()) continue;
+                    $dir3path = $dir3->getPath() . '/' . $dir3->getFilename();
+                    $fileiter = new DirectoryIterator($dir3path);
+                    foreach ($fileiter as $file) {
+                        if ($file->isFile() && $file->getCTime() < $mintime) {
+                            unlink($file->getPath() . '/' . $file->getFilename());
+                        }
+                    }
+                    if (sizeof(scandir($dir3path)) <= 2) {   // first 2 entries are . and ..
+                        rmdir($dir3path);
+                    }
+                }
+                if (sizeof(scandir($dir2path)) <= 2) {   // first 2 entries are . and ..
+                    rmdir($dir2path);
+                }
+            }
+            if (sizeof(scandir($dir1path)) <= 2) {   // first 2 entries are . and ..
+                rmdir($dir1path);
+            }
+        }
+    }
+}
