@@ -33,7 +33,10 @@
  * @return string           The HTML for the element
  */
 function pieform_element_viewacl(Pieform $form, $element) {
-    global $USER;
+    global $USER, $SESSION;
+
+    $strlen = function_exists('mb_strlen') ? 'mb_strlen' : 'strlen';
+
     $smarty = smarty_core();
     $smarty->left_delimiter  = '{{';
     $smarty->right_delimiter = '}}';
@@ -41,44 +44,63 @@ function pieform_element_viewacl(Pieform $form, $element) {
     $value = $form->get_value($element);
 
     // Look for the presets and split them into two groups
-    $public = get_config('allowpublicviews') == '1';
-    $presets = array();
+    $public = false;
+    if (get_config('allowpublicviews') && $USER->institution_allows_public_views()) {
+        $public = true;
+    }
+    else if (get_config('allowpublicprofiles') && $element['viewtype'] == 'profile') {
+        $public = true;
+    }
+    $allpresets = array('public', 'loggedin', 'friends');
+    $allowedpresets = array();
     $loggedinindex = 0;
     if ($public) {
-        $presets[] = 'public';
+        $allowedpresets[] = 'public';
         $loggedinindex = 1;
     }
-    $presets[] = 'loggedin';
+    $allowedpresets[] = 'loggedin';
     if ($form->get_property('userview')) {
-        $presets[] = 'friends';
+        $allowedpresets[] = 'friends';
     }
 
+    $accesslist = array();
     if ($value) {
-        foreach ($value as $key => &$item) {
+        foreach ($value as $item) {
             if (is_array($item)) {
-                if (in_array($item['type'], $presets)) {
+                if ($item['type'] == 'public') {
+                    $item['publicallowed'] = (int)$public;
+                }
+                if (in_array($item['type'], $allpresets)) {
                     $item['name'] = get_string($item['type'], 'view');
                     $item['preset'] = true;
                 }
                 else {
                     $item['name'] = pieform_render_viewacl_getvaluebytype($item['type'], $item['id']);
                 }
-                if (mb_strlen($item['name']) > 30) {
+                if ($strlen($item['name']) > 30) {
                     $item['shortname'] = str_shorten_text($item['name'], 30, true);
                 }
                 // only show access that is still current. Expired access will be deleted if the form is saved
-                if($item['stopdate'] && (time() > strtotime($item['stopdate']))) {
-                    unset($value[$key]);
+                if ($form->is_submitted() || empty($item['stopdate']) || (time() <= strtotime($item['stopdate']))) {
+                    $accesslist[] = $item;
                 }
             }
-            else {
-                unset($value[$key]);
-            }
         }
     }
     
-    $potentialpresets = $presets;
-    foreach ($potentialpresets as &$preset) {
+    $myinstitutions = array();
+    foreach ($USER->get('institutions') as $i) {
+        $myinstitutions[] = array(
+            'type' => 'institution',
+            'id'   => $i->institution,
+            'start' => null,
+            'end'   => null,
+            'name' => hsc($i->displayname),
+            'preset' => false
+        );
+    }
+
+    foreach ($allowedpresets as &$preset) {
         $preset = array(
             'type' => $preset,
             'id'   => $preset,
@@ -107,25 +129,47 @@ function pieform_element_viewacl(Pieform $form, $element) {
             'name' => $g->name,
             'preset' => false
         );
-        if (mb_strlen($g->name) > 30) {
+        if ($strlen($g->name) > 30) {
             $group['shortname'] = str_shorten_text($g->name, 30, true);
         }
         $mygroups[] = $group;
     }
     
-    $smarty->assign('potentialpresets', json_encode($potentialpresets));
+    $faves = array();
+    foreach (get_user_favorites($USER->get('id')) as $u) {
+        $fave = array(
+            'type'   => 'user',
+            'id'     => $u->id,
+            'start'  => null,
+            'end'    => null,
+            'name'   => $u->name,
+            'preset' => false
+        );
+        if ($strlen($u->name) > 30) {
+            $fave['shortname'] = str_shorten_text($u->name, 30, true);
+        }
+        $faves[] = $fave;
+    }
+
+    $smarty->assign('viewtype', $element['viewtype']);
+    $smarty->assign('potentialpresets', json_encode($allowedpresets));
     $smarty->assign('loggedinindex', $loggedinindex);
-    $smarty->assign('accesslist', json_encode($value));
+    $smarty->assign('accesslist', json_encode($accesslist));
     $smarty->assign('viewid', $form->get_property('viewid'));
     $smarty->assign('formname', $form->get_property('name'));
+    $smarty->assign('myinstitutions', json_encode($myinstitutions));
     $smarty->assign('allowcomments', $element['allowcomments']);
     $smarty->assign('allgroups', json_encode($allgroups));
     $smarty->assign('mygroups', json_encode($mygroups));
+    $smarty->assign('faves', json_encode($faves));
     return $smarty->fetch('form/viewacl.tpl');
 }
 
 function pieform_render_viewacl_getvaluebytype($type, $id) {
     switch ($type) {
+        case 'loggedin':
+            return get_string('loggedin', 'view');
+            break;
         case 'user':
             $user = get_record('usr', 'id', $id);
             return display_name($user);
@@ -133,12 +177,14 @@ function pieform_render_viewacl_getvaluebytype($type, $id) {
         case 'group':
             return get_field('group', 'name', 'id', $id);
             break;
+        case 'institution':
+            return get_string('institution', 'admin') . ': ' . get_field('institution', 'displayname', 'name', $id);
+            break;
     }
-    return "$type: $id";
+    return sprintf("%s: %s", ucfirst($type), $id);
 }
 
 function pieform_element_viewacl_get_value(Pieform $form, $element) {
-    global $USER;
     $values = null;
     $global = ($form->get_property('method') == 'get') ? $_GET : $_POST;
     if (isset($element['value'])) {
@@ -151,24 +197,5 @@ function pieform_element_viewacl_get_value(Pieform $form, $element) {
     else if (isset($element['defaultvalue'])) {
         $values = $element['defaultvalue'];
     }
-    if (get_config('allowpublicviews') != '1' && $values) {
-        foreach ($values as $key => $value) {
-            if ($value['type'] == 'public' || $value['type'] == 'token') {
-                unset($values[$key]);
-            }
-        }
-    }
-
-    /*
-        If the above foreach() loop removes any items, json_encode() converts
-        it into an object, which can't be iterated over - array_merge() with
-        only one argument effects a renumber of the array, which json_encode()
-        then handles with expected results.
-    */
-    if (is_array($values)) {
-        return array_values($values);
-    }
-    else {
-        return $values;
-    }
+    return $values;
 }
