@@ -215,6 +215,11 @@ class Institution {
         }
         insert_record('usr_institution', $userinst);
         delete_records('usr_institution_request', 'usr', $userinst->usr, 'institution', $this->name);
+        execute_sql("
+            DELETE FROM {usr_tag}
+            WHERE usr = ? AND tag " . db_ilike() . " 'lastinstitution:%'",
+            array($user->id)
+        );
         // Copy institution views to the user's portfolio
         $checkviewaccess = empty($user->newuser) && !$USER->get('admin');
         $userobj = new User();
@@ -223,6 +228,54 @@ class Institution {
         require_once('activity.php');
         activity_occurred('maharamessage', $message);
         handle_event('updateuser', $userinst->usr);
+
+        // Give institution members access to user's profile page
+        require_once('view.php');
+        if ($profileview = $userobj->get_profile_view()) {
+            $profileview->add_owner_institution_access(array($this->name));
+        }
+
+        db_commit();
+    }
+
+    public function add_members($userids) {
+        global $USER;
+
+        if (empty($userids)) {
+            return;
+        }
+
+        if (!$USER->can_edit_institution($this->name)) {
+            throw new AccessDeniedException("Institution::add_members: access denied");
+        }
+
+        $values = array_map('intval', $userids);
+        array_unshift($values, $this->name);
+        $users = get_records_sql_array('
+            SELECT u.*, r.confirmedusr
+            FROM {usr} u LEFT JOIN {usr_institution_request} r ON u.id = r.usr AND r.institution = ?
+            WHERE u.id IN (' . join(',', array_fill(0, count($values) - 1, '?')) . ') AND u.deleted = 0',
+            $values
+        );
+
+        if (empty($users)) {
+            return;
+        }
+
+        db_begin();
+        foreach ($users as $user) {
+            // If the user hasn't requested membership, allow them to be added to
+            // the institution anyway so long as the logged-in user is a site admin
+            // or institutional admin for the user (in some other institution).
+            if (!$user->confirmedusr) {
+                $userobj = new User;
+                $userobj->from_stdclass($user);
+                if (!$USER->is_admin_for_user($userobj)) {
+                    continue;
+                }
+            }
+            $this->addUserAsMember($user);
+        }
         db_commit();
     }
 
@@ -272,6 +325,20 @@ class Institution {
         db_commit();
     }
 
+    public function decline_requests($userids) {
+        global $USER;
+
+        if (!$USER->can_edit_institution($this->name)) {
+            throw new AccessDeniedException("Institution::decline_requests: access denied");
+        }
+
+        db_begin();
+        foreach ($userids as $id) {
+            $this->declineRequestFromUser($id);
+        }
+        db_commit();
+    }
+
     public function inviteUser($user) {
         $userid = is_object($user) ? $user->id : $user;
         db_begin();
@@ -291,11 +358,52 @@ class Institution {
         db_commit();
     }
 
+    public function invite_users($userids) {
+        global $USER;
+
+        if (!$USER->can_edit_institution($this->name)) {
+            throw new AccessDeniedException("Institution::invite_users: access denied");
+        }
+
+        db_begin();
+        foreach ($userids as $id) {
+            $this->inviteUser($id);
+        }
+        db_commit();
+    }
+
+    public function uninvite_users($userids) {
+        global $USER;
+
+        if (!$USER->can_edit_institution($this->name)) {
+            throw new AccessDeniedException("Institution::uninvite_users: access denied");
+        }
+
+        if (!is_array($userids) || empty($userids)) {
+            return;
+        }
+
+        $ph = array_map('intval', $userids);
+        $ph[] = $this->name;
+
+        delete_records_select(
+            'usr_institution_request',
+            'usr IN (' . join(',', array_fill(0, count($userids), '?')) . ') AND institution = ? AND confirmedinstitution = 1',
+            $ph
+        );
+    }
+
     public function removeMembers($userids) {
         // Remove self last.
         global $USER;
+
+        if (!$USER->can_edit_institution($this->name)) {
+            throw new AccessDeniedException("Institution::removeMembers: access denied");
+        }
+
         $users = get_records_select_array('usr', 'id IN (' . join(',', array_map('intval', $userids)) . ')');
         $removeself = false;
+        db_begin();
         foreach ($users as $user) {
             if ($user->id == $USER->id) {
                 $removeself = true;
@@ -306,6 +414,7 @@ class Institution {
         if ($removeself) {
             $USER->leave_institution($this->name);
         }
+        db_commit();
     }
 
     public function removeMember($user) {
@@ -341,8 +450,42 @@ class Institution {
                 log_debug('resetting pw for '.$user->id);
                 $this->removeMemberSetPassword($user);
             }
+            else if ($authinstances[$oldauth]->authname != 'internal') {
+                $sitename = get_config('sitename');
+                $fullname = display_name($user, null, true);
+                email_user($user, null,
+                    get_string('noinstitutionoldpassemailsubject', 'mahara', $sitename, $this->displayname),
+                    get_string('noinstitutionoldpassemailmessagetext', 'mahara', $fullname, $this->displayname, $sitename, $user->username, get_config('wwwroot'), get_config('wwwroot'), $sitename, get_config('wwwroot')),
+                    get_string('noinstitutionoldpassemailmessagehtml', 'mahara', hsc($fullname), hsc($this->displayname), hsc($sitename), hsc($user->username), get_config('wwwroot'), get_config('wwwroot'), get_config('wwwroot'), hsc($sitename), get_config('wwwroot'), get_config('wwwroot')));
+            }
             update_record('usr', $user);
         }
+
+        // If this user has a favourites list which is updated by this institution, remove it
+        // from this institution's control.
+        // Don't delete it in case the user wants to keep it, but move it out of the way, so
+        // another institution can create a new faves list with the same name.
+        execute_sql("
+            UPDATE {favorite}
+            SET institution = NULL, shortname = substring(shortname from 1 for 100) || '.' || ?
+            WHERE owner = ? AND institution = ?",
+            array(substr($this->name, 0, 100) . '.' . get_random_key(), $user->id, $this->name)
+        );
+
+        execute_sql("
+            DELETE FROM {usr_tag}
+            WHERE usr = ? AND tag " . db_ilike() . " 'lastinstitution:%'",
+            array($user->id)
+        );
+
+        insert_record(
+            'usr_tag',
+            (object) array(
+                'usr' => $user->id,
+                'tag' => 'lastinstitution:' . strtolower($this->name),
+            )
+        );
+
         delete_records('usr_institution', 'usr', $user->id, 'institution', $this->name);
         handle_event('updateuser', $user->id);
         db_commit();
@@ -367,7 +510,7 @@ class Institution {
             email_user($user, null,
                 get_string('noinstitutionsetpassemailsubject', 'mahara', $sitename, $this->displayname),
                 get_string('noinstitutionsetpassemailmessagetext', 'mahara', $fullname, $this->displayname, $sitename, $user->username, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $sitename, get_config('wwwroot'), $pwrequest->key),
-                get_string('noinstitutionsetpassemailmessagehtml', 'mahara', $fullname, $this->displayname, $sitename, $user->username, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $sitename, get_config('wwwroot'), $pwrequest->key, get_config('wwwroot'), $pwrequest->key));
+                get_string('noinstitutionsetpassemailmessagehtml', 'mahara', hsc($fullname), hsc($this->displayname), hsc($sitename), hsc($user->username), get_config('wwwroot'), hsc($pwrequest->key), get_config('wwwroot'), hsc($pwrequest->key), get_config('wwwroot'), hsc($sitename), get_config('wwwroot'), hsc($pwrequest->key), get_config('wwwroot'), hsc($pwrequest->key)));
             insert_record('usr_password_request', $pwrequest);
         }
         catch (SQLException $e) {
@@ -401,6 +544,34 @@ class Institution {
         return ($this->maxuseraccounts != '') && ($this->countMembers() >= $this->maxuseraccounts);
     }
 
+    /**
+     * Returns the current institution admin member records
+     *
+     * @return array  A data structure containing admins
+     */
+    public function admins() {
+        if ($results = get_records_sql_array('
+            SELECT u.id FROM {usr} u INNER JOIN {usr_institution} i ON u.id = i.usr
+            WHERE i.institution = ? AND u.deleted = 0 AND i.admin = 1', array($this->name))) {
+            return array_map(create_function('$a', 'return $a->id;'), $results);
+        }
+        return array();
+    }
+
+    /**
+     * Returns the current institution staff member records
+     *
+     * @return array  A data structure containing staff
+     */
+    public function staff() {
+        if ($results = get_records_sql_array('
+            SELECT u.id FROM {usr} u INNER JOIN {usr_institution} i ON u.id = i.usr
+            WHERE i.institution = ? AND u.deleted = 0 AND i.staff = 1', array($this->name))) {
+            return array_map(create_function('$a', 'return $a->id;'), $results);
+        }
+        return array();
+    }
+
     /**
      * Returns the list of institutions, implements institution searching
      *
@@ -491,10 +662,10 @@ class Institution {
     }
 }
 
-function get_institution_selector($includedefault = true) {
+function get_institution_selector($includedefault = true, $assumesiteadmin=false) {
     global $USER;
 
-    if ($USER->get('admin')) {
+    if ($assumesiteadmin || $USER->get('admin')) {
         if ($includedefault) {
             $institutions = get_records_array('institution', '', '', 'displayname');
         }
@@ -597,6 +768,7 @@ function build_institutions_html($filter, $showdefault, $query, $limit, $offset,
                 'count' => $count,
                 'limit' => $limit,
                 'offset' => $offset,
+                'jumplinks' => 4,
                 'resultcounttextsingular' => get_string('institution', 'admin'),
                 'resultcounttextplural' => get_string('institutions', 'admin'),
             ));
@@ -606,3 +778,7 @@ function build_institutions_html($filter, $showdefault, $query, $limit, $offset,
 
     return $data;
 }
+
+function institution_display_name($name) {
+    return get_field('institution', 'displayname', 'name', $name);
+}
