@@ -35,7 +35,7 @@ defined('INTERNAL') || die();
 function ensure_sanity() {
 
     // PHP version
-    $phpversionrequired = '5.2.0';
+    $phpversionrequired = '5.3.0';
     if (version_compare(phpversion(), $phpversionrequired) < 0) {
         throw new ConfigSanityException(get_string('phpversion', 'error', $phpversionrequired));
     }
@@ -147,7 +147,13 @@ function ensure_sanity() {
 
     // dataroot not writable..
     if (!check_dir_exists(get_config('dataroot')) || !is_writable(get_config('dataroot'))) {
-        throw new ConfigSanityException(get_string('datarootnotwritable', 'error', get_config('dataroot')));
+        $message = get_string('datarootnotwritable', 'error', get_config('dataroot'));
+        if ($openbasedir = ini_get('open_basedir')) {
+            $message .= "\n(" . get_string('openbasedirenabled', 'error') . ' '
+                . get_string('openbasedirpaths', 'error', htmlspecialchars($openbasedir)) // hsc() is not defined yet
+                . ')';
+        }
+        throw new ConfigSanityException($message);
     }
 
     if (
@@ -174,6 +180,12 @@ function ensure_install_sanity() {
     if (!db_is_utf8()) {
         throw new ConfigSanityException(get_string('dbnotutf8', 'error'));
     }
+    if (is_postgres() && !postgres_create_language('plpgsql')) {
+        throw new ConfigSanityException(get_string('plpgsqlnotavailable', 'error'));
+    }
+    if (is_mysql() && !mysql_has_trigger_privilege()) {
+        throw new ConfigSanityException(get_string('mysqlnotriggerprivilege', 'error'));
+    }
 }
 
 function ensure_upgrade_sanity() {
@@ -185,6 +197,71 @@ function ensure_upgrade_sanity() {
                 throw new ConfigSanityException(get_string('dbcollationmismatch', 'admin'));
             }
         }
+        if (!mysql_has_trigger_privilege()) {
+            throw new ConfigSanityException(get_string('mysqlnotriggerprivilege', 'error'));
+        }
+    }
+    if (is_postgres() && !postgres_create_language('plpgsql')) {
+        throw new ConfigSanityException(get_string('plpgsqlnotavailable', 'error'));
+    }
+}
+
+/**
+ * Upgrade/Install the specified mahara components
+ *
+ * @param array $upgrades The list of components to install or upgrade
+ * @return void
+ */
+function upgrade_mahara($upgrades) {
+    if (isset($upgrades['firstcoredata']) && $upgrades['firstcoredata']) {
+        $install = true;
+    }
+    else {
+        $install = false;
+    }
+    uksort($upgrades, 'sort_upgrades');
+    foreach ($upgrades as $name => $data) {
+        if ($name == 'disablelogin') {
+            continue;
+        }
+        if ($install) {
+            log_info(get_string('installingplugin', 'admin', $name));
+        }
+        else {
+            log_info(get_string('upgradingplugin', 'admin', $name));
+        }
+        if ($name == 'firstcoredata' || $name == 'lastcoredata') {
+            $funname = 'core_install_' . $name . '_defaults';
+            $funname();
+            continue;
+        }
+        else if ($install && $name == 'localpreinst') {
+            $name(array('localdata' => true));
+        }
+        else if ($install && $name == 'localpostinst') {
+            // Update local version
+            $config = new StdClass;
+            require(get_config('docroot') . 'local/version.php');
+            set_config('localversion', $config->version);
+            set_config('localrelease', $config->release);
+
+            // Installation is finished
+            set_config('installed', true);
+            log_info('Installation complete.');
+        }
+        else {
+            if ($name == 'core') {
+                $funname = 'upgrade_core';
+            }
+            else if ($name == 'local') {
+                $funname = 'upgrade_local';
+            }
+            else {
+                $funname = 'upgrade_plugin';
+            }
+            $data->name = $name;
+            $funname($data);
+        }
     }
 }
 
@@ -289,7 +366,28 @@ function get_helpfile_location($plugintype, $pluginname, $form, $element, $page=
         return $langfile;
     }
 
-    if ($plugintype != 'core') {
+    if ($plugintype == 'blocktype') { // these are a bit of a special case
+        $bits = explode('/', $pluginname);
+        if (count($bits) == 2) {
+           $location = 'artefact/' . $bits[0] . '/blocktype/' . $bits[1] . '/lang/';
+        }
+        else {
+            try {
+                if ($artefactplugin = blocktype_artefactplugin($pluginname)) {
+                    $location = 'artefact/' . $artefactplugin . '/blocktype/' . $pluginname . '/lang/';
+                }
+                else {
+                    $location = 'blocktype/' . $pluginname . '/lang/';
+                }
+            }
+            catch (SQLException $e) {
+                if (get_config('installed')) {
+                    throw $e;
+                }
+            }
+        }
+    }
+    else if ($plugintype != 'core') {
         $location = $plugintype . '/' . $pluginname . '/lang/';
     }
     else {
@@ -389,7 +487,7 @@ function get_string_location($identifier, $section, $variables, $replacefunc='fo
     // First check all the normal locations for the string in the current language
     $result = get_string_local($langstringroot . $langdirectory, $lang . '/' . $section . '.php', $identifier);
     if ($result !== false) {
-        return $replacefunc($result, $variables);
+        return $replacefunc($result, $variables, $lang);
     }
 
     // If the preferred language was English (utf8) we can abort now
@@ -404,7 +502,7 @@ function get_string_location($identifier, $section, $variables, $replacefunc='fo
         if ($parentlang = get_string_from_file('parentlanguage', $langfile)) {
             $result = get_string_local(get_language_root($parentlang) . 'lang/', $parentlang . '/' . $section . '.php', $identifier);
             if ($result !== false) {
-                return $replacefunc($result, $variables);
+                return $replacefunc($result, $variables, $parentlang);
             }
         }
     }
@@ -459,6 +557,7 @@ function get_languages() {
                     }
                 }
                 closedir($langdir);
+                asort($langs);
             }
             else {
                 log_warn('Unable to read language directory ' . $langbase);
@@ -591,7 +690,9 @@ function get_user_accessible_themes() {
         }
 
     }
-    $themes = array_merge(array('sitedefault' => '- ' . get_string('sitedefault', 'admin') . ' (' . $themes[get_config('theme')] . ') -'), $themes);
+    $themes = array_merge(array('sitedefault' => get_string('nothemeselected', 'view')), $themes);
+    unset($themes['custom']);
+
     return $themes;
 }
 
@@ -632,7 +733,7 @@ function get_all_theme_objects() {
             throw new SystemException('Unable to read theme directory '.$themebase);
         }
         while (false !== ($subdir = readdir($themedir))) {
-            if ($subdir != "." && $subdir != ".." && is_dir($themebase . $subdir)) {
+            if (substr($subdir, 0, 1) != "." && is_dir($themebase . $subdir)) {
                 // is the theme directory name valid?
                 if (!Theme::name_is_valid($subdir)) {
                     log_warn(get_string('themenameinvalid', 'error', $subdir));
@@ -714,14 +815,16 @@ function ini_get_bool($ini_get_arg) {
  */
 function load_config() {
    global $CFG;
-   global $OVERRIDDEN;    // array containing the database config fields overridden by $CFG
+   global $OVERRIDDEN;    // array containing the config fields overridden by $CFG
+
+   // Get a full list of overridden fields
+   foreach ($CFG as $field => $value) {
+        $OVERRIDDEN[] = $field;
+   }
 
    $dbconfig = get_records_array('config', '', '', '', 'field, value');
-
    foreach ($dbconfig as $cfg) {
-       if (isset($CFG->{$cfg->field})) {
-           $OVERRIDDEN[] = $cfg->field;
-       } else {
+       if (!isset($CFG->{$cfg->field})) {
            $CFG->{$cfg->field} = $cfg->value;
        }
    }
@@ -789,17 +892,23 @@ function set_config($key, $value) {
 function get_config_plugin($plugintype, $pluginname, $key) {
     global $CFG;
 
+    $CFG->plugin = new StdClass;
+
     // Suppress NOTICE with @ in case $key is not yet cached
     @$value = $CFG->plugin->{$plugintype}->{$pluginname}->{$key};
-    if (isset($value)) {
+    if (isset($CFG->plugin->{$plugintype})) {
         return $value;
     }
 
-    $records = get_records_array($plugintype . '_config', 'plugin', $pluginname, 'field', 'field, value');
+    $CFG->plugin = new stdClass();
+    $CFG->plugin->{$plugintype} = new StdClass;
+
+    $records = get_records_array($plugintype . '_config');
     if (!empty($records)) {
         foreach($records as $record) {
-            $CFG->plugin->{$plugintype}->{$pluginname}->{$record->field} = $record->value;
-            if ($record->field == $key) {
+            $CFG->plugin->{$plugintype}->{$record->plugin} = new stdClass();
+            $CFG->plugin->{$plugintype}->{$record->plugin}->{$record->field} = $record->value;
+            if ($record->field == $key && $record->plugin == $pluginname) {
                 $value = $record->value;
             }
         }
@@ -826,6 +935,7 @@ function set_config_plugin($plugintype, $pluginname, $key, $value) {
         $status = insert_record($table, $pconfig);
     }
     if ($status) {
+        $CFG->plugin->{$plugintype}->{$pluginname} = new stdClass();
         $CFG->plugin->{$plugintype}->{$pluginname}->{$key} = $value;
         return true;
     }
@@ -970,10 +1080,20 @@ function current_language() {
  * Helper function to sprintf language strings
  * with a variable number of arguments
  * 
- * @param string $string raw string to use
+ * @param mixed $string raw string to use, or an array of strings, one for each plural form
  * @param array $args arguments to sprintf
+ * @param string $lang The language
  */
-function format_langstring($string,$args) {
+function format_langstring($string, $args, $lang='en.utf8') {
+    if (is_array($string) && isset($args[0]) && is_numeric($args[0])) {
+        // If there are multiple strings here, there must be one for each plural
+        // form in the language.  The first argument is passed into the plural
+        // function, which returns an index into the array of strings.
+        $pluralfunction = get_string_location('pluralfunction', 'langconfig', array(), 'raw_langstring', $lang);
+        $index = function_exists($pluralfunction) ? $pluralfunction($args[0]) : 0;
+        $string = isset($string[$index]) ? $string[$index] : current($string);
+    }
+
     return call_user_func_array('sprintf',array_merge(array($string),$args));
 }
 
@@ -1006,6 +1126,7 @@ function is_hash($array) {
 function check_dir_exists($dir, $create=true, $recursive=true) {
 
     $status = true;
+    $dir = trim($dir);
 
     if(!is_dir($dir)) {
         if (!$create) {
@@ -1107,6 +1228,43 @@ function safe_require($plugintype, $pluginname, $filename='lib.php', $function='
     
 }
 
+/**
+ * This function is a wrapper around safe_require which will attempt to
+ * handle missing plugins more gracefully.
+ *
+ * If a missing plugin is detected, then that plugin will be disabled, and
+ * an e-mail will be sent to site administrators to inform them of the
+ * issue.
+ *
+ * See @safe_require for further information on that function.
+ *
+ * @param string $plugintype the type of plugin (eg artefact)
+ * @param string $pluginname the name of the plugin (eg blog)
+ * @param string $filename the name of the file to include within the plugin structure
+ * @param string $function (optional, defaults to require) the require/include function to use
+ * @param string $nonfatal (optional, defaults to false) just returns false if the file doesn't exist
+ */
+function safe_require_plugin($plugintype, $pluginname, $filename='lib.php', $function='require_once', $nonfatal=false) {
+    try {
+        safe_require($plugintype, $pluginname, $filename, $function, $nonfatal);
+        return true;
+    }
+    catch (SystemException $e) {
+        if (get_field($plugintype . '_installed', 'active', 'name', $pluginname) == 1) {
+            set_field($plugintype . '_installed', 'active', 0, 'name', $pluginname);
+            // Alert site admins that the plugin is broken so was disabled
+            $message = new stdClass();
+            $message->users = get_column('usr', 'id', 'admin', 1);
+            $message->subject = get_string('pluginbrokenanddisabledtitle', 'mahara', $pluginname);
+            $message->message = get_string('pluginbrokenanddisabled', 'mahara', $pluginname, $e->getMessage());
+
+            require_once('activity.php');
+            activity_occurred('maharamessage', $message);
+        }
+        return false;
+    }
+}
+
 /**
  * This function returns the list of plugintypes we currently care about.
  *
@@ -1223,7 +1381,7 @@ function blocktype_name_to_namespaced($blocktype) {
     static $resultcache = array();
 
     if (!isset($resultcache[$blocktype])) {
-        $artefactplugin = get_field('blocktype_installed', 'artefactplugin', 'name', $blocktype);
+        $artefactplugin = blocktype_artefactplugin($blocktype);
         if ($artefactplugin) {
             $resultcache[$blocktype] = "$artefactplugin/$blocktype";
         }
@@ -1413,11 +1571,14 @@ class Plugin {
  * (see langconfig.php or the top of {@link get_string_location}
  * for supported keys
  */
-
 function format_date($date, $formatkey='strftimedatetime', $notspecifiedkey='strftimenotspecified', $notspecifiedsection='mahara') {
     if (empty($date)) {
         return get_string($notspecifiedkey, $notspecifiedsection);
     }
+    if (strtoupper(substr(PHP_OS, 0, 3)) == 'WIN') {
+        $fixedkey = str_replace('%e', '%#d', get_string($formatkey));
+        return strftime($fixedkey, $date);
+    }
     return strftime(get_string($formatkey), $date);
 }
 
@@ -1621,6 +1782,16 @@ function can_view_view($view_id, $user_id=null) {
     require_once(get_config('libroot') . 'view.php');
     $view = new View($view_id);
 
+    // group views and logged in users are not affected by
+    // the institution level config for public views
+    if (empty($user_id) && $ownerobj = $view->get_owner_object()) {
+        $owner = new User();
+        $owner->find_by_id($ownerobj->id);
+        if (!$owner->institution_allows_public_views()) {
+            return false;
+        }
+    }
+
     if ($user_id && $user->can_edit_view($view)) {
         return true;
     }
@@ -1631,6 +1802,13 @@ function can_view_view($view_id, $user_id=null) {
         return false;
     }
 
+    // If the view's owner is suspended, deny access to the view
+    if ($view->get('owner')) {
+        if ((!$owner = $view->get_owner_object()) || $owner->suspendedcusr) {
+            return false;
+        }
+    }
+
     // Overriding start/stop dates are set by the owner to deny access
     // to users who would otherwise be allowed to see the view.  However,
     // for some kinds of access (e.g. objectionable content, submitted
@@ -1687,6 +1865,12 @@ function can_view_view($view_id, $user_id=null) {
                     continue;
                 }
             }
+            else if ($a->institution) {
+                // Check if user belongs to the allowed institution
+                if (!in_array($a->institution, array_keys($user->get('institutions')))) {
+                    continue;
+                }
+            }
             else if ($a->accesstype == 'objectionable') {
                 if ($owner = $view->get('owner')) {
                     if ($user->is_admin_for_user($owner)) {
@@ -1830,7 +2014,7 @@ function get_views($users, $userlooking=null, $limit=5, $type=null) {
             v.*,
             ' . db_format_tsfield('atime') . ',
             ' . db_format_tsfield('mtime') . ',
-            ' . db_format_tsfield('ctime') . '
+            ' . db_format_tsfield('v.ctime', 'ctime') . '
         FROM 
             {view} v
             INNER JOIN {view_access} a ON
@@ -1871,7 +2055,7 @@ function get_views($users, $userlooking=null, $limit=5, $type=null) {
             v.*,
             ' . db_format_tsfield('atime') . ',
             ' . db_format_tsfield('mtime') . ',
-            ' . db_format_tsfield('ctime') . '
+            ' . db_format_tsfield('v.ctime', 'ctime') . '
         FROM 
             {view} v
             INNER JOIN {view_access} a ON v.id=a.view AND a.usr=?
@@ -2130,6 +2314,10 @@ function get_real_size($size=0) {
     else if (is_numeric($size)) return (int)$size;
 
     $scan = array(
+        'GB' => 1073741824,
+        'Gb' => 1073741824,
+        'G'  => 1073741824,
+        'g'  => 1073741824,
         'MB' => 1048576,
         'Mb' => 1048576,
         'M'  => 1048576,
@@ -2216,7 +2404,6 @@ function profile_sideblock() {
         'id'          => $USER->get('id'),
         'myname'      => display_name($USER, null, true),
         'username'    => $USER->get('username'),
-        'profileicon' => $USER->get('profileicon') ? $USER->get('profileicon') : 0,
     );
 
     $authinstance = $SESSION->get('mnetuser') ? $SESSION->get('authinstance') : $USER->get('authinstance');
@@ -2232,8 +2419,6 @@ function profile_sideblock() {
             }
         }
     }
-    $data['unreadnotifications'] = call_static_method(generate_class_name('notification', 'internal'), 'unread_count', $USER->get('id'));
-    $data['unreadnotificationsmessage'] = $data['unreadnotifications'] == 1 ? get_string('unreadmessage') : get_string('unreadmessages');
     $invitedgroups = get_records_sql_array('SELECT g.*, gmi.ctime, gmi.reason
              FROM {group} g
              JOIN {group_member_invite} gmi ON gmi.group = g.id
@@ -2268,24 +2453,54 @@ function profile_sideblock() {
  * The time is configured by setting the 'accessidletimeout' configuration 
  * option.
  *
- * NOTE: currently returns all online users, this might not be desirable on a 
- * really busy site.
+ * Limits the number of users to display based on the 'onlineuserssideblockmaxusers'
+ * site configuration option and the Institution specific 'showonlineusers' setting.
+ * If the user belongs to no institution (other than the standard 'mahara' one) then
+ * the decision will be to show ALL users by default.
+ *
  */
 function onlineusers_sideblock() {
     global $USER;
 
-    $onlineusers = get_records_select_array('usr', 'deleted = 0 AND lastaccess > ?',
-        array(db_format_timestamp(time() - get_config('accessidletimeout'))), 'lastaccess DESC');
+    // Determine what level of users to show
+    // 0 = none, 1 = institution/s only, 2 = all users
+    $showusers = 2;
+    $institutions = $USER->institutions;
+    if (!empty($institutions)) {
+        $showusers = 0;
+        foreach ($institutions as $i) {
+            if ($i->showonlineusers == 2) {
+                $showusers = 2;
+                break;
+            }
+            if ($i->showonlineusers == 1) {
+                $showusers = 1;
+            }
+        }
+    }
 
+    $maxonlineusers = get_config('onlineuserssideblockmaxusers');
+    switch ($showusers) {
+        case 0: // show none
+            return array(
+                'users' => array(),
+                'count' => 0,
+                'lastminutes' => floor(get_config('accessidletimeout') / 60),
+            );
+        case 1: // show institution only
+            $sql = 'SELECT DISTINCT u.* FROM {usr} u JOIN {usr_institution} i ON u.id = i.usr
+                WHERE i.institution IN ('.join(',', array_map('db_quote', array_keys($institutions))).')
+                AND lastaccess > ? AND deleted = 0 ORDER BY lastaccess DESC';
+            break;
+        case 2: // show all
+            $sql = 'SELECT * FROM {usr} WHERE lastaccess > ? AND deleted = 0 ORDER BY lastaccess DESC';
+            break;
+    }
+
+    $onlineusers = get_records_sql_array($sql, array(db_format_timestamp(time() - get_config('accessidletimeout'))), 0, $maxonlineusers);
     if ($onlineusers) {
         foreach ($onlineusers as &$user) {
-            if ($user->id == $USER->get('id')) {
-                // Use a shorter caching time for the current user, just in case they change their profile icon
-                $user->profileiconurl = get_config('wwwroot') . 'thumb.php?type=profileicon&id=' . $user->id . '&maxheight=20&maxwidth=20&earlyexpiry=1';
-            }
-            else {
-                $user->profileiconurl = profile_icon_url($user, 20, 20);
-            }
+            $user->profileiconurl = profile_icon_url($user, 20, 20);
 
             // If the user is an MNET user, show where they've come from
             $authobj = AuthFactory::create($user->authinstance);
@@ -2385,6 +2600,7 @@ function recalculate_quota() {
     $plugins = plugins_installed('artefact', true);
 
     $userquotas = array();
+    $groupquotas = array();
 
     foreach ($plugins as $plugin) {
         safe_require('artefact', $plugin->name);
@@ -2400,6 +2616,17 @@ function recalculate_quota() {
                 }
             }
         }
+        if (is_callable($classname . '::recalculate_group_quota')) {
+            $plugingroupquotas = call_static_method($classname, 'recalculate_group_quota');
+            foreach ($plugingroupquotas as $groupid => $usage) {
+                if (!isset($groupquotas[$groupid])) {
+                    $groupquotas[$groupid] = $usage;
+                }
+                else {
+                    $groupquotas[$groupid] += $usage;
+                }
+            }
+        }
     }
 
     foreach ($userquotas as $user => $quota) {
@@ -2411,6 +2638,16 @@ function recalculate_quota() {
         );
         update_record('usr', $data, $where);
     }
+
+    foreach ($groupquotas as $group => $quota) {
+        $data = (object) array(
+            'quotaused' => $quota
+        );
+        $where = (object) array(
+            'id' => $group
+        );
+        update_record('group', $data, $where);
+    }
 }
 
 /**
@@ -2590,6 +2827,25 @@ function cron_site_data_daily() {
     graph_site_data_daily();
 }
 
+/**
+ * A cronjob to generate a sitemap
+ */
+function cron_sitemap_daily() {
+    if (!get_config('generatesitemap')) {
+        return;
+    }
+
+    require_once(get_config('libroot') . 'searchlib.php');
+    require_once(get_config('libroot') . 'group.php');
+    require_once(get_config('libroot') . 'view.php');
+    require_once(get_config('libroot') . 'sitemap.php');
+
+    safe_require('interaction', 'forum');
+
+    $sitemap = new Sitemap();
+    $sitemap->generate();
+}
+
 function build_portfolio_search_html(&$data) {
     global $THEME;
     $artefacttypes = get_records_assoc('artefact_installed_type');
@@ -2631,6 +2887,8 @@ function build_portfolio_search_html(&$data) {
         'count' => $data->count,
         'limit' => $data->limit,
         'offset' => $data->offset,
+        'jumplinks' => 6,
+        'numbersincludeprevnext' => 2,
         'numbersincludefirstlast' => false,
         'resultcounttextsingular' => get_string('result'),
         'resultcounttextplural' => get_string('results'),
@@ -2654,3 +2912,47 @@ function is_html_editor_enabled () {
     return (!get_config('wysiwyg') && ($USER->get_account_preference('wysiwyg') || defined('PUBLIC'))) ||
         get_config('wysiwyg') == 'enable';
 }
+
+/**
+ * Determine if site is running with https
+ *
+ * @return bool
+ */
+function is_https() {
+    return stripos(get_config('wwwroot'), 'https://') !== false;
+}
+
+function sanitize_email($value) {
+    if (filter_var($value, FILTER_VALIDATE_EMAIL) === false) {
+        return '';
+    }
+    return $value;
+}
+
+function sanitize_firstname($value) {
+    if (!preg_match('/\S/', $value)) {
+        return '';
+    }
+    return $value;
+}
+
+function sanitize_lastname($value) {
+    if (!preg_match('/\S/', $value)) {
+        return '';
+    }
+    return $value;
+}
+
+function sanitize_studentid($value) {
+    if (!preg_match('/\S/', $value)) {
+        return '';
+    }
+    return $value;
+}
+
+function sanitize_preferredname($value) {
+    if (!preg_match('/\S/', $value)) {
+        return '';
+    }
+    return $value;
+}
