@@ -65,53 +65,12 @@ defined('INTERNAL') || die();
 function search_user($query_string, $limit, $offset = 0, $data = array()) {
     $plugin = get_config('searchplugin');
     safe_require('search', $plugin);
-    safe_require('artefact', 'internal');
-
-    $publicfields = array_keys(ArtefactTypeProfile::get_public_fields());
-    if (empty($publicfields)) {
-        $publicfields = array('preferredname');
-    }
-    $fieldlist = "('" . join("','", $publicfields) . "')";
-
     $results = call_static_method(generate_class_name('search', $plugin), 'search_user', $query_string, $limit, $offset, $data);
 
     if ($results['data']) {
-        $userlist = '('.join(',', array_map(create_function('$u','return (int)$u[\'id\'];'), $results['data'])).')';
-
-        $public_fields = get_records_sql_array('
-            SELECT 
-                u.id, a.artefacttype, a.title
-            FROM
-                {usr} u
-                LEFT JOIN {artefact} a ON u.id=a.owner AND a.artefacttype IN ' . $fieldlist . '
-            WHERE
-                u.id IN ' . $userlist . '
-            ORDER BY u.firstname, u.lastname, u.id, a.artefacttype',
-            array()
-        );
-
-        $public_fields_byuser = array();
-        if (!empty($public_fields)) {
-            foreach ($public_fields as $field) {
-                // This will be null if the user does not have a field marked public
-                if ($field->artefacttype !== null) {
-                    $public_fields_byuser[$field->id][$field->artefacttype] = $field->title;
-                }
-            }
-        }
-        
         foreach ($results['data'] as &$result) {
             $result['name'] = display_name($result);
-            if (isset($public_fields_byuser[$result['id']])) {
-                foreach ($public_fields_byuser[$result['id']] as $field => $value) {
-                    $result[$field] = $value;
-                }
-            }
-            if (isset($result['country'])) {
-                $result['country'] = get_string('country.' . $result['country']);
-            }
         }
-
     }
 
     return $results;
@@ -131,7 +90,7 @@ function search_user($query_string, $limit, $offset = 0, $data = array()) {
 function get_institutional_admin_search_results($search, $limit) {
     $institution = new StdClass;
     $institution->name = $search->institution;
-    foreach (array('member', 'requested', 'invitedby') as $p) {
+    foreach (array('member', 'requested', 'invitedby', 'lastinstitution') as $p) {
         $institution->{$p} = $search->{$p};
     }
     $results = institutional_admin_user_search($search->query, $institution, $limit);
@@ -190,39 +149,69 @@ function parse_name_query($text) {
 
 }
 
-function get_admin_user_search_results($search, $offset, $limit, $sortby, $sortdir) {
-    // In admin search, the search string is interpreted as either a
-    // name search or an email search depending on its contents
-    $queries = array();
+function get_admin_user_search_results($search, $offset, $limit) {
+    $plugin = get_config('searchplugin');
+    safe_require('search', $plugin);
+
     $constraints = array();
-    if (!empty($search->query)) {
-        list($words, $fullnames) = parse_name_query($search->query);
-        foreach ($words as $word) {
-            if (strpos($word, '@') !== false) {
-                $queries[] = array('field' => 'email',
-                                   'type' => 'contains',
-                                   'string' => $word);
-            } else {
-                $queries[] = array('field' => 'firstname',
-                                   'type' => 'contains',
-                                   'string' => $word);
-                $queries[] = array('field' => 'lastname',
-                                   'type' => 'contains',
-                                   'string' => $word);
-                $queries[] = array('field' => 'username',
-                                   'type' => 'contains',
-                                   'string' => $word);
+
+    if ($plugin == 'internal') {
+        // For the internal plugin, just pass the raw query through as a string, it
+        // is parsed in the plugin.
+        $queries = $search->query;
+    }
+    else {
+        // In admin search, the search string is interpreted as either a
+        // name search or an email search depending on its contents
+        $queries = array();
+        if (!empty($search->query)) {
+            list($words, $fullnames) = parse_name_query($search->query);
+            foreach ($words as $word) {
+                if (strpos($word, '@') !== false) {
+                    $queries[] = array(
+                        'field' => 'email',
+                        'type' => 'contains',
+                        'string' => $word
+                    );
+                }
+                else {
+                    $queries[] = array(
+                        'field' => 'firstname',
+                        'type' => 'contains',
+                        'string' => $word
+                    );
+                    $queries[] = array(
+                        'field' => 'lastname',
+                        'type' => 'contains',
+                        'string' => $word
+                    );
+                    $queries[] = array(
+                        'field' => 'username',
+                        'type' => 'contains',
+                        'string' => $word
+                    );
+                    $queries[] = array(
+                        'field' => 'preferredname',
+                        'type' => 'contains',
+                        'string' => $word
+                    );
+                }
+            }
+            foreach ($fullnames as $n) {
+                $constraints[] = array(
+                    'field' => 'firstname',
+                    'type' => 'contains',
+                    'string' => $n[0]
+                );
+                $constraints[] = array(
+                    'field' => 'lastname',
+                    'type' => 'contains',
+                    'string' => $n[1]
+                );
             }
         }
-        foreach ($fullnames as $n) {
-            $constraints[] = array('field' => 'firstname',
-                                   'type' => 'contains',
-                                   'string' => $n[0]);
-            $constraints[] = array('field' => 'lastname',
-                                   'type' => 'contains',
-                                   'string' => $n[1]);
-        }
     }
+
     if (!empty($search->f)) {
         $constraints[] = array('field' => 'firstname',
                                'type' => 'starts',
@@ -233,25 +222,27 @@ function get_admin_user_search_results($search, $offset, $limit, $sortby, $sortd
                                'type' => 'starts',
                                'string' => $search->l);
     }
+
     // Filter by viewable institutions:
     global $USER;
-    if (!$USER->get('admin')) {
-        if (empty($search->institution) && empty($search->institution_requested)) {
-            $search->institution_requested = 'all';
+    if (!$USER->get('admin') && !$USER->get('staff')) {
+        $allowed = array_merge($USER->get('admininstitutions'), $USER->get('staffinstitutions'));
+        if (empty($search->institution)) {
+            $search->institution = 'all';
         }
-        $allowed = $USER->get('admininstitutions');
-        foreach (array('institution', 'institution_requested') as $p) {
-            if (!empty($search->{$p})) {
-                if ($search->{$p} == 'all' || !isset($allowed[$search->{$p}])) {
-                    $constraints[] = array('field' => $p,
-                                           'type' => 'in',
-                                           'string' => $allowed);
-                } else {
-                    $constraints[] = array('field' => $p,
-                                           'type' => 'equals',
-                                           'string' => $search->{$p});
-                }
-            }
+        if ($search->institution == 'all' || !isset($allowed[$search->institution])) {
+            $constraints[] = array(
+                'field'  => 'institution',
+                'type'   => 'in',
+                'string' => $allowed,
+            );
+        }
+        else {
+            $constraints[] = array(
+                'field'  => 'institution',
+                'type'   => 'equals',
+                'string' => $search->institution,
+            );
         }
     } else if (!empty($search->institution) && $search->institution != 'all') {
         $constraints[] = array('field' => 'institution',
@@ -259,23 +250,41 @@ function get_admin_user_search_results($search, $offset, $limit, $sortby, $sortd
                                'string' => $search->institution);
     }
     
-    $results = admin_user_search($queries, $constraints, $offset, $limit, $sortby, $sortdir);
+    $results = call_static_method(
+        generate_class_name('search', $plugin), 'admin_search_user',
+        $queries, $constraints, $offset, $limit, $search->sortby, $search->sortdir
+    );
+
     if ($results['count']) {
+        $isadmin = $USER->get('admin');
+        $admininstitutions = $USER->get('admininstitutions');
+
         foreach ($results['data'] as &$result) {
             $result['name'] = display_name($result);
             if (!empty($result['institutions'])) {
                 $result['institutions'] = array_combine($result['institutions'],$result['institutions']);
             }
+            if ($isadmin) {
+                continue;
+            }
+
+            // Remove email address when viewed by staff
+            if (!$hideemail = (empty($admininstitutions) || empty($result['institutions']))) {
+                $commoninstitutions = array_intersect($admininstitutions, $result['institutions']);
+                $hideemail |= empty($commoninstitutions);
+            }
+            if ($hideemail) {
+                unset($result['email']);
+            }
         }
     }
+
     return $results;
 }
 
 
-function build_admin_user_search_results($search, $offset, $limit, $sortby, $sortdir) {
-    global $USER;
-
-    $results = get_admin_user_search_results($search, $offset, $limit, $sortby, $sortdir);
+function build_admin_user_search_results($search, $offset, $limit) {
+    global $USER, $THEME;
 
     $params = array();
     foreach ($search as $k => $v) {
@@ -285,24 +294,76 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
     }
     $searchurl = get_config('wwwroot') . 'admin/users/search.php?' . join('&', $params) . '&limit=' . $limit;
 
-    $usernametemplate = '<a href="' . get_config('wwwroot')
-        . '{if $USER->is_admin_for_user($r.id)}admin/users/edit.php?id={$r.id}{else}user/view.php?id={$r.id}{/if}">{$r.username}</a>';
+    $results = get_admin_user_search_results($search, $offset, $limit);
+
+    $results['pagination'] = build_pagination(array(
+            'id' => 'admin_usersearch_pagination',
+            'class' => 'center',
+            'url' => $searchurl,
+            'count' => $results['count'],
+            'limit' => $limit,
+            'jumplinks' => 8,
+            'numbersincludeprevnext' => 2,
+            'offset' => $offset,
+            'datatable' => 'searchresults',
+            'jsonscript' => 'admin/users/search.json.php',
+    ));
 
     $cols = array(
-        'icon'        => array('name'     => '',
-                               'template' => '<img src="{profile_icon_url user=$r maxwidth=40 maxheight=40}" alt="' . get_string('profileimage') . '" />',
-                               'class'    => 'center'),
-        'firstname'   => array('name'     => get_string('firstname')),
-        'lastname'    => array('name'     => get_string('lastname')),
-        'username'    => array('name'     => get_string('username'),
-                               'template' => $usernametemplate),
-        'email'       => array('name'     => get_string('email')),
+        'icon' => array(
+            'template' => 'admin/users/searchiconcolumn.tpl',
+            'class'    => 'center',
+        ),
+        'firstname' => array(
+            'name'     => get_string('firstname'),
+            'sort'     => true,
+        ),
+        'lastname' => array(
+            'name'     => get_string('lastname'),
+            'sort'     => true,
+        ),
+        'preferredname' => array(
+            'name'     => get_string('displayname'),
+            'sort'     => true,
+        ),
+        'username' => array(
+            'name'     => get_string('username'),
+            'sort'     => true,
+            'template' => 'admin/users/searchusernamecolumn.tpl',
+        ),
+        'email' => array(
+            'name'     => get_string('email'),
+            'sort'     => true,
+        ),
     );
 
     $institutions = get_records_assoc('institution', '', '', '', 'name,displayname');
     if (count($institutions) > 1) {
-        $cols['institution'] = array('name'     => get_string('institution'),
-                                     'template' => '{if !$r.institutions}{$institutions.mahara->displayname}{else}{foreach from=$r.institutions item=i}<div>{$institutions[$i]->displayname}</div>{/foreach}{/if}{if !$r.requested}{foreach from=$r.requested item=i}<div class="pending">{str tag=requestto section=admin} {$institutions[$i]->displayname}{if $USER->is_institutional_admin("$i")} (<a href="{$WWWROOT}admin/users/addtoinstitution.php?id={$r.id}&institution={$i}">{str tag=confirm section=admin}</a>){/if}</div>{/foreach}{/if}{if !$r.invitedby}{foreach from=$r.invitedby item=i}<div class="pending">{str tag=invitedby section=admin} {$institutions[$i]->displayname}</div>{/foreach}{/if}');
+        $cols['institution'] = array(
+            'name'     => get_string('institution'),
+            'sort'     => false,
+            'template' => 'admin/users/searchinstitutioncolumn.tpl',
+        );
+    }
+
+    $cols['select'] = array(
+        'headhtml' => '<a href="" id="selectall">' . get_string('All') . '</a>&nbsp;<a href="" id="selectnone">' . get_string('none') . '</a>',
+        'template' => 'admin/users/searchselectcolumn.tpl',
+        'class'    => 'center nojs-hidden-table-cell',
+    );
+
+    if (!$USER->get('admin') && !$USER->is_institutional_admin()) {
+        unset($cols['email']);
+        if (!get_config('staffreports')) {
+            unset($cols['select']);
+        }
+    }
+    else if (!$USER->get('admin') && $results['data']) {
+        foreach ($results['data'] as &$r) {
+            if (!isset($r['email'])) {
+                $r['email'] = '- ' . get_string('emailaddresshidden', 'admin') . ' -';
+            }
+        }
     }
 
     $smarty = smarty_core();
@@ -310,23 +371,15 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
     $smarty->assign_by_ref('institutions', $institutions);
     $smarty->assign('USER', $USER);
     $smarty->assign('searchurl', $searchurl);
-    $smarty->assign('sortby', $sortby);
-    $smarty->assign('sortdir', $sortdir);
-    $smarty->assign('pagebaseurl', $searchurl . '&sortby=' . $sortby . '&sortdir=' . $sortdir);
+    $smarty->assign('sortby', $search->sortby);
+    $smarty->assign('sortdir', $search->sortdir);
+    $smarty->assign('limitoptions', array(10, 50, 100, 200, 500));
     $smarty->assign('cols', $cols);
     $smarty->assign('ncols', count($cols));
     return $smarty->fetch('searchresulttable.tpl');
 }
 
 
-function admin_user_search($queries, $constraints, $offset, $limit, $sortfield, $sortdir) {
-    $plugin = get_config('searchplugin');
-    safe_require('search', $plugin);
-    return call_static_method(generate_class_name('search', $plugin), 'admin_search_user', 
-                              $queries, $constraints, $offset, $limit, $sortfield, $sortdir);
-}
-
-
 /**
  * Returns search results for users in a particular group
  *
@@ -338,32 +391,55 @@ function admin_user_search($queries, $constraints, $offset, $limit, $sortfield,
  * @param int    $limit             How many results to show
  * @param array  $membershiptype    User membershiptype
  * @param bool   $random            Set to true if you want the result to be ordered by random, default false
+ * @param int    $friendof          Only return friends of this user
  *
  */
-function get_group_user_search_results($group, $query, $offset, $limit, $membershiptype, $order=null) {
-    $queries = array();
+function get_group_user_search_results($group, $query, $offset, $limit, $membershiptype, $order=null, $friendof=null) {
+    $plugin = get_config('searchplugin');
+    safe_require('search', $plugin);
+
     $constraints = array();
-    if (!empty($query)) {
-        list($words, $fullnames) = parse_name_query($query);
-        foreach ($words as $word) {
-            $queries[] = array('field' => 'firstname',
-                               'type' => 'contains',
-                               'string' => $word);
-            $queries[] = array('field' => 'lastname',
-                               'type' => 'contains',
-                               'string' => $word);
-        }
-        foreach ($fullnames as $n) {
-            $constraints[] = array('field' => 'firstname',
-                                   'type' => 'contains',
-                                   'string' => $n[0]);
-            $constraints[] = array('field' => 'lastname',
-                                   'type' => 'contains',
-                                   'string' => $n[1]);
+    if ($plugin == 'internal') {
+        // Pass the raw query string through to group_search_user; parsing of the
+        // query depends on the plugin configuration.
+        $queries = $query;
+    }
+    else {
+        $queries = array();
+        if (!empty($query)) {
+            list($words, $fullnames) = parse_name_query($query);
+            foreach ($words as $word) {
+                $queries[] = array(
+                    'field'  => 'firstname',
+                    'type'   => 'contains',
+                    'string' => $word
+                );
+                $queries[] = array(
+                    'field'  => 'lastname',
+                    'type'   => 'contains',
+                    'string' => $word
+                );
+            }
+            foreach ($fullnames as $n) {
+                $constraints[] = array(
+                    'field'  => 'firstname',
+                    'type'   => 'contains',
+                    'string' => $n[0]
+                );
+                $constraints[] = array(
+                    'field'  => 'lastname',
+                    'type'   => 'contains',
+                    'string' => $n[1]
+                );
+            }
         }
     }
 
-    $results = group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype, $order);
+    $results = call_static_method(
+        generate_class_name('search', $plugin), 'group_search_user',
+        $group, $queries, $constraints, $offset, $limit, $membershiptype, $order, $friendof
+    );
+
     if ($results['count']) {
         $userids = array_map(create_function('$a', 'return $a["id"];'), $results['data']);
         $introductions = get_records_sql_assoc("SELECT \"owner\", title
@@ -375,7 +451,7 @@ function get_group_user_search_results($group, $query, $offset, $limit, $members
             $result['name'] = display_name($result);
             $result['introduction'] = isset($introductions[$result['id']]) ? $introductions[$result['id']]->title : '';
             if (isset($result['jointime'])) {
-                $result['jointime'] = strftime(get_string('strftimedate'), $result['jointime']);
+                $result['jointime'] = format_date($result['jointime'], 'strftimedate');
             }
         }
     }
@@ -383,13 +459,6 @@ function get_group_user_search_results($group, $query, $offset, $limit, $members
 }
 
 
-function group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype, $order=null) {
-    $plugin = get_config('searchplugin');
-    safe_require('search', $plugin);
-    return call_static_method(generate_class_name('search', $plugin), 'group_search_user', 
-                              $group, $queries, $constraints, $offset, $limit, $membershiptype, $order);
-}
-
 /**
  * Given a query string and limits, return an array of matching groups using the
  * search plugin defined in config.php
