@@ -353,9 +353,14 @@ function upgrade_plugin($upgrade) {
 
     if ($plugintype == 'blocktype' && strpos($pluginname, '/') !== false) {
         list($artefactplugin, $blocktypename) = explode('/', $pluginname);
+        $location = get_config('docroot') . 'artefact/' . $artefactplugin . '/blocktype/' . $blocktypename . '/db/';
+        $function = 'xmldb_' . $plugintype . '_' . $blocktypename . '_upgrade';
+    }
+    else {
+        $location = get_config('docroot') . $plugintype . '/' . $pluginname . '/db/';
+        $function = 'xmldb_' . $plugintype . '_' . $pluginname . '_upgrade';
     }
 
-    $location = get_config('docroot') . $plugintype . '/' . $pluginname . '/db/';
     db_begin();
 
     if (!empty($upgrade->install)) {
@@ -366,7 +371,6 @@ function upgrade_plugin($upgrade) {
     else {
         if (is_readable($location .  'upgrade.php')) {
             require_once($location . 'upgrade.php');
-            $function = 'xmldb_' . $plugintype . '_' . $pluginname . '_upgrade';
             if (!$function($upgrade->from)) {
                 throw new InstallationException("Failed to run " . $function . " (check logs for errors)");
             }
@@ -580,6 +584,20 @@ function core_postinst() {
     set_config('smtppass', '');
     set_config('smtpsecure', '');
 
+    // XMLDB adds a table's keys immediately after creating the table.  Some
+    // foreign keys therefore cannot be created during the XMLDB installation,
+    // because they refer to tables created later in the installation.  These
+    // missing keys can be created now that all the core tables exist.
+    $table = new XMLDBTable('usr');
+    $key = new XMLDBKey('profileiconfk');
+    $key->setAttributes(XMLDB_KEY_FOREIGN, array('profileicon'), 'artefact', array('id'));
+    add_key($table, $key);
+
+    $table = new XMLDBTable('institution');
+    $key = new XMLDBKey('logofk');
+    $key->setAttributes(XMLDB_KEY_FOREIGN, array('logo'), 'artefact', array('id'));
+    add_key($table, $key);
+
     // PostgreSQL supports indexes over functions of columns, MySQL does not. 
     // We make use if this if we can
     if (is_postgres()) {
@@ -587,6 +605,15 @@ function core_postinst() {
         execute_sql('DROP INDEX {usr_use_uix}');
         execute_sql('CREATE UNIQUE INDEX {usr_use_uix} ON {usr}(LOWER(username))');
 
+        // Add user search indexes
+        // Postgres only.  We could create non-lowercased indexes in MySQL, but
+        // they would not be useful, and would require a change to varchar columns.
+        execute_sql('CREATE INDEX {usr_fir_ix} ON {usr}(LOWER(firstname))');
+        execute_sql('CREATE INDEX {usr_las_ix} ON {usr}(LOWER(lastname))');
+        execute_sql('CREATE INDEX {usr_pre_ix} ON {usr}(LOWER(preferredname))');
+        execute_sql('CREATE INDEX {usr_ema_ix} ON {usr}(LOWER(email))');
+        execute_sql('CREATE INDEX {usr_stu_ix} ON {usr}(LOWER(studentid))');
+
         // Only one profile view per user
         execute_sql("CREATE UNIQUE INDEX {view_own_type_uix} ON {view}(owner) WHERE type = 'profile'");
     }
@@ -607,10 +634,11 @@ function core_postinst() {
         (author IS NULL     AND authorname IS NOT NULL)
     )');
     execute_sql('ALTER TABLE {view_access} ADD CHECK (
-        (accesstype IS NOT NULL AND "group" IS NULL     AND usr IS NULL     AND token IS NULL) OR
-        (accesstype IS NULL     AND "group" IS NOT NULL AND usr IS NULL     AND token IS NULL) OR
-        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NOT NULL AND token IS NULL) OR
-        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NULL     AND token IS NOT NULL)
+        (accesstype IS NOT NULL AND "group" IS NULL     AND usr IS NULL     AND token IS NULL   AND institution IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NOT NULL AND usr IS NULL     AND token IS NULL AND institution IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NOT NULL AND token IS NULL AND institution IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NULL     AND token IS NOT NULL AND institution IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NULL     AND token IS NULL AND institution IS NOT NULL)
     )');
 
     set_antispam_defaults();
@@ -666,7 +694,8 @@ function core_install_lastcoredata_defaults() {
     $user = new StdClass;
     $user->username = 'admin';
     $user->salt = auth_get_random_salt();
-    $user->password = sha1($user->salt . 'mahara');
+    $user->password = crypt('mahara', '$2a$' . get_config('bcrypt_cost') . '$' . substr(md5(get_config('passwordsaltmain') . $user->salt), 0, 22));
+    $user->password = substr($user->password, 0, 7) . substr($user->password, 7+22);
     $user->authinstance = $auth_instance->id;
     $user->passwordchange = 1;
     $user->admin = 1;
@@ -700,6 +729,7 @@ function core_install_firstcoredata_defaults() {
     set_config('createpublicgroups', 'all');
     set_config('allowpublicviews', 1);
     set_config('allowpublicprofiles', 1);
+    set_config('generatesitemap', 1);
     set_config('showselfsearchsideblock', 0);
     set_config('showtagssideblock', 1);
     set_config('tagssideblockmaxtags', 20);
@@ -711,6 +741,9 @@ function core_install_firstcoredata_defaults() {
     set_config('showonlineuserssideblock', 1);
     set_config('footerlinks', serialize(array('privacystatement', 'about', 'contactus')));
     set_config('searchusernames', 1);
+    set_config('onlineuserssideblockmaxusers', 10);
+    set_config('loggedinprofileviewaccess', 1);
+    set_config('dropdownmenu', 0);
 
     // install the applications
     $app = new StdClass;
@@ -814,6 +847,9 @@ function core_install_firstcoredata_defaults() {
         'cron_site_data_daily'                      => array('51', '23', '*', '*', '*'),
         'cron_check_for_updates'                    => array(rand(0, 59), rand(0, 23), '*', '*', '*'),
         'cron_clean_internal_activity_notifications'=> array(45, 22, '*', '*', '*'),
+        'cron_sitemap_daily'                        => array(0, 1, '*', '*', '*'),
+        'file_cleanup_old_cached_files'             => array(0, 1, '*', '*', '*'),
+        'user_login_tries_to_zero'                  => array('*/5', '*', '*', '*', '*'),
     );
     foreach ($cronjobs as $callfunction => $times) {
         $cron = new StdClass;
@@ -955,7 +991,7 @@ function sort_upgrades($k1, $k2) {
 /** blocktype categories the system exports (including artefact categories)
 */
 function get_blocktype_categories() {
-    return array('general', 'internal', 'blog', 'resume', 'fileimagevideo', 'external');
+    return array('fileimagevideo', 'blog', 'general', 'internal', 'resume', 'external');
 }
 
 function install_blocktype_categories_for_plugin($blocktype) {
@@ -1001,10 +1037,11 @@ function install_blocktype_extras() {
 
     $categories = get_blocktype_categories();
     $installedcategories = get_column('blocktype_category', 'name');
+    $sort = empty($installedcategories) ? -1 : get_record_sql('SELECT MAX(sort) AS maxsort FROM {blocktype_category}')->maxsort;
 
     if ($toinstall = array_diff($categories, $installedcategories)) {
         foreach ($toinstall as $i) {
-            insert_record('blocktype_category', (object)array('name' => $i));
+            insert_record('blocktype_category', (object)array('name' => $i, 'sort' => (++$sort)));
         }
     }
 
@@ -1142,6 +1179,30 @@ function site_warnings() {
         $warnings[] = get_string('timezoneidentifierunusable', 'error');
     }
 
+    // Check for low security (i.e. not random enough) session IDs
+    if ((int)ini_get('session.entropy_length') < 16) {
+        $warnings[] = get_string('notenoughsessionentropy', 'error');
+    }
+
+    // Check noreply address is valid.
+    if (!sanitize_email(get_config('noreplyaddress'))) {
+        $warnings[] = get_string('noreplyaddressmissingorinvalid', 'error', get_config('wwwroot') . 'admin/site/options.php?fs=emailsettings');
+    }
+
+    // Check that the GD library has support for jpg, png and gif at least
+    $gdinfo = gd_info();
+    if (!$gdinfo['JPEG Support']) {
+        $warnings[] = get_string('gdlibrarylacksjpegsupport', 'error');
+    }
+
+    if (!$gdinfo['PNG Support']) {
+        $warnings[] = get_string('gdlibrarylackspngsupport', 'error');
+    }
+
+    if (!$gdinfo['GIF Read Support'] || !$gdinfo['GIF Create Support']) {
+        $warnings[] = get_string('gdlibrarylacksgifsupport', 'error');
+    }
+
     // Check file upload settings.
     $postmax       = ini_get('post_max_size');
     $uploadmax     = ini_get('upload_max_filesize');
@@ -1154,5 +1215,19 @@ function site_warnings() {
         $warnings[] = get_string('smallpostmaxsize', 'error', $postmax, $postmax);
     }
 
+    if (ini_get('open_basedir')) {
+        $warnings[] = get_string('openbasedirenabled', 'error') . ' ' . get_string('openbasedirwarning', 'error');
+    }
+
+    $sitesalt = get_config('passwordsaltmain');
+    if (empty($sitesalt)) {
+        $warnings[] = get_string('nopasswordsaltset', 'error');
+    }
+    else if ($sitesalt == 'some long random string here with lots of characters'
+            || trim($sitesalt) === ''
+            || preg_match('/^([a-zA-Z0-9]{0,10})$/', $sitesalt)) {
+        $warnings[] = get_string('passwordsaltweak', 'error');
+    }
+
     return $warnings;
 }
