@@ -37,6 +37,34 @@ class PluginSearchInternal extends PluginSearch {
         return false;
     }
 
+    public static function has_config() {
+        return true;
+    }
+
+    public static function get_config_options() {
+        return array(
+            'elements'   => array(
+                'exactusersearch' =>  array(
+                    'title'        => get_string('exactusersearch', 'search.internal'),
+                    'description'  => get_string('exactusersearchdescription', 'search.internal'),
+                    'help'         => true,
+                    'type'         => 'checkbox',
+                    'defaultvalue' => get_config_plugin('search', 'internal', 'exactusersearch'),
+                ),
+            ),
+        );
+    }
+
+    public function save_config_options($values) {
+        set_config_plugin('search', 'internal', 'exactusersearch', (int) $values['exactusersearch']);
+    }
+
+    public static function postinst($prevversion) {
+        if ($prevversion == 0) {
+            set_config_plugin('search', 'internal', 'exactusersearch', 1);
+        }
+    }
+
     /**
      * Implement user searching with SQL
      *
@@ -47,6 +75,7 @@ class PluginSearchInternal extends PluginSearch {
      * @param integer What result to start at (0 == first result)
      * @param data    Filters the users searched by
      *                can contain:
+     *             'friends' => boolean     // only return $USER's friends
      *             'group' => integer, // only users in this group
      *             'owner' => boolean  // include the group ownwer (only if group is set)
      *             'exclude'=> int     // excludes a user
@@ -79,19 +108,13 @@ class PluginSearchInternal extends PluginSearch {
      *           );
      */
     public static function search_user($query_string, $limit, $offset = 0, $data=array()) {
-        safe_require('artefact', 'internal');
-        $publicfields = array_keys(ArtefactTypeProfile::get_public_fields());
-        if (empty($publicfields)) {
-            $publicfields = array('preferredname');
-        }
-        $fieldlist = '(' . join(',', array_map('db_quote', $publicfields)) . ')';
-        $ilike = db_ilike();
+        global $USER;
+
         $data = self::prepare_search_user_options($data);
         $sql = '
             SELECT
-                COUNT(DISTINCT u.id)
-            FROM {artefact} a
-                INNER JOIN {usr} u ON u.id = a.owner';
+                COUNT(u.id)
+            FROM {usr} u';
         if (isset($data['group'])) {
             $groupadminsql = '';
             if (isset($data['includeadmins']) and !$data['includeadmins']) {
@@ -102,32 +125,38 @@ class PluginSearchInternal extends PluginSearch {
                     (gm.member = u.id AND gm.group = ' . (int)$data['group'] . $groupadminsql . ")\n";
             $sql .= $groupjoin;
         }
-        $sql .= "
-                LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = 'hiderealname')";
-        $querydata = split(' ', preg_replace('/\s\s+/', ' ', strtolower(trim($query_string))));
-        $hidenameallowed = get_config('userscanhiderealnames') ? 'TRUE' : 'FALSE';
-        $searchusernamesallowed = get_config('searchusernames') ? 'TRUE' : 'FALSE';
-        $namesql = "(u.preferredname $ilike '%' || ? || '%')
-                    OR ((u.preferredname IS NULL OR u.preferredname = '' OR NOT $hidenameallowed OR h.value != '1')
-                        AND (u.firstname $ilike '%' || ? || '%' OR u.lastname $ilike '%' || ? || '%'))
-                    OR ($searchusernamesallowed AND u.username $ilike '%' || ? || '%')
-                    OR (a.artefacttype IN $fieldlist
-                        AND ( a.title $ilike '%' || ? || '%'))";
-        $namesql = join('
-                    OR ', array_fill(0, count($querydata), $namesql));
-        $values = array();
-        foreach ($querydata as $w) {
-            $values = array_pad($values, count($values) + 5, $w);
-        }
 
         $where = '
             WHERE
-                u.id <> 0 AND u.active = 1 AND u.deleted = 0
-                AND (
-                    ' . $namesql . '
-                )
-                ' . (isset($data['exclude']) ? 'AND u.id != ' . $data['exclude'] : '') . '
-            ';
+                u.id != 0 AND u.active = 1 AND u.deleted = 0';
+
+        if (!empty($data['friends'])) {
+            // Only include friends in search
+            $where .= ' AND u.id IN (
+                SELECT usr1 FROM {usr_friend} f1 WHERE f1.usr2 = ' . $USER->get('id')
+                . ' UNION SELECT usr2 FROM {usr_friend} f2 WHERE f2.usr1 = ' . $USER->get('id') . ')';
+        }
+
+        if (isset($data['institutions']) && !empty($data['institutions'])) {
+            $where .= '
+                AND u.id IN (
+                    SELECT usr FROM {usr_institution} WHERE institution IN ('
+                . join(',', array_map('db_quote', $data['institutions'])) . ')
+                )';
+        }
+
+        $sql .= "
+                LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = 'hiderealname')";
+
+        list($namesql, $values) = self::name_search_sql($query_string);
+
+        $where .= $namesql;
+
+        if (isset($data['exclude'])) {
+            $where .= '
+                AND u.id != ?';
+            $values[] = $data['exclude'];
+        }
 
         $sql .= $where;
         $count = count_records_sql($sql, $values);
@@ -143,28 +172,11 @@ class PluginSearchInternal extends PluginSearch {
             return $result;
         }
 
-        if (is_postgres()) {
-            $sql = '
-            SELECT DISTINCT ON (' . $data['orderby'] . ')
-                u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.staff
-            FROM {artefact} a
-                INNER JOIN {usr} u ON u.id = a.owner';
-        }
-        else if (is_mysql()) {
-            // @todo This is quite possibly not correct. See the postgres 
-            // query. It should be DISTINCT ON the fields as specified by the 
-            // postgres query. There is a workaround by using SELECT * followed 
-            // by GROUP BY 1, 2, 3, but it's not really valid SQL. The other 
-            // way is to rewrite the query using a self join on the usr table.
-            $sql = '
-            SELECT DISTINCT
-                u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.staff
-            FROM {artefact} a
-                INNER JOIN {usr} u ON u.id = a.owner';
-        }
-        else {
-            throw new SQLException('search_user() not implemented for your database engine (' . get_config('dbtype') . ')');
-        }
+        $sql = '
+            SELECT
+                u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.studentid, u.staff,
+                u.admin, u.profileicon
+            FROM {usr} u';
 
         if (isset($data['group'])) {
             $sql .= $groupjoin;
@@ -186,9 +198,119 @@ class PluginSearchInternal extends PluginSearch {
         return $result;
     }
 
+
+
+    /**
+     * Returns a snippet of an sql WHERE clause to filter users whose (visible)
+     * names match the terms in a given query string.
+     */
+    function name_search_sql($query_string, $usralias='u', $usrprefalias='h') {
+
+        safe_require('artefact', 'internal');
+
+        // Get the list of searchable profile fields from the internal artefact
+        $required   = array_keys(ArtefactTypeProfile::get_always_searchable_fields());
+        $optional   = array_diff(array_keys(ArtefactTypeProfile::get_searchable_fields()), $required);
+        $required[] = 'username'; // Not a profile field, but used in the search query.
+
+        // Get a list of match expressions to use in the WHERE clause
+        $matches = new StdClass;
+        foreach (array_merge($required, $optional) as $f) {
+            $matches->{$f} = self::match_user_field_expression($f, $usralias);
+        }
+
+        $querydata = self::split_query_string(strtolower(trim($query_string)));
+        $hidenameallowed = get_config('userscanhiderealnames') ? 'TRUE' : 'FALSE';
+        $searchusernamesallowed = get_config('searchusernames') ? 'TRUE' : 'FALSE';
+
+        $termsql = "$matches->preferredname
+                    OR (
+                        ($usralias.preferredname IS NULL OR $usralias.preferredname = '' OR NOT $hidenameallowed OR $usrprefalias.value != '1' OR $usrprefalias.value IS NULL)
+                        AND ($matches->firstname OR $matches->lastname)
+                    )
+                    OR ($searchusernamesallowed AND $matches->username)";
+
+        if ($optional) {
+            foreach ($optional as $f) {
+                $termsql .= "
+                    OR {$matches->$f}";
+            }
+        }
+
+        $where = '';
+        $values = array();
+        foreach ($querydata as $term) {
+            $where .= '
+                AND (
+                    ' . $termsql . '
+                )';
+            $values = array_pad($values, count($values) + 4 + count($optional), $term);
+        }
+
+        return array($where, $values);
+    }
+
+
+
+    private static function match_user_field_expression($field, $alias) {
+        if (get_config_plugin('search', 'internal', 'exactusersearch')) {
+            return 'LOWER(' . $alias . '.' . $field . ') = ?';
+        }
+        return $alias . '.' . $field . ' ' . db_ilike() . " '%' || ? || '%'";
+    }
+
+
+    /**
+     * Split a query string into search terms.
+     *
+     * Contents of double-quoted strings are counted as a single term,
+     * '"' can be entered as '\"', '\' as '\\'.
+     */
+    private static function split_query_string($query) {
+        $terms = array();
+
+        // Split string on unescaped double quotes
+        $quotesplit = preg_split('/(?<!\\\)(\")/', $query, -1, PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
+
+        $inphrase = false;
+
+        foreach ($quotesplit as $q) {
+            if ($q == '"') {
+                $inphrase = !$inphrase;
+                continue;
+            }
+
+            // Remove escaping
+            $q = preg_replace(array('/\x5C(?!\x5C)/u', '/\x5C\x5C/u'), array('','\\'), $q);
+            if ($inphrase) {
+                if ($trimmed = trim($q)) {
+                    $terms[] = $trimmed;
+                }
+            }
+            else {
+                // Split unquoted sequences on spaces
+                foreach (preg_split('/\s+/', $q, -1, PREG_SPLIT_NO_EMPTY) as $word) {
+                    $terms[] = $word;
+                }
+            }
+        }
+        return $terms;
+    }
+
+
     private static function prepare_search_user_options($options) {
+        global $USER;
         if (isset($options['group'])) {
-            $options['group'] = intval($options['group']);
+            // This option should only be used by group admins, so just ensure that the caller is
+            // using it correctly.
+            $roles = $USER->get('grouproles');
+            if ($USER->get('admin') || $USER->get('staff')
+                || (isset($roles[$options['group']]) && $roles[$options['group']] == 'admin')) {
+                $options['group'] = intval($options['group']);
+            }
+            else {
+                unset($options['group']);
+            }
         }
         if (isset($options['includeadmins'])) {
             $options['includeadmins'] = (bool)$options['includeadmins'];
@@ -202,6 +324,11 @@ class PluginSearchInternal extends PluginSearch {
         if (isset($options['exclude'])) {
             $options['exclude'] = intval($options['exclude']);
         }
+        if (isset($options['myinstitutions'])) {
+            if ($institutions = array_keys($USER->get('institutions'))) {
+                $options['institutions'] = $institutions;
+            }
+        }
         return $options;
     }
     
@@ -223,7 +350,7 @@ class PluginSearchInternal extends PluginSearch {
     }
 
 
-    public static function admin_search_user($queries, $constraints, $offset, $limit, 
+    public static function admin_search_user($query_string, $constraints, $offset, $limit,
                                              $sortfield, $sortdir) {
         $sort = 'TRUE';
         if (preg_match('/^[a-zA-Z_0-9"]+$/', $sortfield)) {
@@ -241,48 +368,37 @@ class PluginSearchInternal extends PluginSearch {
         // Get the correct keyword for case insensitive LIKE
         $ilike = db_ilike();
 
-        // Only handle OR/AND expressions at the top level.  Eventually we may need subexpressions.
+        // Generate the part that matches the search term
+        $querydata = self::split_query_string(strtolower(trim($query_string)));
 
-        if (!empty($queries)) {
-            $where .= ' AND ( ';
-            $str = array();
-            foreach ($queries as $f) {
-                if (!preg_match('/^[a-zA-Z_0-9"]+$/', $f['field'])) {
-                    continue; // skip this field as it fails validation
-                }
-                $str[] = 'u.' . $f['field'] 
-                    . PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike);
-            }
-            $where .= join(' OR ', $str) . ') ';
-        } 
+        $matches = array();
+        foreach (array('firstname', 'lastname', 'preferredname', 'username', 'email') as $f) {
+            $matches[] = self::match_user_field_expression($f, 'u');
+        }
 
-        // @todo: Institution stuff is messy and will probably need to
-        // be rewritten when we get multiple institutions per user
+        $termsql = join(" OR ", $matches);
+
+        $values = array();
+        foreach ($querydata as $term) {
+            $where .= '
+                AND (
+                    ' . $termsql . '
+                )';
+            $values = array_pad($values, count($values) + 5, $term);
+        }
 
-        $requested = false;
-        $institutionsearch = '';
         if (!empty($constraints)) {
             foreach ($constraints as $f) {
-                if (strpos($f['field'], 'institution') === 0) {
-                    $institutionsearch .= ' 
-                        LEFT OUTER JOIN {usr_institution} i ON i.usr = u.id ';
-                    if (strpos($f['field'], 'requested') > 0) {
-                        $institutionsearch .= ' 
-                            LEFT OUTER JOIN {usr_institution_request} ir ON ir.usr = u.id ';
+                if ($f['field'] == 'institution') {
+                    if ($f['string'] == 'mahara') {
+                        $where .= ' AND u.id NOT IN (SELECT usr FROM {usr_institution})';
                     }
-                    if ($f['field'] == 'institution_requested') {
-                        $where .= ' AND ( i.institution ' .
-                            PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike) .
-                            ' OR ir.institution ' .
-                            PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike) . ')';
-                        $requested = true;
-                    } else {
-                        if ($f['string'] == 'mahara') {
-                            $where .= ' AND i.institution IS NULL';
-                        } else {
-                            $where .= ' AND i.institution'
-                                . PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike);
-                        }
+                    else {
+                        $where .= '
+                            AND u.id IN (
+                                SELECT usr FROM {usr_institution} WHERE institution '
+                            . PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike) . '
+                            )';
                     }
                 } else {
                     $where .= ' AND u.' . $f['field'] 
@@ -290,23 +406,16 @@ class PluginSearchInternal extends PluginSearch {
                 }
             }
         }
-        if (strpos($sort, 'institution') === 0) {
-            $sort = 'i.' . $sort;
-            if ($institutionsearch == '') {
-                $institutionsearch = ' LEFT OUTER JOIN {usr_institution} i ON i.usr = u.id ';
-            }
-        }
 
-        $count = get_field_sql('SELECT COUNT(*) FROM {usr} u ' . $institutionsearch . $where, $values);
+        $count = get_field_sql('SELECT COUNT(*) FROM {usr} u ' . $where, $values);
 
         if ($count > 0) {
             $data = get_records_sql_assoc('
                 SELECT 
-                    u.id, u.firstname, u.lastname, u.username, u.email, u.staff, u.profileicon,
+                    u.id, u.firstname, u.lastname, u.preferredname, u.username, u.email, u.staff, u.profileicon,
                     u.active, NOT u.suspendedcusr IS NULL as suspended
-                FROM
-                    {usr} u ' . $institutionsearch . $where . '
-                ORDER BY ' . $sort,
+                FROM {usr} u ' . $where . '
+                ORDER BY ' . $sort . ', u.id',
                 $values,
                 $offset,
                 $limit);
@@ -320,21 +429,6 @@ class PluginSearchInternal extends PluginSearch {
                         $data[$i->usr]->institutions[] = $i->institution;
                     }
                 }
-                if ($requested) {
-                    $inst = get_records_select_array('usr_institution_request', 
-                                                     'usr IN (' . join(',', array_keys($data)) . ')',
-                                                     null, '', 'usr,institution,confirmedusr,confirmedinstitution');
-                    if ($inst) {
-                        foreach ($inst as $i) {
-                            if ($i->confirmedusr) {
-                                $data[$i->usr]->requested[] = $i->institution;
-                            }
-                            if ($i->confirmedinstitution) {
-                                $data[$i->usr]->invitedby[] = $i->institution;
-                            }
-                        }
-                    }
-                }
                 foreach ($data as &$item) {
                     $item->username = display_username($item);
                     $item = (array)$item;
@@ -355,29 +449,16 @@ class PluginSearchInternal extends PluginSearch {
     }
 
 
-    public static function group_search_user($group, $queries, $constraints, $offset, $limit, $membershiptype, $order=null) {
-        // Only handle OR/AND expressions at the top level.  Eventually we may need subexpressions.
-        $searchsql = '';
-        $values = array();
-        if (!empty($queries)) {
-            $ilike = db_ilike();
-            $searchsql .= ' AND ( ';
-            $str = array();
-            foreach ($queries as $f) {
-                if (!preg_match('/^[a-zA-Z_0-9"]+$/', $f['field'])) {
-                    continue; // skip this field as it fails validation
-                }
-                $str[] = 'u.' . $f['field'] 
-                    . PluginSearchInternal::match_expression($f['type'], $f['string'], $values, $ilike);
-            }
-            $searchsql .= join(' OR ', $str) . ') ';
-        }
+    public static function group_search_user($group, $query_string, $constraints, $offset, $limit, $membershiptype, $order, $friendof) {
+
+        list($searchsql, $values) = self::name_search_sql($query_string);
 
         if ($membershiptype == 'nonmember') {
             $select = '
                     u.id, u.firstname, u.lastname, u.username, u.email, u.profileicon, u.staff';
             $from = '
                 FROM {usr} u
+                    LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = \'hiderealname\')
                 WHERE u.id > 0 AND u.deleted = 0 ' . $searchsql . '
                     AND NOT u.id IN (SELECT member FROM {group_member} gm WHERE gm.group = ?)';
             $values[] = $group;
@@ -388,6 +469,7 @@ class PluginSearchInternal extends PluginSearch {
                     u.id, u.firstname, u.lastname, u.username, u.email, u.profileicon, u.staff';
             $from = '
                 FROM {usr} u
+                    LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = \'hiderealname\')
                 WHERE u.id > 0 AND u.deleted = 0 ' . $searchsql . '
                     AND NOT u.id IN (SELECT member FROM {group_member} gm WHERE gm.group = ?)
                     AND NOT u.id IN (SELECT member FROM {group_member_invite} gmi WHERE gmi.group = ?)';
@@ -402,6 +484,7 @@ class PluginSearchInternal extends PluginSearch {
             $from = '
                 FROM {usr} u
                     INNER JOIN {group_member_request} gmr ON (gmr.member = u.id)
+                    LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = \'hiderealname\')
                 WHERE u.id > 0 AND u.deleted = 0 ' . $searchsql . '
                     AND gmr.group = ?';
             $values[] = $group;
@@ -414,6 +497,7 @@ class PluginSearchInternal extends PluginSearch {
             $from = '
                 FROM {usr} u
                     INNER JOIN {group_member_invite} gmi ON (gmi.member = u.id)
+                    LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = \'hiderealname\')
                 WHERE u.id > 0 AND u.deleted = 0 ' . $searchsql . '
                     AND gmi.group = ?';
             $values[] = $group;
@@ -421,11 +505,12 @@ class PluginSearchInternal extends PluginSearch {
         }
         else { // All group members
             $select = '
-                    u.id, u.firstname, u.lastname, u.username, u.email, u.profileicon,
+                    u.id, u.firstname, u.lastname, u.username, u.preferredname, u.email, u.profileicon,
                     u.staff, ' . db_format_tsfield('gm.ctime', 'jointime') . ', gm.role';
             $from = '
                 FROM {usr} u
                     INNER JOIN {group_member} gm ON (gm.member = u.id)
+                    LEFT OUTER JOIN {usr_account_preference} h ON (u.id = h.usr AND h.field = \'hiderealname\')
                 WHERE u.id > 0 AND u.deleted = 0 ' . $searchsql . '
                     AND gm.group = ?';
             $values[] = $group;
@@ -439,6 +524,14 @@ class PluginSearchInternal extends PluginSearch {
             $orderby = db_random();
         }
 
+        if ($friendof) {
+            $from .= '
+                    AND u.id IN (
+                        SELECT usr1 FROM {usr_friend} WHERE usr2 = ? UNION SELECT usr2 FROM {usr_friend} WHERE usr1 = ?
+                    )';
+            array_push($values, $friendof, $friendof);
+        }
+
         $count = get_field_sql('SELECT COUNT(*)' . $from, $values);
 
         if ($count > 0) {
@@ -470,13 +563,15 @@ class PluginSearchInternal extends PluginSearch {
 
     public static function institutional_admin_search_user($query, $institution, $limit) {
         $sql = '
-            FROM {usr} u ';
+            FROM {usr} u LEFT OUTER JOIN {usr_tag} t ON (t.usr = u.id) ';
 
         $where = '
             WHERE u.id <> 0 AND u.deleted = 0 ';
 
         $values = array();
         if (!empty($query)) {
+            $where .= 'AND (t.tag = LOWER(?) OR ';
+            $values[] = $query;
             $query = preg_replace('/\s\s+/', ' ', $query);
             $words = explode(' ', $query);
             foreach ($words as &$word) {
@@ -484,8 +579,7 @@ class PluginSearchInternal extends PluginSearch {
                 $values[] = $word;
                 $word = 'u.firstname ' . db_ilike() . ' \'%\' || ? || \'%\' OR u.lastname ' . db_ilike() . ' \'%\' || ? || \'%\'';
             }
-            $where .= '
-                AND (' . join(' OR ', $words) . ') ';
+            $where .= join(' OR ', $words) . ') ';
         }
 
         $studentid = '';
@@ -510,13 +604,17 @@ class PluginSearchInternal extends PluginSearch {
                 $studentid = ', req.studentid';
             }
             if (!is_null($institution->invitedby)) {
-                if ($institution->requested == 1) {
+                if ($institution->invitedby == 1) {
                     $where .= ' AND req.confirmedinstitution = 1';
                 } else {
                     $where .= ' AND (req.confirmedinstitution = 0 OR req.confirmedinstitution IS NULL)';
                 }
             }
         }
+        if (!is_null($institution->lastinstitution)) {
+            $where .= " AND t.tag = ?";
+            $values[] = 'lastinstitution:' . $institution->lastinstitution;
+        }
 
         $count = get_field_sql('SELECT COUNT(*) ' . $sql . $where, $values);
 
@@ -525,6 +623,7 @@ class PluginSearchInternal extends PluginSearch {
                 SELECT 
                     u.id, u.firstname, u.lastname, u.username, u.preferredname, 
                     u.admin, u.staff' . $studentid . $sql . $where . '
+                GROUP BY u.id, u.firstname, u.lastname, u.username, u.preferredname, u.admin, u.staff' . $studentid . '
                 ORDER BY u.firstname ASC',
                 $values,
                 0,
@@ -601,12 +700,21 @@ class PluginSearchInternal extends PluginSearch {
             $grouproles = '-1';
         }
 
+        $canseehidden = $USER->get('admin') || $USER->get('staff');
+
        if ($type == 'member') {
             $sql .=  'AND id IN (' . $grouproles . ')';
         }
         else if ($type == 'notmember') {
             $sql .= 'AND id NOT IN (' . $grouproles . ')';
+            if (!$canseehidden) {
+                $sql .= ' AND hidden = 0';
+            }
         }
+        else if (!$canseehidden) {
+            $sql .= ' AND (hidden = 0 OR id IN (' . $grouproles . '))';
+        }
+
         if (!empty($category)) {
             if ($category == -1) { //find unassigned groups
                 $sql .= " AND category IS NULL";
@@ -619,7 +727,7 @@ class PluginSearchInternal extends PluginSearch {
         $count = get_field_sql('SELECT COUNT(*) '.$sql, $values);
 
         if ($count > 0) {
-            $sql = 'SELECT id, name, description, grouptype, jointype, public, ctime, mtime, category ' . $sql . ' ORDER BY name';
+            $sql = 'SELECT id, name, description, grouptype, jointype, request, public, ctime, mtime, category ' . $sql . ' ORDER BY name';
             $data = get_records_sql_array($sql, $values, $offset, $limit);
         }
 
@@ -686,7 +794,7 @@ class PluginSearchInternal extends PluginSearch {
                 (LOWER(at.tag) = ?)
             )";
         array_unshift($querydata[1], $USER->get('id'));
-        array_push($querydata[1], $querystring);
+        array_push($querydata[1], strtolower($querystring));
 
         $results = array(
             'data'   => get_records_sql_array($sql, $querydata[1], $offset, $limit),
@@ -696,6 +804,7 @@ class PluginSearchInternal extends PluginSearch {
         );
 
         if ($results['data']) {
+            require_once(get_config('docroot') . 'artefact/lib.php');
             foreach ($results['data'] as &$result) {
                 $newresult = array();
                 foreach ($result as $key => &$value) {
@@ -704,10 +813,13 @@ class PluginSearchInternal extends PluginSearch {
                     }
                 }
                 $newresult['type'] = 'artefact';
-                $artefactplugin = get_field('artefact_installed_type', 'plugin', 'name', $newresult['artefacttype']);
-                if ($artefactplugin == 'internal') {
+
+                $artefact = artefact_instance_from_id($newresult['id']);
+                $artefactplugin = $artefact->get_plugin_name();
+                if ($artefactplugin == 'internal' && in_array($artefact->get('artefacttype'), PluginArtefactInternal::get_profile_artefact_types())) {
+                    // Profile artefact
                     $newresult['summary'] = $newresult['title'];
-                    $newresult['title'] = get_string($newresult['artefacttype'], 'artefact.' . $artefactplugin);
+                    $newresult['title'] = get_string($artefact->get('artefacttype'), 'artefact.' . $artefactplugin);
                 }
                 else {
                     $newresult['summary'] = $newresult['description'];
@@ -945,7 +1057,7 @@ class PluginSearchInternal extends PluginSearch {
         }
       }
       // Return matching snippet and number of added words
-      return array("a.title ". ($not ? 'NOT ' : '') ."LIKE '%' || ? || '%'" . ($not ? ' AND ' : ' OR ') . 'a.description ' . ($not ? 'NOT ' : '') . "LIKE '%' || ? || '%'", $count);
+      return array("a.title ". ($not ? 'NOT ' : '') . db_ilike() . " '%' || ? || '%'" . ($not ? ' AND ' : ' OR ') . 'a.description ' . ($not ? 'NOT ' : '') . db_ilike() . " '%' || ? || '%'", $count);
     }
 
     /**
