@@ -210,6 +210,13 @@ foreach (array('alpha', 'freq') as $option) {
     $tagsortoptions[$option] = $option == $tagsort;
 }
 
+if (strpos($data->baseurl, 'tags.php?') !== 0) {
+    $data->queryprefix = '?';
+}
+else {
+    $data->queryprefix = '&';
+}
+
 $smarty = smarty(array('paginator'));
 $smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('tags', $tags);
