@@ -35,6 +35,13 @@ define('SECTION_PLUGINTYPE', 'core');
 define('SECTION_PLUGINNAME', 'user');
 define('SECTION_PAGE', 'myfriends');
 
+if (param_variable('acceptfriend_submit', null)) {
+    acceptfriend_form(param_integer('id'));
+}
+else if (param_variable('addfriend_submit', null)) {
+    addfriend_form(param_integer('id'));
+}
+
 $filter = param_alpha('filter', 'all');
 $offset = param_integer('offset', 0);
 $limit = 10;
@@ -42,25 +49,8 @@ $limit = 10;
 $data = search_friend($filter, $limit, $offset);
 $data['filter'] = $filter;
 
-$controlledgroups = count_records_sql("SELECT COUNT(g.id)
-          FROM {group} g
-          JOIN {group_member} gm ON (gm.group = g.id)
-          JOIN {grouptype_roles} gtr ON (gtr.grouptype = g.grouptype AND gtr.role = gm.role)
-          WHERE gm.member = ?
-          AND g.jointype = 'controlled'
-          AND (gm.role = 'admin' OR gtr.see_submitted_views = 1)
-          AND g.deleted = 0", array($USER->get('id')));
-
-$invite = count_records_sql("SELECT COUNT(g.id)
-        FROM {group} g
-        JOIN {group_member} gm ON (gm.group = g.id)
-        WHERE gm.member = ?
-        AND g.jointype = 'invite'
-        AND gm.role = 'admin'
-        AND g.deleted = 0", array($USER->get('id')));
-
-$admingroups = $controlledgroups || $invite;
-
+require_once('group.php');
+$admingroups = (bool) group_get_user_admintutor_groups();
 build_userlist_html($data, 'myfriends', $admingroups);
 
 $filterform = pieform(array(
