@@ -96,8 +96,9 @@ function requestfriendship_submit(Pieform $form, $values) {
     
     // notification info
     $n = new StdClass;
-    $n->url = get_config('wwwroot') . 'user/view.php?id=' . $loggedinid;
+    $n->url = 'user/view.php?id=' . $loggedinid;
     $n->users = array($user->id);
+    $n->fromuser = $loggedinid;
     $lang = get_user_language($user->id);
     $displayname = display_name($USER, $user);
     $n->strings->urltext = (object) array('key' => 'Requests');
