@@ -48,11 +48,35 @@ if (!is_null($replytoid)) {
 }
 
 $returnto = param_alpha('returnto', 'myfriends');
+switch ($returnto) {
+    case 'find':
+        $goto = 'user/find.php';
+        break;
+    case 'view':
+        $goto = 'user/view.php?id=' . $id;
+        break;
+    case 'inbox':
+        $goto = 'account/activity';
+        break;
+    case 'institution':
+        $goto = ($inst = param_alpha('inst', null))
+            ? 'institution/index.php?institution=' . $inst
+            : 'account/activity';
+        break;
+    default:
+      $goto = 'user/myfriends.php';
+}
 
-$user = get_record('usr', 'id', $id, 'deleted', 0);
+$user = get_record('usr', 'id', $id);
 
-if (!$user || !can_send_message($USER->to_stdclass(), $id)) {
-	throw new AccessDeniedException(get_string('cantmessageuser', 'group'));
+if (!$user) {
+    throw new UserNotFoundException(get_string('cantmessageuser', 'group'));
+}
+else if ($user->deleted != 0) {
+    throw new AccessDeniedException(get_string('cantmessageuserdeleted', 'group'));
+}
+else if (!can_send_message($USER->to_stdclass(), $id)) {
+    throw new AccessDeniedException(get_string('cantmessageuser', 'group'));
 }
 
 define('TITLE', get_string('sendmessageto', 'group', display_name($user)));
@@ -66,11 +90,16 @@ $form = pieform(array(
             'title' => $messages ? get_string('Reply', 'group') : get_string('message'),
             'cols'  => 80,
             'rows'  => 10,
+            'rules' => array('maxlength' => 65536),
+        ),
+        'goto' => array(
+            'type' => 'hidden',
+            'value' => $goto,
         ),
         'submit' => array(
             'type' => 'submitcancel',
             'value' => array($messages ? get_string('Reply', 'group') : get_string('sendmessage', 'group'), get_string('cancel')),
-            'goto' => get_config('wwwroot') . ($returnto == 'find' ? 'user/find.php' : ($returnto == 'view' ? 'user/view.php?id=' . $id : 'user/myfriends.php')),
+            'goto' => get_config('wwwroot') . $goto,
         )
     )
 ));
@@ -87,18 +116,5 @@ function sendmessage_submit(Pieform $form, $values) {
     $user = get_record('usr', 'id', $id);
     send_user_message($user, $values['message'], param_integer('replyto', null));
     $SESSION->add_ok_msg(get_string('messagesent', 'group'));
-    switch (param_alpha('returnto', 'myfriends')) {
-        case 'find':
-            redirect('/user/find.php');
-            break;
-        case 'view':
-            redirect('/user/view.php?id=' . $id);
-            break;
-        case 'inbox':
-            redirect('/account/activity');
-            break;
-        default:
-            redirect('/user/myfriends.php');
-            break;
-    }
+    redirect(get_config('wwwroot').$values['goto']);
 }
