@@ -37,6 +37,13 @@ require_once('group.php');
 require_once('pieforms/pieform.php');
 require_once(get_config('libroot') . 'view.php');
 
+if (param_variable('acceptfriend_submit', null)) {
+    acceptfriend_form(param_integer('id'));
+}
+else if (param_variable('addfriend_submit', null)) {
+    addfriend_form(param_integer('id'));
+}
+
 $loggedinid = $USER->get('id');
 if (!empty($loggedinid)) {
     $userid = param_integer('id', $loggedinid);
@@ -64,14 +71,16 @@ else {
     $view = $userobj->get_profile_view();
 }
 
+# access will either be logged in (always) or public as well
 if (!$view) {
+    // No access, so restrict profile view
     throw new AccessDeniedException(get_string('youcannotviewthisusersprofile', 'error'));
 }
 
 $viewid = $view->get('id');
-# access will either be logged in (always) or public as well
-if (!can_view_view($viewid)) {
-    throw new AccessDeniedException(get_string('youcannotviewthisusersprofile', 'error'));
+$restrictedview = !can_view_view($viewid);
+if (!$restrictedview) {
+    $viewcontent = $view->build_columns();
 }
 
 $javascript = array('paginator', 'jquery', 'lib/pieforms/static/core/pieforms.js', 'artefact/resume/resumeshowhide.js');
@@ -95,6 +104,7 @@ $smarty = smarty(
         'sidebars'    => false,
     )
 );
+$smarty->assign('restrictedview', $restrictedview);
 
 $sql = "SELECT g.*, a.type FROM {group} g JOIN (
 SELECT gm.group, 'invite' AS type
@@ -117,21 +127,41 @@ if (!empty($loggedinid) && $loggedinid != $userid) {
     $invitedlist = array();   // Groups admin'ed by the logged in user that the displayed user has been invited to
     $requestedlist = array(); // Groups admin'ed by the logged in user that the displayed user has requested membership of
 
-    // Get the logged in user's "invite only" groups
-    if ($groups = get_records_sql_array("SELECT g.*
-        FROM {group} g
-        JOIN {group_member} gm ON (gm.group = g.id)
-        WHERE gm.member = ?
-        AND g.jointype = 'invite'
-        AND gm.role = 'admin'
-        AND g.deleted = 0", array($loggedinid))) {
-        $invitelist = array();
+    // Get all groups where either:
+    // - the logged in user is an admin, or
+    // - the logged in user has a role which is allowed to assess submitted views, or
+    // - the logged in user is a member & is allowed to invite friends (when the displayed user is a friend)
+    $groups = array();
+    foreach (group_get_user_groups() as $g) {
+        if ($g->role == 'admin' || $g->see_submitted_views || ($is_friend && $g->invitefriends)) {
+            $groups[] = $g;
+        }
+    }
+    if ($groups) {
+        $invitelist     = array(); // List of groups the displayed user can be invited to join
+        $controlledlist = array(); // List of groups the displayed user can be directly added to
+
         foreach ($groups as $group) {
             if (array_key_exists($group->id, $allusergroups)) {
-                $invitedlist[$group->id] = $group->name;
-                continue;
+                if ($allusergroups[$group->id]->type == 'invite') {
+                    $invitedlist[$group->id] = $group->name;
+                }
+                else if ($allusergroups[$group->id]->type == 'request') {
+                    $requestedlist[$group->id] = $group->name;
+                    $controlledlist[$group->id] = $group->name;
+                    continue;
+                }
+                else {
+                    continue; // Already a member
+                }
+            }
+            $canadd = $group->role == 'admin' || $group->see_submitted_views;
+            if ($canadd && $group->jointype == 'controlled') {
+                $controlledlist[$group->id] = $group->name;
+            }
+            if (!isset($invitedlist[$group->id])) {
+                $invitelist[$group->id] = $group->name;
             }
-            $invitelist[$group->id] = $group->name;
         }
         $smarty->assign('invitedlist', join(', ', $invitedlist));
         if (count($invitelist) > 0) {
@@ -161,34 +191,7 @@ if (!empty($loggedinid) && $loggedinid != $userid) {
             ));
             $smarty->assign('inviteform',$inviteform);
         }
-    }
 
-    // Get (a) controlled membership groups,
-    //     (b) request membership groups where the displayed user has requested membership,
-    // where the logged in user either:
-    // 1. is a group admin, or;
-    // 2. has a role in the list of roles who are allowed to assess submitted views for the given grouptype
-    if ($groups = get_records_sql_array("SELECT g.*, gm.ctime
-          FROM {group} g
-          JOIN {group_member} gm ON (gm.group = g.id)
-          JOIN {grouptype_roles} gtr ON (gtr.grouptype = g.grouptype AND gtr.role = gm.role)
-          LEFT JOIN {group_member_request} gmr ON (gmr.member = ? AND gmr.group = g.id)
-          WHERE gm.member = ?
-          AND (g.jointype = 'controlled' OR (g.jointype = 'request' AND gmr.member = ?))
-          AND (gm.role = 'admin' OR gtr.see_submitted_views = 1)
-          AND g.deleted = 0", array($userid,$loggedinid,$userid))) {
-        $controlledlist = array();
-        foreach ($groups as $group) {
-            if (array_key_exists($group->id, $allusergroups)) {
-                continue;
-            }
-            if ($group->jointype == 'request') {
-                $requestedlist[$group->id] = $group->name;
-            }
-            else {
-                $controlledlist[$group->id] = $group->name;
-            }
-        }
         $smarty->assign('requestedlist', join(', ', $requestedlist));
         if (count($controlledlist) > 0) {
             $default = array_keys($controlledlist);
@@ -228,48 +231,14 @@ if (!empty($loggedinid) && $loggedinid != $userid) {
     }
     else if ($record = get_record('usr_friend_request', 'requester', $userid, 'owner', $loggedinid)) {
         $relationship = 'pending';
-        $requestform = pieform(array(
-            'name' =>'approve_deny_friendrequest',
-            'renderer' => 'oneline',
-            'autofocus' => false,
-            'elements' => array(
-                'approve' => array(
-                    'type' => 'submit',
-                    'value' => get_string('approverequest', 'group'),
-                ),
-                'deny' => array(
-                    'type' => 'submit',
-                    'value' => get_string('denyrequest', 'group')
-                ),
-                'id' => array(
-                    'type' => 'hidden',
-                    'value' => $userid
-                )
-            )
-        ));
         $smarty->assign('message', $record->message);
-        $smarty->assign('requestform', $requestform);
+        $smarty->assign('acceptform', acceptfriend_form($userid));
     }
     else {
         $relationship = 'none';
         $friendscontrol = get_account_preference($userid, 'friendscontrol');
         if ($friendscontrol == 'auto') {
-            $newfriendform = pieform(array(
-                'name' => 'addfriend',
-                'autofocus' => false,
-                'renderer' => 'div',
-                'elements' => array(
-                    'add' => array(
-                        'type' => 'submit',
-                        'value' => get_string('addtomyfriends', 'group')
-                    ),
-                    'id' => array(
-                        'type' => 'hidden',
-                        'value' => $userid
-                    )
-                )
-            ));
-            $smarty->assign('newfriendform', $newfriendform);
+            $smarty->assign('newfriendform', addfriend_form($userid));
         }
         $smarty->assign('friendscontrol', $friendscontrol);
     }
@@ -290,6 +259,7 @@ $smarty->assign('USERID', $userid);
 $smarty->assign('viewtitle', get_string('usersprofile', 'mahara', display_name($user, null, true)));
 $smarty->assign('viewtype', 'profile');
 
+$smarty->assign('user', $user);
 if (get_config('viewmicroheaders')) {
     $smarty->assign('microheaders', true);
     $smarty->assign('microheadertitle', $view->display_title(true, false));
@@ -310,7 +280,10 @@ else {
     $smarty->assign('pageheadinghtml', $view->display_title(false));
 }
 
-$smarty->assign('viewcontent', $view->build_columns());
+if (!$restrictedview) {
+    $smarty->assign('viewcontent', $viewcontent);
+}
+
 $smarty->display('user/view.tpl');
 
 mahara_log('views', "$viewid"); // Log view visits
@@ -325,24 +298,18 @@ function invite_submit(Pieform $form, $values) {
 function addmember_submit(Pieform $form, $values) {
     global $USER, $SESSION, $userid;
 
-    $data = new StdClass;
-    $data->group  = $values['group'];
-    $data->member = $userid;
-    $data->ctime  = db_format_timestamp(time());
-    $data->role  = 'member'; // TODO: modify the dropdown to allow the role to be chosen
-    $ctitle = get_field('group', 'name', 'id', $data->group);
-    $adduser = get_record('usr', 'id', $data->member);
+    $ctitle = get_field('group', 'name', 'id', $values['group']);
+    $adduser = get_record('usr', 'id', $userid);
 
     try {
-        insert_record('group_member', $data);
-        delete_records('group_member_request', 'member', $userid, 'group', $data->group);
+        group_add_user($values['group'], $userid, 'member');
         $lang = get_user_language($userid);
         require_once(get_config('libroot') . 'activity.php');
         activity_occurred('maharamessage', array(
             'users'   => array($userid),
             'subject' => get_string_from_language($lang, 'addedtogroupsubject', 'group'),
             'message' => get_string_from_language($lang, 'addedtogroupmessage', 'group', display_name($USER, $adduser), $ctitle),
-            'url'     => get_config('wwwroot') . 'group/view.php?id=' . $values['group'],
+            'url'     => 'group/view.php?id=' . $values['group'],
             'urltext' => $ctitle,
         ));
         $SESSION->add_ok_msg(get_string('useradded', 'group'));
@@ -352,12 +319,3 @@ function addmember_submit(Pieform $form, $values) {
     }
     redirect('/user/view.php?id=' . $userid);
 }
-
-function approve_deny_friendrequest_submit(Pieform $form, $values) {
-    if (isset($values['deny'])) {
-        redirect('/user/denyrequest.php?id=' . $values['id'] . '&returnto=view');
-    }
-    else {
-        acceptfriend_submit($form, $values);
-    }
-}
