@@ -88,9 +88,9 @@ $form = array(
 // For institution views, force edit access of one view at a time for now.  Editing multiple
 // institution views requires doing some tricky stuff with the 'copy for new users/groups'
 // options, and there's not much room for the 'Share' tab in the admin area anyway
-if (!$institution) {
+if (!$institution && $view->get('type') != 'profile') {
     list($collections, $views) = View::get_views_and_collections(
-        $view->get('owner'), $group, $institution, $view->get('accessconf')
+        $view->get('owner'), $group, $institution, $view->get('accessconf'), false
     );
 }
 
@@ -125,17 +125,35 @@ if (!empty($views)) {
     );
 }
 
+if ($view->get('type') == 'profile') {
+    // Make sure all the user's institutions have access to profile view
+    $view->add_owner_institution_access();
+
+    if (get_config('loggedinprofileviewaccess')) {
+        // Force logged-in user access
+        $viewaccess = new stdClass;
+        $viewaccess->accesstype = 'loggedin';
+        $viewaccess->startdate = null;
+        $viewaccess->stopdate = null;
+        $viewaccess->allowcomments = 0;
+        $viewaccess->approvecomments = 1;
+        $view->add_access($viewaccess);
+    }
+}
+
 $allowcomments = $view->get('allowcomments');
 
 $form['elements']['accesslist'] = array(
     'type'          => 'viewacl',
     'allowcomments' => $allowcomments,
     'defaultvalue'  => $view->get_access(get_string('strftimedatetimeshort')),
+    'viewtype'      => $view->get('type'),
 );
 
 
 $form['elements']['more'] = array(
     'type' => 'fieldset',
+    'class' => $view->get('type') == 'profile' ? 'hidden' : '',
     'collapsible' => true,
     'collapsed' => true,
     'legend' => get_string('moreoptions', 'view'),
@@ -182,15 +200,10 @@ if ($institution) {
         $copyoptions = array('copynewuser', 'copyfornewgroups', 'copyfornewgroupsdescription');
         $needsaccess = array('copynewuser');
         $createfor = $view->get_autocreate_grouptypes();
-        foreach (group_get_grouptypes() as $grouptype) {
-            safe_require('grouptype', $grouptype);
-            $jointypestrings = array();
-            foreach (call_static_method('GroupType' . $grouptype, 'allowed_join_types', true) as $jointype) {
-                $jointypestrings[] = get_string('membershiptype.'.$jointype, 'group');
-            }
+        foreach (group_get_grouptype_options() as $grouptype => $grouptypedesc) {
             $form['elements']['more']['elements']['copyfornewgroups_'.$grouptype] = array(
                 'type'         => 'checkbox',
-                'title'        => get_string('name', 'grouptype.' . $grouptype) . ' (' . join(', ', $jointypestrings) . ')',
+                'title'        => $grouptypedesc,
                 'defaultvalue' => $view->get('template') && in_array($grouptype, $createfor),
             );
             $copyoptions[] = 'copyfornewgroups_'.$grouptype;
@@ -246,6 +259,28 @@ addLoadEvent(function() {
 });
 EOF;
 } else {
+    $form['elements']['more']['elements']['retainview'] = array(
+        'type'         => 'checkbox',
+        'title'        => get_string('retainviewrights1', 'view'),
+        'description'  => $group ? get_string('retainviewrightsgroupdescription', 'view') : get_string('retainviewrightsdescription', 'view'),
+        'defaultvalue' => $view->get('template') && $view->get('retainview'),
+    );
+    $js .= <<< EOF
+function update_retainview() {
+    if ($('editaccess_template').checked) {
+        removeElementClass($('editaccess_retainview_container'), 'hidden');
+    }
+    else {
+        addElementClass($('editaccess_retainview_container'), 'hidden');
+        $('editaccess_retainview').checked = false;
+        update_loggedin_access();
+    }
+};
+addLoadEvent(function() {
+    update_retainview();
+    connect('editaccess_template', 'onclick', update_retainview);
+});
+EOF;
     $js .= "function update_loggedin_access() {}\n";
 }
 
@@ -377,9 +412,23 @@ function editaccess_validate(Pieform $form, $values) {
             $form->set_error('copyfornewgroups', get_string('viewscopiedfornewgroupsmustbecopyable', 'view'));
         }
     }
+    $retainview = isset($values['retainview']) ? $values['retainview'] : false;
+    if ($retainview && !$values['template']) {
+        $form->set_error('retainview', get_string('viewswithretainviewrightsmustbecopyable', 'view'));
+    }
     if ($values['startdate'] && $values['stopdate'] && $values['startdate'] > $values['stopdate']) {
         $form->set_error('startdate', get_string('newstartdatemustbebeforestopdate', 'view', 'Overriding'));
     }
+
+    $accesstypestrings = array(
+        'public'      => get_string('public', 'view'),
+        'loggedin'    => get_string('loggedin', 'view'),
+        'friends'     => get_string('friends', 'view'),
+        'user'        => get_string('user', 'group'),
+        'group'       => get_string('group', 'group'),
+        'institution' => get_string('institution'),
+    );
+
     $loggedinaccess = false;
     if ($values['accesslist']) {
         $dateformat = get_string('strftimedatetimeshort');
@@ -388,7 +437,7 @@ function editaccess_validate(Pieform $form, $values) {
                 $item['startdate'] = null;
             }
             else if (!$item['startdate'] = strptime($item['startdate'], $dateformat)) {
-                $SESSION->add_error_msg(get_string('unrecogniseddateformat', 'view'));
+                $SESSION->add_error_msg(get_string('datetimeformatguide'));
                 $form->set_error('accesslist', '');
                 break;
             }
@@ -396,7 +445,7 @@ function editaccess_validate(Pieform $form, $values) {
                 $item['stopdate'] = null;
             }
             else if (!$item['stopdate'] = strptime($item['stopdate'], $dateformat)) {
-                $SESSION->add_error_msg(get_string('unrecogniseddateformat', 'view'));
+                $SESSION->add_error_msg(get_string('datetimeformatguide'));
                 $form->set_error('accesslist', '');
                 break;
             }
@@ -405,12 +454,12 @@ function editaccess_validate(Pieform $form, $values) {
             }
             $now = strptime(date('Y/m/d H:i'), $dateformat);
             if ($item['stopdate'] && ptimetotime($now) > ptimetotime($item['stopdate'])) {
-                $SESSION->add_error_msg(get_string('newstopdatecannotbeinpast', 'view', get_string($item['type'], 'view')));
+                $SESSION->add_error_msg(get_string('newstopdatecannotbeinpast', 'view', $accesstypestrings[$item['type']]));
                 $form->set_error('accesslist', '');
                 break;
             }
             if ($item['startdate'] && $item['stopdate'] && ptimetotime($item['startdate']) > ptimetotime($item['stopdate'])) {
-                $SESSION->add_error_msg(get_string('newstartdatemustbebeforestopdate', 'view', get_string($item['type'], 'view')));
+                $SESSION->add_error_msg(get_string('newstartdatemustbebeforestopdate', 'view', $accesstypestrings[$item['type']]));
                 $form->set_error('accesslist', '');
                 break;
             }
@@ -424,24 +473,26 @@ function editaccess_validate(Pieform $form, $values) {
     }
 }
 
-function editaccess_cancel_submit() {
-    global $institution, $group;
-    if (!empty($institution)) {
-        if ($institution == 'mahara') {
-            $redirecturl = '/admin/site/shareviews.php';
-        } else {
-            $redirecturl = '/view/institutionshare.php';
-        }
-    }
-    else if (!empty($group)) {
-        $redirecturl = '/group/shareviews.php?group=' . $group;
+if (!empty($institution)) {
+    if ($institution == 'mahara') {
+        $shareurl = 'admin/site/shareviews.php';
     }
     else {
-        $redirecturl = '/view/share.php';
+        $shareurl = 'view/institutionshare.php';
     }
-    redirect($redirecturl);
 }
+else if (!empty($group)) {
+    $shareurl = 'group/shareviews.php?group=' . $group;
+}
+else {
+    $shareurl = 'view/share.php';
+}
+$shareurl = get_config('wwwroot') . $shareurl;
 
+function editaccess_cancel_submit() {
+    global $shareurl;
+    redirect($shareurl);
+}
 
 function editaccess_submit(Pieform $form, $values) {
     global $SESSION, $institution, $collections, $views, $view;
@@ -462,6 +513,7 @@ function editaccess_submit(Pieform $form, $values) {
         'startdate'       => $values['startdate'],
         'stopdate'        => $values['stopdate'],
         'template'        => (int) $values['template'],
+        'retainview'      => isset($values['retainview']) ? (int) $values['retainview'] : 0,
         'allowcomments'   => (int) $values['allowcomments'],
         'approvecomments' => (int) ($values['allowcomments'] && $values['approvecomments']),
         'accesslist'      => $values['accesslist'],
@@ -494,16 +546,43 @@ function editaccess_submit(Pieform $form, $values) {
             }
         }
     
-        foreach ($values['views'] as $viewid) {
-            if (!isset($views[$viewid])) {
-                throw new UserException(get_string('editaccessinvalidviewset', 'view'));
+        if (isset($values['views'])) {
+            foreach ($values['views'] as $viewid) {
+                if (!isset($views[$viewid])) {
+                    throw new UserException(get_string('editaccessinvalidviewset', 'view'));
+                }
+                $toupdate[] = $viewid;
             }
-            $toupdate[] = $viewid;
+        }
+        else if ($view->get('type') == 'profile') {
+            // Force default Advanced options
+            $felements = $form->get_property('elements');
+            if (!empty($felements['more']['elements'])) {
+                foreach (array_keys($felements['more']['elements']) as $ename) {
+                    if (property_exists($view, $ename)) {
+                        $viewconfig[$ename] = $view->get($ename);
+                    }
+                }
+            }
+
+            $toupdate[] = $view->get('id');
         }
     }
 
     if (!empty($toupdate)) {
         View::update_view_access($viewconfig, $toupdate);
+
+        if ($view->get('type') == 'profile') {
+            // Ensure the user's institutions are still added to the access list
+            $view->add_owner_institution_access();
+
+            if (get_config('loggedinprofileviewaccess')) {
+                // Force logged-in user access
+                $viewaccess = new stdClass;
+                $viewaccess->accesstype = 'loggedin';
+                $view->add_access($viewaccess);
+            }
+        }
     }
 
     $SESSION->add_ok_msg(get_string('updatedaccessfornumviews', 'view', count($toupdate)));
@@ -517,7 +596,7 @@ function editaccess_submit(Pieform $form, $values) {
 $form = pieform($form);
 
 $smarty = smarty(
-    array('tablerenderer'),
+    array('tablerenderer', 'jquery'),
     array(),
     array(
         'mahara' => array('From', 'To', 'datetimeformatguide'),
@@ -528,4 +607,5 @@ $smarty = smarty(
 $smarty->assign('INLINEJAVASCRIPT', $js);
 $smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $form);
+$smarty->assign('shareurl', $shareurl);
 $smarty->display('view/access.tpl');
