@@ -175,6 +175,15 @@ if (!$view->is_public()) {
     $headers[] = '<meta name="robots" content="noindex">';  // Tell search engines not to index non-public views
 }
 
+// include slimbox2 js and css files, if it is enabled...
+if (get_config_plugin('blocktype', 'gallery', 'useslimbox2')) {
+    $langdir = (get_string('thisdirection', 'langconfig') == 'rtl' ? '-rtl' : '');
+    $headers = array_merge($headers, array(
+        '<script type="text/javascript" src="' . get_config('wwwroot') . 'lib/slimbox2/js/slimbox2.js"></script>',
+        '<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'lib/slimbox2/css/slimbox2' . $langdir . '.css">'
+    ));
+}
+
 $can_edit = $USER->can_edit_view($view) && !$submittedgroup && !$view->is_submitted();
 
 $smarty = smarty(
@@ -214,15 +223,18 @@ $smarty->assign('viewtype', $viewtype);
 $smarty->assign('feedback', $feedback);
 $smarty->assign('owner', $owner);
 $smarty->assign('tags', $view->get('tags'));
+$smarty->assign('author', $view->display_author());
 
 $smarty->assign('PAGEAUTHOR', $view->formatted_owner());
 
+$titletext = ($collection && $shownav) ? hsc($collection->get('name')) : $view->display_title(true, false, false);
+
 if (get_config('viewmicroheaders')) {
     $smarty->assign('microheaders', true);
-    $smarty->assign('microheadertitle', $collection ? hsc($collection->get('name')) : $view->display_title(true, false));
+
+    $smarty->assign('microheadertitle', $titletext);
 
     if ($can_edit) {
-        $smarty->assign('visitstring', $view->visit_message());
         if ($new) {
             $microheaderlinks = array(
                 array(
@@ -246,14 +258,14 @@ if (get_config('viewmicroheaders')) {
 
 }
 else if ($can_edit) {
+    $smarty->assign('visitstring', $view->visit_message());
     $smarty->assign('editurl', get_config('wwwroot') . 'view/blocks.php?id=' . $viewid . ($new ? '&new=1' : ''));
 }
 
 $title = hsc(TITLE);
 
 if (!get_config('viewmicroheaders')) {
-    $title = $collection ? hsc($collection->get('name')) : $view->display_title();
-    $smarty->assign('maintitle', $title);
+    $smarty->assign('maintitle', $titletext);
 }
 
 // Provide a link for roaming teachers to return
